/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

// This file is a Mako template: http://www.makotemplates.org/

// Please note that valid Rust syntax may be mangled by the Mako parser.
// For example, Vec&Foo> will be mangled as Vec&Foo>. To work around these issues, the code
// can be escaped. In the above example, Vec<&Foo> or Vec< &Foo> achieves the desired result of Vec&Foo>.



#[cfg(feature = "servo")]
use app_units::Au;
use custom_properties::CustomPropertiesBuilder;
use servo_arc::{Arc, UniqueArc};
use smallbitvec::SmallBitVec;
use std::borrow::Cow;
use std::{mem, ops};
use std::cell::RefCell;
use std::fmt::{self, Write};

#[cfg(feature = "servo")] use cssparser::RGBA;
use cssparser::{CowRcStr, Parser, TokenSerializationType, serialize_identifier};
use cssparser::ParserInput;
#[cfg(feature = "servo")] use euclid::SideOffsets2D;
use context::QuirksMode;
use font_metrics::FontMetricsProvider;
#[cfg(feature = "gecko")] use gecko_bindings::bindings;
#[cfg(feature = "gecko")] use gecko_bindings::structs::{self, nsCSSPropertyID};
#[cfg(feature = "servo")] use logical_geometry::LogicalMargin;
#[cfg(feature = "servo")] use computed_values;
use logical_geometry::WritingMode;
use media_queries::Device;
use parser::ParserContext;
#[cfg(feature = "gecko")] use properties::longhands::system_font::SystemFont;
use rule_cache::{RuleCache, RuleCacheConditions};
use selector_parser::PseudoElement;
use selectors::parser::SelectorParseErrorKind;
#[cfg(feature = "servo")] use servo_config::prefs::PREFS;
use shared_lock::StylesheetGuards;
use style_traits::{CssWriter, ParseError, ParsingMode, StyleParseErrorKind, ToCss};
use stylesheets::{CssRuleType, Origin, UrlExtraData};
#[cfg(feature = "servo")] use values::Either;
use values::generics::text::LineHeight;
use values::computed;
use values::computed::NonNegativeLength;
use rule_tree::{CascadeLevel, StrongRuleNode};
use self::computed_value_flags::*;
use str::{CssString, CssStringBorrow, CssStringWriter};
use style_adjuster::StyleAdjuster;

pub use self::declaration_block::*;

#[cfg(feature = "gecko")]
#[macro_export]
macro_rules! property_name {
    ($s: tt) => { atom!($s) }
}



#[path="/builddir/build/BUILD/mozilla-release-239e434d6d2b8e1e2b697c3416d1e96d48fe98e5/servo/components/style/properties/computed_value_flags.rs"]
pub mod computed_value_flags;
#[path="/builddir/build/BUILD/mozilla-release-239e434d6d2b8e1e2b697c3416d1e96d48fe98e5/servo/components/style/properties/declaration_block.rs"]
pub mod declaration_block;

/// Conversion with fewer impls than From/Into
pub trait MaybeBoxed<Out> {
    /// Convert
    fn maybe_boxed(self) -> Out;
}

impl<T> MaybeBoxed<T> for T {
    #[inline]
    fn maybe_boxed(self) -> T { self }
}

impl<T> MaybeBoxed<Box<T>> for T {
    #[inline]
    fn maybe_boxed(self) -> Box<T> { Box::new(self) }
}

macro_rules! expanded {
    ( $( $name: ident: $value: expr ),+ ) => {
        expanded!( $( $name: $value, )+ )
    };
    ( $( $name: ident: $value: expr, )+ ) => {
        Longhands {
            $(
                $name: MaybeBoxed::maybe_boxed($value),
            )+
        }
    }
}

/// A module with all the code for longhand properties.
#[allow(missing_docs)]
pub mod longhands {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#background-color
    pub mod background_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::transparent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::transparent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_background_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundColor)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod background_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-image.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-image");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-image.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-image");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundImage);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundImage);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_image(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_image();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundImage)
        }
    }




    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-x
    pub mod background_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::HorizontalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-x.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-position-x");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-position-x.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-position-x");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundPositionX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundPositionX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundPositionX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_position_x(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_position_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_position_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-y
    pub mod background_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::VerticalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-y.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-position-y");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-position-y.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-position-y");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundPositionY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundPositionY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundPositionY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_position_y(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_position_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_position_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionY)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-repeat
    pub mod background_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundRepeat::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-repeat.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-repeat");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-repeat.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-repeat");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundRepeat);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_repeat(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundRepeat)
        }
    }





    
    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-attachment
    pub mod background_attachment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "scroll" => Scroll,
                    "fixed" => Fixed,
                    "local" => Local,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Scroll
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Scroll
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Scroll => computed_value::T::Scroll,
                        SpecifiedValue::Fixed => computed_value::T::Fixed,
                        SpecifiedValue::Local => computed_value::T::Local,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Scroll => SpecifiedValue::Scroll,
                        computed_value::T::Fixed => SpecifiedValue::Fixed,
                        computed_value::T::Local => SpecifiedValue::Local,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for background-attachment.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-attachment");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-attachment.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-attachment");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundAttachment(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundAttachment);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundAttachment);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_attachment(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_attachment();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_attachment();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundAttachment)
        }
    }






    
    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-clip
    pub mod background_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "border-box" => BorderBox,
                    "padding-box" => PaddingBox,
                    "content-box" => ContentBox,
                    "text" => Text,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                        SpecifiedValue::PaddingBox => computed_value::T::PaddingBox,
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                        SpecifiedValue::Text => computed_value::T::Text,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                        computed_value::T::PaddingBox => SpecifiedValue::PaddingBox,
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                        computed_value::T::Text => SpecifiedValue::Text,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for background-clip.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-clip");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-clip.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-clip");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundClip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundClip);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundClip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_clip(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundClip)
        }
    }






    
    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-origin
    pub mod background_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "padding-box" => PaddingBox,
                    "border-box" => BorderBox,
                    "content-box" => ContentBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::PaddingBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::PaddingBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::PaddingBox => computed_value::T::PaddingBox,
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::PaddingBox => SpecifiedValue::PaddingBox,
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for background-origin.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-origin");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-origin.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-origin");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundOrigin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_origin(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundOrigin)
        }
    }






    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-size
    pub mod background_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundSize::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundSize::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundSize::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-size.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-size");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-size.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-size");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_size(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundSize)
        }
    }




// https://drafts.fxtf.org/compositing/#background-blend-mode

    
    

    
        
    
    
    /// https://drafts.fxtf.org/compositing/#background-blend-mode
    pub mod background_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "multiply" => Multiply,
                    "screen" => Screen,
                    "overlay" => Overlay,
                    "darken" => Darken,
                    "lighten" => Lighten,
                    "color-dodge" => ColorDodge,
                    "color-burn" => ColorBurn,
                    "hard-light" => HardLight,
                    "soft-light" => SoftLight,
                    "difference" => Difference,
                    "exclusion" => Exclusion,
                    "hue" => Hue,
                    "saturation" => Saturation,
                    "color" => Color,
                    "luminosity" => Luminosity,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Multiply => computed_value::T::Multiply,
                        SpecifiedValue::Screen => computed_value::T::Screen,
                        SpecifiedValue::Overlay => computed_value::T::Overlay,
                        SpecifiedValue::Darken => computed_value::T::Darken,
                        SpecifiedValue::Lighten => computed_value::T::Lighten,
                        SpecifiedValue::ColorDodge => computed_value::T::ColorDodge,
                        SpecifiedValue::ColorBurn => computed_value::T::ColorBurn,
                        SpecifiedValue::HardLight => computed_value::T::HardLight,
                        SpecifiedValue::SoftLight => computed_value::T::SoftLight,
                        SpecifiedValue::Difference => computed_value::T::Difference,
                        SpecifiedValue::Exclusion => computed_value::T::Exclusion,
                        SpecifiedValue::Hue => computed_value::T::Hue,
                        SpecifiedValue::Saturation => computed_value::T::Saturation,
                        SpecifiedValue::Color => computed_value::T::Color,
                        SpecifiedValue::Luminosity => computed_value::T::Luminosity,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Multiply => SpecifiedValue::Multiply,
                        computed_value::T::Screen => SpecifiedValue::Screen,
                        computed_value::T::Overlay => SpecifiedValue::Overlay,
                        computed_value::T::Darken => SpecifiedValue::Darken,
                        computed_value::T::Lighten => SpecifiedValue::Lighten,
                        computed_value::T::ColorDodge => SpecifiedValue::ColorDodge,
                        computed_value::T::ColorBurn => SpecifiedValue::ColorBurn,
                        computed_value::T::HardLight => SpecifiedValue::HardLight,
                        computed_value::T::SoftLight => SpecifiedValue::SoftLight,
                        computed_value::T::Difference => SpecifiedValue::Difference,
                        computed_value::T::Exclusion => SpecifiedValue::Exclusion,
                        computed_value::T::Hue => SpecifiedValue::Hue,
                        computed_value::T::Saturation => SpecifiedValue::Saturation,
                        computed_value::T::Color => SpecifiedValue::Color,
                        computed_value::T::Luminosity => SpecifiedValue::Luminosity,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for background-blend-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-blend-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of background-blend-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property background-blend-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackgroundBlendMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackgroundBlendMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackgroundBlendMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_background();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_background_blend_mode(iter);
                        }
                        context.builder.put_background(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_background_blend_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_background_blend_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundBlendMode)
        }
    }





    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-color
    pub mod border_top_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderTopColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-style
    pub mod border_top_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderTopStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-width
    pub mod border_top_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderTopWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_top_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-color
    pub mod border_left_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderLeftColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-style
    pub mod border_left_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderLeftStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-width
    pub mod border_left_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderLeftWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderLeftWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderLeftWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_left_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_left_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_left_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-color
    pub mod border_bottom_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBottomColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-style
    pub mod border_bottom_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBottomStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-width
    pub mod border_bottom_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBottomWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_bottom_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-color
    pub mod border_right_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderRightColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-style
    pub mod border_right_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderRightStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-width
    pub mod border_right_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderRightWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderRightWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderRightWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_right_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_right_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_right_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-color
    pub mod border_block_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockStartColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-style
    pub mod border_block_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockStartStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-width
    pub mod border_block_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockStartWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockStartWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_start_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_start_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_start_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-color
    pub mod border_block_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockEndColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-style
    pub mod border_block_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockEndStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-width
    pub mod border_block_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBlockEndWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBlockEndWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_block_end_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_block_end_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_block_end_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-color
    pub mod border_inline_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineStartColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-style
    pub mod border_inline_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineStartStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-width
    pub mod border_inline_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineStartWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineStartWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_start_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_start_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_start_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-color
    pub mod border_inline_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineEndColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-style
    pub mod border_inline_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineEndStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-width
    pub mod border_inline_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderInlineEndWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderInlineEndWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_inline_end_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_inline_end_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_inline_end_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndWidth)
        }
    }




    
    #[cfg(feature = "gecko")]
    impl ::values::specified::BorderStyle {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::NS_STYLE_BORDER_STYLE_NONE as u32;
                // We can't match on enum values if we're matching on a u32
                const SOLID: u32
                    = structs::NS_STYLE_BORDER_STYLE_SOLID as u32;
                // We can't match on enum values if we're matching on a u32
                const DOUBLE: u32
                    = structs::NS_STYLE_BORDER_STYLE_DOUBLE as u32;
                // We can't match on enum values if we're matching on a u32
                const DOTTED: u32
                    = structs::NS_STYLE_BORDER_STYLE_DOTTED as u32;
                // We can't match on enum values if we're matching on a u32
                const DASHED: u32
                    = structs::NS_STYLE_BORDER_STYLE_DASHED as u32;
                // We can't match on enum values if we're matching on a u32
                const HIDDEN: u32
                    = structs::NS_STYLE_BORDER_STYLE_HIDDEN as u32;
                // We can't match on enum values if we're matching on a u32
                const GROOVE: u32
                    = structs::NS_STYLE_BORDER_STYLE_GROOVE as u32;
                // We can't match on enum values if we're matching on a u32
                const RIDGE: u32
                    = structs::NS_STYLE_BORDER_STYLE_RIDGE as u32;
                // We can't match on enum values if we're matching on a u32
                const INSET: u32
                    = structs::NS_STYLE_BORDER_STYLE_INSET as u32;
                // We can't match on enum values if we're matching on a u32
                const OUTSET: u32
                    = structs::NS_STYLE_BORDER_STYLE_OUTSET as u32;
            match kw  {
                    NONE => ::values::specified::BorderStyle::None,
                    SOLID => ::values::specified::BorderStyle::Solid,
                    DOUBLE => ::values::specified::BorderStyle::Double,
                    DOTTED => ::values::specified::BorderStyle::Dotted,
                    DASHED => ::values::specified::BorderStyle::Dashed,
                    HIDDEN => ::values::specified::BorderStyle::Hidden,
                    GROOVE => ::values::specified::BorderStyle::Groove,
                    RIDGE => ::values::specified::BorderStyle::Ridge,
                    INSET => ::values::specified::BorderStyle::Inset,
                    OUTSET => ::values::specified::BorderStyle::Outset,
                _ => panic!("Found unexpected value in style struct for border-style property"),
            }
        }
    }


// FIXME(#4126): when gfx supports painting it, make this Size2D<LengthOrPercentage>
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-left-radius
    pub mod border_top_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderTopLeftRadius);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopLeftRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_top_left_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_left_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_left_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopLeftRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-right-radius
    pub mod border_top_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderTopRightRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderTopRightRadius);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderTopRightRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_top_right_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_top_right_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_top_right_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopRightRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-right-radius
    pub mod border_bottom_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBottomRightRadius);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomRightRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_bottom_right_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_right_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_right_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomRightRadius)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-left-radius
    pub mod border_bottom_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderBottomLeftRadius);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderBottomLeftRadius);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_bottom_left_radius(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_bottom_left_radius();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_bottom_left_radius();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomLeftRadius)
        }
    }



/// -moz-border-*-colors: color, string, enum, none, inherit/initial
/// These non-spec properties are just for Gecko (Stylo) internal use.
    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-border-*-colors)
    pub mod _moz_border_top_colors {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        use values::specified::RGBAColor;

        pub mod computed_value {
            use cssparser::RGBA;
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(pub Option<Vec<RGBA>>);
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub enum SpecifiedValue {
            None,
            Colors(Vec<RGBAColor>),
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.0 {
                    None => return dest.write_str("none"),
                    Some(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match *self {
                    SpecifiedValue::None => return dest.write_str("none"),
                    SpecifiedValue::Colors(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        #[inline] pub fn get_initial_value() -> computed_value::T {
            computed_value::T(None)
        }

        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                match *self {
                    SpecifiedValue::Colors(ref vec) => {
                        computed_value::T(Some(vec.iter()
                                                  .map(|c| c.to_computed_value(context))
                                                  .collect()))
                    },
                    SpecifiedValue::None => {
                        computed_value::T(None)
                    }
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                    computed_value::T(Some(ref vec)) => {
                        SpecifiedValue::Colors(vec.iter()
                                                  .map(ToComputedValue::from_computed_value)
                                                  .collect())
                    },
                    computed_value::T(None) => {
                        SpecifiedValue::None
                    }
                }
            }
        }

        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue::None)
            }

            let mut result = Vec::new();
            while let Ok(value) = input.try(|i| RGBAColor::parse(context, i)) {
                result.push(value);
            }

            if !result.is_empty() {
                Ok(SpecifiedValue::Colors(result))
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBorderTopColors(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBorderTopColors);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBorderTopColors);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_border_top_colors(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_border_top_colors();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_border_top_colors();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBorderTopColors)
        }
    }

    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-border-*-colors)
    pub mod _moz_border_left_colors {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        use values::specified::RGBAColor;

        pub mod computed_value {
            use cssparser::RGBA;
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(pub Option<Vec<RGBA>>);
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub enum SpecifiedValue {
            None,
            Colors(Vec<RGBAColor>),
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.0 {
                    None => return dest.write_str("none"),
                    Some(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match *self {
                    SpecifiedValue::None => return dest.write_str("none"),
                    SpecifiedValue::Colors(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        #[inline] pub fn get_initial_value() -> computed_value::T {
            computed_value::T(None)
        }

        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                match *self {
                    SpecifiedValue::Colors(ref vec) => {
                        computed_value::T(Some(vec.iter()
                                                  .map(|c| c.to_computed_value(context))
                                                  .collect()))
                    },
                    SpecifiedValue::None => {
                        computed_value::T(None)
                    }
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                    computed_value::T(Some(ref vec)) => {
                        SpecifiedValue::Colors(vec.iter()
                                                  .map(ToComputedValue::from_computed_value)
                                                  .collect())
                    },
                    computed_value::T(None) => {
                        SpecifiedValue::None
                    }
                }
            }
        }

        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue::None)
            }

            let mut result = Vec::new();
            while let Ok(value) = input.try(|i| RGBAColor::parse(context, i)) {
                result.push(value);
            }

            if !result.is_empty() {
                Ok(SpecifiedValue::Colors(result))
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBorderLeftColors(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBorderLeftColors);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBorderLeftColors);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_border_left_colors(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_border_left_colors();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_border_left_colors();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBorderLeftColors)
        }
    }

    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-border-*-colors)
    pub mod _moz_border_bottom_colors {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        use values::specified::RGBAColor;

        pub mod computed_value {
            use cssparser::RGBA;
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(pub Option<Vec<RGBA>>);
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub enum SpecifiedValue {
            None,
            Colors(Vec<RGBAColor>),
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.0 {
                    None => return dest.write_str("none"),
                    Some(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match *self {
                    SpecifiedValue::None => return dest.write_str("none"),
                    SpecifiedValue::Colors(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        #[inline] pub fn get_initial_value() -> computed_value::T {
            computed_value::T(None)
        }

        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                match *self {
                    SpecifiedValue::Colors(ref vec) => {
                        computed_value::T(Some(vec.iter()
                                                  .map(|c| c.to_computed_value(context))
                                                  .collect()))
                    },
                    SpecifiedValue::None => {
                        computed_value::T(None)
                    }
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                    computed_value::T(Some(ref vec)) => {
                        SpecifiedValue::Colors(vec.iter()
                                                  .map(ToComputedValue::from_computed_value)
                                                  .collect())
                    },
                    computed_value::T(None) => {
                        SpecifiedValue::None
                    }
                }
            }
        }

        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue::None)
            }

            let mut result = Vec::new();
            while let Ok(value) = input.try(|i| RGBAColor::parse(context, i)) {
                result.push(value);
            }

            if !result.is_empty() {
                Ok(SpecifiedValue::Colors(result))
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBorderBottomColors(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBorderBottomColors);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBorderBottomColors);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_border_bottom_colors(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_border_bottom_colors();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_border_bottom_colors();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBorderBottomColors)
        }
    }

    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-border-*-colors)
    pub mod _moz_border_right_colors {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        use values::specified::RGBAColor;

        pub mod computed_value {
            use cssparser::RGBA;
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(pub Option<Vec<RGBA>>);
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub enum SpecifiedValue {
            None,
            Colors(Vec<RGBAColor>),
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.0 {
                    None => return dest.write_str("none"),
                    Some(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match *self {
                    SpecifiedValue::None => return dest.write_str("none"),
                    SpecifiedValue::Colors(ref vec) => {
                        let mut first = true;
                        for ref color in vec {
                            if !first {
                                dest.write_str(" ")?;
                            }
                            first = false;
                            color.to_css(dest)?
                        }
                        Ok(())
                    }
                }
            }
        }

        #[inline] pub fn get_initial_value() -> computed_value::T {
            computed_value::T(None)
        }

        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                match *self {
                    SpecifiedValue::Colors(ref vec) => {
                        computed_value::T(Some(vec.iter()
                                                  .map(|c| c.to_computed_value(context))
                                                  .collect()))
                    },
                    SpecifiedValue::None => {
                        computed_value::T(None)
                    }
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                    computed_value::T(Some(ref vec)) => {
                        SpecifiedValue::Colors(vec.iter()
                                                  .map(ToComputedValue::from_computed_value)
                                                  .collect())
                    },
                    computed_value::T(None) => {
                        SpecifiedValue::None
                    }
                }
            }
        }

        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue::None)
            }

            let mut result = Vec::new();
            while let Ok(value) = input.try(|i| RGBAColor::parse(context, i)) {
                result.push(value);
            }

            if !result.is_empty() {
                Ok(SpecifiedValue::Colors(result))
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBorderRightColors(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBorderRightColors);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBorderRightColors);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_border_right_colors(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_border_right_colors();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_border_right_colors();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBorderRightColors)
        }
    }



    
    

    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-box-decoration-break
    pub mod box_decoration_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "slice" => Slice,
                    "clone" => Clone,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Slice
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Slice
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Slice => computed_value::T::Slice,
                        SpecifiedValue::Clone => computed_value::T::Clone,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Slice => SpecifiedValue::Slice,
                        computed_value::T::Clone => SpecifiedValue::Clone,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxDecorationBreak(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BoxDecorationBreak);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxDecorationBreak);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_box_decoration_break(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_decoration_break();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_decoration_break();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxDecorationBreak)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-float-edge)
    pub mod _moz_float_edge {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "content-box" => ContentBox,
                    "margin-box" => MarginBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                        SpecifiedValue::MarginBox => computed_value::T::MarginBox,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                        computed_value::T::MarginBox => SpecifiedValue::MarginBox,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozFloatEdge(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozFloatEdge);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozFloatEdge);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_float_edge(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_float_edge();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_float_edge();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozFloatEdge)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod border_image_source {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageSource(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderImageSource);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageSource);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_source(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_source();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_source();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageSource)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-outset
    pub mod border_image_outset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrNumberRect as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrNumberRect as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrNumberRect::all(computed::LengthOrNumber::zero()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::LengthOrNumberRect::all(specified::LengthOrNumber::zero()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrNumberRect::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageOutset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderImageOutset);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageOutset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_outset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_outset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_outset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageOutset)
        }
    }




    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-repeat
    pub mod border_image_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    pub mod computed_value {
        pub use super::RepeatKeyword;

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct T(pub RepeatKeyword, pub RepeatKeyword);
    }

    #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
    pub struct SpecifiedValue(pub RepeatKeyword,
                              pub Option<RepeatKeyword>);

    define_css_keyword_enum!(RepeatKeyword:
                             "stretch" => Stretch,
                             "repeat" => Repeat,
                             "round" => Round,
                             "space" => Space);

    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        computed_value::T(RepeatKeyword::Stretch, RepeatKeyword::Stretch)
    }

    #[inline]
    pub fn get_initial_specified_value() -> SpecifiedValue {
        SpecifiedValue(RepeatKeyword::Stretch, None)
    }

    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, _context: &Context) -> computed_value::T {
            computed_value::T(self.0, self.1.unwrap_or(self.0))
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> Self {
            SpecifiedValue(computed.0, Some(computed.1))
        }
    }

    pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
        let first = RepeatKeyword::parse(input)?;
        let second = input.try(RepeatKeyword::parse).ok();

        Ok(SpecifiedValue(first, second))
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderImageRepeat);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_image_repeat(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderImageRepeat)
        }
    }



    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-width
    pub mod border_image_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderImageWidth as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderImageWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageWidth::all(computed::BorderImageSideWidth::one()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageWidth::all(specified::BorderImageSideWidth::one()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderImageWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderImageWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-slice
    pub mod border_image_slice {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderImageSlice as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderImageSlice as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NumberOrPercentage::Percentage(computed::Percentage(1.)).into() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::NumberOrPercentage::Percentage(specified::Percentage::new(1.)).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderImageSlice::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderImageSlice(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderImageSlice);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BorderImageSlice);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_image_slice(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_image_slice();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_border_image_slice();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageSlice)
        }
    }



#[cfg(feature = "gecko")]
impl ::values::computed::BorderImageWidth {
    pub fn to_gecko_rect(&self, sides: &mut ::gecko_bindings::structs::nsStyleSides) {
        use gecko_bindings::sugar::ns_style_coord::{CoordDataMut, CoordDataValue};
        use gecko::values::GeckoStyleCoordConvertible;
        use values::generics::border::BorderImageSideWidth;

        match self.0 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(0).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(0))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(0).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.1 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(1).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(1))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(1).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.2 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(2).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(2))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(2).set_value(CoordDataValue::Factor(n))
            },
        }
        match self.3 {
            BorderImageSideWidth::Auto => {
                sides.data_at_mut(3).set_value(CoordDataValue::Auto)
            },
            BorderImageSideWidth::Length(l) => {
                l.to_gecko_style_coord(&mut sides.data_at_mut(3))
            },
            BorderImageSideWidth::Number(n) => {
                sides.data_at_mut(3).set_value(CoordDataValue::Factor(n))
            },
        }
    }

    pub fn from_gecko_rect(sides: &::gecko_bindings::structs::nsStyleSides)
                           -> Option<::values::computed::BorderImageWidth> {
        use gecko_bindings::structs::nsStyleUnit::{eStyleUnit_Factor, eStyleUnit_Auto};
        use gecko_bindings::sugar::ns_style_coord::CoordData;
        use gecko::values::GeckoStyleCoordConvertible;
        use values::computed::{LengthOrPercentage, Number};
        use values::generics::border::BorderImageSideWidth;

        Some(
            ::values::computed::BorderImageWidth::new(
                match sides.data_at(0).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(0))
                                .expect("sides[0] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(0))
                                .expect("sides[0] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(1).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(1))
                                .expect("sides[1] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(1))
                                .expect("sides[1] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(2).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(2))
                                .expect("sides[2] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(2))
                                .expect("sides[2] could not convert to LengthOrPercentager"))
                    },
                },
                match sides.data_at(3).unit() {
                    eStyleUnit_Auto => {
                        BorderImageSideWidth::Auto
                    },
                    eStyleUnit_Factor => {
                        BorderImageSideWidth::Number(
                            Number::from_gecko_style_coord(&sides.data_at(3))
                                .expect("sides[3] could not convert to Number"))
                    },
                    _ => {
                        BorderImageSideWidth::Length(
                            LengthOrPercentage::from_gecko_style_coord(&sides.data_at(3))
                                .expect("sides[3] could not convert to LengthOrPercentager"))
                    },
                },
            )
        )
    }
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






// TODO(SimonSapin): don't parse `inline-table`, since we don't support it
//
// We allow "display" to apply to placeholders because we need to make the
// placeholder pseudo-element an inline-block in the UA stylesheet in Gecko.

    
        
    
    /// https://drafts.csswg.org/css-display/#propdef-display
    pub mod display {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Display as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Display as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Display::inline() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Display::inline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Display::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Display(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Display);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Display);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_display(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_display();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_display();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Display)
        }
    }



// FIXME(emilio): Listing all the display values here is very unfortunate, we should teach C++ to use the
// Rust enum directly, or generate the conversions to `StyleDisplay`.

    
    #[cfg(feature = "gecko")]
    impl ::values::specified::Display {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const INLINE: u32
                    = structs::StyleDisplay::Inline as u32;
                // We can't match on enum values if we're matching on a u32
                const BLOCK: u32
                    = structs::StyleDisplay::Block as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_BLOCK: u32
                    = structs::StyleDisplay::InlineBlock as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE: u32
                    = structs::StyleDisplay::Table as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_TABLE: u32
                    = structs::StyleDisplay::InlineTable as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_ROW_GROUP: u32
                    = structs::StyleDisplay::TableRowGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_HEADER_GROUP: u32
                    = structs::StyleDisplay::TableHeaderGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_FOOTER_GROUP: u32
                    = structs::StyleDisplay::TableFooterGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_ROW: u32
                    = structs::StyleDisplay::TableRow as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_COLUMN_GROUP: u32
                    = structs::StyleDisplay::TableColumnGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_COLUMN: u32
                    = structs::StyleDisplay::TableColumn as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_CELL: u32
                    = structs::StyleDisplay::TableCell as u32;
                // We can't match on enum values if we're matching on a u32
                const TABLE_CAPTION: u32
                    = structs::StyleDisplay::TableCaption as u32;
                // We can't match on enum values if we're matching on a u32
                const LIST_ITEM: u32
                    = structs::StyleDisplay::ListItem as u32;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleDisplay::None as u32;
                // We can't match on enum values if we're matching on a u32
                const FLEX: u32
                    = structs::StyleDisplay::Flex as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_FLEX: u32
                    = structs::StyleDisplay::InlineFlex as u32;
                // We can't match on enum values if we're matching on a u32
                const GRID: u32
                    = structs::StyleDisplay::Grid as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_GRID: u32
                    = structs::StyleDisplay::InlineGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY: u32
                    = structs::StyleDisplay::Ruby as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_BASE: u32
                    = structs::StyleDisplay::RubyBase as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_BASE_CONTAINER: u32
                    = structs::StyleDisplay::RubyBaseContainer as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_TEXT: u32
                    = structs::StyleDisplay::RubyText as u32;
                // We can't match on enum values if we're matching on a u32
                const RUBY_TEXT_CONTAINER: u32
                    = structs::StyleDisplay::RubyTextContainer as u32;
                // We can't match on enum values if we're matching on a u32
                const CONTENTS: u32
                    = structs::StyleDisplay::Contents as u32;
                // We can't match on enum values if we're matching on a u32
                const FLOW_ROOT: u32
                    = structs::StyleDisplay::FlowRoot as u32;
                // We can't match on enum values if we're matching on a u32
                const _WEBKIT_BOX: u32
                    = structs::StyleDisplay::WebkitBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _WEBKIT_INLINE_BOX: u32
                    = structs::StyleDisplay::WebkitInlineBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_BOX: u32
                    = structs::StyleDisplay::MozBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_BOX: u32
                    = structs::StyleDisplay::MozInlineBox as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID: u32
                    = structs::StyleDisplay::MozGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_GRID: u32
                    = structs::StyleDisplay::MozInlineGrid as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID_GROUP: u32
                    = structs::StyleDisplay::MozGridGroup as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GRID_LINE: u32
                    = structs::StyleDisplay::MozGridLine as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_STACK: u32
                    = structs::StyleDisplay::MozStack as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_INLINE_STACK: u32
                    = structs::StyleDisplay::MozInlineStack as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_DECK: u32
                    = structs::StyleDisplay::MozDeck as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_POPUP: u32
                    = structs::StyleDisplay::MozPopup as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_GROUPBOX: u32
                    = structs::StyleDisplay::MozGroupbox as u32;
            match kw  {
                    INLINE => ::values::specified::Display::Inline,
                    BLOCK => ::values::specified::Display::Block,
                    INLINE_BLOCK => ::values::specified::Display::InlineBlock,
                    TABLE => ::values::specified::Display::Table,
                    INLINE_TABLE => ::values::specified::Display::InlineTable,
                    TABLE_ROW_GROUP => ::values::specified::Display::TableRowGroup,
                    TABLE_HEADER_GROUP => ::values::specified::Display::TableHeaderGroup,
                    TABLE_FOOTER_GROUP => ::values::specified::Display::TableFooterGroup,
                    TABLE_ROW => ::values::specified::Display::TableRow,
                    TABLE_COLUMN_GROUP => ::values::specified::Display::TableColumnGroup,
                    TABLE_COLUMN => ::values::specified::Display::TableColumn,
                    TABLE_CELL => ::values::specified::Display::TableCell,
                    TABLE_CAPTION => ::values::specified::Display::TableCaption,
                    LIST_ITEM => ::values::specified::Display::ListItem,
                    NONE => ::values::specified::Display::None,
                    FLEX => ::values::specified::Display::Flex,
                    INLINE_FLEX => ::values::specified::Display::InlineFlex,
                    GRID => ::values::specified::Display::Grid,
                    INLINE_GRID => ::values::specified::Display::InlineGrid,
                    RUBY => ::values::specified::Display::Ruby,
                    RUBY_BASE => ::values::specified::Display::RubyBase,
                    RUBY_BASE_CONTAINER => ::values::specified::Display::RubyBaseContainer,
                    RUBY_TEXT => ::values::specified::Display::RubyText,
                    RUBY_TEXT_CONTAINER => ::values::specified::Display::RubyTextContainer,
                    CONTENTS => ::values::specified::Display::Contents,
                    FLOW_ROOT => ::values::specified::Display::FlowRoot,
                    _WEBKIT_BOX => ::values::specified::Display::WebkitBox,
                    _WEBKIT_INLINE_BOX => ::values::specified::Display::WebkitInlineBox,
                    _MOZ_BOX => ::values::specified::Display::MozBox,
                    _MOZ_INLINE_BOX => ::values::specified::Display::MozInlineBox,
                    _MOZ_GRID => ::values::specified::Display::MozGrid,
                    _MOZ_INLINE_GRID => ::values::specified::Display::MozInlineGrid,
                    _MOZ_GRID_GROUP => ::values::specified::Display::MozGridGroup,
                    _MOZ_GRID_LINE => ::values::specified::Display::MozGridLine,
                    _MOZ_STACK => ::values::specified::Display::MozStack,
                    _MOZ_INLINE_STACK => ::values::specified::Display::MozInlineStack,
                    _MOZ_DECK => ::values::specified::Display::MozDeck,
                    _MOZ_POPUP => ::values::specified::Display::MozPopup,
                    _MOZ_GROUPBOX => ::values::specified::Display::MozGroupbox,
                _ => panic!("Found unexpected value in style struct for display property"),
            }
        }
    }



    
    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_top_layer {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "top" => Top,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Top => computed_value::T::Top,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Top => SpecifiedValue::Top,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTopLayer(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozTopLayer);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozTopLayer);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_top_layer(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_top_layer();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_top_layer();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTopLayer)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-position/#position-property
    pub mod position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "static" => Static,
                    "absolute" => Absolute,
                    "relative" => Relative,
                    "fixed" => Fixed,
                    "sticky" => Sticky,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Static
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Static
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Static => computed_value::T::Static,
                        SpecifiedValue::Absolute => computed_value::T::Absolute,
                        SpecifiedValue::Relative => computed_value::T::Relative,
                        SpecifiedValue::Fixed => computed_value::T::Fixed,
                        SpecifiedValue::Sticky => computed_value::T::Sticky,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Static => SpecifiedValue::Static,
                        computed_value::T::Absolute => SpecifiedValue::Absolute,
                        computed_value::T::Relative => SpecifiedValue::Relative,
                        computed_value::T::Fixed => SpecifiedValue::Fixed,
                        computed_value::T::Sticky => SpecifiedValue::Sticky,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Position(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Position);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Position);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_position();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Position)
        }
    }





    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-float
    pub mod float {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "none" => None,
                        "left" => Left,
                        "right" => Right,
                        "inline-start" => InlineStart,
                        "inline-end" => InlineEnd,
                }
                aliases {
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "left" => Left,
                    "right" => Right,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleFloat::None as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::StyleFloat::Left as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::StyleFloat::Right as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_START: u32
                    = structs::StyleFloat::InlineStart as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_END: u32
                    = structs::StyleFloat::InlineEnd as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    LEFT => SpecifiedValue::Left,
                    RIGHT => SpecifiedValue::Right,
                    INLINE_START => SpecifiedValue::InlineStart,
                    INLINE_END => SpecifiedValue::InlineEnd,
                _ => panic!("Found unexpected value in style struct for float property"),
            }
        }
    }

    
            
    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, context: &Context) -> computed_value::T {
            let ltr = context.style().writing_mode.is_bidi_ltr();
            // https://drafts.csswg.org/css-logical-props/#float-clear
            match *self {
                SpecifiedValue::InlineStart => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Left
                    } else {
                        computed_value::T::Right
                    }
                }
                SpecifiedValue::InlineEnd => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Right
                    } else {
                        computed_value::T::Left
                    }
                }
                    SpecifiedValue::None => computed_value::T::None,
                    SpecifiedValue::Left => computed_value::T::Left,
                    SpecifiedValue::Right => computed_value::T::Right,
            }
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                    computed_value::T::None => SpecifiedValue::None,
                    computed_value::T::Left => SpecifiedValue::Left,
                    computed_value::T::Right => SpecifiedValue::Right,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Float(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Float);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Float);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_float(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_float();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_float();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Float)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#flow-control
    pub mod clear {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "none" => None,
                        "left" => Left,
                        "right" => Right,
                        "both" => Both,
                        "inline-start" => InlineStart,
                        "inline-end" => InlineEnd,
                }
                aliases {
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "left" => Left,
                    "right" => Right,
                    "both" => Both,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleClear::None as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::StyleClear::Left as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::StyleClear::Right as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTH: u32
                    = structs::StyleClear::Both as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_START: u32
                    = structs::StyleClear::InlineStart as u32;
                // We can't match on enum values if we're matching on a u32
                const INLINE_END: u32
                    = structs::StyleClear::InlineEnd as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    LEFT => SpecifiedValue::Left,
                    RIGHT => SpecifiedValue::Right,
                    BOTH => SpecifiedValue::Both,
                    INLINE_START => SpecifiedValue::InlineStart,
                    INLINE_END => SpecifiedValue::InlineEnd,
                _ => panic!("Found unexpected value in style struct for clear property"),
            }
        }
    }

    
            
    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, context: &Context) -> computed_value::T {
            let ltr = context.style().writing_mode.is_bidi_ltr();
            // https://drafts.csswg.org/css-logical-props/#float-clear
            match *self {
                SpecifiedValue::InlineStart => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Left
                    } else {
                        computed_value::T::Right
                    }
                }
                SpecifiedValue::InlineEnd => {
                    context.rule_cache_conditions.borrow_mut()
                        .set_writing_mode_dependency(context.builder.writing_mode);
                    if ltr {
                        computed_value::T::Right
                    } else {
                        computed_value::T::Left
                    }
                }
                    SpecifiedValue::None => computed_value::T::None,
                    SpecifiedValue::Left => computed_value::T::Left,
                    SpecifiedValue::Right => computed_value::T::Right,
                    SpecifiedValue::Both => computed_value::T::Both,
            }
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                    computed_value::T::None => SpecifiedValue::None,
                    computed_value::T::Left => SpecifiedValue::Left,
                    computed_value::T::Right => SpecifiedValue::Right,
                    computed_value::T::Both => SpecifiedValue::Both,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Clear(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Clear);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Clear);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_clear(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clear();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clear();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Clear)
        }
    }




    
        
    
    /// https://www.w3.org/TR/CSS2/visudet.html#propdef-vertical-align
    pub mod vertical_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::VerticalAlign as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::VerticalAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::VerticalAlign::baseline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::VerticalAlign::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::VerticalAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::VerticalAlign);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::VerticalAlign);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_vertical_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_vertical_align();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_vertical_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VerticalAlign)
        }
    }



// CSS 2.1, Section 11 - Visual effects


    
    

    
        
    



    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_inline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverflowClipBox::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverflowClipBoxInline);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowClipBoxInline);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_clip_box_inline(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_clip_box_inline();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_clip_box_inline();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxInline)
        }
    }


    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_block {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverflowClipBox::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverflowClipBoxBlock);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowClipBoxBlock);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_clip_box_block(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_clip_box_block();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_clip_box_block();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxBlock)
        }
    }





// FIXME(pcwalton, #2742): Implement scrolling for `scroll` and `auto`.

    
    

    
        
    
    /// https://drafts.csswg.org/css-overflow/#propdef-overflow-x
    pub mod overflow_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "visible" => Visible,
                    "hidden" => Hidden,
                    "scroll" => Scroll,
                    "auto" => Auto,
                    "-moz-hidden-unscrollable" => MozHiddenUnscrollable,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Visible => computed_value::T::Visible,
                        SpecifiedValue::Hidden => computed_value::T::Hidden,
                        SpecifiedValue::Scroll => computed_value::T::Scroll,
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::MozHiddenUnscrollable => computed_value::T::MozHiddenUnscrollable,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Visible => SpecifiedValue::Visible,
                        computed_value::T::Hidden => SpecifiedValue::Hidden,
                        computed_value::T::Scroll => SpecifiedValue::Scroll,
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::MozHiddenUnscrollable => SpecifiedValue::MozHiddenUnscrollable,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverflowX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowX)
        }
    }




// FIXME(pcwalton, #2742): Implement scrolling for `scroll` and `auto`.

    
    /// https://drafts.csswg.org/css-overflow/#propdef-overflow-y
    pub mod overflow_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    pub use super::overflow_x::{SpecifiedValue, parse, get_initial_value, computed_value};

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverflowY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverflowY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overflow_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowY)
        }
    }



    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod transition_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-duration.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-duration");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of transition-duration.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-duration");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionDuration(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransitionDuration);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionDuration);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_duration(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_duration();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_duration();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDuration)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-timing-function
    pub mod transition_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TimingFunction::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-timing-function.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-timing-function");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of transition-timing-function.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-timing-function");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionTimingFunction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransitionTimingFunction);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionTimingFunction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_timing_function(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_timing_function();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_timing_function();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-property
    pub mod transition_property {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransitionProperty as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransitionProperty as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransitionProperty::All }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TransitionProperty::All }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransitionProperty::parse(input)
        }
    
        
        }

        /// The definition of the computed value for transition-property.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of transition-property.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionProperty(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransitionProperty);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionProperty);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_property(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_property();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_property();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionProperty)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-delay
    pub mod transition_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-delay.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-delay");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of transition-delay.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property transition-delay");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransitionDelay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransitionDelay);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransitionDelay);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_transition_delay(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transition_delay();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transition_delay();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDelay)
        }
    }






    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-name
    pub mod animation_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AnimationName as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AnimationName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationName::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AnimationName::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-name.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-name");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-name.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-name");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationName(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationName);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationName);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_name(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_name();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_name();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationName)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod animation_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-duration.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-duration");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-duration.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-duration");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDuration(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationDuration);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDuration);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_duration(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_duration();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_duration();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDuration)
        }
    }




// animation-timing-function is the exception to the rule for allowed_in_keyframe_block:
// https://drafts.csswg.org/css-animations/#keyframes

    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-animation-timing-function
    pub mod animation_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TimingFunction::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-timing-function.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-timing-function");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-timing-function.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-timing-function");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationTimingFunction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationTimingFunction);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationTimingFunction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_timing_function(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_timing_function();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_timing_function();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-iteration-count
    pub mod animation_iteration_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AnimationIterationCount as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AnimationIterationCount as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationIterationCount::one() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationIterationCount::one() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AnimationIterationCount::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-iteration-count.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-iteration-count");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-iteration-count.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-iteration-count");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationIterationCount(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationIterationCount);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationIterationCount);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_iteration_count(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_iteration_count();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_iteration_count();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationIterationCount)
        }
    }






    
    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-direction
    pub mod animation_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "reverse" => Reverse,
                    "alternate" => Alternate,
                    "alternate-reverse" => AlternateReverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Reverse => computed_value::T::Reverse,
                        SpecifiedValue::Alternate => computed_value::T::Alternate,
                        SpecifiedValue::AlternateReverse => computed_value::T::AlternateReverse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Reverse => SpecifiedValue::Reverse,
                        computed_value::T::Alternate => SpecifiedValue::Alternate,
                        computed_value::T::AlternateReverse => SpecifiedValue::AlternateReverse,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for animation-direction.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-direction");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-direction.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-direction");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationDirection);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_direction(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDirection)
        }
    }






    
    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-play-state
    pub mod animation_play_state {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "running" => Running,
                    "paused" => Paused,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Running
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Running
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Running => computed_value::T::Running,
                        SpecifiedValue::Paused => computed_value::T::Paused,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Running => SpecifiedValue::Running,
                        computed_value::T::Paused => SpecifiedValue::Paused,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for animation-play-state.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-play-state");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-play-state.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-play-state");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationPlayState(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationPlayState);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationPlayState);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_play_state(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_play_state();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_play_state();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationPlayState)
        }
    }






    
    

    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-fill-mode
    pub mod animation_fill_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "forwards" => Forwards,
                    "backwards" => Backwards,
                    "both" => Both,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Forwards => computed_value::T::Forwards,
                        SpecifiedValue::Backwards => computed_value::T::Backwards,
                        SpecifiedValue::Both => computed_value::T::Both,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Forwards => SpecifiedValue::Forwards,
                        computed_value::T::Backwards => SpecifiedValue::Backwards,
                        computed_value::T::Both => SpecifiedValue::Both,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for animation-fill-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-fill-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-fill-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-fill-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationFillMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationFillMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationFillMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_fill_mode(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_fill_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_fill_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationFillMode)
        }
    }






    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-delay
    pub mod animation_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-delay.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-delay");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of animation-delay.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property animation-delay");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AnimationDelay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AnimationDelay);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AnimationDelay);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_animation_delay(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_animation_delay();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_animation_delay();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDelay)
        }
    }




    
    
        
    
    /// Nonstandard (https://www.w3.org/TR/2015/WD-css-snappoints-1-20150326/#scroll-snap-points)
    pub mod scroll_snap_points_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapPoint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapPoint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapPoint::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapPoint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapPointsX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapPointsX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapPointsX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_points_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_points_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_points_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapPointsX)
        }
    }


    
    
        
    
    /// Nonstandard (https://www.w3.org/TR/2015/WD-css-snappoints-1-20150326/#scroll-snap-points)
    pub mod scroll_snap_points_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapPoint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapPoint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapPoint::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapPoint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapPointsY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapPointsY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapPointsY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_points_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_points_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_points_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapPointsY)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-destination)
    pub mod scroll_snap_destination {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapDestination(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapDestination);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapDestination);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_scroll_snap_destination(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_destination();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_destination();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ScrollSnapDestination)
        }
    }




    
        
    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-destination)
    pub mod scroll_snap_coordinate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for scroll-snap-coordinate.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of scroll-snap-coordinate.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapCoordinate(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapCoordinate);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapCoordinate);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_box();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_scroll_snap_coordinate(iter);
                        }
                        context.builder.put_box(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_coordinate();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_coordinate();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapCoordinate)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-transforms/#propdef-transform
    pub mod transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Transform::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Transform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Transform);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Transform);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Transform)
        }
    }



// CSSOM View Module
// https://www.w3.org/TR/cssom-view-1/

    
    

    
        
    
    /// https://drafts.csswg.org/cssom-view/#propdef-scroll-behavior
    pub mod scroll_behavior {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "smooth" => Smooth,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Smooth => computed_value::T::Smooth,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Smooth => SpecifiedValue::Smooth,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollBehavior(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollBehavior);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollBehavior);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_behavior(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_behavior();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_behavior();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollBehavior)
        }
    }




    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-type-x)
    pub mod scroll_snap_type_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapType::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapType::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapTypeX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapTypeX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapTypeX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_type_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_type_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_type_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapTypeX)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-snap-type-x)
    pub mod scroll_snap_type_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ScrollSnapType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ScrollSnapType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapType::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ScrollSnapType::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ScrollSnapTypeY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ScrollSnapTypeY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_scroll_snap_type_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_scroll_snap_type_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_scroll_snap_type_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapTypeY)
        }
    }



    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverscrollBehavior::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverscrollBehaviorX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverscrollBehaviorX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overscroll_behavior_x(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overscroll_behavior_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overscroll_behavior_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorX)
        }
    }


    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OverscrollBehavior::parse(input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverscrollBehaviorY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OverscrollBehaviorY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overscroll_behavior_y(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overscroll_behavior_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_overscroll_behavior_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorY)
        }
    }



// Compositing and Blending Level 1
// http://www.w3.org/TR/compositing-1/

    
    

    
        
    
    /// https://drafts.fxtf.org/compositing/#isolation
    pub mod isolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "isolate" => Isolate,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Isolate => computed_value::T::Isolate,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Isolate => SpecifiedValue::Isolate,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Isolation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Isolation);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Isolation);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_isolation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_isolation();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_isolation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Isolation)
        }
    }




// TODO add support for logical values recto and verso

    
    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-after
    pub mod page_break_after {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "always" => Always,
                    "avoid" => Avoid,
                    "left" => Left,
                    "right" => Right,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Always => computed_value::T::Always,
                        SpecifiedValue::Avoid => computed_value::T::Avoid,
                        SpecifiedValue::Left => computed_value::T::Left,
                        SpecifiedValue::Right => computed_value::T::Right,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Always => SpecifiedValue::Always,
                        computed_value::T::Avoid => SpecifiedValue::Avoid,
                        computed_value::T::Left => SpecifiedValue::Left,
                        computed_value::T::Right => SpecifiedValue::Right,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakAfter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PageBreakAfter);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakAfter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_after(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_after();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_after();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakAfter)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-before
    pub mod page_break_before {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "always" => Always,
                    "avoid" => Avoid,
                    "left" => Left,
                    "right" => Right,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Always => computed_value::T::Always,
                        SpecifiedValue::Avoid => computed_value::T::Avoid,
                        SpecifiedValue::Left => computed_value::T::Left,
                        SpecifiedValue::Right => computed_value::T::Right,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Always => SpecifiedValue::Always,
                        computed_value::T::Avoid => SpecifiedValue::Avoid,
                        computed_value::T::Left => SpecifiedValue::Left,
                        computed_value::T::Right => SpecifiedValue::Right,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakBefore(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PageBreakBefore);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakBefore);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_before(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_before();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_before();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakBefore)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css2/page.html#propdef-page-break-inside
    pub mod page_break_inside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "avoid" => Avoid,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Avoid => computed_value::T::Avoid,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Avoid => SpecifiedValue::Avoid,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PageBreakInside(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PageBreakInside);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PageBreakInside);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_page_break_inside(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_page_break_inside();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_page_break_inside();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageBreakInside)
        }
    }




// CSS Basic User Interface Module Level 3
// http://dev.w3.org/csswg/css-ui
// FIXME support logical values `block` and `inline` (https://drafts.csswg.org/css-logical-props/#resize)
//
// This is APPLIES_TO_PLACEHOLDER so we can override, in the UA sheet, the
// 'resize' property we'd inherit from textarea otherwise.  Basically, just
// makes the UA rules easier to write.

    
    

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-resize
    pub mod resize {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "both" => Both,
                    "horizontal" => Horizontal,
                    "vertical" => Vertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Both => computed_value::T::Both,
                        SpecifiedValue::Horizontal => computed_value::T::Horizontal,
                        SpecifiedValue::Vertical => computed_value::T::Vertical,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Both => SpecifiedValue::Both,
                        computed_value::T::Horizontal => SpecifiedValue::Horizontal,
                        computed_value::T::Vertical => SpecifiedValue::Vertical,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Resize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Resize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Resize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_resize(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_resize();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_resize();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Resize)
        }
    }






    
        
    
    /// https://drafts.csswg.org/css-transforms/#perspective
    pub mod perspective {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrNone::parse_non_negative_length(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Perspective(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Perspective);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Perspective);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_perspective(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_perspective();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_perspective();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Perspective)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#perspective-origin-property
    pub mod perspective_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::position::Position::center() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PerspectiveOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PerspectiveOrigin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PerspectiveOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_perspective_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_perspective_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_perspective_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::PerspectiveOrigin)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#backface-visibility-property
    pub mod backface_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "visible" => Visible,
                    "hidden" => Hidden,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Visible => computed_value::T::Visible,
                        SpecifiedValue::Hidden => computed_value::T::Hidden,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Visible => SpecifiedValue::Visible,
                        computed_value::T::Hidden => SpecifiedValue::Hidden,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BackfaceVisibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BackfaceVisibility);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BackfaceVisibility);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_backface_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_backface_visibility();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_backface_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackfaceVisibility)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-box
    pub mod transform_box {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "border-box" => BorderBox,
                    "fill-box" => FillBox,
                    "view-box" => ViewBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                        SpecifiedValue::FillBox => computed_value::T::FillBox,
                        SpecifiedValue::ViewBox => computed_value::T::ViewBox,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                        computed_value::T::FillBox => SpecifiedValue::FillBox,
                        computed_value::T::ViewBox => SpecifiedValue::ViewBox,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformBox(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransformBox);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformBox);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform_box(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_box();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_box();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformBox)
        }
    }




// `auto` keyword is not supported in gecko yet.

    
    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-style-property
    pub mod transform_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "flat" => Flat,
                    "preserve-3d" => Preserve3d,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Flat
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Flat
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Flat => computed_value::T::Flat,
                        SpecifiedValue::Preserve3d => computed_value::T::Preserve3d,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Flat => SpecifiedValue::Flat,
                        computed_value::T::Preserve3d => SpecifiedValue::Preserve3d,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransformStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_transform_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformStyle)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-origin-property
    pub mod transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransformOrigin::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TransformOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TransformOrigin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TransformOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_transform_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_transform_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_transform_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TransformOrigin)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain/#contain-property
    pub mod contain {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Contain as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Contain as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::Contain::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Contain::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Contain(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Contain);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Contain);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_contain(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_contain();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_contain();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Contain)
        }
    }



// Non-standard

    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-appearance)
    pub mod _moz_appearance {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "button" => Button,
                    "button-arrow-down" => ButtonArrowDown,
                    "button-arrow-next" => ButtonArrowNext,
                    "button-arrow-previous" => ButtonArrowPrevious,
                    "button-arrow-up" => ButtonArrowUp,
                    "button-bevel" => ButtonBevel,
                    "button-focus" => ButtonFocus,
                    "caret" => Caret,
                    "checkbox" => Checkbox,
                    "checkbox-container" => CheckboxContainer,
                    "checkbox-label" => CheckboxLabel,
                    "checkmenuitem" => Checkmenuitem,
                    "dialog" => Dialog,
                    "dualbutton" => Dualbutton,
                    "groupbox" => Groupbox,
                    "inner-spin-button" => InnerSpinButton,
                    "listbox" => Listbox,
                    "listitem" => Listitem,
                    "menuarrow" => Menuarrow,
                    "menubar" => Menubar,
                    "menucheckbox" => Menucheckbox,
                    "menuimage" => Menuimage,
                    "menuitem" => Menuitem,
                    "menuitemtext" => Menuitemtext,
                    "menulist" => Menulist,
                    "menulist-button" => MenulistButton,
                    "menulist-text" => MenulistText,
                    "menulist-textfield" => MenulistTextfield,
                    "menupopup" => Menupopup,
                    "menuradio" => Menuradio,
                    "menuseparator" => Menuseparator,
                    "meterbar" => Meterbar,
                    "meterchunk" => Meterchunk,
                    "number-input" => NumberInput,
                    "progressbar" => Progressbar,
                    "progressbar-vertical" => ProgressbarVertical,
                    "progresschunk" => Progresschunk,
                    "progresschunk-vertical" => ProgresschunkVertical,
                    "radio" => Radio,
                    "radio-container" => RadioContainer,
                    "radio-label" => RadioLabel,
                    "radiomenuitem" => Radiomenuitem,
                    "range" => Range,
                    "range-thumb" => RangeThumb,
                    "resizer" => Resizer,
                    "resizerpanel" => Resizerpanel,
                    "scale-horizontal" => ScaleHorizontal,
                    "scalethumbend" => Scalethumbend,
                    "scalethumb-horizontal" => ScalethumbHorizontal,
                    "scalethumbstart" => Scalethumbstart,
                    "scalethumbtick" => Scalethumbtick,
                    "scalethumb-vertical" => ScalethumbVertical,
                    "scale-vertical" => ScaleVertical,
                    "scrollbar" => Scrollbar,
                    "scrollbar-horizontal" => ScrollbarHorizontal,
                    "scrollbar-small" => ScrollbarSmall,
                    "scrollbar-vertical" => ScrollbarVertical,
                    "scrollbarbutton-down" => ScrollbarbuttonDown,
                    "scrollbarbutton-left" => ScrollbarbuttonLeft,
                    "scrollbarbutton-right" => ScrollbarbuttonRight,
                    "scrollbarbutton-up" => ScrollbarbuttonUp,
                    "scrollbarthumb-horizontal" => ScrollbarthumbHorizontal,
                    "scrollbarthumb-vertical" => ScrollbarthumbVertical,
                    "scrollbartrack-horizontal" => ScrollbartrackHorizontal,
                    "scrollbartrack-vertical" => ScrollbartrackVertical,
                    "searchfield" => Searchfield,
                    "separator" => Separator,
                    "spinner" => Spinner,
                    "spinner-downbutton" => SpinnerDownbutton,
                    "spinner-textfield" => SpinnerTextfield,
                    "spinner-upbutton" => SpinnerUpbutton,
                    "splitter" => Splitter,
                    "statusbar" => Statusbar,
                    "statusbarpanel" => Statusbarpanel,
                    "tab" => Tab,
                    "tabpanel" => Tabpanel,
                    "tabpanels" => Tabpanels,
                    "tab-scroll-arrow-back" => TabScrollArrowBack,
                    "tab-scroll-arrow-forward" => TabScrollArrowForward,
                    "textfield" => Textfield,
                    "textfield-multiline" => TextfieldMultiline,
                    "toolbar" => Toolbar,
                    "toolbarbutton" => Toolbarbutton,
                    "toolbarbutton-dropdown" => ToolbarbuttonDropdown,
                    "toolbargripper" => Toolbargripper,
                    "toolbox" => Toolbox,
                    "tooltip" => Tooltip,
                    "treeheader" => Treeheader,
                    "treeheadercell" => Treeheadercell,
                    "treeheadersortarrow" => Treeheadersortarrow,
                    "treeitem" => Treeitem,
                    "treeline" => Treeline,
                    "treetwisty" => Treetwisty,
                    "treetwistyopen" => Treetwistyopen,
                    "treeview" => Treeview,
                    "window" => Window,
                    "-moz-gtk-info-bar" => MozGtkInfoBar,
                    "-moz-mac-active-source-list-selection" => MozMacActiveSourceListSelection,
                    "-moz-mac-disclosure-button-closed" => MozMacDisclosureButtonClosed,
                    "-moz-mac-disclosure-button-open" => MozMacDisclosureButtonOpen,
                    "-moz-mac-fullscreen-button" => MozMacFullscreenButton,
                    "-moz-mac-help-button" => MozMacHelpButton,
                    "-moz-mac-source-list" => MozMacSourceList,
                    "-moz-mac-source-list-selection" => MozMacSourceListSelection,
                    "-moz-mac-vibrancy-dark" => MozMacVibrancyDark,
                    "-moz-mac-vibrancy-light" => MozMacVibrancyLight,
                    "-moz-mac-vibrant-titlebar-light" => MozMacVibrantTitlebarLight,
                    "-moz-mac-vibrant-titlebar-dark" => MozMacVibrantTitlebarDark,
                    "-moz-win-borderless-glass" => MozWinBorderlessGlass,
                    "-moz-win-browsertabbar-toolbox" => MozWinBrowsertabbarToolbox,
                    "-moz-win-communications-toolbox" => MozWinCommunicationsToolbox,
                    "-moz-win-exclude-glass" => MozWinExcludeGlass,
                    "-moz-win-glass" => MozWinGlass,
                    "-moz-win-media-toolbox" => MozWinMediaToolbox,
                    "-moz-window-button-box" => MozWindowButtonBox,
                    "-moz-window-button-box-maximized" => MozWindowButtonBoxMaximized,
                    "-moz-window-button-close" => MozWindowButtonClose,
                    "-moz-window-button-maximize" => MozWindowButtonMaximize,
                    "-moz-window-button-minimize" => MozWindowButtonMinimize,
                    "-moz-window-button-restore" => MozWindowButtonRestore,
                    "-moz-window-frame-bottom" => MozWindowFrameBottom,
                    "-moz-window-frame-left" => MozWindowFrameLeft,
                    "-moz-window-frame-right" => MozWindowFrameRight,
                    "-moz-window-titlebar" => MozWindowTitlebar,
                    "-moz-window-titlebar-maximized" => MozWindowTitlebarMaximized,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Button => computed_value::T::Button,
                        SpecifiedValue::ButtonArrowDown => computed_value::T::ButtonArrowDown,
                        SpecifiedValue::ButtonArrowNext => computed_value::T::ButtonArrowNext,
                        SpecifiedValue::ButtonArrowPrevious => computed_value::T::ButtonArrowPrevious,
                        SpecifiedValue::ButtonArrowUp => computed_value::T::ButtonArrowUp,
                        SpecifiedValue::ButtonBevel => computed_value::T::ButtonBevel,
                        SpecifiedValue::ButtonFocus => computed_value::T::ButtonFocus,
                        SpecifiedValue::Caret => computed_value::T::Caret,
                        SpecifiedValue::Checkbox => computed_value::T::Checkbox,
                        SpecifiedValue::CheckboxContainer => computed_value::T::CheckboxContainer,
                        SpecifiedValue::CheckboxLabel => computed_value::T::CheckboxLabel,
                        SpecifiedValue::Checkmenuitem => computed_value::T::Checkmenuitem,
                        SpecifiedValue::Dialog => computed_value::T::Dialog,
                        SpecifiedValue::Dualbutton => computed_value::T::Dualbutton,
                        SpecifiedValue::Groupbox => computed_value::T::Groupbox,
                        SpecifiedValue::InnerSpinButton => computed_value::T::InnerSpinButton,
                        SpecifiedValue::Listbox => computed_value::T::Listbox,
                        SpecifiedValue::Listitem => computed_value::T::Listitem,
                        SpecifiedValue::Menuarrow => computed_value::T::Menuarrow,
                        SpecifiedValue::Menubar => computed_value::T::Menubar,
                        SpecifiedValue::Menucheckbox => computed_value::T::Menucheckbox,
                        SpecifiedValue::Menuimage => computed_value::T::Menuimage,
                        SpecifiedValue::Menuitem => computed_value::T::Menuitem,
                        SpecifiedValue::Menuitemtext => computed_value::T::Menuitemtext,
                        SpecifiedValue::Menulist => computed_value::T::Menulist,
                        SpecifiedValue::MenulistButton => computed_value::T::MenulistButton,
                        SpecifiedValue::MenulistText => computed_value::T::MenulistText,
                        SpecifiedValue::MenulistTextfield => computed_value::T::MenulistTextfield,
                        SpecifiedValue::Menupopup => computed_value::T::Menupopup,
                        SpecifiedValue::Menuradio => computed_value::T::Menuradio,
                        SpecifiedValue::Menuseparator => computed_value::T::Menuseparator,
                        SpecifiedValue::Meterbar => computed_value::T::Meterbar,
                        SpecifiedValue::Meterchunk => computed_value::T::Meterchunk,
                        SpecifiedValue::NumberInput => computed_value::T::NumberInput,
                        SpecifiedValue::Progressbar => computed_value::T::Progressbar,
                        SpecifiedValue::ProgressbarVertical => computed_value::T::ProgressbarVertical,
                        SpecifiedValue::Progresschunk => computed_value::T::Progresschunk,
                        SpecifiedValue::ProgresschunkVertical => computed_value::T::ProgresschunkVertical,
                        SpecifiedValue::Radio => computed_value::T::Radio,
                        SpecifiedValue::RadioContainer => computed_value::T::RadioContainer,
                        SpecifiedValue::RadioLabel => computed_value::T::RadioLabel,
                        SpecifiedValue::Radiomenuitem => computed_value::T::Radiomenuitem,
                        SpecifiedValue::Range => computed_value::T::Range,
                        SpecifiedValue::RangeThumb => computed_value::T::RangeThumb,
                        SpecifiedValue::Resizer => computed_value::T::Resizer,
                        SpecifiedValue::Resizerpanel => computed_value::T::Resizerpanel,
                        SpecifiedValue::ScaleHorizontal => computed_value::T::ScaleHorizontal,
                        SpecifiedValue::Scalethumbend => computed_value::T::Scalethumbend,
                        SpecifiedValue::ScalethumbHorizontal => computed_value::T::ScalethumbHorizontal,
                        SpecifiedValue::Scalethumbstart => computed_value::T::Scalethumbstart,
                        SpecifiedValue::Scalethumbtick => computed_value::T::Scalethumbtick,
                        SpecifiedValue::ScalethumbVertical => computed_value::T::ScalethumbVertical,
                        SpecifiedValue::ScaleVertical => computed_value::T::ScaleVertical,
                        SpecifiedValue::Scrollbar => computed_value::T::Scrollbar,
                        SpecifiedValue::ScrollbarHorizontal => computed_value::T::ScrollbarHorizontal,
                        SpecifiedValue::ScrollbarSmall => computed_value::T::ScrollbarSmall,
                        SpecifiedValue::ScrollbarVertical => computed_value::T::ScrollbarVertical,
                        SpecifiedValue::ScrollbarbuttonDown => computed_value::T::ScrollbarbuttonDown,
                        SpecifiedValue::ScrollbarbuttonLeft => computed_value::T::ScrollbarbuttonLeft,
                        SpecifiedValue::ScrollbarbuttonRight => computed_value::T::ScrollbarbuttonRight,
                        SpecifiedValue::ScrollbarbuttonUp => computed_value::T::ScrollbarbuttonUp,
                        SpecifiedValue::ScrollbarthumbHorizontal => computed_value::T::ScrollbarthumbHorizontal,
                        SpecifiedValue::ScrollbarthumbVertical => computed_value::T::ScrollbarthumbVertical,
                        SpecifiedValue::ScrollbartrackHorizontal => computed_value::T::ScrollbartrackHorizontal,
                        SpecifiedValue::ScrollbartrackVertical => computed_value::T::ScrollbartrackVertical,
                        SpecifiedValue::Searchfield => computed_value::T::Searchfield,
                        SpecifiedValue::Separator => computed_value::T::Separator,
                        SpecifiedValue::Spinner => computed_value::T::Spinner,
                        SpecifiedValue::SpinnerDownbutton => computed_value::T::SpinnerDownbutton,
                        SpecifiedValue::SpinnerTextfield => computed_value::T::SpinnerTextfield,
                        SpecifiedValue::SpinnerUpbutton => computed_value::T::SpinnerUpbutton,
                        SpecifiedValue::Splitter => computed_value::T::Splitter,
                        SpecifiedValue::Statusbar => computed_value::T::Statusbar,
                        SpecifiedValue::Statusbarpanel => computed_value::T::Statusbarpanel,
                        SpecifiedValue::Tab => computed_value::T::Tab,
                        SpecifiedValue::Tabpanel => computed_value::T::Tabpanel,
                        SpecifiedValue::Tabpanels => computed_value::T::Tabpanels,
                        SpecifiedValue::TabScrollArrowBack => computed_value::T::TabScrollArrowBack,
                        SpecifiedValue::TabScrollArrowForward => computed_value::T::TabScrollArrowForward,
                        SpecifiedValue::Textfield => computed_value::T::Textfield,
                        SpecifiedValue::TextfieldMultiline => computed_value::T::TextfieldMultiline,
                        SpecifiedValue::Toolbar => computed_value::T::Toolbar,
                        SpecifiedValue::Toolbarbutton => computed_value::T::Toolbarbutton,
                        SpecifiedValue::ToolbarbuttonDropdown => computed_value::T::ToolbarbuttonDropdown,
                        SpecifiedValue::Toolbargripper => computed_value::T::Toolbargripper,
                        SpecifiedValue::Toolbox => computed_value::T::Toolbox,
                        SpecifiedValue::Tooltip => computed_value::T::Tooltip,
                        SpecifiedValue::Treeheader => computed_value::T::Treeheader,
                        SpecifiedValue::Treeheadercell => computed_value::T::Treeheadercell,
                        SpecifiedValue::Treeheadersortarrow => computed_value::T::Treeheadersortarrow,
                        SpecifiedValue::Treeitem => computed_value::T::Treeitem,
                        SpecifiedValue::Treeline => computed_value::T::Treeline,
                        SpecifiedValue::Treetwisty => computed_value::T::Treetwisty,
                        SpecifiedValue::Treetwistyopen => computed_value::T::Treetwistyopen,
                        SpecifiedValue::Treeview => computed_value::T::Treeview,
                        SpecifiedValue::Window => computed_value::T::Window,
                        SpecifiedValue::MozGtkInfoBar => computed_value::T::MozGtkInfoBar,
                        SpecifiedValue::MozMacActiveSourceListSelection => computed_value::T::MozMacActiveSourceListSelection,
                        SpecifiedValue::MozMacDisclosureButtonClosed => computed_value::T::MozMacDisclosureButtonClosed,
                        SpecifiedValue::MozMacDisclosureButtonOpen => computed_value::T::MozMacDisclosureButtonOpen,
                        SpecifiedValue::MozMacFullscreenButton => computed_value::T::MozMacFullscreenButton,
                        SpecifiedValue::MozMacHelpButton => computed_value::T::MozMacHelpButton,
                        SpecifiedValue::MozMacSourceList => computed_value::T::MozMacSourceList,
                        SpecifiedValue::MozMacSourceListSelection => computed_value::T::MozMacSourceListSelection,
                        SpecifiedValue::MozMacVibrancyDark => computed_value::T::MozMacVibrancyDark,
                        SpecifiedValue::MozMacVibrancyLight => computed_value::T::MozMacVibrancyLight,
                        SpecifiedValue::MozMacVibrantTitlebarLight => computed_value::T::MozMacVibrantTitlebarLight,
                        SpecifiedValue::MozMacVibrantTitlebarDark => computed_value::T::MozMacVibrantTitlebarDark,
                        SpecifiedValue::MozWinBorderlessGlass => computed_value::T::MozWinBorderlessGlass,
                        SpecifiedValue::MozWinBrowsertabbarToolbox => computed_value::T::MozWinBrowsertabbarToolbox,
                        SpecifiedValue::MozWinCommunicationsToolbox => computed_value::T::MozWinCommunicationsToolbox,
                        SpecifiedValue::MozWinExcludeGlass => computed_value::T::MozWinExcludeGlass,
                        SpecifiedValue::MozWinGlass => computed_value::T::MozWinGlass,
                        SpecifiedValue::MozWinMediaToolbox => computed_value::T::MozWinMediaToolbox,
                        SpecifiedValue::MozWindowButtonBox => computed_value::T::MozWindowButtonBox,
                        SpecifiedValue::MozWindowButtonBoxMaximized => computed_value::T::MozWindowButtonBoxMaximized,
                        SpecifiedValue::MozWindowButtonClose => computed_value::T::MozWindowButtonClose,
                        SpecifiedValue::MozWindowButtonMaximize => computed_value::T::MozWindowButtonMaximize,
                        SpecifiedValue::MozWindowButtonMinimize => computed_value::T::MozWindowButtonMinimize,
                        SpecifiedValue::MozWindowButtonRestore => computed_value::T::MozWindowButtonRestore,
                        SpecifiedValue::MozWindowFrameBottom => computed_value::T::MozWindowFrameBottom,
                        SpecifiedValue::MozWindowFrameLeft => computed_value::T::MozWindowFrameLeft,
                        SpecifiedValue::MozWindowFrameRight => computed_value::T::MozWindowFrameRight,
                        SpecifiedValue::MozWindowTitlebar => computed_value::T::MozWindowTitlebar,
                        SpecifiedValue::MozWindowTitlebarMaximized => computed_value::T::MozWindowTitlebarMaximized,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Button => SpecifiedValue::Button,
                        computed_value::T::ButtonArrowDown => SpecifiedValue::ButtonArrowDown,
                        computed_value::T::ButtonArrowNext => SpecifiedValue::ButtonArrowNext,
                        computed_value::T::ButtonArrowPrevious => SpecifiedValue::ButtonArrowPrevious,
                        computed_value::T::ButtonArrowUp => SpecifiedValue::ButtonArrowUp,
                        computed_value::T::ButtonBevel => SpecifiedValue::ButtonBevel,
                        computed_value::T::ButtonFocus => SpecifiedValue::ButtonFocus,
                        computed_value::T::Caret => SpecifiedValue::Caret,
                        computed_value::T::Checkbox => SpecifiedValue::Checkbox,
                        computed_value::T::CheckboxContainer => SpecifiedValue::CheckboxContainer,
                        computed_value::T::CheckboxLabel => SpecifiedValue::CheckboxLabel,
                        computed_value::T::Checkmenuitem => SpecifiedValue::Checkmenuitem,
                        computed_value::T::Dialog => SpecifiedValue::Dialog,
                        computed_value::T::Dualbutton => SpecifiedValue::Dualbutton,
                        computed_value::T::Groupbox => SpecifiedValue::Groupbox,
                        computed_value::T::InnerSpinButton => SpecifiedValue::InnerSpinButton,
                        computed_value::T::Listbox => SpecifiedValue::Listbox,
                        computed_value::T::Listitem => SpecifiedValue::Listitem,
                        computed_value::T::Menuarrow => SpecifiedValue::Menuarrow,
                        computed_value::T::Menubar => SpecifiedValue::Menubar,
                        computed_value::T::Menucheckbox => SpecifiedValue::Menucheckbox,
                        computed_value::T::Menuimage => SpecifiedValue::Menuimage,
                        computed_value::T::Menuitem => SpecifiedValue::Menuitem,
                        computed_value::T::Menuitemtext => SpecifiedValue::Menuitemtext,
                        computed_value::T::Menulist => SpecifiedValue::Menulist,
                        computed_value::T::MenulistButton => SpecifiedValue::MenulistButton,
                        computed_value::T::MenulistText => SpecifiedValue::MenulistText,
                        computed_value::T::MenulistTextfield => SpecifiedValue::MenulistTextfield,
                        computed_value::T::Menupopup => SpecifiedValue::Menupopup,
                        computed_value::T::Menuradio => SpecifiedValue::Menuradio,
                        computed_value::T::Menuseparator => SpecifiedValue::Menuseparator,
                        computed_value::T::Meterbar => SpecifiedValue::Meterbar,
                        computed_value::T::Meterchunk => SpecifiedValue::Meterchunk,
                        computed_value::T::NumberInput => SpecifiedValue::NumberInput,
                        computed_value::T::Progressbar => SpecifiedValue::Progressbar,
                        computed_value::T::ProgressbarVertical => SpecifiedValue::ProgressbarVertical,
                        computed_value::T::Progresschunk => SpecifiedValue::Progresschunk,
                        computed_value::T::ProgresschunkVertical => SpecifiedValue::ProgresschunkVertical,
                        computed_value::T::Radio => SpecifiedValue::Radio,
                        computed_value::T::RadioContainer => SpecifiedValue::RadioContainer,
                        computed_value::T::RadioLabel => SpecifiedValue::RadioLabel,
                        computed_value::T::Radiomenuitem => SpecifiedValue::Radiomenuitem,
                        computed_value::T::Range => SpecifiedValue::Range,
                        computed_value::T::RangeThumb => SpecifiedValue::RangeThumb,
                        computed_value::T::Resizer => SpecifiedValue::Resizer,
                        computed_value::T::Resizerpanel => SpecifiedValue::Resizerpanel,
                        computed_value::T::ScaleHorizontal => SpecifiedValue::ScaleHorizontal,
                        computed_value::T::Scalethumbend => SpecifiedValue::Scalethumbend,
                        computed_value::T::ScalethumbHorizontal => SpecifiedValue::ScalethumbHorizontal,
                        computed_value::T::Scalethumbstart => SpecifiedValue::Scalethumbstart,
                        computed_value::T::Scalethumbtick => SpecifiedValue::Scalethumbtick,
                        computed_value::T::ScalethumbVertical => SpecifiedValue::ScalethumbVertical,
                        computed_value::T::ScaleVertical => SpecifiedValue::ScaleVertical,
                        computed_value::T::Scrollbar => SpecifiedValue::Scrollbar,
                        computed_value::T::ScrollbarHorizontal => SpecifiedValue::ScrollbarHorizontal,
                        computed_value::T::ScrollbarSmall => SpecifiedValue::ScrollbarSmall,
                        computed_value::T::ScrollbarVertical => SpecifiedValue::ScrollbarVertical,
                        computed_value::T::ScrollbarbuttonDown => SpecifiedValue::ScrollbarbuttonDown,
                        computed_value::T::ScrollbarbuttonLeft => SpecifiedValue::ScrollbarbuttonLeft,
                        computed_value::T::ScrollbarbuttonRight => SpecifiedValue::ScrollbarbuttonRight,
                        computed_value::T::ScrollbarbuttonUp => SpecifiedValue::ScrollbarbuttonUp,
                        computed_value::T::ScrollbarthumbHorizontal => SpecifiedValue::ScrollbarthumbHorizontal,
                        computed_value::T::ScrollbarthumbVertical => SpecifiedValue::ScrollbarthumbVertical,
                        computed_value::T::ScrollbartrackHorizontal => SpecifiedValue::ScrollbartrackHorizontal,
                        computed_value::T::ScrollbartrackVertical => SpecifiedValue::ScrollbartrackVertical,
                        computed_value::T::Searchfield => SpecifiedValue::Searchfield,
                        computed_value::T::Separator => SpecifiedValue::Separator,
                        computed_value::T::Spinner => SpecifiedValue::Spinner,
                        computed_value::T::SpinnerDownbutton => SpecifiedValue::SpinnerDownbutton,
                        computed_value::T::SpinnerTextfield => SpecifiedValue::SpinnerTextfield,
                        computed_value::T::SpinnerUpbutton => SpecifiedValue::SpinnerUpbutton,
                        computed_value::T::Splitter => SpecifiedValue::Splitter,
                        computed_value::T::Statusbar => SpecifiedValue::Statusbar,
                        computed_value::T::Statusbarpanel => SpecifiedValue::Statusbarpanel,
                        computed_value::T::Tab => SpecifiedValue::Tab,
                        computed_value::T::Tabpanel => SpecifiedValue::Tabpanel,
                        computed_value::T::Tabpanels => SpecifiedValue::Tabpanels,
                        computed_value::T::TabScrollArrowBack => SpecifiedValue::TabScrollArrowBack,
                        computed_value::T::TabScrollArrowForward => SpecifiedValue::TabScrollArrowForward,
                        computed_value::T::Textfield => SpecifiedValue::Textfield,
                        computed_value::T::TextfieldMultiline => SpecifiedValue::TextfieldMultiline,
                        computed_value::T::Toolbar => SpecifiedValue::Toolbar,
                        computed_value::T::Toolbarbutton => SpecifiedValue::Toolbarbutton,
                        computed_value::T::ToolbarbuttonDropdown => SpecifiedValue::ToolbarbuttonDropdown,
                        computed_value::T::Toolbargripper => SpecifiedValue::Toolbargripper,
                        computed_value::T::Toolbox => SpecifiedValue::Toolbox,
                        computed_value::T::Tooltip => SpecifiedValue::Tooltip,
                        computed_value::T::Treeheader => SpecifiedValue::Treeheader,
                        computed_value::T::Treeheadercell => SpecifiedValue::Treeheadercell,
                        computed_value::T::Treeheadersortarrow => SpecifiedValue::Treeheadersortarrow,
                        computed_value::T::Treeitem => SpecifiedValue::Treeitem,
                        computed_value::T::Treeline => SpecifiedValue::Treeline,
                        computed_value::T::Treetwisty => SpecifiedValue::Treetwisty,
                        computed_value::T::Treetwistyopen => SpecifiedValue::Treetwistyopen,
                        computed_value::T::Treeview => SpecifiedValue::Treeview,
                        computed_value::T::Window => SpecifiedValue::Window,
                        computed_value::T::MozGtkInfoBar => SpecifiedValue::MozGtkInfoBar,
                        computed_value::T::MozMacActiveSourceListSelection => SpecifiedValue::MozMacActiveSourceListSelection,
                        computed_value::T::MozMacDisclosureButtonClosed => SpecifiedValue::MozMacDisclosureButtonClosed,
                        computed_value::T::MozMacDisclosureButtonOpen => SpecifiedValue::MozMacDisclosureButtonOpen,
                        computed_value::T::MozMacFullscreenButton => SpecifiedValue::MozMacFullscreenButton,
                        computed_value::T::MozMacHelpButton => SpecifiedValue::MozMacHelpButton,
                        computed_value::T::MozMacSourceList => SpecifiedValue::MozMacSourceList,
                        computed_value::T::MozMacSourceListSelection => SpecifiedValue::MozMacSourceListSelection,
                        computed_value::T::MozMacVibrancyDark => SpecifiedValue::MozMacVibrancyDark,
                        computed_value::T::MozMacVibrancyLight => SpecifiedValue::MozMacVibrancyLight,
                        computed_value::T::MozMacVibrantTitlebarLight => SpecifiedValue::MozMacVibrantTitlebarLight,
                        computed_value::T::MozMacVibrantTitlebarDark => SpecifiedValue::MozMacVibrantTitlebarDark,
                        computed_value::T::MozWinBorderlessGlass => SpecifiedValue::MozWinBorderlessGlass,
                        computed_value::T::MozWinBrowsertabbarToolbox => SpecifiedValue::MozWinBrowsertabbarToolbox,
                        computed_value::T::MozWinCommunicationsToolbox => SpecifiedValue::MozWinCommunicationsToolbox,
                        computed_value::T::MozWinExcludeGlass => SpecifiedValue::MozWinExcludeGlass,
                        computed_value::T::MozWinGlass => SpecifiedValue::MozWinGlass,
                        computed_value::T::MozWinMediaToolbox => SpecifiedValue::MozWinMediaToolbox,
                        computed_value::T::MozWindowButtonBox => SpecifiedValue::MozWindowButtonBox,
                        computed_value::T::MozWindowButtonBoxMaximized => SpecifiedValue::MozWindowButtonBoxMaximized,
                        computed_value::T::MozWindowButtonClose => SpecifiedValue::MozWindowButtonClose,
                        computed_value::T::MozWindowButtonMaximize => SpecifiedValue::MozWindowButtonMaximize,
                        computed_value::T::MozWindowButtonMinimize => SpecifiedValue::MozWindowButtonMinimize,
                        computed_value::T::MozWindowButtonRestore => SpecifiedValue::MozWindowButtonRestore,
                        computed_value::T::MozWindowFrameBottom => SpecifiedValue::MozWindowFrameBottom,
                        computed_value::T::MozWindowFrameLeft => SpecifiedValue::MozWindowFrameLeft,
                        computed_value::T::MozWindowFrameRight => SpecifiedValue::MozWindowFrameRight,
                        computed_value::T::MozWindowTitlebar => SpecifiedValue::MozWindowTitlebar,
                        computed_value::T::MozWindowTitlebarMaximized => SpecifiedValue::MozWindowTitlebarMaximized,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozAppearance(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozAppearance);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozAppearance);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_appearance(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_appearance();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_appearance();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozAppearance)
        }
    }





    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-binding)
    pub mod _moz_binding {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBinding(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBinding);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBinding);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_binding(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_binding();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_binding();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozBinding)
        }
    }




    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-orient)
    pub mod _moz_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "inline" => Inline,
                    "block" => Block,
                    "horizontal" => Horizontal,
                    "vertical" => Vertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Inline
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Inline
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Inline => computed_value::T::Inline,
                        SpecifiedValue::Block => computed_value::T::Block,
                        SpecifiedValue::Horizontal => computed_value::T::Horizontal,
                        SpecifiedValue::Vertical => computed_value::T::Vertical,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Inline => SpecifiedValue::Inline,
                        computed_value::T::Block => SpecifiedValue::Block,
                        computed_value::T::Horizontal => SpecifiedValue::Horizontal,
                        computed_value::T::Vertical => SpecifiedValue::Vertical,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOrient(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOrient);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOrient);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_orient(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_orient();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_orient();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOrient)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-will-change/#will-change
    pub mod will_change {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::WillChange as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::WillChange as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WillChange::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::WillChange::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WillChange(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WillChange);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::WillChange);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_will_change(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_will_change();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_will_change();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WillChange)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-image-threshold-property
    pub mod shape_image_threshold {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeImageThreshold(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ShapeImageThreshold);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ShapeImageThreshold);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_shape_image_threshold(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_image_threshold();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_shape_image_threshold();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeImageThreshold)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-outside-property
    pub mod shape_outside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::basic_shape::FloatAreaShape as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::basic_shape::FloatAreaShape as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ShapeSource::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::basic_shape::FloatAreaShape::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeOutside(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ShapeOutside);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ShapeOutside);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_shape_outside(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_outside();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_shape_outside();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ShapeOutside)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#touch-action
    pub mod touch_action {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TouchAction as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TouchAction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TouchAction::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TouchAction::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TouchAction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TouchAction);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TouchAction);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_touch_action(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_touch_action();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_touch_action();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TouchAction)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */








    
        
    
    /// https://drafts.csswg.org/css-color/#color
    pub mod color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ColorPropertyValue as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ColorPropertyValue as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::cssparser::RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ColorPropertyValue::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Color(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Color);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Color)
        }
    }



// FIXME(#15973): Add servo support for system colors
//
// FIXME(emilio): Move outside of mako.
pub mod system_colors {
    
    use cssparser::Parser;
    use gecko_bindings::bindings::Gecko_GetLookAndFeelSystemColor;
    use gecko_bindings::structs::root::mozilla::LookAndFeel_ColorID;
    use std::fmt::{self, Write};
    use style_traits::{CssWriter, ToCss};
    use values::computed::{Context, ToComputedValue};

    pub type SystemColor = LookAndFeel_ColorID;

    // It's hard to implement MallocSizeOf for LookAndFeel_ColorID because it
    // is a bindgen type. So we implement it on the typedef instead.
    malloc_size_of_is_0!(SystemColor);

    impl ToCss for SystemColor {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
        where
            W: Write,
        {
            let s = match *self {
                    LookAndFeel_ColorID::eColorID_activeborder => "activeborder",
                    LookAndFeel_ColorID::eColorID_activecaption => "activecaption",
                    LookAndFeel_ColorID::eColorID_appworkspace => "appworkspace",
                    LookAndFeel_ColorID::eColorID_background => "background",
                    LookAndFeel_ColorID::eColorID_buttonface => "buttonface",
                    LookAndFeel_ColorID::eColorID_buttonhighlight => "buttonhighlight",
                    LookAndFeel_ColorID::eColorID_buttonshadow => "buttonshadow",
                    LookAndFeel_ColorID::eColorID_buttontext => "buttontext",
                    LookAndFeel_ColorID::eColorID_captiontext => "captiontext",
                    LookAndFeel_ColorID::eColorID_graytext => "graytext",
                    LookAndFeel_ColorID::eColorID_highlight => "highlight",
                    LookAndFeel_ColorID::eColorID_highlighttext => "highlighttext",
                    LookAndFeel_ColorID::eColorID_inactiveborder => "inactiveborder",
                    LookAndFeel_ColorID::eColorID_inactivecaption => "inactivecaption",
                    LookAndFeel_ColorID::eColorID_inactivecaptiontext => "inactivecaptiontext",
                    LookAndFeel_ColorID::eColorID_infobackground => "infobackground",
                    LookAndFeel_ColorID::eColorID_infotext => "infotext",
                    LookAndFeel_ColorID::eColorID_menu => "menu",
                    LookAndFeel_ColorID::eColorID_menutext => "menutext",
                    LookAndFeel_ColorID::eColorID_scrollbar => "scrollbar",
                    LookAndFeel_ColorID::eColorID_threeddarkshadow => "threeddarkshadow",
                    LookAndFeel_ColorID::eColorID_threedface => "threedface",
                    LookAndFeel_ColorID::eColorID_threedhighlight => "threedhighlight",
                    LookAndFeel_ColorID::eColorID_threedlightshadow => "threedlightshadow",
                    LookAndFeel_ColorID::eColorID_threedshadow => "threedshadow",
                    LookAndFeel_ColorID::eColorID_window => "window",
                    LookAndFeel_ColorID::eColorID_windowframe => "windowframe",
                    LookAndFeel_ColorID::eColorID_windowtext => "windowtext",
                    LookAndFeel_ColorID::eColorID__moz_buttondefault => "-moz-buttondefault",
                    LookAndFeel_ColorID::eColorID__moz_buttonhoverface => "-moz-buttonhoverface",
                    LookAndFeel_ColorID::eColorID__moz_buttonhovertext => "-moz-buttonhovertext",
                    LookAndFeel_ColorID::eColorID__moz_cellhighlight => "-moz-cellhighlight",
                    LookAndFeel_ColorID::eColorID__moz_cellhighlighttext => "-moz-cellhighlighttext",
                    LookAndFeel_ColorID::eColorID__moz_eventreerow => "-moz-eventreerow",
                    LookAndFeel_ColorID::eColorID__moz_field => "-moz-field",
                    LookAndFeel_ColorID::eColorID__moz_fieldtext => "-moz-fieldtext",
                    LookAndFeel_ColorID::eColorID__moz_dialog => "-moz-dialog",
                    LookAndFeel_ColorID::eColorID__moz_dialogtext => "-moz-dialogtext",
                    LookAndFeel_ColorID::eColorID__moz_dragtargetzone => "-moz-dragtargetzone",
                    LookAndFeel_ColorID::eColorID__moz_gtk_info_bar_text => "-moz-gtk-info-bar-text",
                    LookAndFeel_ColorID::eColorID__moz_html_cellhighlight => "-moz-html-cellhighlight",
                    LookAndFeel_ColorID::eColorID__moz_html_cellhighlighttext => "-moz-html-cellhighlighttext",
                    LookAndFeel_ColorID::eColorID__moz_mac_buttonactivetext => "-moz-mac-buttonactivetext",
                    LookAndFeel_ColorID::eColorID__moz_mac_chrome_active => "-moz-mac-chrome-active",
                    LookAndFeel_ColorID::eColorID__moz_mac_chrome_inactive => "-moz-mac-chrome-inactive",
                    LookAndFeel_ColorID::eColorID__moz_mac_defaultbuttontext => "-moz-mac-defaultbuttontext",
                    LookAndFeel_ColorID::eColorID__moz_mac_focusring => "-moz-mac-focusring",
                    LookAndFeel_ColorID::eColorID__moz_mac_menuselect => "-moz-mac-menuselect",
                    LookAndFeel_ColorID::eColorID__moz_mac_menushadow => "-moz-mac-menushadow",
                    LookAndFeel_ColorID::eColorID__moz_mac_menutextdisable => "-moz-mac-menutextdisable",
                    LookAndFeel_ColorID::eColorID__moz_mac_menutextselect => "-moz-mac-menutextselect",
                    LookAndFeel_ColorID::eColorID__moz_mac_disabledtoolbartext => "-moz-mac-disabledtoolbartext",
                    LookAndFeel_ColorID::eColorID__moz_mac_secondaryhighlight => "-moz-mac-secondaryhighlight",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_light => "-moz-mac-vibrancy-light",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_dark => "-moz-mac-vibrancy-dark",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_light => "-moz-mac-vibrant-titlebar-light",
                    LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_dark => "-moz-mac-vibrant-titlebar-dark",
                    LookAndFeel_ColorID::eColorID__moz_mac_menupopup => "-moz-mac-menupopup",
                    LookAndFeel_ColorID::eColorID__moz_mac_menuitem => "-moz-mac-menuitem",
                    LookAndFeel_ColorID::eColorID__moz_mac_active_menuitem => "-moz-mac-active-menuitem",
                    LookAndFeel_ColorID::eColorID__moz_mac_source_list => "-moz-mac-source-list",
                    LookAndFeel_ColorID::eColorID__moz_mac_source_list_selection => "-moz-mac-source-list-selection",
                    LookAndFeel_ColorID::eColorID__moz_mac_active_source_list_selection => "-moz-mac-active-source-list-selection",
                    LookAndFeel_ColorID::eColorID__moz_mac_tooltip => "-moz-mac-tooltip",
                    LookAndFeel_ColorID::eColorID__moz_menuhover => "-moz-menuhover",
                    LookAndFeel_ColorID::eColorID__moz_menuhovertext => "-moz-menuhovertext",
                    LookAndFeel_ColorID::eColorID__moz_menubartext => "-moz-menubartext",
                    LookAndFeel_ColorID::eColorID__moz_menubarhovertext => "-moz-menubarhovertext",
                    LookAndFeel_ColorID::eColorID__moz_oddtreerow => "-moz-oddtreerow",
                    LookAndFeel_ColorID::eColorID__moz_win_mediatext => "-moz-win-mediatext",
                    LookAndFeel_ColorID::eColorID__moz_win_communicationstext => "-moz-win-communicationstext",
                    LookAndFeel_ColorID::eColorID__moz_win_accentcolor => "-moz-win-accentcolor",
                    LookAndFeel_ColorID::eColorID__moz_win_accentcolortext => "-moz-win-accentcolortext",
                    LookAndFeel_ColorID::eColorID__moz_nativehyperlinktext => "-moz-nativehyperlinktext",
                    LookAndFeel_ColorID::eColorID__moz_comboboxtext => "-moz-comboboxtext",
                    LookAndFeel_ColorID::eColorID__moz_combobox => "-moz-combobox",
                    LookAndFeel_ColorID::eColorID_WindowBackground => "WindowBackground",
                    LookAndFeel_ColorID::eColorID_WindowForeground => "WindowForeground",
                    LookAndFeel_ColorID::eColorID_WidgetBackground => "WidgetBackground",
                    LookAndFeel_ColorID::eColorID_WidgetForeground => "WidgetForeground",
                    LookAndFeel_ColorID::eColorID_WidgetSelectBackground => "WidgetSelectBackground",
                    LookAndFeel_ColorID::eColorID_WidgetSelectForeground => "WidgetSelectForeground",
                    LookAndFeel_ColorID::eColorID_Widget3DHighlight => "Widget3DHighlight",
                    LookAndFeel_ColorID::eColorID_Widget3DShadow => "Widget3DShadow",
                    LookAndFeel_ColorID::eColorID_TextBackground => "TextBackground",
                    LookAndFeel_ColorID::eColorID_TextForeground => "TextForeground",
                    LookAndFeel_ColorID::eColorID_TextSelectBackground => "TextSelectBackground",
                    LookAndFeel_ColorID::eColorID_TextSelectForeground => "TextSelectForeground",
                    LookAndFeel_ColorID::eColorID_TextSelectForegroundCustom => "TextSelectForegroundCustom",
                    LookAndFeel_ColorID::eColorID_TextSelectBackgroundDisabled => "TextSelectBackgroundDisabled",
                    LookAndFeel_ColorID::eColorID_TextSelectBackgroundAttention => "TextSelectBackgroundAttention",
                    LookAndFeel_ColorID::eColorID_TextHighlightBackground => "TextHighlightBackground",
                    LookAndFeel_ColorID::eColorID_TextHighlightForeground => "TextHighlightForeground",
                    LookAndFeel_ColorID::eColorID_IMERawInputBackground => "IMERawInputBackground",
                    LookAndFeel_ColorID::eColorID_IMERawInputForeground => "IMERawInputForeground",
                    LookAndFeel_ColorID::eColorID_IMERawInputUnderline => "IMERawInputUnderline",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextBackground => "IMESelectedRawTextBackground",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextForeground => "IMESelectedRawTextForeground",
                    LookAndFeel_ColorID::eColorID_IMESelectedRawTextUnderline => "IMESelectedRawTextUnderline",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextBackground => "IMEConvertedTextBackground",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextForeground => "IMEConvertedTextForeground",
                    LookAndFeel_ColorID::eColorID_IMEConvertedTextUnderline => "IMEConvertedTextUnderline",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextBackground => "IMESelectedConvertedTextBackground",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextForeground => "IMESelectedConvertedTextForeground",
                    LookAndFeel_ColorID::eColorID_IMESelectedConvertedTextUnderline => "IMESelectedConvertedTextUnderline",
                    LookAndFeel_ColorID::eColorID_SpellCheckerUnderline => "SpellCheckerUnderline",
                LookAndFeel_ColorID::eColorID_LAST_COLOR => unreachable!(),
            };
            dest.write_str(s)
        }
    }

    impl ToComputedValue for SystemColor {
        type ComputedValue = u32; // nscolor

        #[inline]
        fn to_computed_value(&self, cx: &Context) -> Self::ComputedValue {
            unsafe {
                Gecko_GetLookAndFeelSystemColor(*self as i32,
                                                cx.device().pres_context())
            }
        }

        #[inline]
        fn from_computed_value(_: &Self::ComputedValue) -> Self {
            unreachable!()
        }
    }

    impl SystemColor {
        pub fn parse<'i, 't>(input: &mut Parser<'i, 't>,) -> Result<Self, ()> {
            ascii_case_insensitive_phf_map! {
                color_name -> SystemColor = {
                        "activeborder" => LookAndFeel_ColorID::eColorID_activeborder,
                        "activecaption" => LookAndFeel_ColorID::eColorID_activecaption,
                        "appworkspace" => LookAndFeel_ColorID::eColorID_appworkspace,
                        "background" => LookAndFeel_ColorID::eColorID_background,
                        "buttonface" => LookAndFeel_ColorID::eColorID_buttonface,
                        "buttonhighlight" => LookAndFeel_ColorID::eColorID_buttonhighlight,
                        "buttonshadow" => LookAndFeel_ColorID::eColorID_buttonshadow,
                        "buttontext" => LookAndFeel_ColorID::eColorID_buttontext,
                        "captiontext" => LookAndFeel_ColorID::eColorID_captiontext,
                        "graytext" => LookAndFeel_ColorID::eColorID_graytext,
                        "highlight" => LookAndFeel_ColorID::eColorID_highlight,
                        "highlighttext" => LookAndFeel_ColorID::eColorID_highlighttext,
                        "inactiveborder" => LookAndFeel_ColorID::eColorID_inactiveborder,
                        "inactivecaption" => LookAndFeel_ColorID::eColorID_inactivecaption,
                        "inactivecaptiontext" => LookAndFeel_ColorID::eColorID_inactivecaptiontext,
                        "infobackground" => LookAndFeel_ColorID::eColorID_infobackground,
                        "infotext" => LookAndFeel_ColorID::eColorID_infotext,
                        "menu" => LookAndFeel_ColorID::eColorID_menu,
                        "menutext" => LookAndFeel_ColorID::eColorID_menutext,
                        "scrollbar" => LookAndFeel_ColorID::eColorID_scrollbar,
                        "threeddarkshadow" => LookAndFeel_ColorID::eColorID_threeddarkshadow,
                        "threedface" => LookAndFeel_ColorID::eColorID_threedface,
                        "threedhighlight" => LookAndFeel_ColorID::eColorID_threedhighlight,
                        "threedlightshadow" => LookAndFeel_ColorID::eColorID_threedlightshadow,
                        "threedshadow" => LookAndFeel_ColorID::eColorID_threedshadow,
                        "window" => LookAndFeel_ColorID::eColorID_window,
                        "windowframe" => LookAndFeel_ColorID::eColorID_windowframe,
                        "windowtext" => LookAndFeel_ColorID::eColorID_windowtext,
                        "-moz-buttondefault" => LookAndFeel_ColorID::eColorID__moz_buttondefault,
                        "-moz-buttonhoverface" => LookAndFeel_ColorID::eColorID__moz_buttonhoverface,
                        "-moz-buttonhovertext" => LookAndFeel_ColorID::eColorID__moz_buttonhovertext,
                        "-moz-cellhighlight" => LookAndFeel_ColorID::eColorID__moz_cellhighlight,
                        "-moz-cellhighlighttext" => LookAndFeel_ColorID::eColorID__moz_cellhighlighttext,
                        "-moz-eventreerow" => LookAndFeel_ColorID::eColorID__moz_eventreerow,
                        "-moz-field" => LookAndFeel_ColorID::eColorID__moz_field,
                        "-moz-fieldtext" => LookAndFeel_ColorID::eColorID__moz_fieldtext,
                        "-moz-dialog" => LookAndFeel_ColorID::eColorID__moz_dialog,
                        "-moz-dialogtext" => LookAndFeel_ColorID::eColorID__moz_dialogtext,
                        "-moz-dragtargetzone" => LookAndFeel_ColorID::eColorID__moz_dragtargetzone,
                        "-moz-gtk-info-bar-text" => LookAndFeel_ColorID::eColorID__moz_gtk_info_bar_text,
                        "-moz-html-cellhighlight" => LookAndFeel_ColorID::eColorID__moz_html_cellhighlight,
                        "-moz-html-cellhighlighttext" => LookAndFeel_ColorID::eColorID__moz_html_cellhighlighttext,
                        "-moz-mac-buttonactivetext" => LookAndFeel_ColorID::eColorID__moz_mac_buttonactivetext,
                        "-moz-mac-chrome-active" => LookAndFeel_ColorID::eColorID__moz_mac_chrome_active,
                        "-moz-mac-chrome-inactive" => LookAndFeel_ColorID::eColorID__moz_mac_chrome_inactive,
                        "-moz-mac-defaultbuttontext" => LookAndFeel_ColorID::eColorID__moz_mac_defaultbuttontext,
                        "-moz-mac-focusring" => LookAndFeel_ColorID::eColorID__moz_mac_focusring,
                        "-moz-mac-menuselect" => LookAndFeel_ColorID::eColorID__moz_mac_menuselect,
                        "-moz-mac-menushadow" => LookAndFeel_ColorID::eColorID__moz_mac_menushadow,
                        "-moz-mac-menutextdisable" => LookAndFeel_ColorID::eColorID__moz_mac_menutextdisable,
                        "-moz-mac-menutextselect" => LookAndFeel_ColorID::eColorID__moz_mac_menutextselect,
                        "-moz-mac-disabledtoolbartext" => LookAndFeel_ColorID::eColorID__moz_mac_disabledtoolbartext,
                        "-moz-mac-secondaryhighlight" => LookAndFeel_ColorID::eColorID__moz_mac_secondaryhighlight,
                        "-moz-mac-vibrancy-light" => LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_light,
                        "-moz-mac-vibrancy-dark" => LookAndFeel_ColorID::eColorID__moz_mac_vibrancy_dark,
                        "-moz-mac-vibrant-titlebar-light" => LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_light,
                        "-moz-mac-vibrant-titlebar-dark" => LookAndFeel_ColorID::eColorID__moz_mac_vibrant_titlebar_dark,
                        "-moz-mac-menupopup" => LookAndFeel_ColorID::eColorID__moz_mac_menupopup,
                        "-moz-mac-menuitem" => LookAndFeel_ColorID::eColorID__moz_mac_menuitem,
                        "-moz-mac-active-menuitem" => LookAndFeel_ColorID::eColorID__moz_mac_active_menuitem,
                        "-moz-mac-source-list" => LookAndFeel_ColorID::eColorID__moz_mac_source_list,
                        "-moz-mac-source-list-selection" => LookAndFeel_ColorID::eColorID__moz_mac_source_list_selection,
                        "-moz-mac-active-source-list-selection" => LookAndFeel_ColorID::eColorID__moz_mac_active_source_list_selection,
                        "-moz-mac-tooltip" => LookAndFeel_ColorID::eColorID__moz_mac_tooltip,
                        "-moz-menuhover" => LookAndFeel_ColorID::eColorID__moz_menuhover,
                        "-moz-menuhovertext" => LookAndFeel_ColorID::eColorID__moz_menuhovertext,
                        "-moz-menubartext" => LookAndFeel_ColorID::eColorID__moz_menubartext,
                        "-moz-menubarhovertext" => LookAndFeel_ColorID::eColorID__moz_menubarhovertext,
                        "-moz-oddtreerow" => LookAndFeel_ColorID::eColorID__moz_oddtreerow,
                        "-moz-win-mediatext" => LookAndFeel_ColorID::eColorID__moz_win_mediatext,
                        "-moz-win-communicationstext" => LookAndFeel_ColorID::eColorID__moz_win_communicationstext,
                        "-moz-win-accentcolor" => LookAndFeel_ColorID::eColorID__moz_win_accentcolor,
                        "-moz-win-accentcolortext" => LookAndFeel_ColorID::eColorID__moz_win_accentcolortext,
                        "-moz-nativehyperlinktext" => LookAndFeel_ColorID::eColorID__moz_nativehyperlinktext,
                        "-moz-comboboxtext" => LookAndFeel_ColorID::eColorID__moz_comboboxtext,
                        "-moz-combobox" => LookAndFeel_ColorID::eColorID__moz_combobox,
                }
            }

            let ident = input.expect_ident().map_err(|_| ())?;
            color_name(ident).cloned().ok_or(())
        }
    }
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-width
    pub mod column_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::length::NonNegativeLengthOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::length::NonNegativeLengthOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Auto) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::Second(Auto) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::length::NonNegativeLengthOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnWidth)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-count
    pub mod column_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::PositiveIntegerOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::PositiveIntegerOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Auto) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::Second(Auto) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::PositiveIntegerOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnCount(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnCount);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnCount);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_count(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_count();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_count();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnCount)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-gap
    pub mod column_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::length::NonNegativeLengthOrNormal as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::length::NonNegativeLengthOrNormal as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Normal) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::length::NonNegativeLengthOrNormal::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnGap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnGap)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-fill
    pub mod column_fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "balance" => Balance,
                    "auto" => Auto,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Balance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Balance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Balance => computed_value::T::Balance,
                        SpecifiedValue::Auto => computed_value::T::Auto,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Balance => SpecifiedValue::Balance,
                        computed_value::T::Auto => SpecifiedValue::Auto,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnFill(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnFill);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnFill);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_fill(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_fill();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_fill();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnFill)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-width
    pub mod column_rule_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Medium }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnRuleWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleWidth)
        }
    }



// https://drafts.csswg.org/css-multicol-1/#crc

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-color
    pub mod column_rule_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnRuleColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleColor)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-span
    pub mod column_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "all" => All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::All => computed_value::T::All,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::All => SpecifiedValue::All,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnSpan(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnSpan);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnSpan);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_span(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_span();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_span();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnSpan)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-style
    pub mod column_rule_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "hidden" => Hidden,
                    "dotted" => Dotted,
                    "dashed" => Dashed,
                    "solid" => Solid,
                    "double" => Double,
                    "groove" => Groove,
                    "ridge" => Ridge,
                    "inset" => Inset,
                    "outset" => Outset,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Hidden => computed_value::T::Hidden,
                        SpecifiedValue::Dotted => computed_value::T::Dotted,
                        SpecifiedValue::Dashed => computed_value::T::Dashed,
                        SpecifiedValue::Solid => computed_value::T::Solid,
                        SpecifiedValue::Double => computed_value::T::Double,
                        SpecifiedValue::Groove => computed_value::T::Groove,
                        SpecifiedValue::Ridge => computed_value::T::Ridge,
                        SpecifiedValue::Inset => computed_value::T::Inset,
                        SpecifiedValue::Outset => computed_value::T::Outset,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Hidden => SpecifiedValue::Hidden,
                        computed_value::T::Dotted => SpecifiedValue::Dotted,
                        computed_value::T::Dashed => SpecifiedValue::Dashed,
                        computed_value::T::Solid => SpecifiedValue::Solid,
                        computed_value::T::Double => SpecifiedValue::Double,
                        computed_value::T::Groove => SpecifiedValue::Groove,
                        computed_value::T::Ridge => SpecifiedValue::Ridge,
                        computed_value::T::Inset => SpecifiedValue::Inset,
                        computed_value::T::Outset => SpecifiedValue::Outset,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColumnRuleStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColumnRuleStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ColumnRuleStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_column_rule_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_column_rule_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_column_rule_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleStyle)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    /// https://drafts.csswg.org/css-content/#propdef-content
    pub mod content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    #[cfg(feature = "gecko")]
    use values::generics::CounterStyleOrNone;
    #[cfg(feature = "gecko")]
    use values::specified::url::SpecifiedUrl;
    #[cfg(feature = "gecko")]
    use values::specified::Attr;

    #[cfg(feature = "servo")]
    use super::list_style_type;

    pub use self::computed_value::T as SpecifiedValue;
    pub use self::computed_value::ContentItem;

    pub mod computed_value {
        use cssparser;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        #[cfg(feature = "gecko")]
        use values::specified::url::SpecifiedUrl;

        #[cfg(feature = "servo")]
        type CounterStyleType = super::super::list_style_type::computed_value::T;
        #[cfg(feature = "gecko")]
        type CounterStyleType = ::values::generics::CounterStyleOrNone;

        #[cfg(feature = "gecko")]
        use values::specified::Attr;

        #[derive(Clone, Debug, Eq, MallocSizeOf, PartialEq, ToComputedValue)]
        pub enum ContentItem {
            /// Literal string content.
            String(String),
            /// `counter(name, style)`.
            Counter(String, CounterStyleType),
            /// `counters(name, separator, style)`.
            Counters(String, String, CounterStyleType),
            /// `open-quote`.
            OpenQuote,
            /// `close-quote`.
            CloseQuote,
            /// `no-open-quote`.
            NoOpenQuote,
            /// `no-close-quote`.
            NoCloseQuote,

                /// `attr([namespace? `|`]? ident)`
                Attr(Attr),
                /// `url(url)`
                Url(SpecifiedUrl),
        }

        impl ToCss for ContentItem {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                match *self {
                    ContentItem::String(ref s) => s.to_css(dest),
                    ContentItem::Counter(ref s, ref counter_style) => {
                        dest.write_str("counter(")?;
                        cssparser::serialize_identifier(&**s, dest)?;
                        dest.write_str(", ")?;
                        counter_style.to_css(dest)?;
                        dest.write_str(")")
                    }
                    ContentItem::Counters(ref s, ref separator, ref counter_style) => {
                        dest.write_str("counters(")?;
                        cssparser::serialize_identifier(&**s, dest)?;
                        dest.write_str(", ")?;
                        separator.to_css(dest)?;
                        dest.write_str(", ")?;
                        counter_style.to_css(dest)?;
                        dest.write_str(")")
                    }
                    ContentItem::OpenQuote => dest.write_str("open-quote"),
                    ContentItem::CloseQuote => dest.write_str("close-quote"),
                    ContentItem::NoOpenQuote => dest.write_str("no-open-quote"),
                    ContentItem::NoCloseQuote => dest.write_str("no-close-quote"),

                        ContentItem::Attr(ref attr) => {
                            attr.to_css(dest)
                        }
                        ContentItem::Url(ref url) => url.to_css(dest),
                }
            }
        }

        #[derive(Clone, Debug, Eq, MallocSizeOf, PartialEq, ToComputedValue)]
        pub enum T {
            Normal,
            None,
            #[cfg(feature = "gecko")]
            MozAltContent,
            Items(Vec<ContentItem>),
        }

        impl ToCss for T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                match *self {
                    T::Normal => dest.write_str("normal"),
                    T::None => dest.write_str("none"),
                        T::MozAltContent => dest.write_str("-moz-alt-content"),
                    T::Items(ref content) => {
                        let mut iter = content.iter();
                        iter.next().unwrap().to_css(dest)?;
                        for c in iter {
                            dest.write_str(" ")?;
                            c.to_css(dest)?;
                        }
                        Ok(())
                    }
                }
            }
        }
    }
    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        computed_value::T::Normal
    }

    #[cfg(feature = "servo")]
    fn parse_counter_style(context: &ParserContext, input: &mut Parser) -> list_style_type::computed_value::T {
        input.try(|input| {
            input.expect_comma()?;
            list_style_type::parse(context, input)
        }).unwrap_or(list_style_type::computed_value::T::Decimal)
    }

    #[cfg(feature = "gecko")]
    fn parse_counter_style(context: &ParserContext, input: &mut Parser) -> CounterStyleOrNone {
        input.try(|input| {
            input.expect_comma()?;
            CounterStyleOrNone::parse(context, input)
        }).unwrap_or(CounterStyleOrNone::decimal())
    }

    // normal | none | [ <string> | <counter> | open-quote | close-quote | no-open-quote |
    // no-close-quote ]+
    // TODO: <uri>, attr(<identifier>)
    pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
        if input.try(|input| input.expect_ident_matching("normal")).is_ok() {
            return Ok(SpecifiedValue::Normal)
        }
        if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(SpecifiedValue::None)
        }
            if input.try(|input| input.expect_ident_matching("-moz-alt-content")).is_ok() {
                return Ok(SpecifiedValue::MozAltContent)
            }

        let mut content = vec![];
        loop {
                if let Ok(mut url) = input.try(|i| SpecifiedUrl::parse(context, i)) {
                    url.build_image_value();
                    content.push(ContentItem::Url(url));
                    continue;
                }
            // FIXME: remove clone() when lifetimes are non-lexical
            match input.next().map(|t| t.clone()) {
                Ok(Token::QuotedString(ref value)) => {
                    content.push(ContentItem::String(value.as_ref().to_owned()))
                }
                Ok(Token::Function(ref name)) => {
                    let result = match_ignore_ascii_case! { &name,
                        "counter" => Some(input.parse_nested_block(|input| {
                            let name = input.expect_ident()?.as_ref().to_owned();
                            let style = parse_counter_style(context, input);
                            Ok(ContentItem::Counter(name, style))
                        })),
                        "counters" => Some(input.parse_nested_block(|input| {
                            let name = input.expect_ident()?.as_ref().to_owned();
                            input.expect_comma()?;
                            let separator = input.expect_string()?.as_ref().to_owned();
                            let style = parse_counter_style(context, input);
                            Ok(ContentItem::Counters(name, separator, style))
                        })),
                            "attr" => Some(input.parse_nested_block(|input| {
                                Ok(ContentItem::Attr(Attr::parse_function(context, input)?))
                            })),
                        _ => None
                    };
                    match result {
                        Some(result) => content.push(result?),
                        None => return Err(input.new_custom_error(
                            StyleParseErrorKind::UnexpectedFunction(name.clone())
                        ))
                    }
                }
                Ok(Token::Ident(ref ident)) => {
                    let valid = match_ignore_ascii_case! { &ident,
                        "open-quote" => { content.push(ContentItem::OpenQuote); true },
                        "close-quote" => { content.push(ContentItem::CloseQuote); true },
                        "no-open-quote" => { content.push(ContentItem::NoOpenQuote); true },
                        "no-close-quote" => { content.push(ContentItem::NoCloseQuote); true },

                        _ => false,
                    };
                    if !valid {
                        return Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent(ident.clone())))
                    }
                }
                Err(_) => break,
                Ok(t) => return Err(input.new_unexpected_token_error(t))
            }
        }
        if content.is_empty() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }
        Ok(SpecifiedValue::Items(content))
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Content(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Content);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Content);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Content)
        }
    }



    
    /// https://drafts.csswg.org/css-lists/#propdef-counter-increment
    pub mod counter_increment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    use std::fmt::{self, Write};
    use style_traits::{CssWriter, ToCss};
    use values::CustomIdent;

    #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
    #[derive(Clone, Debug, PartialEq)]
    pub struct SpecifiedValue(pub Vec<(CustomIdent, specified::Integer)>);

    pub mod computed_value {
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, ToCss};
        use values::CustomIdent;

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct T(pub Vec<(CustomIdent, i32)>);

        impl ToCss for T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                if self.0.is_empty() {
                    return dest.write_str("none")
                }

                let mut first = true;
                for &(ref name, value) in &self.0 {
                    if !first {
                        dest.write_str(" ")?;
                    }
                    first = false;
                    name.to_css(dest)?;
                    dest.write_str(" ")?;
                    value.to_css(dest)?;
                }
                Ok(())
            }
        }
    }

    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        fn to_computed_value(&self, context: &Context) -> Self::ComputedValue {
            computed_value::T(self.0.iter().map(|&(ref name, ref value)| {
                (name.clone(), value.to_computed_value(context))
            }).collect::<Vec<_>>())
        }

        fn from_computed_value(computed: &Self::ComputedValue) -> Self {
            SpecifiedValue(computed.0.iter().map(|&(ref name, ref value)| {
                (name.clone(), specified::Integer::from_computed_value(&value))
            }).collect::<Vec<_>>())
        }
    }

    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        computed_value::T(Vec::new())
    }

    impl ToCss for SpecifiedValue {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
        where
            W: Write,
        {
            if self.0.is_empty() {
                return dest.write_str("none");
            }
            let mut first = true;
            for &(ref name, ref value) in &self.0 {
                if !first {
                    dest.write_str(" ")?;
                }
                first = false;
                name.to_css(dest)?;
                dest.write_str(" ")?;
                value.to_css(dest)?;
            }

            Ok(())
        }
    }

    pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
        parse_common(context, 1, input)
    }

    pub fn parse_common<'i, 't>(context: &ParserContext, default_value: i32, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
        if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(SpecifiedValue(Vec::new()))
        }

        let mut counters = Vec::new();
        loop {
            let location = input.current_source_location();
            let counter_name = match input.next() {
                Ok(&Token::Ident(ref ident)) => CustomIdent::from_ident(location, ident, &["none"])?,
                Ok(t) => return Err(location.new_unexpected_token_error(t.clone())),
                Err(_) => break,
            };
            let counter_delta = input.try(|input| specified::Integer::parse(context, input))
                                     .unwrap_or(specified::Integer::new(default_value));
            counters.push((counter_name, counter_delta))
        }

        if !counters.is_empty() {
            Ok(SpecifiedValue(counters))
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CounterIncrement(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::CounterIncrement);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::CounterIncrement);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_counter_increment(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_counter_increment();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_counter_increment();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterIncrement)
        }
    }



    
    /// https://drafts.csswg.org/css-lists-3/#propdef-counter-reset
    pub mod counter_reset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    pub use super::counter_increment::{SpecifiedValue, computed_value, get_initial_value};
    use super::counter_increment::parse_common;

    pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue,ParseError<'i>> {
        parse_common(context, 0, input)
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CounterReset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::CounterReset);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::CounterReset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_counter_reset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_counter_reset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_counter_reset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterReset)
        }
    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// Box-shadow, etc.



    
        
    
    /// https://drafts.csswg.org/css-color/#opacity
    pub mod opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Opacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Opacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Opacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Opacity)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#box-shadow
    pub mod box_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BoxShadow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BoxShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BoxShadow::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for box-shadow.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of box-shadow.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BoxShadow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxShadow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_effects();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_box_shadow(iter);
                        }
                        context.builder.put_effects(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_shadow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxShadow)
        }
    }





    
        
    
    /// https://drafts.fxtf.org/css-masking/#clip-property
    pub mod clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ClipRectOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ClipRectOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ClipRectOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ClipRectOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Clip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Clip);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Clip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_clip(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Clip)
        }
    }




    
        
    
    
    /// https://drafts.fxtf.org/filters/#propdef-filter
    pub mod filter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Filter as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Filter as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Filter::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for filter.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Space::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of filter.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Space::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Space::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Filter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Filter);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Filter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_effects();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_filter(iter);
                        }
                        context.builder.put_effects(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_filter();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_filter();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Filter)
        }
    }





    
    

    
        
    
    /// https://drafts.fxtf.org/compositing/#propdef-mix-blend-mode
    pub mod mix_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "multiply" => Multiply,
                    "screen" => Screen,
                    "overlay" => Overlay,
                    "darken" => Darken,
                    "lighten" => Lighten,
                    "color-dodge" => ColorDodge,
                    "color-burn" => ColorBurn,
                    "hard-light" => HardLight,
                    "soft-light" => SoftLight,
                    "difference" => Difference,
                    "exclusion" => Exclusion,
                    "hue" => Hue,
                    "saturation" => Saturation,
                    "color" => Color,
                    "luminosity" => Luminosity,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Multiply => computed_value::T::Multiply,
                        SpecifiedValue::Screen => computed_value::T::Screen,
                        SpecifiedValue::Overlay => computed_value::T::Overlay,
                        SpecifiedValue::Darken => computed_value::T::Darken,
                        SpecifiedValue::Lighten => computed_value::T::Lighten,
                        SpecifiedValue::ColorDodge => computed_value::T::ColorDodge,
                        SpecifiedValue::ColorBurn => computed_value::T::ColorBurn,
                        SpecifiedValue::HardLight => computed_value::T::HardLight,
                        SpecifiedValue::SoftLight => computed_value::T::SoftLight,
                        SpecifiedValue::Difference => computed_value::T::Difference,
                        SpecifiedValue::Exclusion => computed_value::T::Exclusion,
                        SpecifiedValue::Hue => computed_value::T::Hue,
                        SpecifiedValue::Saturation => computed_value::T::Saturation,
                        SpecifiedValue::Color => computed_value::T::Color,
                        SpecifiedValue::Luminosity => computed_value::T::Luminosity,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Multiply => SpecifiedValue::Multiply,
                        computed_value::T::Screen => SpecifiedValue::Screen,
                        computed_value::T::Overlay => SpecifiedValue::Overlay,
                        computed_value::T::Darken => SpecifiedValue::Darken,
                        computed_value::T::Lighten => SpecifiedValue::Lighten,
                        computed_value::T::ColorDodge => SpecifiedValue::ColorDodge,
                        computed_value::T::ColorBurn => SpecifiedValue::ColorBurn,
                        computed_value::T::HardLight => SpecifiedValue::HardLight,
                        computed_value::T::SoftLight => SpecifiedValue::SoftLight,
                        computed_value::T::Difference => SpecifiedValue::Difference,
                        computed_value::T::Exclusion => SpecifiedValue::Exclusion,
                        computed_value::T::Hue => SpecifiedValue::Hue,
                        computed_value::T::Saturation => SpecifiedValue::Saturation,
                        computed_value::T::Color => SpecifiedValue::Color,
                        computed_value::T::Luminosity => SpecifiedValue::Luminosity,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MixBlendMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MixBlendMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MixBlendMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mix_blend_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mix_blend_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mix_blend_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MixBlendMode)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-family
    pub mod font_family {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontFamily as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontFamily as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFamily::serif() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontFamily::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontFamily(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontFamily);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_family(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_family();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_family();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontFamily)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-style
    pub mod font_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            use cssparser::Parser;
            use parser::{Parse, ParserContext};

            use style_traits::ParseError;
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "italic" => Italic,
                    "oblique" => Oblique,
            }

            impl Parse for T {
                fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                    T::parse(input)
                }
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_STYLE_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const ITALIC: i32
                    = structs::NS_FONT_STYLE_ITALIC as i32;
                // We can't match on enum values if we're matching on a u32
                const OBLIQUE: i32
                    = structs::NS_FONT_STYLE_OBLIQUE as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    ITALIC => T::Italic,
                    OBLIQUE => T::Oblique,
                _ => panic!("Found unexpected value in style struct for font-style property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_style
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_style();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStyle)
        }
    }







    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-caps
    pub mod font_variant_caps {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            use cssparser::Parser;
            use parser::{Parse, ParserContext};

            use style_traits::ParseError;
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "small-caps" => SmallCaps,
                    "all-small-caps" => AllSmallCaps,
                    "petite-caps" => PetiteCaps,
                    "all-petite-caps" => AllPetiteCaps,
                    "unicase" => Unicase,
                    "titling-caps" => TitlingCaps,
            }

            impl Parse for T {
                fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                    T::parse(input)
                }
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_VARIANT_CAPS_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const SMALL_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_SMALLCAPS as i32;
                // We can't match on enum values if we're matching on a u32
                const ALL_SMALL_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_ALLSMALL as i32;
                // We can't match on enum values if we're matching on a u32
                const PETITE_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_PETITECAPS as i32;
                // We can't match on enum values if we're matching on a u32
                const ALL_PETITE_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_ALLPETITE as i32;
                // We can't match on enum values if we're matching on a u32
                const UNICASE: i32
                    = structs::NS_FONT_VARIANT_CAPS_UNICASE as i32;
                // We can't match on enum values if we're matching on a u32
                const TITLING_CAPS: i32
                    = structs::NS_FONT_VARIANT_CAPS_TITLING as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    SMALL_CAPS => T::SmallCaps,
                    ALL_SMALL_CAPS => T::AllSmallCaps,
                    PETITE_CAPS => T::PetiteCaps,
                    ALL_PETITE_CAPS => T::AllPetiteCaps,
                    UNICASE => T::Unicase,
                    TITLING_CAPS => T::TitlingCaps,
                _ => panic!("Found unexpected value in style struct for font-variant-caps property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_variant_caps
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantCaps(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantCaps);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_caps(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_caps();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_caps();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantCaps)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-weight
    pub mod font_weight {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontWeight as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontWeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontWeight::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontWeight::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontWeight::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontWeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontWeight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_weight(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_weight();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_weight();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontWeight)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size
    pub mod font_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSize::medium() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSize::medium() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSize::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                             specified::FontSize::cascade_specified_font_size(
                                 context,
                                 &specified_value,
                                 computed,
                             );
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            computed::FontSize::cascade_initial_font_size(context);
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            computed::FontSize::cascade_inherit_font_size(context);
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size-adjust
    pub mod font_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSizeAdjust as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSizeAdjust as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSizeAdjust::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSizeAdjust::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSizeAdjust::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSizeAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontSizeAdjust);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_size_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_size_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_size_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSizeAdjust)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-synthesis
    pub mod font_synthesis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::FontSynthesis::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSynthesis::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontSynthesis(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontSynthesis);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_synthesis(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_synthesis();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_synthesis();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesis)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-stretch
    pub mod font_stretch {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            use cssparser::Parser;
            use parser::{Parse, ParserContext};

            use style_traits::ParseError;
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "ultra-condensed" => UltraCondensed,
                    "extra-condensed" => ExtraCondensed,
                    "condensed" => Condensed,
                    "semi-condensed" => SemiCondensed,
                    "semi-expanded" => SemiExpanded,
                    "expanded" => Expanded,
                    "extra-expanded" => ExtraExpanded,
                    "ultra-expanded" => UltraExpanded,
            }

            impl Parse for T {
                fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                    T::parse(input)
                }
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_STRETCH_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const ULTRA_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_ULTRA_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXTRA_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_EXTRA_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const CONDENSED: i32
                    = structs::NS_FONT_STRETCH_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const SEMI_CONDENSED: i32
                    = structs::NS_FONT_STRETCH_SEMI_CONDENSED as i32;
                // We can't match on enum values if we're matching on a u32
                const SEMI_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_SEMI_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXPANDED: i32
                    = structs::NS_FONT_STRETCH_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const EXTRA_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_EXTRA_EXPANDED as i32;
                // We can't match on enum values if we're matching on a u32
                const ULTRA_EXPANDED: i32
                    = structs::NS_FONT_STRETCH_ULTRA_EXPANDED as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    ULTRA_CONDENSED => T::UltraCondensed,
                    EXTRA_CONDENSED => T::ExtraCondensed,
                    CONDENSED => T::Condensed,
                    SEMI_CONDENSED => T::SemiCondensed,
                    SEMI_EXPANDED => T::SemiExpanded,
                    EXPANDED => T::Expanded,
                    EXTRA_EXPANDED => T::ExtraExpanded,
                    ULTRA_EXPANDED => T::UltraExpanded,
                _ => panic!("Found unexpected value in style struct for font-stretch property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_stretch
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontStretch(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontStretch);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_stretch(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_stretch();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_stretch();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStretch)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-kerning
    pub mod font_kerning {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            use cssparser::Parser;
            use parser::{Parse, ParserContext};

            use style_traits::ParseError;
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "none" => None,
                    "normal" => Normal,
            }

            impl Parse for T {
                fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                    T::parse(input)
                }
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const AUTO: i32
                    = structs::NS_FONT_KERNING_AUTO as i32;
                // We can't match on enum values if we're matching on a u32
                const NONE: i32
                    = structs::NS_FONT_KERNING_NONE as i32;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_KERNING_NORMAL as i32;
            match kw as i32 {
                    AUTO => T::Auto,
                    NONE => T::None,
                    NORMAL => T::Normal,
                _ => panic!("Found unexpected value in style struct for font-kerning property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_kerning
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Auto)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontKerning(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontKerning);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_kerning(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_kerning();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_kerning();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontKerning)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-alternates
    pub mod font_variant_alternates {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantAlternates as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantAlternates as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantAlternates::get_initial_value() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantAlternates::get_initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantAlternates::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantAlternates(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantAlternates);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_alternates(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_alternates();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_alternates();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantAlternates)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-east-asian
    pub mod font_variant_east_asian {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantEastAsian as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantEastAsian as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantEastAsian::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantEastAsian::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantEastAsian::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantEastAsian(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantEastAsian);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_east_asian(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_east_asian();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_east_asian();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantEastAsian)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-ligatures
    pub mod font_variant_ligatures {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantLigatures as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantLigatures as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantLigatures::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantLigatures::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantLigatures::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantLigatures(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantLigatures);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_ligatures(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_ligatures();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_ligatures();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantLigatures)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-numeric
    pub mod font_variant_numeric {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantNumeric as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantNumeric as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantNumeric::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantNumeric::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantNumeric::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantNumeric(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantNumeric);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_numeric(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_numeric();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_numeric();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantNumeric)
        }
    }




    
    
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-position
    pub mod font_variant_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use properties::longhands::system_font::SystemFont;

        pub mod computed_value {
            use cssparser::Parser;
            use parser::{Parse, ParserContext};

            use style_traits::ParseError;
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "sub" => Sub,
                    "super" => Super,
            }

            impl Parse for T {
                fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                    T::parse(input)
                }
            }

            
    
    #[cfg(feature = "gecko")]
    impl T {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: i32
                    = structs::NS_FONT_VARIANT_POSITION_NORMAL as i32;
                // We can't match on enum values if we're matching on a u32
                const SUB: i32
                    = structs::NS_FONT_VARIANT_POSITION_SUB as i32;
                // We can't match on enum values if we're matching on a u32
                const SUPER_: i32
                    = structs::NS_FONT_VARIANT_POSITION_SUPER as i32;
            match kw as i32 {
                    NORMAL => T::Normal,
                    SUB => T::Sub,
                    SUPER_ => T::Super,
                _ => panic!("Found unexpected value in style struct for font-variant-position property"),
            }
        }
    }

        }

        #[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
        #[derive(Clone, Copy, Debug, Eq, PartialEq, ToCss)]
        pub enum SpecifiedValue {
            Keyword(computed_value::T),
            System(SystemFont),
        }

        pub fn parse<'i, 't>(_: &ParserContext, input: &mut Parser<'i, 't>) -> Result<SpecifiedValue, ParseError<'i>> {
            Ok(SpecifiedValue::Keyword(computed_value::T::parse(input)?))
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            fn to_computed_value(&self, _cx: &Context) -> Self::ComputedValue {
                match *self {
                    SpecifiedValue::Keyword(v) => v,
                    SpecifiedValue::System(_) => {
                            _cx.cached_system_font.as_ref().unwrap().font_variant_position
                    }
                }
            }
            fn from_computed_value(other: &computed_value::T) -> Self {
                SpecifiedValue::Keyword(*other)
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Keyword(computed_value::T::Normal)
        }

        impl SpecifiedValue {
            pub fn system_font(f: SystemFont) -> Self {
                SpecifiedValue::System(f)
            }
            pub fn get_system(&self) -> Option<SystemFont> {
                if let SpecifiedValue::System(s) = *self {
                    Some(s)
                } else {
                    None
                }
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariantPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariantPosition);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variant_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variant_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variant_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantPosition)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-feature-settings
    pub mod font_feature_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontFeatureSettings as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontFeatureSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFeatureSettings::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontFeatureSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontFeatureSettings::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontFeatureSettings(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontFeatureSettings);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_font_feature_settings(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_feature_settings();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_feature_settings();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::FontFeatureSettings)
        }
    }






    
        
    
    /// ${variation_spec}
    pub mod font_variation_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontVariantSettings as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontVariantSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::FontVariantSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontVariantSettings::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontVariationSettings(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontVariationSettings);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_variation_settings(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_variation_settings();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_variation_settings();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariationSettings)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-language-override
    pub mod font_language_override {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::FontLanguageOverride as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::FontLanguageOverride as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontLanguageOverride::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontLanguageOverride::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontLanguageOverride::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FontLanguageOverride(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FontLanguageOverride);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        if let Some(sf) = specified_value.get_system() {
                            longhands::system_font::resolve_system_font(sf, context);
                        }
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_font_language_override(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_font_language_override();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_font_language_override();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontLanguageOverride)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_lang {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XLang as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XLang as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XLang::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XLang::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XLang(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::XLang);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_lang(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_lang();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__x_lang();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XLang)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_size_multiplier {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptSizeMultiplier as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptSizeMultiplier as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozScriptSizeMultiplier::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptSizeMultiplier::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptSizeMultiplier(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozScriptSizeMultiplier);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_size_multiplier(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_size_multiplier();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_size_multiplier();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptSizeMultiplier)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_level {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptLevel as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptLevel as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptLevel::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptLevel(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozScriptLevel);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_level(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_level();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_level();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptLevel)
        }
    }




    
    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_math_display {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "inline" => Inline,
                    "block" => Block,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Inline
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Inline
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Inline => computed_value::T::Inline,
                        SpecifiedValue::Block => computed_value::T::Block,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Inline => SpecifiedValue::Inline,
                        computed_value::T::Block => SpecifiedValue::Block,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMathDisplay(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozMathDisplay);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_math_display(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_math_display();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_math_display();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMathDisplay)
        }
    }





    
    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_math_variant {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "normal" => Normal,
                    "bold" => Bold,
                    "italic" => Italic,
                    "bold-italic" => BoldItalic,
                    "script" => Script,
                    "bold-script" => BoldScript,
                    "fraktur" => Fraktur,
                    "double-struck" => DoubleStruck,
                    "bold-fraktur" => BoldFraktur,
                    "sans-serif" => SansSerif,
                    "bold-sans-serif" => BoldSansSerif,
                    "sans-serif-italic" => SansSerifItalic,
                    "sans-serif-bold-italic" => SansSerifBoldItalic,
                    "monospace" => Monospace,
                    "initial" => Initial,
                    "tailed" => Tailed,
                    "looped" => Looped,
                    "stretched" => Stretched,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::NS_MATHML_MATHVARIANT_NONE as u32;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::NS_MATHML_MATHVARIANT_NORMAL as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD as u32;
                // We can't match on enum values if we're matching on a u32
                const ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const SCRIPT: u32
                    = structs::NS_MATHML_MATHVARIANT_SCRIPT as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SCRIPT: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_SCRIPT as u32;
                // We can't match on enum values if we're matching on a u32
                const FRAKTUR: u32
                    = structs::NS_MATHML_MATHVARIANT_FRAKTUR as u32;
                // We can't match on enum values if we're matching on a u32
                const DOUBLE_STRUCK: u32
                    = structs::NS_MATHML_MATHVARIANT_DOUBLE_STRUCK as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_FRAKTUR: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_FRAKTUR as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SANS_SERIF: u32
                    = structs::NS_MATHML_MATHVARIANT_BOLD_SANS_SERIF as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_BOLD_ITALIC: u32
                    = structs::NS_MATHML_MATHVARIANT_SANS_SERIF_BOLD_ITALIC as u32;
                // We can't match on enum values if we're matching on a u32
                const MONOSPACE: u32
                    = structs::NS_MATHML_MATHVARIANT_MONOSPACE as u32;
                // We can't match on enum values if we're matching on a u32
                const INITIAL: u32
                    = structs::NS_MATHML_MATHVARIANT_INITIAL as u32;
                // We can't match on enum values if we're matching on a u32
                const TAILED: u32
                    = structs::NS_MATHML_MATHVARIANT_TAILED as u32;
                // We can't match on enum values if we're matching on a u32
                const LOOPED: u32
                    = structs::NS_MATHML_MATHVARIANT_LOOPED as u32;
                // We can't match on enum values if we're matching on a u32
                const STRETCHED: u32
                    = structs::NS_MATHML_MATHVARIANT_STRETCHED as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    NORMAL => SpecifiedValue::Normal,
                    BOLD => SpecifiedValue::Bold,
                    ITALIC => SpecifiedValue::Italic,
                    BOLD_ITALIC => SpecifiedValue::BoldItalic,
                    SCRIPT => SpecifiedValue::Script,
                    BOLD_SCRIPT => SpecifiedValue::BoldScript,
                    FRAKTUR => SpecifiedValue::Fraktur,
                    DOUBLE_STRUCK => SpecifiedValue::DoubleStruck,
                    BOLD_FRAKTUR => SpecifiedValue::BoldFraktur,
                    SANS_SERIF => SpecifiedValue::SansSerif,
                    BOLD_SANS_SERIF => SpecifiedValue::BoldSansSerif,
                    SANS_SERIF_ITALIC => SpecifiedValue::SansSerifItalic,
                    SANS_SERIF_BOLD_ITALIC => SpecifiedValue::SansSerifBoldItalic,
                    MONOSPACE => SpecifiedValue::Monospace,
                    INITIAL => SpecifiedValue::Initial,
                    TAILED => SpecifiedValue::Tailed,
                    LOOPED => SpecifiedValue::Looped,
                    STRETCHED => SpecifiedValue::Stretched,
                _ => panic!("Found unexpected value in style struct for -moz-math-variant property"),
            }
        }
    }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Bold => computed_value::T::Bold,
                        SpecifiedValue::Italic => computed_value::T::Italic,
                        SpecifiedValue::BoldItalic => computed_value::T::BoldItalic,
                        SpecifiedValue::Script => computed_value::T::Script,
                        SpecifiedValue::BoldScript => computed_value::T::BoldScript,
                        SpecifiedValue::Fraktur => computed_value::T::Fraktur,
                        SpecifiedValue::DoubleStruck => computed_value::T::DoubleStruck,
                        SpecifiedValue::BoldFraktur => computed_value::T::BoldFraktur,
                        SpecifiedValue::SansSerif => computed_value::T::SansSerif,
                        SpecifiedValue::BoldSansSerif => computed_value::T::BoldSansSerif,
                        SpecifiedValue::SansSerifItalic => computed_value::T::SansSerifItalic,
                        SpecifiedValue::SansSerifBoldItalic => computed_value::T::SansSerifBoldItalic,
                        SpecifiedValue::Monospace => computed_value::T::Monospace,
                        SpecifiedValue::Initial => computed_value::T::Initial,
                        SpecifiedValue::Tailed => computed_value::T::Tailed,
                        SpecifiedValue::Looped => computed_value::T::Looped,
                        SpecifiedValue::Stretched => computed_value::T::Stretched,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Bold => SpecifiedValue::Bold,
                        computed_value::T::Italic => SpecifiedValue::Italic,
                        computed_value::T::BoldItalic => SpecifiedValue::BoldItalic,
                        computed_value::T::Script => SpecifiedValue::Script,
                        computed_value::T::BoldScript => SpecifiedValue::BoldScript,
                        computed_value::T::Fraktur => SpecifiedValue::Fraktur,
                        computed_value::T::DoubleStruck => SpecifiedValue::DoubleStruck,
                        computed_value::T::BoldFraktur => SpecifiedValue::BoldFraktur,
                        computed_value::T::SansSerif => SpecifiedValue::SansSerif,
                        computed_value::T::BoldSansSerif => SpecifiedValue::BoldSansSerif,
                        computed_value::T::SansSerifItalic => SpecifiedValue::SansSerifItalic,
                        computed_value::T::SansSerifBoldItalic => SpecifiedValue::SansSerifBoldItalic,
                        computed_value::T::Monospace => SpecifiedValue::Monospace,
                        computed_value::T::Initial => SpecifiedValue::Initial,
                        computed_value::T::Tailed => SpecifiedValue::Tailed,
                        computed_value::T::Looped => SpecifiedValue::Looped,
                        computed_value::T::Stretched => SpecifiedValue::Stretched,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMathVariant(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozMathVariant);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_math_variant(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_math_variant();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_math_variant();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMathVariant)
        }
    }





    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_script_min_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozScriptMinSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozScriptMinSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::MozScriptMinSize::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozScriptMinSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozScriptMinSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozScriptMinSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_script_min_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_script_min_size();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_script_min_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozScriptMinSize)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_text_zoom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XTextZoom as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XTextZoom as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XTextZoom(true) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XTextZoom::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XTextZoom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::XTextZoom);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_text_zoom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_text_zoom();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__x_text_zoom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XTextZoom)
        }
    }



    pub mod system_font {
        //! We deal with system fonts here
        //!
        //! System fonts can only be set as a group via the font shorthand.
        //! They resolve at compute time (not parse time -- this lets the
        //! browser respond to changes to the OS font settings).
        //!
        //! While Gecko handles these as a separate property and keyword
        //! values on each property indicating that the font should be picked
        //! from the -x-system-font property, we avoid this. Instead,
        //! each font longhand has a special SystemFont variant which contains
        //! the specified system font. When the cascade function (in helpers)
        //! detects that a value has a system font, it will resolve it, and
        //! cache it on the ComputedValues. After this, it can be just fetched
        //! whenever a font longhand on the same element needs the system font.

        use app_units::Au;
        use cssparser::{Parser, ToCss};
        use gecko_bindings::structs::FontFamilyType;
        use properties::longhands;
        use std::fmt;
        use std::hash::{Hash, Hasher};
        use style_traits::ParseError;
        use values::computed::{ToComputedValue, Context};

        
        #[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, PartialEq, ToCss)]
        pub enum SystemFont {
                Caption,
                Icon,
                Menu,
                MessageBox,
                SmallCaption,
                StatusBar,
                MozWindow,
                MozDocument,
                MozWorkspace,
                MozDesktop,
                MozInfo,
                MozDialog,
                MozButton,
                MozPullDownMenu,
                MozList,
                MozField,
        }

        // ComputedValues are compared at times
        // so we need these impls. We don't want to
        // add Eq to Number (which contains a float)
        // so instead we have an eq impl which skips the
        // cached values
        impl PartialEq for ComputedSystemFont {
            fn eq(&self, other: &Self) -> bool {
                self.system_font == other.system_font
            }
        }
        impl Eq for ComputedSystemFont {}

        impl Hash for ComputedSystemFont {
            fn hash<H: Hasher>(&self, hasher: &mut H) {
                self.system_font.hash(hasher)
            }
        }

        impl ToComputedValue for SystemFont {
            type ComputedValue = ComputedSystemFont;

            fn to_computed_value(&self, cx: &Context) -> Self::ComputedValue {
                use gecko_bindings::bindings;
                use gecko_bindings::structs::{LookAndFeel_FontID, nsFont};
                use std::mem;
                use values::computed::font::{FontSize, FontFamilyList};

                let id = match *self {
                        SystemFont::Caption => {
                            LookAndFeel_FontID::eFont_Caption
                        }
                        SystemFont::Icon => {
                            LookAndFeel_FontID::eFont_Icon
                        }
                        SystemFont::Menu => {
                            LookAndFeel_FontID::eFont_Menu
                        }
                        SystemFont::MessageBox => {
                            LookAndFeel_FontID::eFont_MessageBox
                        }
                        SystemFont::SmallCaption => {
                            LookAndFeel_FontID::eFont_SmallCaption
                        }
                        SystemFont::StatusBar => {
                            LookAndFeel_FontID::eFont_StatusBar
                        }
                        SystemFont::MozWindow => {
                            LookAndFeel_FontID::eFont_Window
                        }
                        SystemFont::MozDocument => {
                            LookAndFeel_FontID::eFont_Document
                        }
                        SystemFont::MozWorkspace => {
                            LookAndFeel_FontID::eFont_Workspace
                        }
                        SystemFont::MozDesktop => {
                            LookAndFeel_FontID::eFont_Desktop
                        }
                        SystemFont::MozInfo => {
                            LookAndFeel_FontID::eFont_Info
                        }
                        SystemFont::MozDialog => {
                            LookAndFeel_FontID::eFont_Dialog
                        }
                        SystemFont::MozButton => {
                            LookAndFeel_FontID::eFont_Button
                        }
                        SystemFont::MozPullDownMenu => {
                            LookAndFeel_FontID::eFont_PullDownMenu
                        }
                        SystemFont::MozList => {
                            LookAndFeel_FontID::eFont_List
                        }
                        SystemFont::MozField => {
                            LookAndFeel_FontID::eFont_Field
                        }
                };

                let mut system: nsFont = unsafe { mem::uninitialized() };
                unsafe {
                    bindings::Gecko_nsFont_InitSystem(
                        &mut system,
                        id as i32,
                        cx.style().get_font().gecko(),
                        cx.device().pres_context()
                    )
                }
                let weight = longhands::font_weight::computed_value::T::from_gecko_weight(system.weight);
                let ret = ComputedSystemFont {
                    font_family: longhands::font_family::computed_value::T(
                        FontFamilyList(
                            unsafe { system.fontlist.mFontlist.mBasePtr.to_safe() }
                        )
                    ),
                    font_size: FontSize {
                            size: Au(system.size).into(),
                            keyword_info: None
                    },
                    font_weight: weight,
                    font_size_adjust: longhands::font_size_adjust::computed_value
                                               ::T::from_gecko_adjust(system.sizeAdjust),
                        font_style: longhands::font_style::computed_value::T::from_gecko_keyword(
                            system.style
                                as u32
                        ),
                        font_variant_caps: longhands::font_variant_caps::computed_value::T::from_gecko_keyword(
                            system.variantCaps
                                as u32
                        ),
                        font_stretch: longhands::font_stretch::computed_value::T::from_gecko_keyword(
                            system.stretch
                                as u32
                        ),
                        font_kerning: longhands::font_kerning::computed_value::T::from_gecko_keyword(
                            system.kerning
                                as u32
                        ),
                        font_variant_position: longhands::font_variant_position::computed_value::T::from_gecko_keyword(
                            system.variantPosition
                                as u32
                        ),
                        font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T::from_gecko_keyword(
                            system.variantLigatures
                        ),
                        font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T::from_gecko_keyword(
                            system.variantEastAsian
                        ),
                        font_variant_numeric: longhands::font_variant_numeric::computed_value::T::from_gecko_keyword(
                            system.variantNumeric
                        ),
                    font_language_override: longhands::font_language_override::computed_value
                                                     ::T(system.languageOverride),
                    font_feature_settings: longhands::font_feature_settings::get_initial_value(),
                    font_variant_alternates: longhands::font_variant_alternates::get_initial_value(),
                    system_font: *self,
                    default_font_type: system.fontlist.mDefaultFontType,
                };
                unsafe { bindings::Gecko_nsFont_Destroy(&mut system); }
                ret
            }

            fn from_computed_value(_: &ComputedSystemFont) -> Self {
                unreachable!()
            }
        }

        #[inline]
        /// Compute and cache a system font
        ///
        /// Must be called before attempting to compute a system font
        /// specified value
        pub fn resolve_system_font(system: SystemFont, context: &mut Context) {
            // Checking if context.cached_system_font.is_none() isn't enough,
            // if animating from one system font to another the cached system font
            // may change
            if Some(system) != context.cached_system_font.as_ref().map(|x| x.system_font) {
                let computed = system.to_computed_value(context);
                context.cached_system_font = Some(computed);
            }
        }

        #[derive(Clone, Debug)]
        pub struct ComputedSystemFont {
                pub font_family: longhands::font_family::computed_value::T,
                pub font_size: longhands::font_size::computed_value::T,
                pub font_style: longhands::font_style::computed_value::T,
                pub font_variant_caps: longhands::font_variant_caps::computed_value::T,
                pub font_stretch: longhands::font_stretch::computed_value::T,
                pub font_kerning: longhands::font_kerning::computed_value::T,
                pub font_variant_position: longhands::font_variant_position::computed_value::T,
                pub font_weight: longhands::font_weight::computed_value::T,
                pub font_size_adjust: longhands::font_size_adjust::computed_value::T,
                pub font_variant_alternates: longhands::font_variant_alternates::computed_value::T,
                pub font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T,
                pub font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T,
                pub font_variant_numeric: longhands::font_variant_numeric::computed_value::T,
                pub font_language_override: longhands::font_language_override::computed_value::T,
                pub font_feature_settings: longhands::font_feature_settings::computed_value::T,
            pub system_font: SystemFont,
            pub default_font_type: FontFamilyType,
        }

        impl SystemFont {
            pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
                try_match_ident_ignore_ascii_case! { input,
                        "caption" => Ok(SystemFont::Caption),
                        "icon" => Ok(SystemFont::Icon),
                        "menu" => Ok(SystemFont::Menu),
                        "message-box" => Ok(SystemFont::MessageBox),
                        "small-caption" => Ok(SystemFont::SmallCaption),
                        "status-bar" => Ok(SystemFont::StatusBar),
                        "-moz-window" => Ok(SystemFont::MozWindow),
                        "-moz-document" => Ok(SystemFont::MozDocument),
                        "-moz-workspace" => Ok(SystemFont::MozWorkspace),
                        "-moz-desktop" => Ok(SystemFont::MozDesktop),
                        "-moz-info" => Ok(SystemFont::MozInfo),
                        "-moz-dialog" => Ok(SystemFont::MozDialog),
                        "-moz-button" => Ok(SystemFont::MozButton),
                        "-moz-pull-down-menu" => Ok(SystemFont::MozPullDownMenu),
                        "-moz-list" => Ok(SystemFont::MozList),
                        "-moz-field" => Ok(SystemFont::MozField),
                }
            }
        }

        impl ToCss for SystemFont {
            fn to_css<W>(&self, dest: &mut W) -> fmt::Result where W: fmt::Write {
                // We may want to do something better in the future, see
                // w3c/csswg-drafts#1586.
                dest.write_str("-moz-use-system-font")
            }
        }
    }


    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/font-smooth)
    pub mod _moz_osx_font_smoothing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "grayscale" => Grayscale,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Grayscale => computed_value::T::Grayscale,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Grayscale => SpecifiedValue::Grayscale,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOsxFontSmoothing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOsxFontSmoothing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_osx_font_smoothing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_osx_font_smoothing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_osx_font_smoothing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOsxFontSmoothing)
        }
    }





    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_font_smoothing_background_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::transparent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozFontSmoothingBackgroundColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozFontSmoothingBackgroundColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_font_smoothing_background_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_font_smoothing_background_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_font_smoothing_background_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozFontSmoothingBackgroundColor)
        }
    }




    
        
    
    /// Nonstandard (Internal-only)
    pub mod _moz_min_font_size_ratio {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Percentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Percentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Percentage::hundred() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Percentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozMinFontSizeRatio(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozMinFontSizeRatio);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_min_font_size_ratio(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_min_font_size_ratio();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_min_font_size_ratio();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMinFontSizeRatio)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





// TODO: collapse. Well, do tables first.

    
    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-visibility
    pub mod visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "visible" => Visible,
                    "hidden" => Hidden,
                    "collapse" => Collapse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Visible => computed_value::T::Visible,
                        SpecifiedValue::Hidden => computed_value::T::Hidden,
                        SpecifiedValue::Collapse => computed_value::T::Collapse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Visible => SpecifiedValue::Visible,
                        computed_value::T::Hidden => SpecifiedValue::Hidden,
                        computed_value::T::Collapse => SpecifiedValue::Collapse,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Visibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Visibility);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_visibility();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Visibility)
        }
    }




// CSS Writing Modes Level 3
// https://drafts.csswg.org/css-writing-modes-3

    
    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-writing-mode
    pub mod writing_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "horizontal-tb" => HorizontalTb,
                        "vertical-rl" => VerticalRl,
                        "vertical-lr" => VerticalLr,
                        "sideways-rl" => SidewaysRl,
                        "sideways-lr" => SidewaysLr,
                }
                aliases {
                        "rl-tb" => HorizontalTb,
                        "lr" => HorizontalTb,
                        "rl" => HorizontalTb,
                        "lr-tb" => HorizontalTb,
                        "tb-rl" => VerticalRl,
                        "tb" => VerticalRl,
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "horizontal-tb" => HorizontalTb,
                    "vertical-rl" => VerticalRl,
                    "vertical-lr" => VerticalLr,
                    "sideways-rl" => SidewaysRl,
                    "sideways-lr" => SidewaysLr,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::HorizontalTb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::HorizontalTb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::HorizontalTb => computed_value::T::HorizontalTb,
                        SpecifiedValue::VerticalRl => computed_value::T::VerticalRl,
                        SpecifiedValue::VerticalLr => computed_value::T::VerticalLr,
                        SpecifiedValue::SidewaysRl => computed_value::T::SidewaysRl,
                        SpecifiedValue::SidewaysLr => computed_value::T::SidewaysLr,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::HorizontalTb => SpecifiedValue::HorizontalTb,
                        computed_value::T::VerticalRl => SpecifiedValue::VerticalRl,
                        computed_value::T::VerticalLr => SpecifiedValue::VerticalLr,
                        computed_value::T::SidewaysRl => SpecifiedValue::SidewaysRl,
                        computed_value::T::SidewaysLr => SpecifiedValue::SidewaysLr,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WritingMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WritingMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_writing_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_writing_mode();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_writing_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WritingMode)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-direction
    pub mod direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "ltr" => Ltr,
                    "rtl" => Rtl,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Ltr
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Ltr
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const LTR: u32
                    = structs::NS_STYLE_DIRECTION_LTR as u32;
                // We can't match on enum values if we're matching on a u32
                const RTL: u32
                    = structs::NS_STYLE_DIRECTION_RTL as u32;
            match kw  {
                    LTR => SpecifiedValue::Ltr,
                    RTL => SpecifiedValue::Rtl,
                _ => panic!("Found unexpected value in style struct for direction property"),
            }
        }
    }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Ltr => computed_value::T::Ltr,
                        SpecifiedValue::Rtl => computed_value::T::Rtl,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Ltr => SpecifiedValue::Ltr,
                        computed_value::T::Rtl => SpecifiedValue::Rtl,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Direction(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Direction);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_direction();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Direction)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-text-orientation
    pub mod text_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "mixed" => Mixed,
                        "upright" => Upright,
                        "sideways" => Sideways,
                }
                aliases {
                        "sideways-right" => Sideways,
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "mixed" => Mixed,
                    "upright" => Upright,
                    "sideways" => Sideways,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Mixed
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Mixed
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Mixed => computed_value::T::Mixed,
                        SpecifiedValue::Upright => computed_value::T::Upright,
                        SpecifiedValue::Sideways => computed_value::T::Sideways,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Mixed => SpecifiedValue::Mixed,
                        computed_value::T::Upright => SpecifiedValue::Upright,
                        computed_value::T::Sideways => SpecifiedValue::Sideways,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextOrientation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextOrientation);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_orientation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_orientation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_orientation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextOrientation)
        }
    }




// CSS Color Module Level 4
// https://drafts.csswg.org/css-color/

    
    

    
        
    
    /// https://drafts.csswg.org/css-color/#propdef-color-adjust
    pub mod color_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "economy" => Economy,
                    "exact" => Exact,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Economy
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Economy
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Economy => computed_value::T::Economy,
                        SpecifiedValue::Exact => computed_value::T::Exact,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Economy => SpecifiedValue::Economy,
                        computed_value::T::Exact => SpecifiedValue::Exact,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColorAdjust);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorAdjust)
        }
    }





// According to to CSS-IMAGES-3, `optimizespeed` and `optimizequality` are synonyms for `auto`
// And, firefox doesn't support `pixelated` yet (https://bugzilla.mozilla.org/show_bug.cgi?id=856337)

    
    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-rendering
    pub mod image_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "optimizespeed" => Optimizespeed,
                    "optimizequality" => Optimizequality,
                    "-moz-crisp-edges" => MozCrispEdges,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Optimizespeed => computed_value::T::Optimizespeed,
                        SpecifiedValue::Optimizequality => computed_value::T::Optimizequality,
                        SpecifiedValue::MozCrispEdges => computed_value::T::MozCrispEdges,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Optimizespeed => SpecifiedValue::Optimizespeed,
                        computed_value::T::Optimizequality => SpecifiedValue::Optimizequality,
                        computed_value::T::MozCrispEdges => SpecifiedValue::MozCrispEdges,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImageRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ImageRendering);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_image_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_image_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_image_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageRendering)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-orientation,                     /// additional values in https://developer.mozilla.org/en-US/docs/Web/CSS/image-orientation
    pub mod image_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageOrientation as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageOrientation as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ImageOrientation::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageOrientation::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImageOrientation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ImageOrientation);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_image_orientation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_image_orientation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_image_orientation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageOrientation)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-collapse
    pub mod border_collapse {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "separate" => Separate,
                    "collapse" => Collapse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Separate
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Separate
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Separate => computed_value::T::Separate,
                        SpecifiedValue::Collapse => computed_value::T::Collapse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Separate => SpecifiedValue::Separate,
                        computed_value::T::Collapse => SpecifiedValue::Collapse,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderCollapse(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderCollapse);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_border_collapse(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_collapse();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_border_collapse();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderCollapse)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-empty-cells
    pub mod empty_cells {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "show" => Show,
                    "hide" => Hide,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Show
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Show
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Show => computed_value::T::Show,
                        SpecifiedValue::Hide => computed_value::T::Hide,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Show => SpecifiedValue::Show,
                        computed_value::T::Hide => SpecifiedValue::Hide,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::EmptyCells(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::EmptyCells);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_empty_cells(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_empty_cells();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_empty_cells();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::EmptyCells)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-caption-side
    pub mod caption_side {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "top" => Top,
                    "bottom" => Bottom,
                    "right" => Right,
                    "left" => Left,
                    "top-outside" => TopOutside,
                    "bottom-outside" => BottomOutside,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Top
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Top
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const TOP: u32
                    = structs::NS_STYLE_CAPTION_SIDE_TOP as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTTOM: u32
                    = structs::NS_STYLE_CAPTION_SIDE_BOTTOM as u32;
                // We can't match on enum values if we're matching on a u32
                const RIGHT: u32
                    = structs::NS_STYLE_CAPTION_SIDE_RIGHT as u32;
                // We can't match on enum values if we're matching on a u32
                const LEFT: u32
                    = structs::NS_STYLE_CAPTION_SIDE_LEFT as u32;
                // We can't match on enum values if we're matching on a u32
                const TOP_OUTSIDE: u32
                    = structs::NS_STYLE_CAPTION_SIDE_TOP_OUTSIDE as u32;
                // We can't match on enum values if we're matching on a u32
                const BOTTOM_OUTSIDE: u32
                    = structs::NS_STYLE_CAPTION_SIDE_BOTTOM_OUTSIDE as u32;
            match kw  {
                    TOP => SpecifiedValue::Top,
                    BOTTOM => SpecifiedValue::Bottom,
                    RIGHT => SpecifiedValue::Right,
                    LEFT => SpecifiedValue::Left,
                    TOP_OUTSIDE => SpecifiedValue::TopOutside,
                    BOTTOM_OUTSIDE => SpecifiedValue::BottomOutside,
                _ => panic!("Found unexpected value in style struct for caption-side property"),
            }
        }
    }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Top => computed_value::T::Top,
                        SpecifiedValue::Bottom => computed_value::T::Bottom,
                        SpecifiedValue::Right => computed_value::T::Right,
                        SpecifiedValue::Left => computed_value::T::Left,
                        SpecifiedValue::TopOutside => computed_value::T::TopOutside,
                        SpecifiedValue::BottomOutside => computed_value::T::BottomOutside,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Top => SpecifiedValue::Top,
                        computed_value::T::Bottom => SpecifiedValue::Bottom,
                        computed_value::T::Right => SpecifiedValue::Right,
                        computed_value::T::Left => SpecifiedValue::Left,
                        computed_value::T::TopOutside => SpecifiedValue::TopOutside,
                        computed_value::T::BottomOutside => SpecifiedValue::BottomOutside,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CaptionSide(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::CaptionSide);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_caption_side(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_caption_side();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_caption_side();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaptionSide)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-spacing
    pub mod border_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderSpacing::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BorderSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BorderSpacing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_border_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_border_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_border_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderSpacing)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css2/visudet.html#propdef-line-height
    pub mod line_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LineHeight as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LineHeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LineHeight::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LineHeight::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LineHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::LineHeight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_line_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_line_height();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_line_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LineHeight)
        }
    }



// CSS Text Module Level 3

// TODO(pcwalton): `full-width`

    
    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-transform
    pub mod text_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "capitalize" => Capitalize,
                    "uppercase" => Uppercase,
                    "lowercase" => Lowercase,
                    "full-width" => FullWidth,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Capitalize => computed_value::T::Capitalize,
                        SpecifiedValue::Uppercase => computed_value::T::Uppercase,
                        SpecifiedValue::Lowercase => computed_value::T::Lowercase,
                        SpecifiedValue::FullWidth => computed_value::T::FullWidth,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Capitalize => SpecifiedValue::Capitalize,
                        computed_value::T::Uppercase => SpecifiedValue::Uppercase,
                        computed_value::T::Lowercase => SpecifiedValue::Lowercase,
                        computed_value::T::FullWidth => SpecifiedValue::FullWidth,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextTransform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextTransform);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_transform();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextTransform)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-hyphens
    pub mod hyphens {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "manual" => Manual,
                    "none" => None,
                    "auto" => Auto,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Manual
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Manual
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Manual => computed_value::T::Manual,
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Auto => computed_value::T::Auto,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Manual => SpecifiedValue::Manual,
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Auto => SpecifiedValue::Auto,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Hyphens(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Hyphens);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_hyphens(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_hyphens();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_hyphens();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Hyphens)
        }
    }




// TODO: Support <percentage>

    
    

    
        
    
    /// https://drafts.csswg.org/css-size-adjust/#adjustment-control
    pub mod _moz_text_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "none" => None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::None => computed_value::T::None,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::None => SpecifiedValue::None,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTextSizeAdjust(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozTextSizeAdjust);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_text_size_adjust(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_text_size_adjust();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_text_size_adjust();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTextSizeAdjust)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-indent
    pub mod text_indent {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextIndent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextIndent);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_indent(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_indent();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_indent();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextIndent)
        }
    }



// Also known as "word-wrap" (which is more popular because of IE), but this is the preferred
// name per CSS-TEXT 6.2.

    
    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-overflow-wrap
    pub mod overflow_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "break-word" => BreakWord,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::BreakWord => computed_value::T::BreakWord,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::BreakWord => SpecifiedValue::BreakWord,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OverflowWrap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OverflowWrap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_overflow_wrap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_overflow_wrap();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_overflow_wrap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowWrap)
        }
    }




// TODO(pcwalton): Support `word-break: keep-all` once we have better CJK support.

    
    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-break
    pub mod word_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "break-all" => BreakAll,
                    "keep-all" => KeepAll,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::BreakAll => computed_value::T::BreakAll,
                        SpecifiedValue::KeepAll => computed_value::T::KeepAll,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::BreakAll => SpecifiedValue::BreakAll,
                        computed_value::T::KeepAll => SpecifiedValue::KeepAll,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WordBreak(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WordBreak);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_word_break(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_word_break();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_word_break();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordBreak)
        }
    }




// TODO(pcwalton): Support `text-justify: distribute`.

    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-justify
    pub mod text_justify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "auto" => Auto,
                        "none" => None,
                        "inter-word" => InterWord,
                        "inter-character" => InterCharacter,
                        "distribute" => Distribute,
                }
                aliases {
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "none" => None,
                    "inter-word" => InterWord,
                    "inter-character" => InterCharacter,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            

    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, _: &Context) -> computed_value::T {
            match *self {
                    SpecifiedValue::Auto => computed_value::T::Auto,
                    SpecifiedValue::None => computed_value::T::None,
                    SpecifiedValue::InterWord => computed_value::T::InterWord,
                    SpecifiedValue::InterCharacter => computed_value::T::InterCharacter,
                    // https://drafts.csswg.org/css-text-3/#valdef-text-justify-distribute
                    SpecifiedValue::Distribute => computed_value::T::InterCharacter,
            }
        }

        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> SpecifiedValue {
            match *computed {
                    computed_value::T::Auto => SpecifiedValue::Auto,
                    computed_value::T::None => SpecifiedValue::None,
                    computed_value::T::InterWord => SpecifiedValue::InterWord,
                    computed_value::T::InterCharacter => SpecifiedValue::InterCharacter,
            }
        }
    }

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextJustify(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextJustify);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_justify(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_justify();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_justify();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextJustify)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align-last
    pub mod text_align_last {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "start" => Start,
                    "end" => End,
                    "left" => Left,
                    "right" => Right,
                    "center" => Center,
                    "justify" => Justify,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Start => computed_value::T::Start,
                        SpecifiedValue::End => computed_value::T::End,
                        SpecifiedValue::Left => computed_value::T::Left,
                        SpecifiedValue::Right => computed_value::T::Right,
                        SpecifiedValue::Center => computed_value::T::Center,
                        SpecifiedValue::Justify => computed_value::T::Justify,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Start => SpecifiedValue::Start,
                        computed_value::T::End => SpecifiedValue::End,
                        computed_value::T::Left => SpecifiedValue::Left,
                        computed_value::T::Right => SpecifiedValue::Right,
                        computed_value::T::Center => SpecifiedValue::Center,
                        computed_value::T::Justify => SpecifiedValue::Justify,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAlignLast(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextAlignLast);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_align_last(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_align_last();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_align_last();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlignLast)
        }
    }




// TODO make this a shorthand and implement text-align-last/text-align-all
//
// FIXME(emilio): This can't really be that complicated.

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align
    pub mod text_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextAlign as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextAlign::start() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextAlign::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextAlign);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_align();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-letter-spacing
    pub mod letter_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LetterSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LetterSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LetterSpacing::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LetterSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LetterSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::LetterSpacing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_letter_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_letter_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_letter_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LetterSpacing)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-spacing
    pub mod word_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::WordSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::WordSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WordSpacing::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::WordSpacing::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WordSpacing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WordSpacing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_word_spacing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_word_spacing();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_word_spacing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordSpacing)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-white-space
    pub mod white_space {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "pre" => Pre,
                    "nowrap" => Nowrap,
                    "pre-wrap" => PreWrap,
                    "pre-line" => PreLine,
                    "-moz-pre-space" => MozPreSpace,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::StyleWhiteSpace::Normal as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE: u32
                    = structs::StyleWhiteSpace::Pre as u32;
                // We can't match on enum values if we're matching on a u32
                const NOWRAP: u32
                    = structs::StyleWhiteSpace::Nowrap as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE_WRAP: u32
                    = structs::StyleWhiteSpace::PreWrap as u32;
                // We can't match on enum values if we're matching on a u32
                const PRE_LINE: u32
                    = structs::StyleWhiteSpace::PreLine as u32;
                // We can't match on enum values if we're matching on a u32
                const _MOZ_PRE_SPACE: u32
                    = structs::StyleWhiteSpace::PreSpace as u32;
            match kw  {
                    NORMAL => SpecifiedValue::Normal,
                    PRE => SpecifiedValue::Pre,
                    NOWRAP => SpecifiedValue::Nowrap,
                    PRE_WRAP => SpecifiedValue::PreWrap,
                    PRE_LINE => SpecifiedValue::PreLine,
                    _MOZ_PRE_SPACE => SpecifiedValue::MozPreSpace,
                _ => panic!("Found unexpected value in style struct for white-space property"),
            }
        }
    }

    
            
    trivial_to_computed_value!(SpecifiedValue);

        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WhiteSpace(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WhiteSpace);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_white_space(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_white_space();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_white_space();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WhiteSpace)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-text-decor-3/#text-shadow-property
    pub mod text_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SimpleShadow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SimpleShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SimpleShadow::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for text-shadow.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of text-shadow.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextShadow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_inheritedtext();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_text_shadow(iter);
                        }
                        context.builder.put_inheritedtext(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_shadow();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextShadow)
        }
    }





    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-style
    pub mod text_emphasis_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    use computed_values::writing_mode::T as WritingMode;
    use std::fmt::{self, Write};
    use style_traits::{CssWriter, ToCss};
    use unicode_segmentation::UnicodeSegmentation;


    pub mod computed_value {
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        #[cfg_attr(feature = "servo", derive(ToComputedValue))]
        pub enum T {
            Keyword(KeywordValue),
            None,
            String(String),
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct KeywordValue {
            pub fill: bool,
            pub shape: super::ShapeKeyword,
        }
    }

    #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
    pub enum SpecifiedValue {
        Keyword(KeywordValue),
        None,
        String(String),
    }

    #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
    pub enum KeywordValue {
        Fill(bool),
        Shape(ShapeKeyword),
        FillAndShape(bool, ShapeKeyword),
    }

    impl ToCss for KeywordValue {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if let Some(fill) = self.fill() {
                if fill {
                    dest.write_str("filled")?;
                } else {
                    dest.write_str("open")?;
                }
            }
            if let Some(shape) = self.shape() {
                if self.fill().is_some() {
                    dest.write_str(" ")?;
                }
                shape.to_css(dest)?;
            }
            Ok(())
        }
    }

    impl ToCss for computed_value::KeywordValue {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
        where
            W: Write,
        {
            if self.fill {
                dest.write_str("filled")?;
            } else {
                dest.write_str("open")?;
            }
            dest.write_str(" ")?;
            self.shape.to_css(dest)
        }
    }

    impl KeywordValue {
        fn fill(&self) -> Option<bool> {
            match *self {
                KeywordValue::Fill(fill) |
                KeywordValue::FillAndShape(fill,_) => Some(fill),
                _ => None,
            }
        }
        fn shape(&self) -> Option<ShapeKeyword> {
            match *self {
                KeywordValue::Shape(shape) |
                KeywordValue::FillAndShape(_, shape) => Some(shape),
                _ => None,
            }
        }
    }

    define_css_keyword_enum!(ShapeKeyword:
                             "dot" => Dot,
                             "circle" => Circle,
                             "double-circle" => DoubleCircle,
                             "triangle" => Triangle,
                             "sesame" => Sesame);

    impl ShapeKeyword {
        pub fn char(&self, fill: bool) -> &str {
            match *self {
                ShapeKeyword::Dot => if fill { "\u{2022}" } else { "\u{25e6}" },
                ShapeKeyword::Circle =>  if fill { "\u{25cf}" } else { "\u{25cb}" },
                ShapeKeyword::DoubleCircle =>  if fill { "\u{25c9}" } else { "\u{25ce}" },
                ShapeKeyword::Triangle =>  if fill { "\u{25b2}" } else { "\u{25b3}" },
                ShapeKeyword::Sesame =>  if fill { "\u{fe45}" } else { "\u{fe46}" },
            }
        }
    }

    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        computed_value::T::None
    }

    #[inline]
    pub fn get_initial_specified_value() -> SpecifiedValue {
        SpecifiedValue::None
    }

    impl ToComputedValue for SpecifiedValue {
        type ComputedValue = computed_value::T;

        #[inline]
        fn to_computed_value(&self, context: &Context) -> computed_value::T {
            match *self {
                SpecifiedValue::Keyword(ref keyword) => {
                    let default_shape = if context.style().get_inheritedbox()
                                                  .clone_writing_mode() == WritingMode::HorizontalTb {
                        ShapeKeyword::Circle
                    } else {
                        ShapeKeyword::Sesame
                    };
                    computed_value::T::Keyword(computed_value::KeywordValue {
                        fill: keyword.fill().unwrap_or(true),
                        shape: keyword.shape().unwrap_or(default_shape),
                    })
                },
                SpecifiedValue::None => computed_value::T::None,
                SpecifiedValue::String(ref s) => {
                    // Passing `true` to iterate over extended grapheme clusters, following
                    // recommendation at http://www.unicode.org/reports/tr29/#Grapheme_Cluster_Boundaries
                    let string = s.graphemes(true).next().unwrap_or("").to_string();
                    computed_value::T::String(string)
                }
            }
        }
        #[inline]
        fn from_computed_value(computed: &computed_value::T) -> Self {
            match *computed {
                computed_value::T::Keyword(ref keyword) =>
                    SpecifiedValue::Keyword(KeywordValue::FillAndShape(keyword.fill,keyword.shape)),
                computed_value::T::None => SpecifiedValue::None,
                computed_value::T::String(ref string) => SpecifiedValue::String(string.clone())
            }
        }
    }

    pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
        if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(SpecifiedValue::None);
        }

        if let Ok(s) = input.try(|i| i.expect_string().map(|s| s.as_ref().to_owned())) {
            // Handle <string>
            return Ok(SpecifiedValue::String(s));
        }

        // Handle a pair of keywords
        let mut shape = input.try(ShapeKeyword::parse);
        let fill = if input.try(|input| input.expect_ident_matching("filled")).is_ok() {
            Some(true)
        } else if input.try(|input| input.expect_ident_matching("open")).is_ok() {
            Some(false)
        } else { None };
        if shape.is_err() {
            shape = input.try(ShapeKeyword::parse);
        }

        // At least one of shape or fill must be handled
        let keyword_value = match (fill, shape) {
            (Some(fill), Ok(shape)) => KeywordValue::FillAndShape(fill,shape),
            (Some(fill), Err(_)) => KeywordValue::Fill(fill),
            (None, Ok(shape)) => KeywordValue::Shape(shape),
            _ => return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError)),
        };
        Ok(SpecifiedValue::Keyword(keyword_value))
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextEmphasisStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_text_emphasis_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_style();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TextEmphasisStyle)
        }
    }



    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-position
    pub mod text_emphasis_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    define_css_keyword_enum!(HorizontalWritingModeValue:
                             "over" => Over,
                             "under" => Under);
    add_impls_for_keyword_enum!(VerticalWritingModeValue);
    define_css_keyword_enum!(VerticalWritingModeValue:
                             "right" => Right,
                             "left" => Left);
    add_impls_for_keyword_enum!(HorizontalWritingModeValue);

    #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToComputedValue, ToCss)]
    pub struct SpecifiedValue(pub HorizontalWritingModeValue, pub VerticalWritingModeValue);

    pub mod computed_value {
        pub type T = super::SpecifiedValue;
    }

    pub fn get_initial_value() -> computed_value::T {
        SpecifiedValue(HorizontalWritingModeValue::Over, VerticalWritingModeValue::Right)
    }

    pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue, ParseError<'i>> {
       if let Ok(horizontal) = input.try(|input| HorizontalWritingModeValue::parse(input)) {
            let vertical = VerticalWritingModeValue::parse(input)?;
            Ok(SpecifiedValue(horizontal, vertical))
        } else {
            let vertical = VerticalWritingModeValue::parse(input)?;
            let horizontal = HorizontalWritingModeValue::parse(input)?;
            Ok(SpecifiedValue(horizontal, vertical))
        }
    }

        impl SpecifiedValue {
            pub fn from_gecko_keyword(kw: u32) -> Self {
                use gecko_bindings::structs;

                let vert = if kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_RIGHT != 0 {
                    VerticalWritingModeValue::Right
                } else {
                    debug_assert!(kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_LEFT != 0);
                    VerticalWritingModeValue::Left
                };
                let horiz = if kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_OVER != 0 {
                    HorizontalWritingModeValue::Over
                } else {
                    debug_assert!(kw & structs::NS_STYLE_TEXT_EMPHASIS_POSITION_UNDER != 0);
                    HorizontalWritingModeValue::Under
                };
                SpecifiedValue(horiz, vert)
            }
        }

        impl From<u8> for SpecifiedValue {
            fn from(bits: u8) -> SpecifiedValue {
                SpecifiedValue::from_gecko_keyword(bits as u32)
            }
        }

        impl From<SpecifiedValue> for u8 {
            fn from(v: SpecifiedValue) -> u8 {
                use gecko_bindings::structs;

                let mut result = match v.0 {
                    HorizontalWritingModeValue::Over => structs::NS_STYLE_TEXT_EMPHASIS_POSITION_OVER,
                    HorizontalWritingModeValue::Under => structs::NS_STYLE_TEXT_EMPHASIS_POSITION_UNDER,
                };
                match v.1 {
                    VerticalWritingModeValue::Right => {
                        result |= structs::NS_STYLE_TEXT_EMPHASIS_POSITION_RIGHT;
                    }
                    VerticalWritingModeValue::Left => {
                        result |= structs::NS_STYLE_TEXT_EMPHASIS_POSITION_LEFT;
                    }
                };
                result as u8
            }
        }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextEmphasisPosition);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_emphasis_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisPosition)
        }
    }



    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-color
    pub mod text_emphasis_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextEmphasisColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextEmphasisColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_emphasis_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_emphasis_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_emphasis_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-3/#tab-size-property
    pub mod _moz_tab_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::length::NonNegativeLengthOrNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::length::NonNegativeLengthOrNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::Either::Second(From::from(8.0)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::length::NonNegativeLengthOrNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozTabSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozTabSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_tab_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_tab_size();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_tab_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTabSize)
        }
    }




// CSS Compatibility
// https://compat.spec.whatwg.org

    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-fill-color
    pub mod _webkit_text_fill_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextFillColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WebkitTextFillColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_fill_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_fill_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_fill_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextFillColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-color
    pub mod _webkit_text_stroke_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WebkitTextStrokeColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_stroke_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_stroke_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_stroke_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-width
    pub mod _webkit_text_stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(0.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Length(specified::Length::zero()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::WebkitTextStrokeWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__webkit_text_stroke_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__webkit_text_stroke_width();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__webkit_text_stroke_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeWidth)
        }
    }



// CSS Ruby Layout Module Level 1
// https://drafts.csswg.org/css-ruby/

    
    

    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-align-property
    pub mod ruby_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "space-around" => SpaceAround,
                    "start" => Start,
                    "center" => Center,
                    "space-between" => SpaceBetween,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::SpaceAround
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::SpaceAround
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::SpaceAround => computed_value::T::SpaceAround,
                        SpecifiedValue::Start => computed_value::T::Start,
                        SpecifiedValue::Center => computed_value::T::Center,
                        SpecifiedValue::SpaceBetween => computed_value::T::SpaceBetween,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::SpaceAround => SpecifiedValue::SpaceAround,
                        computed_value::T::Start => SpecifiedValue::Start,
                        computed_value::T::Center => SpecifiedValue::Center,
                        computed_value::T::SpaceBetween => SpecifiedValue::SpaceBetween,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::RubyAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::RubyAlign);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ruby_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ruby_align();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_ruby_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyAlign)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-position-property
    pub mod ruby_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "over" => Over,
                    "under" => Under,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Over
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Over
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Over => computed_value::T::Over,
                        SpecifiedValue::Under => computed_value::T::Under,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Over => SpecifiedValue::Over,
                        computed_value::T::Under => SpecifiedValue::Under,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::RubyPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::RubyPosition);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ruby_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ruby_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_ruby_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyPosition)
        }
    }




// CSS Writing Modes Module Level 3
// https://drafts.csswg.org/css-writing-modes-3/


    
    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes-3/#text-combine-upright
    pub mod text_combine_upright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "all" => All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::All => computed_value::T::All,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::All => SpecifiedValue::All,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextCombineUpright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextCombineUpright);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_combine_upright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_combine_upright();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_combine_upright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextCombineUpright)
        }
    }




// SVG 1.1: Section 11 - Painting: Filling, Stroking and Marker Symbols

    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#TextRenderingProperty
    pub mod text_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "optimizespeed" => Optimizespeed,
                    "optimizelegibility" => Optimizelegibility,
                    "geometricprecision" => Geometricprecision,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Optimizespeed => computed_value::T::Optimizespeed,
                        SpecifiedValue::Optimizelegibility => computed_value::T::Optimizelegibility,
                        SpecifiedValue::Geometricprecision => computed_value::T::Geometricprecision,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Optimizespeed => SpecifiedValue::Optimizespeed,
                        computed_value::T::Optimizelegibility => SpecifiedValue::Optimizelegibility,
                        computed_value::T::Geometricprecision => SpecifiedValue::Geometricprecision,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextRendering);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextRendering)
        }
    }




// FIXME Firefox expects the initial value of this property to change depending
// on the value of the layout.css.control-characters.visible pref.

    
    

    
        
    
    /// Nonstandard
    pub mod _moz_control_character_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "hidden" => Hidden,
                    "visible" => Visible,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Hidden
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Hidden
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Hidden => computed_value::T::Hidden,
                        SpecifiedValue::Visible => computed_value::T::Visible,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Hidden => SpecifiedValue::Hidden,
                        computed_value::T::Visible => SpecifiedValue::Visible,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozControlCharacterVisibility(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozControlCharacterVisibility);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_control_character_visibility(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_control_character_visibility();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_control_character_visibility();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozControlCharacterVisibility)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    

    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-position
    pub mod list_style_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "outside" => Outside,
                    "inside" => Inside,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Outside
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Outside
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Outside => computed_value::T::Outside,
                        SpecifiedValue::Inside => computed_value::T::Inside,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Outside => SpecifiedValue::Outside,
                        computed_value::T::Inside => SpecifiedValue::Inside,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStylePosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ListStylePosition);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_list_style_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_position();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStylePosition)
        }
    }




// TODO(pcwalton): Implement the full set of counter styles per CSS-COUNTER-STYLES [1] 6.1:
//
//     decimal-leading-zero, armenian, upper-armenian, lower-armenian, georgian, lower-roman,
//     upper-roman
//
// TODO(bholley): Missing quite a few gecko properties here as well.
//
// In gecko, {upper,lower}-{roman,alpha} are implemented as @counter-styles in the
// UA, however they can also be set from pres attrs. When @counter-style is supported
// we may need to look into this and handle these differently.
//
// [1]: http://dev.w3.org/csswg/css-counter-styles/
    
    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-type
    pub mod list_style_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ListStyleType as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ListStyleType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ListStyleType::disc() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ListStyleType::disc() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ListStyleType::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStyleType(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ListStyleType);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_list_style_type(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_type();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_type();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ListStyleType)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-image
    pub mod list_style_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ListStyleImage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ListStyleImage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::ListStyleImage::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ListStyleImage::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ListStyleImage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ListStyleImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ListStyleImage);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_list_style_image(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_list_style_image();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_list_style_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ListStyleImage)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-content/#propdef-quotes
    pub mod quotes {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Quotes as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Quotes as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Quotes::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Quotes::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Quotes(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Quotes);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_quotes(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_quotes();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_quotes();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Quotes)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-image-region)
    pub mod _moz_image_region {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ClipRectOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ClipRectOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ClipRectOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ClipRectOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozImageRegion(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozImageRegion);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_image_region(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_image_region();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_image_region();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozImageRegion)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-top
    pub mod margin_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginTop(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginTop);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginTop);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-left
    pub mod margin_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginLeft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginLeft);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginLeft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-bottom
    pub mod margin_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginBottom);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-right
    pub mod margin_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginRight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginRight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginRight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginBlockStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginBlockEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginInlineStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Length(computed::Length::new(0.)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarginInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarginInlineEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MarginInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_margin_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_margin_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_margin_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineEnd)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






// TODO(pcwalton): `invert`

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-color
    pub mod outline_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OutlineColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-style
    pub mod outline_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::OutlineStyle as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::OutlineStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OutlineStyle::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::OutlineStyle::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::OutlineStyle::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OutlineStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-width
    pub mod outline_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use ::values::computed::NonNegativeLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(3.) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::Medium }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OutlineWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineWidth)
        }
    }



// The -moz-outline-radius-* properties are non-standard and not on a standards track.
    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_topleft {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusTopleft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOutlineRadiusTopleft);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusTopleft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_topleft(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_topleft();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_topleft();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusTopleft)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_topright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOutlineRadiusTopright);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusTopright);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_topright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_topright();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_topright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusTopright)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_bottomright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusBottomright(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOutlineRadiusBottomright);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusBottomright);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_bottomright(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_bottomright();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_bottomright();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusBottomright)
        }
    }


    
    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius_bottomleft {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderCornerRadius::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozOutlineRadiusBottomleft);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozOutlineRadiusBottomleft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_outline_radius_bottomleft(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_outline_radius_bottomleft();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_outline_radius_bottomleft();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozOutlineRadiusBottomleft)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-offset
    pub mod outline_offset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::Length::new(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Length::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OutlineOffset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OutlineOffset);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OutlineOffset);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_outline_offset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_outline_offset();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_outline_offset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineOffset)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





// APPLIES_TO_PLACEHOLDER so we can set it in UA  stylesheets.  But we use a
// !important value there, so pages can't set it.
    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-top
    pub mod padding_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingTop(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingTop);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingTop);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-left
    pub mod padding_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingLeft(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingLeft);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingLeft);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-bottom
    pub mod padding_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingBottom);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-right
    pub mod padding_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingRight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingRight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingRight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingBlockStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingBlockEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingInlineStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaddingInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaddingInlineEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::PaddingInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_padding_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_padding_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_padding_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineEnd)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
        
    
    /// https://drafts.csswg.org/css-ui/#cursor
    pub mod cursor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Cursor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Cursor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Cursor::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Cursor::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Cursor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Cursor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Cursor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_cursor(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_cursor();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_cursor();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Cursor)
        }
    }



// NB: `pointer-events: auto` (and use of `pointer-events` in anything that isn't SVG, in fact)
// is nonstandard, slated for CSS4-UI.
// TODO(pcwalton): SVG-only values.

    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/interact.html#PointerEventsProperty
    pub mod pointer_events {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "none" => None,
                    "visiblepainted" => Visiblepainted,
                    "visiblefill" => Visiblefill,
                    "visiblestroke" => Visiblestroke,
                    "visible" => Visible,
                    "painted" => Painted,
                    "fill" => Fill,
                    "stroke" => Stroke,
                    "all" => All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Visiblepainted => computed_value::T::Visiblepainted,
                        SpecifiedValue::Visiblefill => computed_value::T::Visiblefill,
                        SpecifiedValue::Visiblestroke => computed_value::T::Visiblestroke,
                        SpecifiedValue::Visible => computed_value::T::Visible,
                        SpecifiedValue::Painted => computed_value::T::Painted,
                        SpecifiedValue::Fill => computed_value::T::Fill,
                        SpecifiedValue::Stroke => computed_value::T::Stroke,
                        SpecifiedValue::All => computed_value::T::All,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Visiblepainted => SpecifiedValue::Visiblepainted,
                        computed_value::T::Visiblefill => SpecifiedValue::Visiblefill,
                        computed_value::T::Visiblestroke => SpecifiedValue::Visiblestroke,
                        computed_value::T::Visible => SpecifiedValue::Visible,
                        computed_value::T::Painted => SpecifiedValue::Painted,
                        computed_value::T::Fill => SpecifiedValue::Fill,
                        computed_value::T::Stroke => SpecifiedValue::Stroke,
                        computed_value::T::All => SpecifiedValue::All,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PointerEvents(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PointerEvents);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_pointer_events(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_pointer_events();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_pointer_events();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PointerEvents)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-input)
    pub mod _moz_user_input {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "none" => None,
                    "enabled" => Enabled,
                    "disabled" => Disabled,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Enabled => computed_value::T::Enabled,
                        SpecifiedValue::Disabled => computed_value::T::Disabled,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Enabled => SpecifiedValue::Enabled,
                        computed_value::T::Disabled => SpecifiedValue::Disabled,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserInput(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozUserInput);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_input(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_input();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_input();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserInput)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-modify)
    pub mod _moz_user_modify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "read-only" => ReadOnly,
                    "read-write" => ReadWrite,
                    "write-only" => WriteOnly,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ReadOnly
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ReadOnly
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const READ_ONLY: u32
                    = structs::StyleUserModify::ReadOnly as u32;
                // We can't match on enum values if we're matching on a u32
                const READ_WRITE: u32
                    = structs::StyleUserModify::ReadWrite as u32;
                // We can't match on enum values if we're matching on a u32
                const WRITE_ONLY: u32
                    = structs::StyleUserModify::WriteOnly as u32;
            match kw  {
                    READ_ONLY => SpecifiedValue::ReadOnly,
                    READ_WRITE => SpecifiedValue::ReadWrite,
                    WRITE_ONLY => SpecifiedValue::WriteOnly,
                _ => panic!("Found unexpected value in style struct for -moz-user-modify property"),
            }
        }
    }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::ReadOnly => computed_value::T::ReadOnly,
                        SpecifiedValue::ReadWrite => computed_value::T::ReadWrite,
                        SpecifiedValue::WriteOnly => computed_value::T::WriteOnly,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::ReadOnly => SpecifiedValue::ReadOnly,
                        computed_value::T::ReadWrite => SpecifiedValue::ReadWrite,
                        computed_value::T::WriteOnly => SpecifiedValue::WriteOnly,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserModify(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozUserModify);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_modify(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_modify();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_modify();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserModify)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-focus)
    pub mod _moz_user_focus {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "ignore" => Ignore,
                    "normal" => Normal,
                    "select-after" => SelectAfter,
                    "select-before" => SelectBefore,
                    "select-menu" => SelectMenu,
                    "select-same" => SelectSame,
                    "select-all" => SelectAll,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Ignore => computed_value::T::Ignore,
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::SelectAfter => computed_value::T::SelectAfter,
                        SpecifiedValue::SelectBefore => computed_value::T::SelectBefore,
                        SpecifiedValue::SelectMenu => computed_value::T::SelectMenu,
                        SpecifiedValue::SelectSame => computed_value::T::SelectSame,
                        SpecifiedValue::SelectAll => computed_value::T::SelectAll,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Ignore => SpecifiedValue::Ignore,
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::SelectAfter => SpecifiedValue::SelectAfter,
                        computed_value::T::SelectBefore => SpecifiedValue::SelectBefore,
                        computed_value::T::SelectMenu => SpecifiedValue::SelectMenu,
                        computed_value::T::SelectSame => SpecifiedValue::SelectSame,
                        computed_value::T::SelectAll => SpecifiedValue::SelectAll,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserFocus(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozUserFocus);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_focus(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_focus();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_user_focus();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserFocus)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-ui/#caret-color
    pub mod caret_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ColorOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ColorOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Auto) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ColorOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::CaretColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::CaretColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_caret_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_caret_color();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_caret_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaretColor)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







// "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-top
    pub mod top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Top(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Top);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Top);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_top(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_top();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_top();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Top)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-left
    pub mod left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Left(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Left);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Left);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_left(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_left();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_left();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Left)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-bottom
    pub mod bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Bottom(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Bottom);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Bottom);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_bottom(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_bottom();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_bottom();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Bottom)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-right
    pub mod right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Right(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Right);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Right);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_right(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_right();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_right();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Right)
        }
    }


// offset-* logical properties, map to "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-block-start
    pub mod offset_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetBlockStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OffsetBlockStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetBlockStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_block_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_block_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_block_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetBlockStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-block-end
    pub mod offset_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetBlockEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OffsetBlockEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetBlockEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_block_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_block_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_block_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetBlockEnd)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-inline-start
    pub mod offset_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetInlineStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OffsetInlineStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetInlineStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_inline_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_inline_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_inline_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetInlineStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-offset-inline-end
    pub mod offset_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::LengthOrPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::LengthOrPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentageOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthOrPercentageOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::OffsetInlineEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::OffsetInlineEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::OffsetInlineEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_offset_inline_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_offset_inline_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_offset_inline_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetInlineEnd)
        }
    }



#[cfg(feature = "gecko")]
macro_rules! impl_align_conversions {
    ($name: path) => {
        impl From<u8> for $name {
            fn from(bits: u8) -> $name {
                $name(::values::specified::align::AlignFlags::from_bits(bits)
                      .expect("bits contain valid flag"))
            }
        }

        impl From<$name> for u8 {
            fn from(v: $name) -> u8 {
                v.0.bits()
            }
        }
    };
}


    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#z-index
    pub mod z_index {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::IntegerOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::IntegerOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(Auto) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::IntegerOrAuto::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ZIndex(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ZIndex);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ZIndex);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_z_index(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_z_index();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_z_index();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ZIndex)
        }
    }




// CSS Flexible Box Layout Module Level 1
// http://www.w3.org/TR/css3-flexbox/

// Flex container properties

    
    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-direction-property
    pub mod flex_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "row" => Row,
                    "row-reverse" => RowReverse,
                    "column" => Column,
                    "column-reverse" => ColumnReverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Row
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Row
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Row => computed_value::T::Row,
                        SpecifiedValue::RowReverse => computed_value::T::RowReverse,
                        SpecifiedValue::Column => computed_value::T::Column,
                        SpecifiedValue::ColumnReverse => computed_value::T::ColumnReverse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Row => SpecifiedValue::Row,
                        computed_value::T::RowReverse => SpecifiedValue::RowReverse,
                        computed_value::T::Column => SpecifiedValue::Column,
                        computed_value::T::ColumnReverse => SpecifiedValue::ColumnReverse,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FlexDirection);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexDirection)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-wrap-property
    pub mod flex_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "nowrap" => Nowrap,
                    "wrap" => Wrap,
                    "wrap-reverse" => WrapReverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nowrap
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nowrap
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Nowrap => computed_value::T::Nowrap,
                        SpecifiedValue::Wrap => computed_value::T::Wrap,
                        SpecifiedValue::WrapReverse => computed_value::T::WrapReverse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Nowrap => SpecifiedValue::Nowrap,
                        computed_value::T::Wrap => SpecifiedValue::Wrap,
                        computed_value::T::WrapReverse => SpecifiedValue::WrapReverse,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexWrap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FlexWrap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexWrap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_wrap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_wrap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_wrap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexWrap)
        }
    }




    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-content
    pub mod justify_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignJustifyContent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignJustifyContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignJustifyContent::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignJustifyContent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifyContent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::JustifyContent);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifyContent);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-content
    pub mod align_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignJustifyContent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignJustifyContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignJustifyContent::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignJustifyContent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignContent(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AlignContent);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignContent);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_content(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_content();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_content();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-items
    pub mod align_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignItems as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignItems::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignItems::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignItems(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AlignItems);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignItems);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_items(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_items();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_items();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignItems)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::AlignItems);

    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-items
    pub mod justify_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::JustifyItems as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::JustifyItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::JustifyItems::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::JustifyItems::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifyItems(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::JustifyItems);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifyItems);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_items(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_items();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_items();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyItems)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::JustifyItems);

// Flex item properties

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-grow-property
    pub mod flex_grow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexGrow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FlexGrow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexGrow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_grow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_grow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_grow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexGrow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-shrink-property
    pub mod flex_shrink {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(1.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexShrink(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FlexShrink);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexShrink);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_shrink(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_shrink();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_shrink();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexShrink)
        }
    }



// https://drafts.csswg.org/css-align/#align-self-property
    
    
        
    
    /// https://drafts.csswg.org/css-align/#align-self-property
    pub mod align_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignJustifySelf as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignJustifySelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignJustifySelf::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignJustifySelf::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::AlignSelf(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::AlignSelf);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::AlignSelf);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_align_self(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_align_self();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_align_self();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignSelf)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#justify-self-property
    pub mod justify_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::AlignJustifySelf as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::AlignJustifySelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignJustifySelf::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::AlignJustifySelf::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::JustifySelf(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::JustifySelf);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::JustifySelf);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_justify_self(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_justify_self();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_justify_self();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifySelf)
        }
    }



    #[cfg(feature = "gecko")]
    impl_align_conversions!(::values::specified::align::AlignJustifySelf);

// https://drafts.csswg.org/css-flexbox/#propdef-order

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#order-property
    pub mod order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Integer::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Order(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Order);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Order);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_order(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_order();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_order();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Order)
        }
    }



// FIXME(emilio): All the sizes stuff, and the MozLength values should be
// unified with Servo, or at least be less hacky.
//
// The block direction ones don't even accept extremum lengths during parsing,
// and should be converted to just LengthOrPercentage.
    // FIXME: Gecko doesn't support content value yet.
    
    
    
    /// https://drafts.csswg.org/css-flexbox/#flex-basis-property
    pub mod flex_basis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MozLength::ExtremumLength(..) = computed {
                        
                        if false != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FlexBasis(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FlexBasis);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FlexBasis);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flex_basis(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flex_basis();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flex_basis();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexBasis)
        }
    }


    
        // width, height, block-size, inline-size
        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MozLength::ExtremumLength(..) = computed {
                        
                        if false != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Width(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Width);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Width);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Width)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        // max-width, max-height, max-block-size, max-inline-size
        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod min_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MozLength::ExtremumLength(..) = computed {
                        
                        if false != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MinWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinWidth)
        }
    }


        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod max_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MaxLength;

        pub mod computed_value {
            pub type T = ::values::computed::MaxLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MaxLength);


        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MaxLength;
            MaxLength::none()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MaxLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MaxLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MaxLength::ExtremumLength(..) = computed {
                        
                        if false != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaxWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxWidth);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_width();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxWidth)
        }
    }


    
        // width, height, block-size, inline-size
        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MozLength::ExtremumLength(..) = computed {
                        
                        if true != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Height(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Height);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::Height);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Height)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        // max-width, max-height, max-block-size, max-inline-size
        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod min_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MozLength::ExtremumLength(..) = computed {
                        
                        if true != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MinHeight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinHeight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinHeight)
        }
    }


        
    
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod max_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            use values::specified::AllowQuirks;
        use values::specified::MaxLength;

        pub mod computed_value {
            pub type T = ::values::computed::MaxLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MaxLength);


        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MaxLength;
            MaxLength::none()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MaxLength::parse_quirky(context, input, AllowQuirks::Yes);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MaxLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                    if let MaxLength::ExtremumLength(..) = computed {
                        
                        if true != context.builder.writing_mode.is_vertical() {
                            return get_initial_value()
                        }
                    }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxHeight(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaxHeight);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxHeight);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_height(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_height();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_height();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxHeight)
        }
    }


    
        // width, height, block-size, inline-size
        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                    if let Ok(MozLength::ExtremumLength(..)) = ret {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                        if let MozLength::ExtremumLength(..) = computed {
                            return get_initial_value()
                        }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BlockSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BlockSize)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        // max-width, max-height, max-block-size, max-inline-size
        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod min_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                    if let Ok(MozLength::ExtremumLength(..)) = ret {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MozLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                        if let MozLength::ExtremumLength(..) = computed {
                            return get_initial_value()
                        }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinBlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MinBlockSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinBlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinBlockSize)
        }
    }


        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod max_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MaxLength;

        pub mod computed_value {
            pub type T = ::values::computed::MaxLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MaxLength);


        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MaxLength;
            MaxLength::none()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MaxLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                    if let Ok(MaxLength::ExtremumLength(..)) = ret {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                    use values::computed::MaxLength;
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                        if let MaxLength::ExtremumLength(..) = computed {
                            return get_initial_value()
                        }
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxBlockSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaxBlockSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxBlockSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_block_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_block_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_block_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxBlockSize)
        }
    }


    
        // width, height, block-size, inline-size
        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::InlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::InlineSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::InlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InlineSize)
        }
    }


        // min-width, min-height, min-block-size, min-inline-size,
        // max-width, max-height, max-block-size, max-inline-size
        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod min_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MozLength;

        pub mod computed_value {
            pub type T = ::values::computed::MozLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MozLength);

        impl SpecifiedValue {
            /// Returns the `auto` value.
            pub fn auto() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::Auto))
            }

            /// Returns a value representing a `0` length.
            pub fn zero() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero()))
            }

            /// Returns a value representing a `0%` length.
            pub fn zero_percent() -> Self {
                use values::specified::length::LengthOrPercentageOrAuto;
                SpecifiedValue(MozLength::LengthOrPercentageOrAuto(LengthOrPercentageOrAuto::zero_percent()))
            }
        }

        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MozLength;
            MozLength::auto()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MozLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MinInlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MinInlineSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MinInlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_min_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_min_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_min_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinInlineSize)
        }
    }


        
    
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod max_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        use values::specified::MaxLength;

        pub mod computed_value {
            pub type T = ::values::computed::MaxLength;
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
        pub struct SpecifiedValue(pub MaxLength);


        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            use values::computed::MaxLength;
            MaxLength::none()
        }

        impl Parse for SpecifiedValue {
            fn parse<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<SpecifiedValue, ParseError<'i>> {
                let ret = MaxLength::parse(context, input);
                // Keyword values don't make sense in the block direction; don't parse them
                ret.map(SpecifiedValue)
            }
        }

        fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(context, input)
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;
            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                let computed = self.0.to_computed_value(context);

                // filter out keyword values in the block direction
                computed
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(ToComputedValue::from_computed_value(computed))
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaxInlineSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaxInlineSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaxInlineSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        context.rule_cache_conditions.borrow_mut()
                            .set_writing_mode_dependency(context.builder.writing_mode);
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_max_inline_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_max_inline_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_max_inline_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxInlineSize)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-box-sizing
    pub mod box_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "content-box" => ContentBox,
                    "border-box" => BorderBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::BoxSizing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::BoxSizing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::BoxSizing);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_box_sizing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_box_sizing();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_box_sizing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxSizing)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-object-fit
    pub mod object_fit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "fill" => Fill,
                    "contain" => Contain,
                    "cover" => Cover,
                    "none" => None,
                    "scale-down" => ScaleDown,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Fill
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Fill
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Fill => computed_value::T::Fill,
                        SpecifiedValue::Contain => computed_value::T::Contain,
                        SpecifiedValue::Cover => computed_value::T::Cover,
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::ScaleDown => computed_value::T::ScaleDown,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Fill => SpecifiedValue::Fill,
                        computed_value::T::Contain => SpecifiedValue::Contain,
                        computed_value::T::Cover => SpecifiedValue::Cover,
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::ScaleDown => SpecifiedValue::ScaleDown,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ObjectFit(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ObjectFit);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ObjectFit);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_object_fit(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_object_fit();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_object_fit();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ObjectFit)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-images-3/#the-object-position
    pub mod object_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Position::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ObjectPosition(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ObjectPosition);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ObjectPosition);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_object_position(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_object_position();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_object_position();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ObjectPosition)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-gap
    pub mod grid_row_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridRowGap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_row_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridRowGap)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-start
    pub mod grid_row_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridRowStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_row_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridRowStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-end
    pub mod grid_row_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridRowEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridRowEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridRowEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_row_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_row_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_row_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridRowEnd)
        }
    }



    // NOTE: According to the spec, this should handle multiple values of `<track-size>`,
    // but gecko supports only a single value
    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-rows
    pub mod grid_auto_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TrackSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TrackSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TrackSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoRows(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridAutoRows);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoRows);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_auto_rows(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_rows();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_rows();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridAutoRows)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-rows
    pub mod grid_template_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateComponent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateRows(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridTemplateRows);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateRows);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_template_rows(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_rows();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_rows();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridTemplateRows)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-gap
    pub mod grid_column_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeLengthOrPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeLengthOrPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthOrPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthOrPercentage::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnGap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridColumnGap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnGap);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_column_gap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_gap();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_gap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridColumnGap)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-start
    pub mod grid_column_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridColumnStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnStart);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_column_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_start();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridColumnStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-end
    pub mod grid_column_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridColumnEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridColumnEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridColumnEnd);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_column_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_column_end();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_column_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridColumnEnd)
        }
    }



    // NOTE: According to the spec, this should handle multiple values of `<track-size>`,
    // but gecko supports only a single value
    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-columns
    pub mod grid_auto_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TrackSize as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TrackSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TrackSize::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoColumns(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridAutoColumns);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoColumns);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_auto_columns(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_columns();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_columns();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridAutoColumns)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-columns
    pub mod grid_template_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateComponent::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateColumns(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridTemplateColumns);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateColumns);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_template_columns(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_columns();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_columns();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridTemplateColumns)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-flow
    pub mod grid_auto_flow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridAutoFlow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridAutoFlow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridAutoFlow::row() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridAutoFlow::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridAutoFlow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridAutoFlow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridAutoFlow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_grid_auto_flow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_auto_flow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_auto_flow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridAutoFlow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-areas
    pub mod grid_template_areas {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GridTemplateAreas as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GridTemplateAreas as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridTemplateAreas::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GridTemplateAreas::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::GridTemplateAreas(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::GridTemplateAreas);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::GridTemplateAreas);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_grid_template_areas(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_grid_template_areas();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_grid_template_areas();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::GridTemplateAreas)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-table-layout
    pub mod table_layout {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "fixed" => Fixed,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Fixed => computed_value::T::Fixed,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Fixed => SpecifiedValue::Fixed,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TableLayout(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TableLayout);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TableLayout);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_table_layout(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_table_layout();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_table_layout();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TableLayout)
        }
    }





    
        
    
    /// Internal-only (for `<col span>` pres attr)
    pub mod _x_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::XSpan as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::XSpan as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XSpan(1) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::XSpan::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::XSpan(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::XSpan);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::XSpan);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__x_span(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__x_span();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__x_span();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XSpan)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */







    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-text-overflow
    pub mod text_overflow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextOverflow as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextOverflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextOverflow::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextOverflow::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextOverflow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextOverflow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextOverflow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_text_overflow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_overflow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_overflow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TextOverflow)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-unicode-bidi
    pub mod unicode_bidi {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "embed" => Embed,
                    "isolate" => Isolate,
                    "bidi-override" => BidiOverride,
                    "isolate-override" => IsolateOverride,
                    "plaintext" => Plaintext,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Embed => computed_value::T::Embed,
                        SpecifiedValue::Isolate => computed_value::T::Isolate,
                        SpecifiedValue::BidiOverride => computed_value::T::BidiOverride,
                        SpecifiedValue::IsolateOverride => computed_value::T::IsolateOverride,
                        SpecifiedValue::Plaintext => computed_value::T::Plaintext,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Embed => SpecifiedValue::Embed,
                        computed_value::T::Isolate => SpecifiedValue::Isolate,
                        computed_value::T::BidiOverride => SpecifiedValue::BidiOverride,
                        computed_value::T::IsolateOverride => SpecifiedValue::IsolateOverride,
                        computed_value::T::Plaintext => SpecifiedValue::Plaintext,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::UnicodeBidi(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::UnicodeBidi);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::UnicodeBidi);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_unicode_bidi(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_unicode_bidi();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_unicode_bidi();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::UnicodeBidi)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-line
    pub mod text_decoration_line {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TextDecorationLine as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TextDecorationLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::TextDecorationLine::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TextDecorationLine::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TextDecorationLine::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationLine(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextDecorationLine);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationLine);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_line(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_line();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_line();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationLine)
        }
    }




    
    

    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-style
    pub mod text_decoration_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "solid" => Solid,
                    "double" => Double,
                    "dotted" => Dotted,
                    "dashed" => Dashed,
                    "wavy" => Wavy,
                    "-moz-none" => MozNone,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Solid
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Solid
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Solid => computed_value::T::Solid,
                        SpecifiedValue::Double => computed_value::T::Double,
                        SpecifiedValue::Dotted => computed_value::T::Dotted,
                        SpecifiedValue::Dashed => computed_value::T::Dashed,
                        SpecifiedValue::Wavy => computed_value::T::Wavy,
                        SpecifiedValue::MozNone => computed_value::T::MozNone,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Solid => SpecifiedValue::Solid,
                        computed_value::T::Double => SpecifiedValue::Double,
                        computed_value::T::Dotted => SpecifiedValue::Dotted,
                        computed_value::T::Dashed => SpecifiedValue::Dashed,
                        computed_value::T::Wavy => SpecifiedValue::Wavy,
                        computed_value::T::MozNone => SpecifiedValue::MozNone,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationStyle(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextDecorationStyle);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationStyle);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_style(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_style();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_style();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationStyle)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-color
    pub mod text_decoration_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextDecorationColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextDecorationColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::TextDecorationColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_decoration_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_decoration_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_text_decoration_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-inline/#sizing-drop-initials
    pub mod initial_letter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::InitialLetter as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::InitialLetter as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::InitialLetter::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::InitialLetter::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::InitialLetter::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::InitialLetter(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::InitialLetter);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::InitialLetter);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_initial_letter(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_initial_letter();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_initial_letter();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InitialLetter)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




// CSS Basic User Interface Module Level 1
// https://drafts.csswg.org/css-ui-3/


// TODO spec says that UAs should not support this
// we should probably remove from gecko (https://bugzilla.mozilla.org/show_bug.cgi?id=1328331)

    
    

    
        
    
    /// https://drafts.csswg.org/css-ui/#input-method-editor
    pub mod ime_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "normal" => Normal,
                    "active" => Active,
                    "disabled" => Disabled,
                    "inactive" => Inactive,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Active => computed_value::T::Active,
                        SpecifiedValue::Disabled => computed_value::T::Disabled,
                        SpecifiedValue::Inactive => computed_value::T::Inactive,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Active => SpecifiedValue::Active,
                        computed_value::T::Disabled => SpecifiedValue::Disabled,
                        computed_value::T::Inactive => SpecifiedValue::Inactive,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ImeMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ImeMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ImeMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_ime_mode(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_ime_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_ime_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImeMode)
        }
    }





    
    

    
        
    
    /// https://drafts.csswg.org/css-ui-4/#propdef-user-select
    pub mod _moz_user_select {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "auto" => Auto,
                        "text" => Text,
                        "none" => None,
                        "all" => All,
                        "element" => Element,
                        "elements" => Elements,
                        "toggle" => Toggle,
                        "tri-state" => TriState,
                        "-moz-all" => MozAll,
                        "-moz-text" => MozText,
                }
                aliases {
                        "-moz-none" => None,
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "text" => Text,
                    "none" => None,
                    "all" => All,
                    "element" => Element,
                    "elements" => Elements,
                    "toggle" => Toggle,
                    "tri-state" => TriState,
                    "-moz-all" => MozAll,
                    "-moz-text" => MozText,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Text => computed_value::T::Text,
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::All => computed_value::T::All,
                        SpecifiedValue::Element => computed_value::T::Element,
                        SpecifiedValue::Elements => computed_value::T::Elements,
                        SpecifiedValue::Toggle => computed_value::T::Toggle,
                        SpecifiedValue::TriState => computed_value::T::TriState,
                        SpecifiedValue::MozAll => computed_value::T::MozAll,
                        SpecifiedValue::MozText => computed_value::T::MozText,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Text => SpecifiedValue::Text,
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::All => SpecifiedValue::All,
                        computed_value::T::Element => SpecifiedValue::Element,
                        computed_value::T::Elements => SpecifiedValue::Elements,
                        computed_value::T::Toggle => SpecifiedValue::Toggle,
                        computed_value::T::TriState => SpecifiedValue::TriState,
                        computed_value::T::MozAll => SpecifiedValue::MozAll,
                        computed_value::T::MozText => SpecifiedValue::MozText,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozUserSelect(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozUserSelect);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozUserSelect);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_user_select(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_user_select();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_user_select();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserSelect)
        }
    }




// TODO(emilio): This probably should be hidden from content.

    
    

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_window_dragging {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "default" => Default,
                    "drag" => Drag,
                    "no-drag" => NoDrag,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Default
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Default
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Default => computed_value::T::Default,
                        SpecifiedValue::Drag => computed_value::T::Drag,
                        SpecifiedValue::NoDrag => computed_value::T::NoDrag,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Default => SpecifiedValue::Default,
                        computed_value::T::Drag => SpecifiedValue::Drag,
                        computed_value::T::NoDrag => SpecifiedValue::NoDrag,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowDragging(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozWindowDragging);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowDragging);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_dragging(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_dragging();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_dragging();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowDragging)
        }
    }





    
    

    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "default" => Default,
                    "menu" => Menu,
                    "tooltip" => Tooltip,
                    "sheet" => Sheet,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::Default => computed_value::T::Default,
                        SpecifiedValue::Menu => computed_value::T::Menu,
                        SpecifiedValue::Tooltip => computed_value::T::Tooltip,
                        SpecifiedValue::Sheet => computed_value::T::Sheet,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::Default => SpecifiedValue::Default,
                        computed_value::T::Menu => SpecifiedValue::Menu,
                        computed_value::T::Tooltip => SpecifiedValue::Tooltip,
                        computed_value::T::Sheet => SpecifiedValue::Sheet,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowShadow(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozWindowShadow);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowShadow);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_shadow(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_shadow();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_shadow();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowShadow)
        }
    }





    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozWindowOpacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowOpacity)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Transform::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowTransform(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozWindowTransform);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowTransform);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_window_transform(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_transform();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_transform();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowTransform)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::TransformOrigin::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozWindowTransformOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozWindowTransformOrigin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozWindowTransformOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set__moz_window_transform_origin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_window_transform_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_window_transform_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozWindowTransformOrigin)
        }
    }



// TODO(emilio): Probably also should be hidden from content.

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_force_broken_image_icon {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozForceBrokenImageIcon as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozForceBrokenImageIcon as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozForceBrokenImageIcon::false_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozForceBrokenImageIcon::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozForceBrokenImageIcon(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozForceBrokenImageIcon);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozForceBrokenImageIcon);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_force_broken_image_icon(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_force_broken_image_icon();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_force_broken_image_icon();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozForceBrokenImageIcon)
        }
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// SVG 1.1 (Second Edition)
// https://www.w3.org/TR/SVG/


// Section 10 - Text


    
    

    
        
    
    /// https://www.w3.org/TR/SVG/text.html#TextAnchorProperty
    pub mod text_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "start" => Start,
                    "middle" => Middle,
                    "end" => End,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Start => computed_value::T::Start,
                        SpecifiedValue::Middle => computed_value::T::Middle,
                        SpecifiedValue::End => computed_value::T::End,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Start => SpecifiedValue::Start,
                        computed_value::T::Middle => SpecifiedValue::Middle,
                        computed_value::T::End => SpecifiedValue::End,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::TextAnchor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::TextAnchor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_text_anchor(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_text_anchor();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_text_anchor();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAnchor)
        }
    }




// Section 11 - Painting: Filling, Stroking and Marker Symbols

    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ColorInterpolationProperty
    pub mod color_interpolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "srgb" => Srgb,
                    "auto" => Auto,
                    "linearrgb" => Linearrgb,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Srgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Srgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Srgb => computed_value::T::Srgb,
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Linearrgb => computed_value::T::Linearrgb,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Srgb => SpecifiedValue::Srgb,
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Linearrgb => SpecifiedValue::Linearrgb,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorInterpolation(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColorInterpolation);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_interpolation(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_interpolation();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_interpolation();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolation)
        }
    }





    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ColorInterpolationFiltersProperty
    pub mod color_interpolation_filters {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "linearrgb" => Linearrgb,
                    "auto" => Auto,
                    "srgb" => Srgb,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Linearrgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Linearrgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Linearrgb => computed_value::T::Linearrgb,
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Srgb => computed_value::T::Srgb,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Linearrgb => SpecifiedValue::Linearrgb,
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Srgb => SpecifiedValue::Srgb,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ColorInterpolationFilters(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ColorInterpolationFilters);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_color_interpolation_filters(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_color_interpolation_filters();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_color_interpolation_filters();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolationFilters)
        }
    }





    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#SpecifyingFillPaint
    pub mod fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::SVGPaint::black() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Fill(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Fill);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_fill(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Fill)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#FillOpacityProperty
    pub mod fill_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGOpacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FillOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FillOpacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_fill_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill_opacity();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillOpacity)
        }
    }




    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#FillRuleProperty
    pub mod fill_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "nonzero" => Nonzero,
                    "evenodd" => Evenodd,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nonzero
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nonzero
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Nonzero => computed_value::T::Nonzero,
                        SpecifiedValue::Evenodd => computed_value::T::Evenodd,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Nonzero => SpecifiedValue::Nonzero,
                        computed_value::T::Evenodd => SpecifiedValue::Evenodd,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FillRule(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FillRule);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_fill_rule(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_fill_rule();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_fill_rule();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillRule)
        }
    }





    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#ShapeRenderingProperty
    pub mod shape_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "optimizespeed" => Optimizespeed,
                    "crispedges" => Crispedges,
                    "geometricprecision" => Geometricprecision,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::Optimizespeed => computed_value::T::Optimizespeed,
                        SpecifiedValue::Crispedges => computed_value::T::Crispedges,
                        SpecifiedValue::Geometricprecision => computed_value::T::Geometricprecision,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::Optimizespeed => SpecifiedValue::Optimizespeed,
                        computed_value::T::Crispedges => SpecifiedValue::Crispedges,
                        computed_value::T::Geometricprecision => SpecifiedValue::Geometricprecision,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ShapeRendering(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ShapeRendering);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_shape_rendering(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_shape_rendering();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_shape_rendering();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeRendering)
        }
    }





    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#SpecifyingStrokePaint
    pub mod stroke {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaint::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::Stroke(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::Stroke);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_stroke(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Stroke)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeWidth
    pub mod stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGWidth as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { ::values::computed::NonNegativeLength::new(1.).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGWidth::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeWidth(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeWidth);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_width(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_width();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_width();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeWidth)
        }
    }




    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeLinecapProperty
    pub mod stroke_linecap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "butt" => Butt,
                    "round" => Round,
                    "square" => Square,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Butt
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Butt
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Butt => computed_value::T::Butt,
                        SpecifiedValue::Round => computed_value::T::Round,
                        SpecifiedValue::Square => computed_value::T::Square,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Butt => SpecifiedValue::Butt,
                        computed_value::T::Round => SpecifiedValue::Round,
                        computed_value::T::Square => SpecifiedValue::Square,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeLinecap(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeLinecap);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_linecap(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_linecap();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_linecap();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinecap)
        }
    }





    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeLinejoinProperty
    pub mod stroke_linejoin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "miter" => Miter,
                    "round" => Round,
                    "bevel" => Bevel,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Miter
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Miter
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Miter => computed_value::T::Miter,
                        SpecifiedValue::Round => computed_value::T::Round,
                        SpecifiedValue::Bevel => computed_value::T::Bevel,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Miter => SpecifiedValue::Miter,
                        computed_value::T::Round => SpecifiedValue::Round,
                        computed_value::T::Bevel => SpecifiedValue::Bevel,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeLinejoin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeLinejoin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_linejoin(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_linejoin();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_linejoin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinejoin)
        }
    }





    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeMiterlimitProperty
    pub mod stroke_miterlimit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::GreaterThanOrEqualToOneNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::GreaterThanOrEqualToOneNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(4.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::GreaterThanOrEqualToOneNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeMiterlimit(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeMiterlimit);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_miterlimit(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_miterlimit();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_miterlimit();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeMiterlimit)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG11/painting.html#StrokeOpacityProperty
    pub mod stroke_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGOpacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeOpacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_opacity();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeOpacity)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeDashing
    pub mod stroke_dasharray {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGStrokeDashArray as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGStrokeDashArray as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGStrokeDashArray::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeDasharray(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeDasharray);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_dasharray(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_dasharray();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_dasharray();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDasharray)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#StrokeDashing
    pub mod stroke_dashoffset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGLength as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Au(0).into() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGLength::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StrokeDashoffset(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StrokeDashoffset);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stroke_dashoffset(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stroke_dashoffset();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_stroke_dashoffset();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDashoffset)
        }
    }



// Section 14 - Clipping, Masking and Compositing

    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/masking.html#ClipRuleProperty
    pub mod clip_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "nonzero" => Nonzero,
                    "evenodd" => Evenodd,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nonzero
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nonzero
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Nonzero => computed_value::T::Nonzero,
                        SpecifiedValue::Evenodd => computed_value::T::Evenodd,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Nonzero => SpecifiedValue::Nonzero,
                        computed_value::T::Evenodd => SpecifiedValue::Evenodd,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ClipRule(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ClipRule);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_clip_rule(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip_rule();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_clip_rule();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ClipRule)
        }
    }





    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerStart(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarkerStart);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_marker_start(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_start();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_start();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MarkerStart)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_mid {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerMid(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarkerMid);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_marker_mid(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_mid();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_mid();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MarkerMid)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#VertexMarkerProperties
    pub mod marker_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::Second(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::UrlOrNone::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MarkerEnd(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MarkerEnd);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_marker_end(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_marker_end();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_marker_end();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MarkerEnd)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG2/painting.html#PaintOrder
    pub mod paint_order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::SVGPaintOrder as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::SVGPaintOrder as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::SVGPaintOrder::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::SVGPaintOrder::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::PaintOrder(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::PaintOrder);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_paint_order(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset_paint_order();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit_paint_order();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaintOrder)
        }
    }




    
        
    
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-context-properties)
    pub mod _moz_context_properties {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::MozContextProperties as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::MozContextProperties as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MozContextProperties::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for -moz-context-properties.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use std::vec::IntoIter;
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub Vec<single_value::T>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<single_value::T>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of -moz-context-properties.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        dest.write_str("none")?;
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                computed_value::T(vec![])
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

                if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Ok(SpecifiedValue(Vec::new()))
                }

            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozContextProperties(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozContextProperties);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    None;

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_inheritedsvg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set__moz_context_properties(iter);
                        }
                        context.builder.put_inheritedsvg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_context_properties();
                    },
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Inherit => {
                            context.builder.inherit__moz_context_properties();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozContextProperties)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    
    

    
        
    
    /// https://www.w3.org/TR/SVG11/text.html#DominantBaselineProperty
    pub mod dominant_baseline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "auto" => Auto,
                    "use-script" => UseScript,
                    "no-change" => NoChange,
                    "reset-size" => ResetSize,
                    "ideographic" => Ideographic,
                    "alphabetic" => Alphabetic,
                    "hanging" => Hanging,
                    "mathematical" => Mathematical,
                    "central" => Central,
                    "middle" => Middle,
                    "text-after-edge" => TextAfterEdge,
                    "text-before-edge" => TextBeforeEdge,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Auto => computed_value::T::Auto,
                        SpecifiedValue::UseScript => computed_value::T::UseScript,
                        SpecifiedValue::NoChange => computed_value::T::NoChange,
                        SpecifiedValue::ResetSize => computed_value::T::ResetSize,
                        SpecifiedValue::Ideographic => computed_value::T::Ideographic,
                        SpecifiedValue::Alphabetic => computed_value::T::Alphabetic,
                        SpecifiedValue::Hanging => computed_value::T::Hanging,
                        SpecifiedValue::Mathematical => computed_value::T::Mathematical,
                        SpecifiedValue::Central => computed_value::T::Central,
                        SpecifiedValue::Middle => computed_value::T::Middle,
                        SpecifiedValue::TextAfterEdge => computed_value::T::TextAfterEdge,
                        SpecifiedValue::TextBeforeEdge => computed_value::T::TextBeforeEdge,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Auto => SpecifiedValue::Auto,
                        computed_value::T::UseScript => SpecifiedValue::UseScript,
                        computed_value::T::NoChange => SpecifiedValue::NoChange,
                        computed_value::T::ResetSize => SpecifiedValue::ResetSize,
                        computed_value::T::Ideographic => SpecifiedValue::Ideographic,
                        computed_value::T::Alphabetic => SpecifiedValue::Alphabetic,
                        computed_value::T::Hanging => SpecifiedValue::Hanging,
                        computed_value::T::Mathematical => SpecifiedValue::Mathematical,
                        computed_value::T::Central => SpecifiedValue::Central,
                        computed_value::T::Middle => SpecifiedValue::Middle,
                        computed_value::T::TextAfterEdge => SpecifiedValue::TextAfterEdge,
                        computed_value::T::TextBeforeEdge => SpecifiedValue::TextBeforeEdge,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::DominantBaseline(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::DominantBaseline);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::DominantBaseline);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_dominant_baseline(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_dominant_baseline();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_dominant_baseline();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::DominantBaseline)
        }
    }





    
    

    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#VectorEffectProperty
    pub mod vector_effect {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "none" => None,
                    "non-scaling-stroke" => NonScalingStroke,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::None => computed_value::T::None,
                        SpecifiedValue::NonScalingStroke => computed_value::T::NonScalingStroke,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::None => SpecifiedValue::None,
                        computed_value::T::NonScalingStroke => SpecifiedValue::NonScalingStroke,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::VectorEffect(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::VectorEffect);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::VectorEffect);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_vector_effect(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_vector_effect();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_vector_effect();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VectorEffect)
        }
    }




// Section 13 - Gradients and Patterns


    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#StopColorProperty
    pub mod stop_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StopColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StopColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::StopColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stop_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stop_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_stop_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopColor)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVGTiny12/painting.html#propdef-stop-opacity
    pub mod stop_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::StopOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::StopOpacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::StopOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_stop_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_stop_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_stop_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopOpacity)
        }
    }



// Section 15 - Filter Effects


    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#FloodColorProperty
    pub mod flood_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(0, 0, 0, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FloodColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FloodColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FloodColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flood_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flood_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flood_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodColor)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#FloodOpacityProperty
    pub mod flood_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Opacity::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::FloodOpacity(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::FloodOpacity);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::FloodOpacity);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_flood_opacity(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_flood_opacity();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_flood_opacity();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodOpacity)
        }
    }




    
        
    
    /// https://www.w3.org/TR/SVG/filters.html#LightingColorProperty
    pub mod lighting_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::RGBAColor as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::RGBAColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { RGBA::new(255, 255, 255, 255) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::RGBAColor::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::LightingColor(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::LightingColor);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::LightingColor);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_lighting_color(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_lighting_color();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_lighting_color();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LightingColor)
        }
    }



// CSS Masking Module Level 1
// https://drafts.fxtf.org/css-masking

    
    

    
        
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-type
    pub mod mask_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "luminance" => Luminance,
                    "alpha" => Alpha,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Luminance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Luminance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Luminance => computed_value::T::Luminance,
                        SpecifiedValue::Alpha => computed_value::T::Alpha,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Luminance => SpecifiedValue::Luminance,
                        computed_value::T::Alpha => SpecifiedValue::Alpha,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskType(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskType);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskType);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mask_type(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_type();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_type();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskType)
        }
    }





    
        
    
    /// https://drafts.fxtf.org/css-masking/#propdef-clip-path
    pub mod clip_path {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::basic_shape::ClippingShape as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::basic_shape::ClippingShape as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ShapeSource::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::basic_shape::ClippingShape::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::ClipPath(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::ClipPath);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::ClipPath);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = (**specified_value).to_computed_value(context);
                            context.builder.set_clip_path(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_clip_path();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_clip_path();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ClipPath)
        }
    }




    
    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-mode
    pub mod mask_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "match-source" => MatchSource,
                    "alpha" => Alpha,
                    "luminance" => Luminance,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::MatchSource
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::MatchSource
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::MatchSource => computed_value::T::MatchSource,
                        SpecifiedValue::Alpha => computed_value::T::Alpha,
                        SpecifiedValue::Luminance => computed_value::T::Luminance,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::MatchSource => SpecifiedValue::MatchSource,
                        computed_value::T::Alpha => SpecifiedValue::Alpha,
                        computed_value::T::Luminance => SpecifiedValue::Luminance,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for mask-mode.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-mode");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskMode(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskMode);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskMode);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_mode(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_mode();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_mode();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskMode)
        }
    }






    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-repeat
    pub mod mask_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BackgroundRepeat::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-repeat.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-repeat");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-repeat.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-repeat");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskRepeat(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskRepeat);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskRepeat);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_repeat(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_repeat();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_repeat();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskRepeat)
        }
    }




    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-position
    pub mod mask_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::HorizontalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-x.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-position-x");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-position-x.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-position-x");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskPositionX(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskPositionX);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskPositionX);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_position_x(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_position_x();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_position_x();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-position
    pub mod mask_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthOrPercentage::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::position::VerticalPosition::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-y.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            #[derive(Animate, ComputeSquaredDistance)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );

                use values::animated::{ToAnimatedZero};

                impl ToAnimatedZero for T {
                    #[inline]
                    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
                }

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-position-y");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-position-y.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-position-y");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskPositionY(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskPositionY);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskPositionY);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_position_y(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_position_y();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_position_y();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionY)
        }
    }





    
    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-clip
    pub mod mask_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "border-box" => BorderBox,
                    "content-box" => ContentBox,
                    "padding-box" => PaddingBox,
                    "fill-box" => FillBox,
                    "stroke-box" => StrokeBox,
                    "view-box" => ViewBox,
                    "no-clip" => NoClip,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                        SpecifiedValue::PaddingBox => computed_value::T::PaddingBox,
                        SpecifiedValue::FillBox => computed_value::T::FillBox,
                        SpecifiedValue::StrokeBox => computed_value::T::StrokeBox,
                        SpecifiedValue::ViewBox => computed_value::T::ViewBox,
                        SpecifiedValue::NoClip => computed_value::T::NoClip,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                        computed_value::T::PaddingBox => SpecifiedValue::PaddingBox,
                        computed_value::T::FillBox => SpecifiedValue::FillBox,
                        computed_value::T::StrokeBox => SpecifiedValue::StrokeBox,
                        computed_value::T::ViewBox => SpecifiedValue::ViewBox,
                        computed_value::T::NoClip => SpecifiedValue::NoClip,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for mask-clip.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-clip");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-clip.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-clip");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskClip(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskClip);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskClip);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_clip(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_clip();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_clip();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskClip)
        }
    }






    
    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-origin
    pub mod mask_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "border-box" => BorderBox,
                    "content-box" => ContentBox,
                    "padding-box" => PaddingBox,
                    "fill-box" => FillBox,
                    "stroke-box" => StrokeBox,
                    "view-box" => ViewBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::BorderBox => computed_value::T::BorderBox,
                        SpecifiedValue::ContentBox => computed_value::T::ContentBox,
                        SpecifiedValue::PaddingBox => computed_value::T::PaddingBox,
                        SpecifiedValue::FillBox => computed_value::T::FillBox,
                        SpecifiedValue::StrokeBox => computed_value::T::StrokeBox,
                        SpecifiedValue::ViewBox => computed_value::T::ViewBox,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::BorderBox => SpecifiedValue::BorderBox,
                        computed_value::T::ContentBox => SpecifiedValue::ContentBox,
                        computed_value::T::PaddingBox => SpecifiedValue::PaddingBox,
                        computed_value::T::FillBox => SpecifiedValue::FillBox,
                        computed_value::T::StrokeBox => SpecifiedValue::StrokeBox,
                        computed_value::T::ViewBox => SpecifiedValue::ViewBox,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for mask-origin.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-origin");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-origin.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-origin");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskOrigin(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskOrigin);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskOrigin);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_origin(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_origin();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_origin();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskOrigin)
        }
    }






    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-size
    pub mod mask_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
    use properties::longhands::background_size;
    pub use ::properties::longhands::background_size::SpecifiedValue;
    pub use ::properties::longhands::background_size::single_value as single_value;
    pub use ::properties::longhands::background_size::computed_value as computed_value;

    #[inline]
    pub fn get_initial_value() -> computed_value::T {
        background_size::get_initial_value()
    }

    pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                         -> Result<SpecifiedValue,ParseError<'i>> {
        background_size::parse(context, input)
    }

        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskSize(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskSize);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskSize);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set_mask_size(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_size();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_size();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskSize)
        }
    }



    
    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-composite
    pub mod mask_composite {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "add" => Add,
                    "subtract" => Subtract,
                    "intersect" => Intersect,
                    "exclude" => Exclude,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Add
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Add
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Add => computed_value::T::Add,
                        SpecifiedValue::Subtract => computed_value::T::Subtract,
                        SpecifiedValue::Intersect => computed_value::T::Intersect,
                        SpecifiedValue::Exclude => computed_value::T::Exclude,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Add => SpecifiedValue::Add,
                        computed_value::T::Subtract => SpecifiedValue::Subtract,
                        computed_value::T::Intersect => SpecifiedValue::Intersect,
                        computed_value::T::Exclude => SpecifiedValue::Exclude,
                }
            }
        }
    
        
        }

        /// The definition of the computed value for mask-composite.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-composite");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-composite.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-composite");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskComposite(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskComposite);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskComposite);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_composite(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_composite();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_composite();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskComposite)
        }
    }






    
        
    
    
    /// https://drafts.fxtf.org/css-masking/#propdef-mask-image
    pub mod mask_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        use std::fmt::{self, Write};
        use style_traits::{CssWriter, Separator, ToCss};

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use values::{computed, specified};
            #[allow(unused_imports)]
            use values::{Auto, Either, None_, Normal};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::ImageLayer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::ImageLayer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Either::First(None_) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { Either::First(None_) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ImageLayer::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-image.
        pub mod computed_value {
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::{IntoIter, SmallVec};
            use values::computed::ComputedVecIter;

            /// The computed value, effectively a list of single values.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
            pub struct T(
                pub SmallVec<[single_value::T; 1]>,
            );


            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;

            impl IntoIterator for T {
                type Item = single_value::T;
                type IntoIter = IntoIter<[single_value::T; 1]>;
                fn into_iter(self) -> Self::IntoIter {
                    self.0.into_iter()
                }
            }
        }

        impl ToCss for computed_value::T {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-image");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        /// The specified value of mask-image.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        pub struct SpecifiedValue(pub Vec<single_value::SpecifiedValue>);

        impl ToCss for SpecifiedValue {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let mut iter = self.0.iter();
                if let Some(val) = iter.next() {
                    val.to_css(dest)?;
                } else {
                        warn!("Found empty value for property mask-image");
                }
                for i in iter {
                    dest.write_str(::style_traits::Comma::separator())?;
                    i.to_css(dest)?;
                }
                Ok(())
            }
        }

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::T(v)
        }

        pub fn parse<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            ::style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            }).map(SpecifiedValue)
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            pub fn compute_iter<'a, 'cx, 'cx_a>(&'a self, context: &'cx Context<'cx_a>)
                -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::T(self.compute_iter(context).collect())
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                SpecifiedValue(computed.0.iter()
                                    .map(ToComputedValue::from_computed_value)
                                    .collect())
            }
        }
    
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MaskImage(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MaskImage);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MaskImage);

            match value {
                DeclaredValue::Value(specified_value) => {
                        // In the case of a vector property we want to pass
                        // down an iterator so that this can be computed
                        // without allocation
                        //
                        // However, computing requires a context, but the
                        // style struct being mutated is on the context. We
                        // temporarily remove it, mutate it, and then put it
                        // back. Vector longhands cannot touch their own
                        // style struct whilst computing, else this will
                        // panic.
                        let mut s =
                            context.builder.take_svg();
                        {
                            let iter = specified_value.compute_iter(context);
                            s.set_mask_image(iter);
                        }
                        context.builder.put_svg(s);
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset_mask_image();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit_mask_image();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskImage)
        }
    }




    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




// Non-standard properties that Gecko uses for XUL elements.



    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-align)
    pub mod _moz_box_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "stretch" => Stretch,
                    "start" => Start,
                    "center" => Center,
                    "baseline" => Baseline,
                    "end" => End,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Stretch
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Stretch
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Stretch => computed_value::T::Stretch,
                        SpecifiedValue::Start => computed_value::T::Start,
                        SpecifiedValue::Center => computed_value::T::Center,
                        SpecifiedValue::Baseline => computed_value::T::Baseline,
                        SpecifiedValue::End => computed_value::T::End,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Stretch => SpecifiedValue::Stretch,
                        computed_value::T::Start => SpecifiedValue::Start,
                        computed_value::T::Center => SpecifiedValue::Center,
                        computed_value::T::Baseline => SpecifiedValue::Baseline,
                        computed_value::T::End => SpecifiedValue::End,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxAlign(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxAlign);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxAlign);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_align(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_align();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_align();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxAlign)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-direction)
    pub mod _moz_box_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "normal" => Normal,
                    "reverse" => Reverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Normal => computed_value::T::Normal,
                        SpecifiedValue::Reverse => computed_value::T::Reverse,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Normal => SpecifiedValue::Normal,
                        computed_value::T::Reverse => SpecifiedValue::Reverse,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxDirection(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxDirection);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxDirection);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_direction(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_direction();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_direction();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxDirection)
        }
    }





    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-flex)
    pub mod _moz_box_flex {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeNumber::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxFlex(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxFlex);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxFlex);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_flex(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_flex();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_flex();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxFlex)
        }
    }




    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-orient)
    pub mod _moz_box_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            define_css_keyword_enum! { SpecifiedValue:
                values {
                        "horizontal" => Horizontal,
                        "vertical" => Vertical,
                }
                aliases {
                        "inline-axis" => Horizontal,
                        "block-axis" => Vertical,
                }
            }
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "horizontal" => Horizontal,
                    "vertical" => Vertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Horizontal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Horizontal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Horizontal => computed_value::T::Horizontal,
                        SpecifiedValue::Vertical => computed_value::T::Vertical,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Horizontal => SpecifiedValue::Horizontal,
                        computed_value::T::Vertical => SpecifiedValue::Vertical,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxOrient(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxOrient);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxOrient);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_orient(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_orient();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_orient();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrient)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-pack)
    pub mod _moz_box_pack {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "start" => Start,
                    "center" => Center,
                    "end" => End,
                    "justify" => Justify,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::Start => computed_value::T::Start,
                        SpecifiedValue::Center => computed_value::T::Center,
                        SpecifiedValue::End => computed_value::T::End,
                        SpecifiedValue::Justify => computed_value::T::Justify,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::Start => SpecifiedValue::Start,
                        computed_value::T::Center => SpecifiedValue::Center,
                        computed_value::T::End => SpecifiedValue::End,
                        computed_value::T::Justify => SpecifiedValue::Justify,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxPack(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxPack);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxPack);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_pack(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_pack();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_pack();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxPack)
        }
    }





    
    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-stack-sizing)
    pub mod _moz_stack_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
            pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            define_css_keyword_enum! { T:
                    "stretch-to-fit" => StretchToFit,
                    "ignore" => Ignore,
                    "ignore-horizontal" => IgnoreHorizontal,
                    "ignore-vertical" => IgnoreVertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::StretchToFit
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::StretchToFit
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }
        impl Parse for SpecifiedValue {
            #[inline]
            fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
                SpecifiedValue::parse(input)
            }
        }

    
            
        // FIXME(emilio): WTF is this even trying to do? Those are no-ops,
        // should be derived instead!
        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, _context: &Context) -> computed_value::T {
                match *self {
                        SpecifiedValue::StretchToFit => computed_value::T::StretchToFit,
                        SpecifiedValue::Ignore => computed_value::T::Ignore,
                        SpecifiedValue::IgnoreHorizontal => computed_value::T::IgnoreHorizontal,
                        SpecifiedValue::IgnoreVertical => computed_value::T::IgnoreVertical,
                }
            }
            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                match *computed {
                        computed_value::T::StretchToFit => SpecifiedValue::StretchToFit,
                        computed_value::T::Ignore => SpecifiedValue::Ignore,
                        computed_value::T::IgnoreHorizontal => SpecifiedValue::IgnoreHorizontal,
                        computed_value::T::IgnoreVertical => SpecifiedValue::IgnoreVertical,
                }
            }
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozStackSizing(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozStackSizing);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozStackSizing);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_stack_sizing(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_stack_sizing();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_stack_sizing();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozStackSizing)
        }
    }





    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-box-ordinal-group)
    pub mod _moz_box_ordinal_group {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use values::{Auto, Either, None_, Normal};
        #[allow(unused_imports)]
        use error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use properties::longhands;
        #[allow(unused_imports)]
        use properties::{DeclaredValue, LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use values::{computed, generics, specified};
        #[allow(unused_imports)]
        use Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use cssparser::{Color as CSSParserColor, RGBA};
        #[allow(unused_imports)]
        use values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(context: &ParserContext,
                             input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Integer::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            let value = match *declaration {
                PropertyDeclaration::MozBoxOrdinalGroup(ref value) => {
                    DeclaredValue::Value(value)
                },
                PropertyDeclaration::CSSWideKeyword(id, value) => {
                    debug_assert!(id == LonghandId::MozBoxOrdinalGroup);
                    DeclaredValue::CSSWideKeyword(value)
                },
                PropertyDeclaration::WithVariables(..) => {
                    panic!("variables should already have been substituted")
                }
                _ => panic!("entered the wrong cascade_property() implementation"),
            };

            context.for_non_inherited_property =
                    Some(LonghandId::MozBoxOrdinalGroup);

            match value {
                DeclaredValue::Value(specified_value) => {
                        let computed = specified_value.to_computed_value(context);
                            context.builder.set__moz_box_ordinal_group(computed)
                }
                DeclaredValue::WithVariables(_) => unreachable!(),
                DeclaredValue::CSSWideKeyword(keyword) => match keyword {
                    CSSWideKeyword::Unset |
                    CSSWideKeyword::Initial => {
                            context.builder.reset__moz_box_ordinal_group();
                    },
                    CSSWideKeyword::Inherit => {
                            context.rule_cache_conditions.borrow_mut().set_uncacheable();
                            context.builder.inherit__moz_box_ordinal_group();
                    }
                }
            }
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrdinalGroup)
        }
    }



}

macro_rules! unwrap_or_initial {
    ($prop: ident) => (unwrap_or_initial!($prop, $prop));
    ($prop: ident, $expr: expr) =>
        ($expr.unwrap_or_else(|| $prop::get_initial_specified_value()));
}

/// A module with code for all the shorthand css properties, and a few
/// serialization helpers.
#[allow(missing_docs)]
pub mod shorthands {
    use cssparser::Parser;
    use parser::{Parse, ParserContext};
    use style_traits::{ParseError, StyleParseErrorKind};
    use values::specified;

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

use style_traits::{CssWriter, ToCss};
use values::specified::{BorderStyle, Color};
use std::fmt::{self, Write};

fn serialize_directional_border<W, I,>(
    dest: &mut CssWriter<W>,
    width: &I,
    style: &BorderStyle,
    color: &Color,
) -> fmt::Result
where
    W: Write,
    I: ToCss,
{
    width.to_css(dest)?;
    dest.write_str(" ")?;
    style.to_css(dest)?;
    if *color != Color::CurrentColor {
        dest.write_str(" ")?;
        color.to_css(dest)?;
    }
    Ok(())
}

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */



// TODO: other background-* properties


    /// https://drafts.csswg.org/css-backgrounds/#the-background
    pub mod background {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub background_color:
                    longhands::background_color::SpecifiedValue
                    ,
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
                pub background_repeat:
                    longhands::background_repeat::SpecifiedValue
                    ,
                pub background_attachment:
                    longhands::background_attachment::SpecifiedValue
                    ,
                pub background_image:
                    longhands::background_image::SpecifiedValue
                    ,
                pub background_size:
                    longhands::background_size::SpecifiedValue
                    ,
                pub background_origin:
                    longhands::background_origin::SpecifiedValue
                    ,
                pub background_clip:
                    longhands::background_clip::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_color:
                    &'a longhands::background_color::SpecifiedValue,
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
                pub background_repeat:
                    &'a longhands::background_repeat::SpecifiedValue,
                pub background_attachment:
                    &'a longhands::background_attachment::SpecifiedValue,
                pub background_image:
                    &'a longhands::background_image::SpecifiedValue,
                pub background_size:
                    &'a longhands::background_size::SpecifiedValue,
                pub background_origin:
                    &'a longhands::background_origin::SpecifiedValue,
                pub background_clip:
                    &'a longhands::background_clip::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_color = None;
                    let mut background_position_x = None;
                    let mut background_position_y = None;
                    let mut background_repeat = None;
                    let mut background_attachment = None;
                    let mut background_image = None;
                    let mut background_size = None;
                    let mut background_origin = None;
                    let mut background_clip = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BackgroundColor(ref value) => {
                                background_color = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                            PropertyDeclaration::BackgroundRepeat(ref value) => {
                                background_repeat = Some(value)
                            },
                            PropertyDeclaration::BackgroundAttachment(ref value) => {
                                background_attachment = Some(value)
                            },
                            PropertyDeclaration::BackgroundImage(ref value) => {
                                background_image = Some(value)
                            },
                            PropertyDeclaration::BackgroundSize(ref value) => {
                                background_size = Some(value)
                            },
                            PropertyDeclaration::BackgroundOrigin(ref value) => {
                                background_origin = Some(value)
                            },
                            PropertyDeclaration::BackgroundClip(ref value) => {
                                background_clip = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_color,
                        background_position_x,
                        background_position_y,
                        background_repeat,
                        background_attachment,
                        background_image,
                        background_size,
                        background_origin,
                        background_clip,
                ) {

                    (
                        Some(background_color),
                        Some(background_position_x),
                        Some(background_position_y),
                        Some(background_repeat),
                        Some(background_attachment),
                        Some(background_image),
                        Some(background_size),
                        Some(background_origin),
                        Some(background_clip),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_color: background_color,
                            background_position_x: background_position_x,
                            background_position_y: background_position_y,
                            background_repeat: background_repeat,
                            background_attachment: background_attachment,
                            background_image: background_image,
                            background_size: background_size,
                            background_origin: background_origin,
                            background_clip: background_clip,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundColor(
                        longhands.background_color
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
                    declarations.push(PropertyDeclaration::BackgroundRepeat(
                        longhands.background_repeat
                    ));
                    declarations.push(PropertyDeclaration::BackgroundAttachment(
                        longhands.background_attachment
                    ));
                    declarations.push(PropertyDeclaration::BackgroundImage(
                        longhands.background_image
                    ));
                    declarations.push(PropertyDeclaration::BackgroundSize(
                        longhands.background_size
                    ));
                    declarations.push(PropertyDeclaration::BackgroundOrigin(
                        longhands.background_origin
                    ));
                    declarations.push(PropertyDeclaration::BackgroundClip(
                        longhands.background_clip
                    ));
            })
        }

        
    use properties::longhands::{background_position_x, background_position_y, background_repeat};
    use properties::longhands::{background_attachment, background_image, background_size, background_origin};
    use properties::longhands::background_clip;
    use properties::longhands::background_clip::single_value::computed_value::T as Clip;
    use properties::longhands::background_origin::single_value::computed_value::T as Origin;
    use values::specified::{Color, Position, PositionComponent};
    use parser::Parse;

    // FIXME(emilio): Should be the same type!
    impl From<background_origin::single_value::SpecifiedValue> for background_clip::single_value::SpecifiedValue {
        fn from(origin: background_origin::single_value::SpecifiedValue) ->
            background_clip::single_value::SpecifiedValue {
            match origin {
                background_origin::single_value::SpecifiedValue::ContentBox =>
                    background_clip::single_value::SpecifiedValue::ContentBox,
                background_origin::single_value::SpecifiedValue::PaddingBox =>
                    background_clip::single_value::SpecifiedValue::PaddingBox,
                background_origin::single_value::SpecifiedValue::BorderBox =>
                    background_clip::single_value::SpecifiedValue::BorderBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut background_color = None;

            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_image = background_image::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_position_x = background_position_x::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_position_y = background_position_y::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_repeat = background_repeat::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_size = background_size::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_attachment = background_attachment::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_origin = background_origin::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut background_clip = background_clip::SpecifiedValue(Vec::with_capacity(1));
        input.parse_comma_separated(|input| {
            // background-color can only be in the last element, so if it
            // is parsed anywhere before, the value is invalid.
            if background_color.is_some() {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }

                let mut image = None;
                let mut position = None;
                let mut repeat = None;
                let mut size = None;
                let mut attachment = None;
                let mut origin = None;
                let mut clip = None;
            loop {
                if background_color.is_none() {
                    if let Ok(value) = input.try(|i| Color::parse(context, i)) {
                        background_color = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|input| Position::parse(context, input)) {
                        position = Some(value);

                        // Parse background size, if applicable.
                        size = input.try(|input| {
                            input.expect_delim('/')?;
                            background_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if image.is_none() {
                        if let Ok(value) = input.try(|input| background_image::single_value
                                                                               ::parse(context, input)) {
                            image = Some(value);
                            continue
                        }
                    }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| background_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if attachment.is_none() {
                        if let Ok(value) = input.try(|input| background_attachment::single_value
                                                                               ::parse(context, input)) {
                            attachment = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try(|input| background_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try(|input| background_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(background_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || position.is_some();
                any = any || repeat.is_some();
                any = any || size.is_some();
                any = any || attachment.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
            any = any || background_color.is_some();
            if any {
                if let Some(position) = position {
                    background_position_x.0.push(position.horizontal);
                    background_position_y.0.push(position.vertical);
                } else {
                    background_position_x.0.push(PositionComponent::zero());
                    background_position_y.0.push(PositionComponent::zero());
                }
                    if let Some(bg_image) = image {
                        background_image.0.push(bg_image);
                    } else {
                        background_image.0.push(background_image::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_repeat) = repeat {
                        background_repeat.0.push(bg_repeat);
                    } else {
                        background_repeat.0.push(background_repeat::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_size) = size {
                        background_size.0.push(bg_size);
                    } else {
                        background_size.0.push(background_size::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_attachment) = attachment {
                        background_attachment.0.push(bg_attachment);
                    } else {
                        background_attachment.0.push(background_attachment::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_origin) = origin {
                        background_origin.0.push(bg_origin);
                    } else {
                        background_origin.0.push(background_origin::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_clip) = clip {
                        background_clip.0.push(bg_clip);
                    } else {
                        background_clip.0.push(background_clip::single_value
                                                                    ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
             background_color: background_color.unwrap_or(Color::transparent()),
             background_image: background_image,
             background_position_x: background_position_x,
             background_position_y: background_position_y,
             background_repeat: background_repeat,
             background_attachment: background_attachment,
             background_size: background_size,
             background_origin: background_origin,
             background_clip: background_clip,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_image.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If a value list length is differs then we don't do a shorthand serialization.
            // The exceptions to this is color which appears once only and is serialized
            // with the last item.
                if len != self.background_image.0.len() {
                    return Ok(());
                }
                if len != self.background_position_x.0.len() {
                    return Ok(());
                }
                if len != self.background_position_y.0.len() {
                    return Ok(());
                }
                if len != self.background_size.0.len() {
                    return Ok(());
                }
                if len != self.background_repeat.0.len() {
                    return Ok(());
                }
                if len != self.background_origin.0.len() {
                    return Ok(());
                }
                if len != self.background_clip.0.len() {
                    return Ok(());
                }
                if len != self.background_attachment.0.len() {
                    return Ok(());
                }

            for i in 0..len {
                    let image = &self.background_image.0[i];
                    let position_x = &self.background_position_x.0[i];
                    let position_y = &self.background_position_y.0[i];
                    let repeat = &self.background_repeat.0[i];
                    let size = &self.background_size.0[i];
                    let attachment = &self.background_attachment.0[i];
                    let origin = &self.background_origin.0[i];
                    let clip = &self.background_clip.0[i];

                if i != 0 {
                    dest.write_str(", ")?;
                }

                if i == len - 1 {
                    self.background_color.to_css(dest)?;
                    dest.write_str(" ")?;
                }

                image.to_css(dest)?;
                    dest.write_str(" ")?;
                    repeat.to_css(dest)?;
                    dest.write_str(" ")?;
                    attachment.to_css(dest)?;

                dest.write_str(" ")?;
                Position {
                    horizontal: position_x.clone(),
                    vertical: position_y.clone()
                }.to_css(dest)?;

                if *size != background_size::single_value::get_initial_specified_value() {
                    dest.write_str(" / ")?;
                    size.to_css(dest)?;
                }

                if *origin != Origin::PaddingBox || *clip != Clip::BorderBox {
                    dest.write_str(" ")?;
                    origin.to_css(dest)?;
                    if *clip != From::from(*origin) {
                        dest.write_str(" ")?;
                        clip.to_css(dest)?;
                    }
                }
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-4/#the-background-position
    pub mod background_position {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_position_x = None;
                    let mut background_position_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_position_x,
                        background_position_y,
                ) {

                    (
                        Some(background_position_x),
                        Some(background_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_position_x: background_position_x,
                            background_position_y: background_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
            })
        }

        
    use properties::longhands::{background_position_x, background_position_y};
    use values::specified::AllowQuirks;
    use values::specified::position::Position;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate.  Note that we always push at least one item if parsing
        // succeeds.
        let mut position_x = background_position_x::SpecifiedValue(Vec::with_capacity(1));
        let mut position_y = background_position_y::SpecifiedValue(Vec::with_capacity(1));
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse_quirky(context, input, AllowQuirks::Yes)?;
            position_x.0.push(value.horizontal);
            position_y.0.push(value.vertical);
            any = true;
            Ok(())
        })?;
        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            background_position_x: position_x,
            background_position_y: position_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_position_x.0.len();
            if len == 0 || len != self.background_position_y.0.len() {
                return Ok(());
            }
            for i in 0..len {
                Position {
                    horizontal: self.background_position_x.0[i].clone(),
                    vertical: self.background_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-color
    pub mod border_color {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_right_color = None;
                    let mut border_bottom_color = None;
                    let mut border_left_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_right_color,
                        border_bottom_color,
                        border_left_color,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_right_color),
                        Some(border_bottom_color),
                        Some(border_left_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color: border_top_color,
                            border_right_color: border_right_color,
                            border_bottom_color: border_bottom_color,
                            border_left_color: border_left_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::Color::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    border_top_color: rect.0,
                    border_right_color: rect.1,
                    border_bottom_color: rect.2,
                    border_left_color: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_color,
                    &self.border_right_color,
                    &self.border_bottom_color,
                    &self.border_left_color,
                );
                rect.to_css(dest)
            }
        }
    
    }




    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-style
    pub mod border_style {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_style = None;
                    let mut border_right_style = None;
                    let mut border_bottom_style = None;
                    let mut border_left_style = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_style,
                        border_right_style,
                        border_bottom_style,
                        border_left_style,
                ) {

                    (
                        Some(border_top_style),
                        Some(border_right_style),
                        Some(border_bottom_style),
                        Some(border_left_style),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_style: border_top_style,
                            border_right_style: border_right_style,
                            border_bottom_style: border_bottom_style,
                            border_left_style: border_left_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::BorderStyle::parse(_c, i)
            })?;
            Ok(expanded! {
                    border_top_style: rect.0,
                    border_right_style: rect.1,
                    border_bottom_style: rect.2,
                    border_left_style: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_style,
                    &self.border_right_style,
                    &self.border_bottom_style,
                    &self.border_left_style,
                );
                rect.to_css(dest)
            }
        }
    
    }





    /// https://drafts.csswg.org/css-backgrounds/#border-width
    pub mod border_width {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_width = None;
                    let mut border_left_width = None;
                    let mut border_bottom_width = None;
                    let mut border_right_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_width,
                        border_left_width,
                        border_bottom_width,
                        border_right_width,
                ) {

                    (
                        Some(border_top_width),
                        Some(border_left_width),
                        Some(border_bottom_width),
                        Some(border_right_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_width: border_top_width,
                            border_left_width: border_left_width,
                            border_bottom_width: border_bottom_width,
                            border_right_width: border_right_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::specified::{AllowQuirks, BorderSideWidth};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let rect = Rect::parse_with(context, input, |_, i| {
            BorderSideWidth::parse_quirky(context, i, AllowQuirks::Yes)
        })?;
        Ok(expanded! {
            border_top_width: rect.0,
            border_right_width: rect.1,
            border_bottom_width: rect.2,
            border_left_width: rect.3,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let top = &self.border_top_width;
            let left = &self.border_left_width;
            let bottom = &self.border_bottom_width;
            let right = &self.border_right_width;
            Rect::new(top, right, bottom, left).to_css(dest)
        }
    }

    }



pub fn parse_border<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                            -> Result<(specified::Color,
                                       specified::BorderStyle,
                                       specified::BorderSideWidth), ParseError<'i>> {
    use values::specified::{Color, BorderStyle, BorderSideWidth};
    let _unused = context;
    let mut color = None;
    let mut style = None;
    let mut width = None;
    let mut any = false;
    loop {
        if color.is_none() {
            if let Ok(value) = input.try(|i| Color::parse(context, i)) {
                color = Some(value);
                any = true;
                continue
            }
        }
        if style.is_none() {
            if let Ok(value) = input.try(|i| BorderStyle::parse(context, i)) {
                style = Some(value);
                any = true;
                continue
            }
        }
        if width.is_none() {
            if let Ok(value) = input.try(|i| BorderSideWidth::parse(context, i)) {
                width = Some(value);
                any = true;
                continue
            }
        }
        break
    }
    if any {
        Ok((color.unwrap_or_else(|| Color::currentcolor()),
            style.unwrap_or(BorderStyle::None),
            width.unwrap_or(BorderSideWidth::Medium)))
    } else {
        Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
    }
}

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-top
    pub mod border_top {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_top_style = None;
                    let mut border_top_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_top_style,
                        border_top_width,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_top_style),
                        Some(border_top_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color: border_top_color,
                            border_top_style: border_top_style,
                            border_top_width: border_top_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_top_color: color,
            border_top_style: style,
            border_top_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_top_width,
                self.border_top_style,
                self.border_top_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-left
    pub mod border_left {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_left_color = None;
                    let mut border_left_style = None;
                    let mut border_left_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_left_color,
                        border_left_style,
                        border_left_width,
                ) {

                    (
                        Some(border_left_color),
                        Some(border_left_style),
                        Some(border_left_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_left_color: border_left_color,
                            border_left_style: border_left_style,
                            border_left_width: border_left_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_left_color: color,
            border_left_style: style,
            border_left_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_left_width,
                self.border_left_style,
                self.border_left_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-bottom
    pub mod border_bottom {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_bottom_color = None;
                    let mut border_bottom_style = None;
                    let mut border_bottom_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_bottom_color,
                        border_bottom_style,
                        border_bottom_width,
                ) {

                    (
                        Some(border_bottom_color),
                        Some(border_bottom_style),
                        Some(border_bottom_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_bottom_color: border_bottom_color,
                            border_bottom_style: border_bottom_style,
                            border_bottom_width: border_bottom_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_bottom_color: color,
            border_bottom_style: style,
            border_bottom_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_bottom_width,
                self.border_bottom_style,
                self.border_bottom_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-right
    pub mod border_right {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_right_color = None;
                    let mut border_right_style = None;
                    let mut border_right_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_right_color,
                        border_right_style,
                        border_right_width,
                ) {

                    (
                        Some(border_right_color),
                        Some(border_right_style),
                        Some(border_right_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_right_color: border_right_color,
                            border_right_style: border_right_style,
                            border_right_width: border_right_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_right_color: color,
            border_right_style: style,
            border_right_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_right_width,
                self.border_right_style,
                self.border_right_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start
    pub mod border_block_start {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_block_start_color:
                    longhands::border_block_start_color::SpecifiedValue
                    ,
                pub border_block_start_style:
                    longhands::border_block_start_style::SpecifiedValue
                    ,
                pub border_block_start_width:
                    longhands::border_block_start_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_color:
                    &'a longhands::border_block_start_color::SpecifiedValue,
                pub border_block_start_style:
                    &'a longhands::border_block_start_style::SpecifiedValue,
                pub border_block_start_width:
                    &'a longhands::border_block_start_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_color = None;
                    let mut border_block_start_style = None;
                    let mut border_block_start_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                                border_block_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                                border_block_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                                border_block_start_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_color,
                        border_block_start_style,
                        border_block_start_width,
                ) {

                    (
                        Some(border_block_start_color),
                        Some(border_block_start_style),
                        Some(border_block_start_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_color: border_block_start_color,
                            border_block_start_style: border_block_start_style,
                            border_block_start_width: border_block_start_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartColor(
                        longhands.border_block_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartStyle(
                        longhands.border_block_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartWidth(
                        longhands.border_block_start_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_start_color: color,
            border_block_start_style: style,
            border_block_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_block_start_width,
                self.border_block_start_style,
                self.border_block_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end
    pub mod border_block_end {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_block_end_color:
                    longhands::border_block_end_color::SpecifiedValue
                    ,
                pub border_block_end_style:
                    longhands::border_block_end_style::SpecifiedValue
                    ,
                pub border_block_end_width:
                    longhands::border_block_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_end_color:
                    &'a longhands::border_block_end_color::SpecifiedValue,
                pub border_block_end_style:
                    &'a longhands::border_block_end_style::SpecifiedValue,
                pub border_block_end_width:
                    &'a longhands::border_block_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_end_color = None;
                    let mut border_block_end_style = None;
                    let mut border_block_end_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                                border_block_end_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                                border_block_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                                border_block_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_end_color,
                        border_block_end_style,
                        border_block_end_width,
                ) {

                    (
                        Some(border_block_end_color),
                        Some(border_block_end_style),
                        Some(border_block_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_end_color: border_block_end_color,
                            border_block_end_style: border_block_end_style,
                            border_block_end_width: border_block_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockEndColor(
                        longhands.border_block_end_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndStyle(
                        longhands.border_block_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndWidth(
                        longhands.border_block_end_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_end_color: color,
            border_block_end_style: style,
            border_block_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_block_end_width,
                self.border_block_end_style,
                self.border_block_end_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start
    pub mod border_inline_start {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_inline_start_color:
                    longhands::border_inline_start_color::SpecifiedValue
                    ,
                pub border_inline_start_style:
                    longhands::border_inline_start_style::SpecifiedValue
                    ,
                pub border_inline_start_width:
                    longhands::border_inline_start_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_color:
                    &'a longhands::border_inline_start_color::SpecifiedValue,
                pub border_inline_start_style:
                    &'a longhands::border_inline_start_style::SpecifiedValue,
                pub border_inline_start_width:
                    &'a longhands::border_inline_start_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_color = None;
                    let mut border_inline_start_style = None;
                    let mut border_inline_start_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                                border_inline_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                                border_inline_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                                border_inline_start_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_color,
                        border_inline_start_style,
                        border_inline_start_width,
                ) {

                    (
                        Some(border_inline_start_color),
                        Some(border_inline_start_style),
                        Some(border_inline_start_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_color: border_inline_start_color,
                            border_inline_start_style: border_inline_start_style,
                            border_inline_start_width: border_inline_start_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartColor(
                        longhands.border_inline_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartStyle(
                        longhands.border_inline_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartWidth(
                        longhands.border_inline_start_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_start_color: color,
            border_inline_start_style: style,
            border_inline_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_inline_start_width,
                self.border_inline_start_style,
                self.border_inline_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end
    pub mod border_inline_end {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_inline_end_color:
                    longhands::border_inline_end_color::SpecifiedValue
                    ,
                pub border_inline_end_style:
                    longhands::border_inline_end_style::SpecifiedValue
                    ,
                pub border_inline_end_width:
                    longhands::border_inline_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_end_color:
                    &'a longhands::border_inline_end_color::SpecifiedValue,
                pub border_inline_end_style:
                    &'a longhands::border_inline_end_style::SpecifiedValue,
                pub border_inline_end_width:
                    &'a longhands::border_inline_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_end_color = None;
                    let mut border_inline_end_style = None;
                    let mut border_inline_end_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                                border_inline_end_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                                border_inline_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                                border_inline_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_end_color,
                        border_inline_end_style,
                        border_inline_end_width,
                ) {

                    (
                        Some(border_inline_end_color),
                        Some(border_inline_end_style),
                        Some(border_inline_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_end_color: border_inline_end_color,
                            border_inline_end_style: border_inline_end_style,
                            border_inline_end_width: border_inline_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineEndColor(
                        longhands.border_inline_end_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndStyle(
                        longhands.border_inline_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndWidth(
                        longhands.border_inline_end_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_end_color: color,
            border_inline_end_style: style,
            border_inline_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            super::serialize_directional_border(
                dest,
                self.border_inline_end_width,
                self.border_inline_end_style,
                self.border_inline_end_color
            )
        }
    }

    
    }




    /// https://drafts.csswg.org/css-backgrounds/#border
    pub mod border {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                        Box<
                    longhands::border_image_source::SpecifiedValue
                        >
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color = None;
                    let mut border_top_style = None;
                    let mut border_top_width = None;
                    let mut border_left_color = None;
                    let mut border_left_style = None;
                    let mut border_left_width = None;
                    let mut border_bottom_color = None;
                    let mut border_bottom_style = None;
                    let mut border_bottom_width = None;
                    let mut border_right_color = None;
                    let mut border_right_style = None;
                    let mut border_right_width = None;
                    let mut border_image_outset = None;
                    let mut border_image_repeat = None;
                    let mut border_image_slice = None;
                    let mut border_image_source = None;
                    let mut border_image_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_top_style,
                        border_top_width,
                        border_left_color,
                        border_left_style,
                        border_left_width,
                        border_bottom_color,
                        border_bottom_style,
                        border_bottom_width,
                        border_right_color,
                        border_right_style,
                        border_right_width,
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_top_style),
                        Some(border_top_width),
                        Some(border_left_color),
                        Some(border_left_style),
                        Some(border_left_width),
                        Some(border_bottom_color),
                        Some(border_bottom_style),
                        Some(border_bottom_width),
                        Some(border_right_color),
                        Some(border_right_style),
                        Some(border_right_width),
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color: border_top_color,
                            border_top_style: border_top_style,
                            border_top_width: border_top_width,
                            border_left_color: border_left_color,
                            border_left_style: border_left_style,
                            border_left_width: border_left_width,
                            border_bottom_color: border_bottom_color,
                            border_bottom_style: border_bottom_style,
                            border_bottom_width: border_bottom_width,
                            border_right_color: border_right_color,
                            border_right_style: border_right_style,
                            border_right_width: border_right_width,
                            border_image_outset: border_image_outset,
                            border_image_repeat: border_image_repeat,
                            border_image_slice: border_image_slice,
                            border_image_source: border_image_source,
                            border_image_width: border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        use properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
        use properties::longhands::{border_image_source, border_image_width};

        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
                border_top_color: color.clone(),
                border_top_style: style,
                border_top_width: width.clone(),
                border_left_color: color.clone(),
                border_left_style: style,
                border_left_width: width.clone(),
                border_bottom_color: color.clone(),
                border_bottom_style: style,
                border_bottom_width: width.clone(),
                border_right_color: color.clone(),
                border_right_style: style,
                border_right_width: width.clone(),

            // The ‘border’ shorthand resets ‘border-image’ to its initial value.
            // See https://drafts.csswg.org/css-backgrounds-3/#the-border-shorthands
                border_image_outset: border_image_outset::get_initial_specified_value(),
                border_image_repeat: border_image_repeat::get_initial_specified_value(),
                border_image_slice: border_image_slice::get_initial_specified_value(),
                border_image_source: border_image_source::get_initial_specified_value(),
                border_image_width: border_image_width::get_initial_specified_value(),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let all_equal = {
                  let border_top_width = self.border_top_width;
                  let border_top_style = self.border_top_style;
                  let border_top_color = self.border_top_color;
                  let border_left_width = self.border_left_width;
                  let border_left_style = self.border_left_style;
                  let border_left_color = self.border_left_color;
                  let border_bottom_width = self.border_bottom_width;
                  let border_bottom_style = self.border_bottom_style;
                  let border_bottom_color = self.border_bottom_color;
                  let border_right_width = self.border_right_width;
                  let border_right_style = self.border_right_style;
                  let border_right_color = self.border_right_color;

                border_top_width == border_right_width &&
                border_right_width == border_bottom_width &&
                border_bottom_width == border_left_width &&

                border_top_style == border_right_style &&
                border_right_style == border_bottom_style &&
                border_bottom_style == border_left_style &&

                border_top_color == border_right_color &&
                border_right_color == border_bottom_color &&
                border_bottom_color == border_left_color
            };

            // If all longhands are all present, then all sides should be the same,
            // so we can just one set of color/style/width
            if all_equal {
                super::serialize_directional_border(
                    dest,
                    self.border_right_width,
                    self.border_right_style,
                    self.border_right_color
                )
            } else {
                Ok(())
            }
        }
    }


    }




    /// https://drafts.csswg.org/css-backgrounds/#border-radius
    pub mod border_radius {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_top_left_radius:
                        Box<
                    longhands::border_top_left_radius::SpecifiedValue
                        >
                    ,
                pub border_top_right_radius:
                        Box<
                    longhands::border_top_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_right_radius:
                        Box<
                    longhands::border_bottom_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_left_radius:
                        Box<
                    longhands::border_bottom_left_radius::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_left_radius:
                    &'a longhands::border_top_left_radius::SpecifiedValue,
                pub border_top_right_radius:
                    &'a longhands::border_top_right_radius::SpecifiedValue,
                pub border_bottom_right_radius:
                    &'a longhands::border_bottom_right_radius::SpecifiedValue,
                pub border_bottom_left_radius:
                    &'a longhands::border_bottom_left_radius::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_left_radius = None;
                    let mut border_top_right_radius = None;
                    let mut border_bottom_right_radius = None;
                    let mut border_bottom_left_radius = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                                border_top_left_radius = Some(value)
                            },
                            PropertyDeclaration::BorderTopRightRadius(ref value) => {
                                border_top_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                                border_bottom_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                                border_bottom_left_radius = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_left_radius,
                        border_top_right_radius,
                        border_bottom_right_radius,
                        border_bottom_left_radius,
                ) {

                    (
                        Some(border_top_left_radius),
                        Some(border_top_right_radius),
                        Some(border_bottom_right_radius),
                        Some(border_bottom_left_radius),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_left_radius: border_top_left_radius,
                            border_top_right_radius: border_top_right_radius,
                            border_bottom_right_radius: border_bottom_right_radius,
                            border_bottom_left_radius: border_bottom_left_radius,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopLeftRadius(
                        longhands.border_top_left_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderTopRightRadius(
                        longhands.border_top_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomRightRadius(
                        longhands.border_bottom_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomLeftRadius(
                        longhands.border_bottom_left_radius
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::generics::border::BorderCornerRadius;
    use values::specified::border::BorderRadius;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let radii = BorderRadius::parse(context, input)?;
        Ok(expanded! {
            border_top_left_radius: radii.top_left,
            border_top_right_radius: radii.top_right,
            border_bottom_right_radius: radii.bottom_right,
            border_bottom_left_radius: radii.bottom_left,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let LonghandsToSerialize {
                border_top_left_radius: &BorderCornerRadius(ref tl),
                border_top_right_radius: &BorderCornerRadius(ref tr),
                border_bottom_right_radius: &BorderCornerRadius(ref br),
                border_bottom_left_radius: &BorderCornerRadius(ref bl),
            } = *self;


            let widths = Rect::new(tl.width(), tr.width(), br.width(), bl.width());
            let heights = Rect::new(tl.height(), tr.height(), br.height(), bl.height());

            BorderRadius::serialize_rects(widths, heights, dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-3/#border-image
    pub mod border_image {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                        Box<
                    longhands::border_image_source::SpecifiedValue
                        >
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_image_outset = None;
                    let mut border_image_repeat = None;
                    let mut border_image_slice = None;
                    let mut border_image_source = None;
                    let mut border_image_width = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_image_outset: border_image_outset,
                            border_image_repeat: border_image_repeat,
                            border_image_slice: border_image_slice,
                            border_image_source: border_image_source,
                            border_image_width: border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        
    use properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
    use properties::longhands::{border_image_source, border_image_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let mut border_image_outset = border_image_outset::get_initial_specified_value();
            let mut border_image_repeat = border_image_repeat::get_initial_specified_value();
            let mut border_image_slice = border_image_slice::get_initial_specified_value();
            let mut border_image_source = border_image_source::get_initial_specified_value();
            let mut border_image_width = border_image_width::get_initial_specified_value();

        let result: Result<_, ParseError> = input.try(|input| {
                let mut outset = None;
                let mut repeat = None;
                let mut slice = None;
                let mut source = None;
                let mut width = None;
            loop {
                if slice.is_none() {
                    if let Ok(value) = input.try(|input| border_image_slice::parse(context, input)) {
                        slice = Some(value);
                        // Parse border image width and outset, if applicable.
                        let maybe_width_outset: Result<_, ParseError> = input.try(|input| {
                            input.expect_delim('/')?;

                            // Parse border image width, if applicable.
                            let w = input.try(|input|
                                border_image_width::parse(context, input)).ok();

                            // Parse border image outset if applicable.
                            let o = input.try(|input| {
                                input.expect_delim('/')?;
                                border_image_outset::parse(context, input)
                            }).ok();
                            if w.is_none() && o.is_none() {
                               Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                            }
                            else {
                               Ok((w, o))
                            }
                        });
                        if let Ok((w, o)) = maybe_width_outset {
                            width = w;
                            outset = o;
                        }

                        continue
                    }
                }
                    if source.is_none() {
                        if let Ok(value) = input.try(|input| border_image_source::parse(context, input)) {
                            source = Some(value);
                            continue
                        }
                    }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| border_image_repeat::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                break
            }
            let mut any = false;
                any = any || outset.is_some();
                any = any || repeat.is_some();
                any = any || slice.is_some();
                any = any || source.is_some();
                any = any || width.is_some();
            if any {
                    if let Some(b_outset) = outset {
                        border_image_outset = b_outset;
                    }
                    if let Some(b_repeat) = repeat {
                        border_image_repeat = b_repeat;
                    }
                    if let Some(b_slice) = slice {
                        border_image_slice = b_slice;
                    }
                    if let Some(b_source) = source {
                        border_image_source = b_source;
                    }
                    if let Some(b_width) = width {
                        border_image_width = b_width;
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        });
        result?;

        Ok(expanded! {
                border_image_outset: border_image_outset,
                border_image_repeat: border_image_repeat,
                border_image_slice: border_image_slice,
                border_image_source: border_image_source,
                border_image_width: border_image_width,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.border_image_source.to_css(dest)?;
            dest.write_str(" ")?;
            self.border_image_slice.to_css(dest)?;
            dest.write_str(" / ")?;
            self.border_image_width.to_css(dest)?;
            dest.write_str(" / ")?;
            self.border_image_outset.to_css(dest)?;
            dest.write_str(" ")?;
            self.border_image_repeat.to_css(dest)
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-overflow/#propdef-overflow
    pub mod overflow {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overflow_x:
                    longhands::overflow_x::SpecifiedValue
                    ,
                pub overflow_y:
                    longhands::overflow_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_x:
                    &'a longhands::overflow_x::SpecifiedValue,
                pub overflow_y:
                    &'a longhands::overflow_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_x = None;
                    let mut overflow_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverflowX(ref value) => {
                                overflow_x = Some(value)
                            },
                            PropertyDeclaration::OverflowY(ref value) => {
                                overflow_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_x,
                        overflow_y,
                ) {

                    (
                        Some(overflow_x),
                        Some(overflow_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_x: overflow_x,
                            overflow_y: overflow_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowX(
                        longhands.overflow_x
                    ));
                    declarations.push(PropertyDeclaration::OverflowY(
                        longhands.overflow_y
                    ));
            })
        }

        
    use properties::longhands::overflow_x::parse as parse_overflow;
        use properties::longhands::overflow_x::SpecifiedValue;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let moz_kw_found = input.try(|input| {
                try_match_ident_ignore_ascii_case! { input,
                    "-moz-scrollbars-horizontal" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Scroll,
                            overflow_y: SpecifiedValue::Hidden,
                        })
                    }
                    "-moz-scrollbars-vertical" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Hidden,
                            overflow_y: SpecifiedValue::Scroll,
                        })
                    }
                    "-moz-scrollbars-none" => {
                        Ok(expanded! {
                            overflow_x: SpecifiedValue::Hidden,
                            overflow_y: SpecifiedValue::Hidden,
                        })
                    }
                }
            });
            if moz_kw_found.is_ok() {
                return moz_kw_found
            }
        let overflow = parse_overflow(context, input)?;
        Ok(expanded! {
            overflow_x: overflow,
            overflow_y: overflow,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.overflow_x == self.overflow_y {
                self.overflow_x.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }




    /// Internal, may be standardized in the future 
    pub mod overflow_clip_box {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overflow_clip_box_block:
                    longhands::overflow_clip_box_block::SpecifiedValue
                    ,
                pub overflow_clip_box_inline:
                    longhands::overflow_clip_box_inline::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_clip_box_block:
                    &'a longhands::overflow_clip_box_block::SpecifiedValue,
                pub overflow_clip_box_inline:
                    &'a longhands::overflow_clip_box_inline::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_clip_box_block = None;
                    let mut overflow_clip_box_inline = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                                overflow_clip_box_block = Some(value)
                            },
                            PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                                overflow_clip_box_inline = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_clip_box_block,
                        overflow_clip_box_inline,
                ) {

                    (
                        Some(overflow_clip_box_block),
                        Some(overflow_clip_box_inline),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_clip_box_block: overflow_clip_box_block,
                            overflow_clip_box_inline: overflow_clip_box_inline,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowClipBoxBlock(
                        longhands.overflow_clip_box_block
                    ));
                    declarations.push(PropertyDeclaration::OverflowClipBoxInline(
                        longhands.overflow_clip_box_inline
                    ));
            })
        }

        
    use values::specified::OverflowClipBox;
    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let block_value = OverflowClipBox::parse(input)?;
        let inline_value =
            input.try(|input| OverflowClipBox::parse(input)).unwrap_or(block_value);

        Ok(expanded! {
          overflow_clip_box_block: block_value,
          overflow_clip_box_inline: inline_value,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.overflow_clip_box_block.to_css(dest)?;

            if self.overflow_clip_box_block != self.overflow_clip_box_inline {
                dest.write_str(" ")?;
                self.overflow_clip_box_inline.to_css(dest)?;
            }

            Ok(())
        }
    }

    }


macro_rules! try_parse_one {
    ($context: expr, $input: expr, $var: ident, $prop_module: ident) => {
        if $var.is_none() {
            if let Ok(value) = $input.try(|i| {
                $prop_module::single_value::parse($context, i)
            }) {
                $var = Some(value);
                continue;
            }
        }
    };
}



    /// https://drafts.csswg.org/css-transitions/#propdef-transition
    pub mod transition {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub transition_property:
                    longhands::transition_property::SpecifiedValue
                    ,
                pub transition_duration:
                    longhands::transition_duration::SpecifiedValue
                    ,
                pub transition_timing_function:
                    longhands::transition_timing_function::SpecifiedValue
                    ,
                pub transition_delay:
                    longhands::transition_delay::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub transition_property:
                    &'a longhands::transition_property::SpecifiedValue,
                pub transition_duration:
                    &'a longhands::transition_duration::SpecifiedValue,
                pub transition_timing_function:
                    &'a longhands::transition_timing_function::SpecifiedValue,
                pub transition_delay:
                    &'a longhands::transition_delay::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut transition_property = None;
                    let mut transition_duration = None;
                    let mut transition_timing_function = None;
                    let mut transition_delay = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TransitionProperty(ref value) => {
                                transition_property = Some(value)
                            },
                            PropertyDeclaration::TransitionDuration(ref value) => {
                                transition_duration = Some(value)
                            },
                            PropertyDeclaration::TransitionTimingFunction(ref value) => {
                                transition_timing_function = Some(value)
                            },
                            PropertyDeclaration::TransitionDelay(ref value) => {
                                transition_delay = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        transition_property,
                        transition_duration,
                        transition_timing_function,
                        transition_delay,
                ) {

                    (
                        Some(transition_property),
                        Some(transition_duration),
                        Some(transition_timing_function),
                        Some(transition_delay),
                    ) =>
                    Ok(LonghandsToSerialize {
                            transition_property: transition_property,
                            transition_duration: transition_duration,
                            transition_timing_function: transition_timing_function,
                            transition_delay: transition_delay,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TransitionProperty(
                        longhands.transition_property
                    ));
                    declarations.push(PropertyDeclaration::TransitionDuration(
                        longhands.transition_duration
                    ));
                    declarations.push(PropertyDeclaration::TransitionTimingFunction(
                        longhands.transition_timing_function
                    ));
                    declarations.push(PropertyDeclaration::TransitionDelay(
                        longhands.transition_delay
                    ));
            })
        }

        
    use properties::longhands::transition_delay;
    use properties::longhands::transition_duration;
    use properties::longhands::transition_property;
    use properties::longhands::transition_timing_function;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        struct SingleTransition {
            transition_duration: transition_duration::SingleSpecifiedValue,
            transition_timing_function: transition_timing_function::SingleSpecifiedValue,
            transition_delay: transition_delay::SingleSpecifiedValue,
            // Unlike other properties, transition-property uses an Option<> to
            // represent 'none' as `None`.
            transition_property: Option<transition_property::SingleSpecifiedValue>,
        }

        fn parse_one_transition<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                        -> Result<SingleTransition,ParseError<'i>> {
            let mut property = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;

            let mut parsed = 0;
            loop {
                parsed += 1;

                try_parse_one!(context, input, duration, transition_duration);
                try_parse_one!(context, input, timing_function, transition_timing_function);
                try_parse_one!(context, input, delay, transition_delay);
                // Must check 'transition-property' after 'transition-timing-function' since
                // 'transition-property' accepts any keyword.
                if property.is_none() {
                    if let Ok(value) = input.try(|i| transition_property::SingleSpecifiedValue::parse(i)) {
                        property = Some(Some(value));
                        continue;
                    } else if input.try(|i| i.expect_ident_matching("none")).is_ok() {
                        // 'none' is not a valid value for <single-transition-property>,
                        // so it's not acceptable in the function above.
                        property = Some(None);
                        continue;
                    }
                }

                parsed -= 1;
                break
            }

            if parsed != 0 {
                Ok(SingleTransition {
                    transition_duration: duration.unwrap_or_else(transition_duration::single_value
                                                                                 ::get_initial_specified_value),
                    transition_timing_function: timing_function.unwrap_or_else(transition_timing_function::single_value
                                                                                 ::get_initial_specified_value),
                    transition_delay: delay.unwrap_or_else(transition_delay::single_value
                                                                                 ::get_initial_specified_value),
                    transition_property: property.unwrap_or(
                        Some(transition_property::single_value::get_initial_specified_value())),
                })
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        let mut propertys = Vec::new();
        let mut durations = Vec::new();
        let mut timing_functions = Vec::new();
        let mut delays = Vec::new();

        let results = input.parse_comma_separated(|i| parse_one_transition(context, i))?;
        let multiple_items = results.len() >= 2;
        for result in results {
            if let Some(value) = result.transition_property {
                propertys.push(value);
            } else if multiple_items {
                // If there is more than one item, and any of transitions has 'none',
                // then it's invalid. Othersize, leave propertys to be empty (which
                // means "transition-property: none");
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }

            durations.push(result.transition_duration);
            timing_functions.push(result.transition_timing_function);
            delays.push(result.transition_delay);
        }

        Ok(expanded! {
            transition_property: transition_property::SpecifiedValue(propertys),
            transition_duration: transition_duration::SpecifiedValue(durations),
            transition_timing_function: transition_timing_function::SpecifiedValue(timing_functions),
            transition_delay: transition_delay::SpecifiedValue(delays),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let property_len = self.transition_property.0.len();

            // There are two cases that we can do shorthand serialization:
            // * when all value lists have the same length, or
            // * when transition-property is none, and other value lists have exactly one item.
            if property_len == 0 {
                    if self.transition_duration.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != 1 {
                        return Ok(());
                    }
            } else {
                    if self.transition_duration.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != property_len {
                        return Ok(());
                    }
            }

            // Representative length.
            let len = self.transition_duration.0.len();

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }
                if property_len == 0 {
                    dest.write_str("none")?;
                } else {
                    self.transition_property.0[i].to_css(dest)?;
                }
                    dest.write_str(" ")?;
                    self.transition_duration.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.transition_timing_function.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.transition_delay.0[i].to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-animations/#propdef-animation
    pub mod animation {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub animation_name:
                    longhands::animation_name::SpecifiedValue
                    ,
                pub animation_duration:
                    longhands::animation_duration::SpecifiedValue
                    ,
                pub animation_timing_function:
                    longhands::animation_timing_function::SpecifiedValue
                    ,
                pub animation_delay:
                    longhands::animation_delay::SpecifiedValue
                    ,
                pub animation_iteration_count:
                    longhands::animation_iteration_count::SpecifiedValue
                    ,
                pub animation_direction:
                    longhands::animation_direction::SpecifiedValue
                    ,
                pub animation_fill_mode:
                    longhands::animation_fill_mode::SpecifiedValue
                    ,
                pub animation_play_state:
                    longhands::animation_play_state::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub animation_name:
                    &'a longhands::animation_name::SpecifiedValue,
                pub animation_duration:
                    &'a longhands::animation_duration::SpecifiedValue,
                pub animation_timing_function:
                    &'a longhands::animation_timing_function::SpecifiedValue,
                pub animation_delay:
                    &'a longhands::animation_delay::SpecifiedValue,
                pub animation_iteration_count:
                    &'a longhands::animation_iteration_count::SpecifiedValue,
                pub animation_direction:
                    &'a longhands::animation_direction::SpecifiedValue,
                pub animation_fill_mode:
                    &'a longhands::animation_fill_mode::SpecifiedValue,
                pub animation_play_state:
                    &'a longhands::animation_play_state::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut animation_name = None;
                    let mut animation_duration = None;
                    let mut animation_timing_function = None;
                    let mut animation_delay = None;
                    let mut animation_iteration_count = None;
                    let mut animation_direction = None;
                    let mut animation_fill_mode = None;
                    let mut animation_play_state = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AnimationName(ref value) => {
                                animation_name = Some(value)
                            },
                            PropertyDeclaration::AnimationDuration(ref value) => {
                                animation_duration = Some(value)
                            },
                            PropertyDeclaration::AnimationTimingFunction(ref value) => {
                                animation_timing_function = Some(value)
                            },
                            PropertyDeclaration::AnimationDelay(ref value) => {
                                animation_delay = Some(value)
                            },
                            PropertyDeclaration::AnimationIterationCount(ref value) => {
                                animation_iteration_count = Some(value)
                            },
                            PropertyDeclaration::AnimationDirection(ref value) => {
                                animation_direction = Some(value)
                            },
                            PropertyDeclaration::AnimationFillMode(ref value) => {
                                animation_fill_mode = Some(value)
                            },
                            PropertyDeclaration::AnimationPlayState(ref value) => {
                                animation_play_state = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        animation_name,
                        animation_duration,
                        animation_timing_function,
                        animation_delay,
                        animation_iteration_count,
                        animation_direction,
                        animation_fill_mode,
                        animation_play_state,
                ) {

                    (
                        Some(animation_name),
                        Some(animation_duration),
                        Some(animation_timing_function),
                        Some(animation_delay),
                        Some(animation_iteration_count),
                        Some(animation_direction),
                        Some(animation_fill_mode),
                        Some(animation_play_state),
                    ) =>
                    Ok(LonghandsToSerialize {
                            animation_name: animation_name,
                            animation_duration: animation_duration,
                            animation_timing_function: animation_timing_function,
                            animation_delay: animation_delay,
                            animation_iteration_count: animation_iteration_count,
                            animation_direction: animation_direction,
                            animation_fill_mode: animation_fill_mode,
                            animation_play_state: animation_play_state,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AnimationName(
                        longhands.animation_name
                    ));
                    declarations.push(PropertyDeclaration::AnimationDuration(
                        longhands.animation_duration
                    ));
                    declarations.push(PropertyDeclaration::AnimationTimingFunction(
                        longhands.animation_timing_function
                    ));
                    declarations.push(PropertyDeclaration::AnimationDelay(
                        longhands.animation_delay
                    ));
                    declarations.push(PropertyDeclaration::AnimationIterationCount(
                        longhands.animation_iteration_count
                    ));
                    declarations.push(PropertyDeclaration::AnimationDirection(
                        longhands.animation_direction
                    ));
                    declarations.push(PropertyDeclaration::AnimationFillMode(
                        longhands.animation_fill_mode
                    ));
                    declarations.push(PropertyDeclaration::AnimationPlayState(
                        longhands.animation_play_state
                    ));
            })
        }

        
    
    use properties::longhands::animation_name;
    use properties::longhands::animation_duration;
    use properties::longhands::animation_timing_function;
    use properties::longhands::animation_delay;
    use properties::longhands::animation_iteration_count;
    use properties::longhands::animation_direction;
    use properties::longhands::animation_fill_mode;
    use properties::longhands::animation_play_state;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        struct SingleAnimation {
            animation_name: animation_name::SingleSpecifiedValue,
            animation_duration: animation_duration::SingleSpecifiedValue,
            animation_timing_function: animation_timing_function::SingleSpecifiedValue,
            animation_delay: animation_delay::SingleSpecifiedValue,
            animation_iteration_count: animation_iteration_count::SingleSpecifiedValue,
            animation_direction: animation_direction::SingleSpecifiedValue,
            animation_fill_mode: animation_fill_mode::SingleSpecifiedValue,
            animation_play_state: animation_play_state::SingleSpecifiedValue,
        }

        fn parse_one_animation<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                       -> Result<SingleAnimation,ParseError<'i>> {
            let mut name = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;
            let mut iteration_count = None;
            let mut direction = None;
            let mut fill_mode = None;
            let mut play_state = None;

            let mut parsed = 0;
            // NB: Name must be the last one here so that keywords valid for other
            // longhands are not interpreted as names.
            //
            // Also, duration must be before delay, see
            // https://drafts.csswg.org/css-animations/#typedef-single-animation
            loop {
                parsed += 1;
                try_parse_one!(context, input, duration, animation_duration);
                try_parse_one!(context, input, timing_function, animation_timing_function);
                try_parse_one!(context, input, delay, animation_delay);
                try_parse_one!(context, input, iteration_count, animation_iteration_count);
                try_parse_one!(context, input, direction, animation_direction);
                try_parse_one!(context, input, fill_mode, animation_fill_mode);
                try_parse_one!(context, input, play_state, animation_play_state);
                try_parse_one!(context, input, name, animation_name);

                parsed -= 1;
                break
            }

            // If nothing is parsed, this is an invalid entry.
            if parsed == 0 {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            } else {
                Ok(SingleAnimation {
                    animation_name: name.unwrap_or_else(animation_name::single_value
                                                              ::get_initial_specified_value),
                    animation_duration: duration.unwrap_or_else(animation_duration::single_value
                                                              ::get_initial_specified_value),
                    animation_timing_function: timing_function.unwrap_or_else(animation_timing_function::single_value
                                                              ::get_initial_specified_value),
                    animation_delay: delay.unwrap_or_else(animation_delay::single_value
                                                              ::get_initial_specified_value),
                    animation_iteration_count: iteration_count.unwrap_or_else(animation_iteration_count::single_value
                                                              ::get_initial_specified_value),
                    animation_direction: direction.unwrap_or_else(animation_direction::single_value
                                                              ::get_initial_specified_value),
                    animation_fill_mode: fill_mode.unwrap_or_else(animation_fill_mode::single_value
                                                              ::get_initial_specified_value),
                    animation_play_state: play_state.unwrap_or_else(animation_play_state::single_value
                                                              ::get_initial_specified_value),
                })
            }
        }

        let mut names = vec![];
        let mut durations = vec![];
        let mut timing_functions = vec![];
        let mut delays = vec![];
        let mut iteration_counts = vec![];
        let mut directions = vec![];
        let mut fill_modes = vec![];
        let mut play_states = vec![];

        let results = input.parse_comma_separated(|i| parse_one_animation(context, i))?;
        for result in results.into_iter() {
            names.push(result.animation_name);
            durations.push(result.animation_duration);
            timing_functions.push(result.animation_timing_function);
            delays.push(result.animation_delay);
            iteration_counts.push(result.animation_iteration_count);
            directions.push(result.animation_direction);
            fill_modes.push(result.animation_fill_mode);
            play_states.push(result.animation_play_state);
        }

        Ok(expanded! {
            animation_name: animation_name::SpecifiedValue(names),
            animation_duration: animation_duration::SpecifiedValue(durations),
            animation_timing_function: animation_timing_function::SpecifiedValue(timing_functions),
            animation_delay: animation_delay::SpecifiedValue(delays),
            animation_iteration_count: animation_iteration_count::SpecifiedValue(iteration_counts),
            animation_direction: animation_direction::SpecifiedValue(directions),
            animation_fill_mode: animation_fill_mode::SpecifiedValue(fill_modes),
            animation_play_state: animation_play_state::SpecifiedValue(play_states),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.animation_name.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If any value list length is differs then we don't do a shorthand serialization
            // either.
                if len != self.animation_duration.0.len() {
                    return Ok(())
                }
                if len != self.animation_timing_function.0.len() {
                    return Ok(())
                }
                if len != self.animation_delay.0.len() {
                    return Ok(())
                }
                if len != self.animation_iteration_count.0.len() {
                    return Ok(())
                }
                if len != self.animation_direction.0.len() {
                    return Ok(())
                }
                if len != self.animation_fill_mode.0.len() {
                    return Ok(())
                }
                if len != self.animation_play_state.0.len() {
                    return Ok(())
                }

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                    self.animation_duration.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_timing_function.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_delay.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_iteration_count.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_direction.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_fill_mode.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                    self.animation_play_state.0[i].to_css(dest)?;
                    dest.write_str(" ")?;
                self.animation_name.0[i].to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-scroll-snap/#propdef-scroll-snap-type
    pub mod scroll_snap_type {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub scroll_snap_type_x:
                    longhands::scroll_snap_type_x::SpecifiedValue
                    ,
                pub scroll_snap_type_y:
                    longhands::scroll_snap_type_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_snap_type_x:
                    &'a longhands::scroll_snap_type_x::SpecifiedValue,
                pub scroll_snap_type_y:
                    &'a longhands::scroll_snap_type_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_snap_type_x = None;
                    let mut scroll_snap_type_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ScrollSnapTypeX(ref value) => {
                                scroll_snap_type_x = Some(value)
                            },
                            PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                                scroll_snap_type_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_snap_type_x,
                        scroll_snap_type_y,
                ) {

                    (
                        Some(scroll_snap_type_x),
                        Some(scroll_snap_type_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_snap_type_x: scroll_snap_type_x,
                            scroll_snap_type_y: scroll_snap_type_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollSnapTypeX(
                        longhands.scroll_snap_type_x
                    ));
                    declarations.push(PropertyDeclaration::ScrollSnapTypeY(
                        longhands.scroll_snap_type_y
                    ));
            })
        }

        
    use properties::longhands::scroll_snap_type_x;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let result = scroll_snap_type_x::parse(context, input)?;
        Ok(expanded! {
            scroll_snap_type_x: result,
            scroll_snap_type_y: result,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        // Serializes into the single keyword value if both scroll-snap-type-x and scroll-snap-type-y are same.
        // Otherwise into an empty string. This is done to match Gecko's behaviour.
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.scroll_snap_type_x == self.scroll_snap_type_y {
                self.scroll_snap_type_x.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }




    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub overscroll_behavior_x:
                    longhands::overscroll_behavior_x::SpecifiedValue
                    ,
                pub overscroll_behavior_y:
                    longhands::overscroll_behavior_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overscroll_behavior_x:
                    &'a longhands::overscroll_behavior_x::SpecifiedValue,
                pub overscroll_behavior_y:
                    &'a longhands::overscroll_behavior_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overscroll_behavior_x = None;
                    let mut overscroll_behavior_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                                overscroll_behavior_x = Some(value)
                            },
                            PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                                overscroll_behavior_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overscroll_behavior_x,
                        overscroll_behavior_y,
                ) {

                    (
                        Some(overscroll_behavior_x),
                        Some(overscroll_behavior_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overscroll_behavior_x: overscroll_behavior_x,
                            overscroll_behavior_y: overscroll_behavior_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverscrollBehaviorX(
                        longhands.overscroll_behavior_x
                    ));
                    declarations.push(PropertyDeclaration::OverscrollBehaviorY(
                        longhands.overscroll_behavior_y
                    ));
            })
        }

        
    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>
    ) -> Result<Longhands, ParseError<'i>> {
        use values::specified::OverscrollBehavior;
        let behavior_x = OverscrollBehavior::parse(input)?;
        let behavior_y = input.try(OverscrollBehavior::parse).unwrap_or(behavior_x);
        Ok(expanded! {
            overscroll_behavior_x: behavior_x,
            overscroll_behavior_y: behavior_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        // Serializes into the single keyword value if both overscroll-behavior-x and overscroll-behavior-y are same.
        // Otherwise into two values separated by a space.
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.overscroll_behavior_x.to_css(dest)?;
            if self.overscroll_behavior_y != self.overscroll_behavior_x {
                dest.write_str(" ")?;
                self.overscroll_behavior_y.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// Non-standard: https://developer.mozilla.org/en-US/docs/Web/CSS/transform
    pub mod _moz_transform {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub transform:
                    longhands::transform::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub transform:
                    &'a longhands::transform::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut transform = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::Transform(ref value) => {
                                transform = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        transform,
                ) {

                    (
                        Some(transform),
                    ) =>
                    Ok(LonghandsToSerialize {
                            transform: transform,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::Transform(
                        longhands.transform
                    ));
            })
        }

        
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        use values::specified::transform::Transform;
        Ok(expanded! {
            transform: Transform::parse_prefixed(context, input)?,
        })
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-multicol/#propdef-columns
    pub mod columns {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub column_width:
                    longhands::column_width::SpecifiedValue
                    ,
                pub column_count:
                    longhands::column_count::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub column_width:
                    &'a longhands::column_width::SpecifiedValue,
                pub column_count:
                    &'a longhands::column_count::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_width = None;
                    let mut column_count = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ColumnWidth(ref value) => {
                                column_width = Some(value)
                            },
                            PropertyDeclaration::ColumnCount(ref value) => {
                                column_count = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_width,
                        column_count,
                ) {

                    (
                        Some(column_width),
                        Some(column_count),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_width: column_width,
                            column_count: column_count,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnWidth(
                        longhands.column_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnCount(
                        longhands.column_count
                    ));
            })
        }

        
    use properties::longhands::{column_count, column_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {

        let mut column_count = None;
        let mut column_width = None;
        let mut autos = 0;

        loop {
            if input.try(|input| input.expect_ident_matching("auto")).is_ok() {
                // Leave the options to None, 'auto' is the initial value.
                autos += 1;
                continue
            }

            if column_count.is_none() {
                if let Ok(value) = input.try(|input| column_count::parse(context, input)) {
                    column_count = Some(value);
                    continue
                }
            }

            if column_width.is_none() {
                if let Ok(value) = input.try(|input| column_width::parse(context, input)) {
                    column_width = Some(value);
                    continue
                }
            }

            break
        }

        let values = autos + column_count.iter().len() + column_width.iter().len();
        if values == 0 || values > 2 {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        } else {
            Ok(expanded! {
                column_count: unwrap_or_initial!(column_count),
                column_width: unwrap_or_initial!(column_width),
            })
        }
    }

    }




    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule
    pub mod column_rule {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub column_rule_width:
                    longhands::column_rule_width::SpecifiedValue
                    ,
                pub column_rule_style:
                    longhands::column_rule_style::SpecifiedValue
                    ,
                pub column_rule_color:
                    longhands::column_rule_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub column_rule_width:
                    &'a longhands::column_rule_width::SpecifiedValue,
                pub column_rule_style:
                    &'a longhands::column_rule_style::SpecifiedValue,
                pub column_rule_color:
                    &'a longhands::column_rule_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_rule_width = None;
                    let mut column_rule_style = None;
                    let mut column_rule_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ColumnRuleWidth(ref value) => {
                                column_rule_width = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleStyle(ref value) => {
                                column_rule_style = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleColor(ref value) => {
                                column_rule_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_rule_width,
                        column_rule_style,
                        column_rule_color,
                ) {

                    (
                        Some(column_rule_width),
                        Some(column_rule_style),
                        Some(column_rule_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_rule_width: column_rule_width,
                            column_rule_style: column_rule_style,
                            column_rule_color: column_rule_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnRuleWidth(
                        longhands.column_rule_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleStyle(
                        longhands.column_rule_style
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleColor(
                        longhands.column_rule_color
                    ));
            })
        }

        
    use properties::longhands::{column_rule_width, column_rule_style};
    use properties::longhands::column_rule_color;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut column_rule_width = None;
        let mut column_rule_style = None;
        let mut column_rule_color = None;
        let mut any = false;

        loop {
            if column_rule_width.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_width::parse(context, input)) {
                    column_rule_width = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_style.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_style::parse(context, input)) {
                    column_rule_style = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_color.is_none() {
                if let Ok(value) = input.try(|input|
                        column_rule_color::parse(context, input)) {
                    column_rule_color = Some(value);
                    any = true;
                    continue
                }
            }

            break
        }
        if any {
            Ok(expanded! {
                column_rule_width: unwrap_or_initial!(column_rule_width),
                column_rule_style: unwrap_or_initial!(column_rule_style),
                column_rule_color: unwrap_or_initial!(column_rule_color),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */






    /// https://drafts.csswg.org/css-fonts-3/#propdef-font
    pub mod font {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub font_style:
                    longhands::font_style::SpecifiedValue
                    ,
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_weight:
                    longhands::font_weight::SpecifiedValue
                    ,
                pub font_stretch:
                    longhands::font_stretch::SpecifiedValue
                    ,
                pub font_size:
                    longhands::font_size::SpecifiedValue
                    ,
                pub line_height:
                    longhands::line_height::SpecifiedValue
                    ,
                pub font_family:
                    longhands::font_family::SpecifiedValue
                    ,
                pub font_size_adjust:
                    longhands::font_size_adjust::SpecifiedValue
                    ,
                pub font_kerning:
                    longhands::font_kerning::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
                pub font_language_override:
                    longhands::font_language_override::SpecifiedValue
                    ,
                pub font_feature_settings:
                        Box<
                    longhands::font_feature_settings::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_style:
                    &'a longhands::font_style::SpecifiedValue,
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_weight:
                    &'a longhands::font_weight::SpecifiedValue,
                pub font_stretch:
                    &'a longhands::font_stretch::SpecifiedValue,
                pub font_size:
                    &'a longhands::font_size::SpecifiedValue,
                pub line_height:
                    &'a longhands::line_height::SpecifiedValue,
                pub font_family:
                    &'a longhands::font_family::SpecifiedValue,
                pub font_size_adjust:
                    &'a longhands::font_size_adjust::SpecifiedValue,
                pub font_kerning:
                    &'a longhands::font_kerning::SpecifiedValue,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
                pub font_language_override:
                    &'a longhands::font_language_override::SpecifiedValue,
                pub font_feature_settings:
                    &'a longhands::font_feature_settings::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_style = None;
                    let mut font_variant_caps = None;
                    let mut font_weight = None;
                    let mut font_stretch = None;
                    let mut font_size = None;
                    let mut line_height = None;
                    let mut font_family = None;
                    let mut font_size_adjust = None;
                    let mut font_kerning = None;
                    let mut font_variant_alternates = None;
                    let mut font_variant_east_asian = None;
                    let mut font_variant_ligatures = None;
                    let mut font_variant_numeric = None;
                    let mut font_variant_position = None;
                    let mut font_language_override = None;
                    let mut font_feature_settings = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FontStyle(ref value) => {
                                font_style = Some(value)
                            },
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontWeight(ref value) => {
                                font_weight = Some(value)
                            },
                            PropertyDeclaration::FontStretch(ref value) => {
                                font_stretch = Some(value)
                            },
                            PropertyDeclaration::FontSize(ref value) => {
                                font_size = Some(value)
                            },
                            PropertyDeclaration::LineHeight(ref value) => {
                                line_height = Some(value)
                            },
                            PropertyDeclaration::FontFamily(ref value) => {
                                font_family = Some(value)
                            },
                            PropertyDeclaration::FontSizeAdjust(ref value) => {
                                font_size_adjust = Some(value)
                            },
                            PropertyDeclaration::FontKerning(ref value) => {
                                font_kerning = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                            PropertyDeclaration::FontLanguageOverride(ref value) => {
                                font_language_override = Some(value)
                            },
                            PropertyDeclaration::FontFeatureSettings(ref value) => {
                                font_feature_settings = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_style,
                        font_variant_caps,
                        font_weight,
                        font_stretch,
                        font_size,
                        line_height,
                        font_family,
                        font_size_adjust,
                        font_kerning,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                        font_language_override,
                        font_feature_settings,
                ) {

                    (
                        Some(font_style),
                        Some(font_variant_caps),
                        Some(font_weight),
                        Some(font_stretch),
                        Some(font_size),
                        Some(line_height),
                        Some(font_family),
                        Some(font_size_adjust),
                        Some(font_kerning),
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                        Some(font_language_override),
                        Some(font_feature_settings),
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_style: font_style,
                            font_variant_caps: font_variant_caps,
                            font_weight: font_weight,
                            font_stretch: font_stretch,
                            font_size: font_size,
                            line_height: line_height,
                            font_family: font_family,
                            font_size_adjust: font_size_adjust,
                            font_kerning: font_kerning,
                            font_variant_alternates: font_variant_alternates,
                            font_variant_east_asian: font_variant_east_asian,
                            font_variant_ligatures: font_variant_ligatures,
                            font_variant_numeric: font_variant_numeric,
                            font_variant_position: font_variant_position,
                            font_language_override: font_language_override,
                            font_feature_settings: font_feature_settings,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontStyle(
                        longhands.font_style
                    ));
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontWeight(
                        longhands.font_weight
                    ));
                    declarations.push(PropertyDeclaration::FontStretch(
                        longhands.font_stretch
                    ));
                    declarations.push(PropertyDeclaration::FontSize(
                        longhands.font_size
                    ));
                    declarations.push(PropertyDeclaration::LineHeight(
                        longhands.line_height
                    ));
                    declarations.push(PropertyDeclaration::FontFamily(
                        longhands.font_family
                    ));
                    declarations.push(PropertyDeclaration::FontSizeAdjust(
                        longhands.font_size_adjust
                    ));
                    declarations.push(PropertyDeclaration::FontKerning(
                        longhands.font_kerning
                    ));
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
                    declarations.push(PropertyDeclaration::FontLanguageOverride(
                        longhands.font_language_override
                    ));
                    declarations.push(PropertyDeclaration::FontFeatureSettings(
                        longhands.font_feature_settings
                    ));
            })
        }

        
    use parser::Parse;
    use properties::longhands::{font_family, font_style, font_weight, font_stretch};
    use properties::longhands::font_variant_caps;
    #[cfg(feature = "gecko")]
    use properties::longhands::system_font::SystemFont;
    use values::specified::text::LineHeight;
    use values::specified::FontSize;

    
            use properties::longhands::font_kerning;
            use properties::longhands::font_language_override;
            use properties::longhands::font_size_adjust;
            use properties::longhands::font_variant_alternates;
            use properties::longhands::font_variant_east_asian;
            use properties::longhands::font_variant_ligatures;
            use properties::longhands::font_variant_numeric;
            use properties::longhands::font_variant_position;
            use properties::longhands::font_feature_settings;
    use self::font_family::SpecifiedValue as FontFamily;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut nb_normals = 0;
        let mut style = None;
        let mut variant_caps = None;
        let mut weight = None;
        let mut stretch = None;
        let size;
            if let Ok(sys) = input.try(SystemFont::parse) {
                return Ok(expanded! {
                             font_family: font_family::SpecifiedValue::system_font(sys),
                             font_size: FontSize::system_font(sys),
                             font_style: font_style::SpecifiedValue::system_font(sys),
                             font_variant_caps: font_variant_caps::SpecifiedValue::system_font(sys),
                             font_stretch: font_stretch::SpecifiedValue::system_font(sys),
                             font_kerning: font_kerning::SpecifiedValue::system_font(sys),
                             font_variant_position: font_variant_position::SpecifiedValue::system_font(sys),
                             font_weight: font_weight::SpecifiedValue::system_font(sys),
                             font_size_adjust: font_size_adjust::SpecifiedValue::system_font(sys),
                             font_variant_alternates: font_variant_alternates::SpecifiedValue::system_font(sys),
                             font_variant_ligatures: font_variant_ligatures::SpecifiedValue::system_font(sys),
                             font_variant_east_asian: font_variant_east_asian::SpecifiedValue::system_font(sys),
                             font_variant_numeric: font_variant_numeric::SpecifiedValue::system_font(sys),
                             font_language_override: font_language_override::SpecifiedValue::system_font(sys),
                             font_feature_settings: font_feature_settings::SpecifiedValue::system_font(sys),
                     // line-height is just reset to initial
                     line_height: LineHeight::normal(),
                 })
            }
        loop {
            // Special-case 'normal' because it is valid in each of
            // font-style, font-weight, font-variant and font-stretch.
            // Leaves the values to None, 'normal' is the initial value for each of them.
            if input.try(|input| input.expect_ident_matching("normal")).is_ok() {
                nb_normals += 1;
                continue;
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| font_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            if weight.is_none() {
                if let Ok(value) = input.try(|input| font_weight::parse(context, input)) {
                    weight = Some(value);
                    continue
                }
            }
            if variant_caps.is_none() {
                if let Ok(value) = input.try(|input| font_variant_caps::parse(context, input)) {
                    variant_caps = Some(value);
                    continue
                }
            }
            if stretch.is_none() {
                if let Ok(value) = input.try(|input| font_stretch::parse(context, input)) {
                    stretch = Some(value);
                    continue
                }
            }
            size = Some(FontSize::parse(context, input)?);
            break
        }

        let size = match size {
            Some(s) => s,
            None => {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        };

        let line_height = if input.try(|input| input.expect_delim('/')).is_ok() {
            Some(LineHeight::parse(context, input)?)
        } else {
            None
        };

        #[inline]
        fn count<T>(opt: &Option<T>) -> u8 {
            if opt.is_some() { 1 } else { 0 }
        }

        if (count(&style) + count(&weight) + count(&variant_caps) + count(&stretch) + nb_normals) > 4 {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        let family = FontFamily::parse_specified(input)?;
        Ok(expanded! {
                font_style: unwrap_or_initial!(font_style, style),
                font_weight: unwrap_or_initial!(font_weight, weight),
                font_stretch: unwrap_or_initial!(font_stretch, stretch),
                font_variant_caps: unwrap_or_initial!(font_variant_caps, variant_caps),
            font_size: size,
            line_height: line_height.unwrap_or(LineHeight::normal()),
            font_family: family,
                    font_kerning: font_kerning::get_initial_specified_value(),
                    font_language_override: font_language_override::get_initial_specified_value(),
                    font_size_adjust: font_size_adjust::get_initial_specified_value(),
                    font_variant_alternates: font_variant_alternates::get_initial_specified_value(),
                    font_variant_east_asian: font_variant_east_asian::get_initial_specified_value(),
                    font_variant_ligatures: font_variant_ligatures::get_initial_specified_value(),
                    font_variant_numeric: font_variant_numeric::get_initial_specified_value(),
                    font_variant_position: font_variant_position::get_initial_specified_value(),
                    font_feature_settings: font_feature_settings::get_initial_specified_value(),
        })
    }

        enum CheckSystemResult {
            AllSystem(SystemFont),
            SomeSystem,
            None
        }
    enum SerializeFor {
        Normal,
        Canvas,
    }

    impl<'a> LonghandsToSerialize<'a> {
        fn to_css_for<W>(
            &self,
            serialize_for: SerializeFor,
            dest: &mut CssWriter<W>,
        ) -> fmt::Result
        where
            W: Write,
        {
                match self.check_system() {
                    CheckSystemResult::AllSystem(sys) => return sys.to_css(dest),
                    CheckSystemResult::SomeSystem => return Ok(()),
                    CheckSystemResult::None => ()
                }

                    if self.font_kerning != &font_kerning::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_language_override != &font_language_override::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_size_adjust != &font_size_adjust::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_variant_alternates != &font_variant_alternates::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_variant_east_asian != &font_variant_east_asian::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_variant_ligatures != &font_variant_ligatures::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_variant_numeric != &font_variant_numeric::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_variant_position != &font_variant_position::get_initial_specified_value() {
                        return Ok(());
                    }
                    if self.font_feature_settings != &font_feature_settings::get_initial_specified_value() {
                        return Ok(());
                    }

            // In case of serialization for canvas font, we need to drop
            // initial values of properties other than size and family.
                let needs_this_property = match serialize_for {
                    SerializeFor::Normal => true,
                    SerializeFor::Canvas =>
                        self.font_style != &font_style::get_initial_specified_value(),
                };
                if needs_this_property {
                    self.font_style.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                let needs_this_property = match serialize_for {
                    SerializeFor::Normal => true,
                    SerializeFor::Canvas =>
                        self.font_variant_caps != &font_variant_caps::get_initial_specified_value(),
                };
                if needs_this_property {
                    self.font_variant_caps.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                let needs_this_property = match serialize_for {
                    SerializeFor::Normal => true,
                    SerializeFor::Canvas =>
                        self.font_weight != &font_weight::get_initial_specified_value(),
                };
                if needs_this_property {
                    self.font_weight.to_css(dest)?;
                    dest.write_str(" ")?;
                }
                let needs_this_property = match serialize_for {
                    SerializeFor::Normal => true,
                    SerializeFor::Canvas =>
                        self.font_stretch != &font_stretch::get_initial_specified_value(),
                };
                if needs_this_property {
                    self.font_stretch.to_css(dest)?;
                    dest.write_str(" ")?;
                }

            self.font_size.to_css(dest)?;

            if *self.line_height != LineHeight::normal() {
                dest.write_str("/")?;
                self.line_height.to_css(dest)?;
            }

            dest.write_str(" ")?;
            self.font_family.to_css(dest)?;

            Ok(())
        }

            /// Check if some or all members are system fonts
            fn check_system(&self) -> CheckSystemResult {
                let mut sys = None;
                let mut all = true;

                    if let Some(s) = self.font_family.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_size.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_style.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_caps.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_stretch.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_kerning.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_position.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_weight.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_size_adjust.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_alternates.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_ligatures.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_east_asian.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_variant_numeric.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_language_override.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                    if let Some(s) = self.font_feature_settings.get_system() {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    } else {
                        all = false;
                    }
                if self.line_height != &LineHeight::normal() {
                    all = false
                }
                if all {
                    CheckSystemResult::AllSystem(sys.unwrap())
                } else if sys.is_some() {
                    CheckSystemResult::SomeSystem
                } else {
                    CheckSystemResult::None
                }
            }

            /// Serialize the shorthand value for canvas font attribute.
            pub fn to_css_for_canvas<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                self.to_css_for(SerializeFor::Canvas, dest)
            }
    }

    // This may be a bit off, unsure, possibly needs changes
    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.to_css_for(SerializeFor::Normal, dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-variant
    pub mod font_variant {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_variant_caps = None;
                    let mut font_variant_alternates = None;
                    let mut font_variant_east_asian = None;
                    let mut font_variant_ligatures = None;
                    let mut font_variant_numeric = None;
                    let mut font_variant_position = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_variant_caps,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                ) {

                    (
                        Some(font_variant_caps),
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_variant_caps: font_variant_caps,
                            font_variant_alternates: font_variant_alternates,
                            font_variant_east_asian: font_variant_east_asian,
                            font_variant_ligatures: font_variant_ligatures,
                            font_variant_numeric: font_variant_numeric,
                            font_variant_position: font_variant_position,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
            })
        }

        
    
    

    use properties::longhands::font_variant_caps;
    use properties::longhands::font_variant_alternates;
    use properties::longhands::font_variant_east_asian;
    use properties::longhands::font_variant_ligatures;
    use properties::longhands::font_variant_numeric;
    use properties::longhands::font_variant_position;
    #[allow(unused_imports)]
    use values::specified::FontVariantLigatures;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut caps = None;
        let mut alternates = None;
        let mut east_asian = None;
        let mut ligatures = None;
        let mut numeric = None;
        let mut position = None;

        if input.try(|input| input.expect_ident_matching("normal")).is_ok() {
            // Leave the values to None, 'normal' is the initial value for all the sub properties.
        } else if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            // The 'none' value sets 'font-variant-ligatures' to 'none' and resets all other sub properties
            // to their initial value.
            ligatures = Some(FontVariantLigatures::none());
        } else {
            let mut has_custom_value: bool = false;
            loop {
                if input.try(|input| input.expect_ident_matching("normal")).is_ok() ||
                   input.try(|input| input.expect_ident_matching("none")).is_ok() {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                }
                if caps.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_caps::parse(context, i)) {
                        has_custom_value = true;
                        caps = Some(value);
                        continue
                    }
                }
                if alternates.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_alternates::parse(context, i)) {
                        has_custom_value = true;
                        alternates = Some(value);
                        continue
                    }
                }
                if east_asian.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_east_asian::parse(context, i)) {
                        has_custom_value = true;
                        east_asian = Some(value);
                        continue
                    }
                }
                if ligatures.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_ligatures::parse(context, i)) {
                        has_custom_value = true;
                        ligatures = Some(value);
                        continue
                    }
                }
                if numeric.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_numeric::parse(context, i)) {
                        has_custom_value = true;
                        numeric = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|i| font_variant_position::parse(context, i)) {
                        has_custom_value = true;
                        position = Some(value);
                        continue
                    }
                }

                break
            }

            if !has_custom_value {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        Ok(expanded! {
            font_variant_caps: unwrap_or_initial!(font_variant_caps, caps),
            font_variant_alternates: unwrap_or_initial!(font_variant_alternates, alternates),
            font_variant_east_asian: unwrap_or_initial!(font_variant_east_asian, east_asian),
            font_variant_ligatures: unwrap_or_initial!(font_variant_ligatures, ligatures),
            font_variant_numeric: unwrap_or_initial!(font_variant_numeric, numeric),
            font_variant_position: unwrap_or_initial!(font_variant_position, position),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        #[allow(unused_assignments)]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {

            let has_none_ligatures =
                self.font_variant_ligatures == &FontVariantLigatures::none();

            const TOTAL_SUBPROPS: usize = 6;
            let mut nb_normals = 0;
            if self.font_variant_caps == &font_variant_caps::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_alternates == &font_variant_alternates::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_east_asian == &font_variant_east_asian::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_ligatures == &font_variant_ligatures::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_numeric == &font_variant_numeric::get_initial_specified_value() {
                nb_normals += 1;
            }
            if self.font_variant_position == &font_variant_position::get_initial_specified_value() {
                nb_normals += 1;
            }


            if nb_normals > 0 && nb_normals == TOTAL_SUBPROPS {
                dest.write_str("normal")?;
            } else if has_none_ligatures {
                if nb_normals == TOTAL_SUBPROPS - 1 {
                    // Serialize to 'none' if 'font-variant-ligatures' is set to 'none' and all other
                    // font feature properties are reset to their initial value.
                    dest.write_str("none")?;
                } else {
                    return Ok(())
                }
            } else {
                let mut has_any = false;
                if self.font_variant_caps != &font_variant_caps::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_caps.to_css(dest)?;
                }
                if self.font_variant_alternates != &font_variant_alternates::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_alternates.to_css(dest)?;
                }
                if self.font_variant_east_asian != &font_variant_east_asian::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_east_asian.to_css(dest)?;
                }
                if self.font_variant_ligatures != &font_variant_ligatures::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_ligatures.to_css(dest)?;
                }
                if self.font_variant_numeric != &font_variant_numeric::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_numeric.to_css(dest)?;
                }
                if self.font_variant_position != &font_variant_position::get_initial_specified_value() {
                    if has_any {
                        dest.write_str(" ")?;
                    }
                    has_any = true;
                    self.font_variant_position.to_css(dest)?;
                }
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor-3/#text-emphasis-property
    pub mod text_emphasis {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub text_emphasis_style:
                        Box<
                    longhands::text_emphasis_style::SpecifiedValue
                        >
                    ,
                pub text_emphasis_color:
                    longhands::text_emphasis_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub text_emphasis_style:
                    &'a longhands::text_emphasis_style::SpecifiedValue,
                pub text_emphasis_color:
                    &'a longhands::text_emphasis_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_emphasis_style = None;
                    let mut text_emphasis_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                                text_emphasis_style = Some(value)
                            },
                            PropertyDeclaration::TextEmphasisColor(ref value) => {
                                text_emphasis_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_emphasis_style,
                        text_emphasis_color,
                ) {

                    (
                        Some(text_emphasis_style),
                        Some(text_emphasis_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_emphasis_style: text_emphasis_style,
                            text_emphasis_color: text_emphasis_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextEmphasisStyle(
                        longhands.text_emphasis_style
                    ));
                    declarations.push(PropertyDeclaration::TextEmphasisColor(
                        longhands.text_emphasis_color
                    ));
            })
        }

        
    use properties::longhands::{text_emphasis_color, text_emphasis_style};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut style = None;

        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|input| text_emphasis_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| text_emphasis_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            break
        }
        if color.is_some() || style.is_some() {
            Ok(expanded! {
                text_emphasis_color: unwrap_or_initial!(text_emphasis_color, color),
                text_emphasis_style: unwrap_or_initial!(text_emphasis_style, style),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


// CSS Compatibility
// https://compat.spec.whatwg.org/


    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke
    pub mod _webkit_text_stroke {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub _webkit_text_stroke_width:
                    longhands::_webkit_text_stroke_width::SpecifiedValue
                    ,
                pub _webkit_text_stroke_color:
                    longhands::_webkit_text_stroke_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub _webkit_text_stroke_width:
                    &'a longhands::_webkit_text_stroke_width::SpecifiedValue,
                pub _webkit_text_stroke_color:
                    &'a longhands::_webkit_text_stroke_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut _webkit_text_stroke_width = None;
                    let mut _webkit_text_stroke_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                                _webkit_text_stroke_width = Some(value)
                            },
                            PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                                _webkit_text_stroke_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        _webkit_text_stroke_width,
                        _webkit_text_stroke_color,
                ) {

                    (
                        Some(_webkit_text_stroke_width),
                        Some(_webkit_text_stroke_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            _webkit_text_stroke_width: _webkit_text_stroke_width,
                            _webkit_text_stroke_color: _webkit_text_stroke_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::WebkitTextStrokeWidth(
                        longhands._webkit_text_stroke_width
                    ));
                    declarations.push(PropertyDeclaration::WebkitTextStrokeColor(
                        longhands._webkit_text_stroke_color
                    ));
            })
        }

        
    use properties::longhands::{_webkit_text_stroke_color, _webkit_text_stroke_width};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut width = None;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|input| _webkit_text_stroke_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }

            if width.is_none() {
                if let Ok(value) = input.try(|input| _webkit_text_stroke_width::parse(context, input)) {
                    width = Some(value);
                    continue
                }
            }
            break
        }

        if color.is_some() || width.is_some() {
            Ok(expanded! {
                _webkit_text_stroke_color: unwrap_or_initial!(_webkit_text_stroke_color, color),
                _webkit_text_stroke_width: unwrap_or_initial!(_webkit_text_stroke_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-lists/#propdef-list-style
    pub mod list_style {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub list_style_position:
                    longhands::list_style_position::SpecifiedValue
                    ,
                pub list_style_image:
                        Box<
                    longhands::list_style_image::SpecifiedValue
                        >
                    ,
                pub list_style_type:
                        Box<
                    longhands::list_style_type::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub list_style_position:
                    &'a longhands::list_style_position::SpecifiedValue,
                pub list_style_image:
                    &'a longhands::list_style_image::SpecifiedValue,
                pub list_style_type:
                    &'a longhands::list_style_type::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut list_style_position = None;
                    let mut list_style_image = None;
                    let mut list_style_type = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::ListStylePosition(ref value) => {
                                list_style_position = Some(value)
                            },
                            PropertyDeclaration::ListStyleImage(ref value) => {
                                list_style_image = Some(value)
                            },
                            PropertyDeclaration::ListStyleType(ref value) => {
                                list_style_type = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        list_style_position,
                        list_style_image,
                        list_style_type,
                ) {

                    (
                        Some(list_style_position),
                        Some(list_style_image),
                        Some(list_style_type),
                    ) =>
                    Ok(LonghandsToSerialize {
                            list_style_position: list_style_position,
                            list_style_image: list_style_image,
                            list_style_type: list_style_type,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ListStylePosition(
                        longhands.list_style_position
                    ));
                    declarations.push(PropertyDeclaration::ListStyleImage(
                        longhands.list_style_image
                    ));
                    declarations.push(PropertyDeclaration::ListStyleType(
                        longhands.list_style_type
                    ));
            })
        }

        
    use properties::longhands::{list_style_image, list_style_position, list_style_type};
    use values::{Either, None_};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // `none` is ambiguous until we've finished parsing the shorthands, so we count the number
        // of times we see it.
        let mut nones = 0u8;
        let (mut image, mut position, mut list_style_type, mut any) = (None, None, None, false);
        loop {
            if input.try(|input| input.expect_ident_matching("none")).is_ok() {
                nones = nones + 1;
                if nones > 2 {
                    return Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent("none".into())))
                }
                any = true;
                continue
            }

            if image.is_none() {
                if let Ok(value) = input.try(|input| list_style_image::parse(context, input)) {
                    image = Some(value);
                    any = true;
                    continue
                }
            }

            if position.is_none() {
                if let Ok(value) = input.try(|input| list_style_position::parse(context, input)) {
                    position = Some(value);
                    any = true;
                    continue
                }
            }

            // list-style-type must be checked the last, because it accepts
            // arbitrary identifier for custom counter style, and thus may
            // affect values of list-style-position.
            if list_style_type.is_none() {
                if let Ok(value) = input.try(|input| list_style_type::parse(context, input)) {
                    list_style_type = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }

        let position = unwrap_or_initial!(list_style_position, position);

        fn list_style_type_none() -> list_style_type::SpecifiedValue {
            use values::generics::CounterStyleOrNone;
            list_style_type::SpecifiedValue::CounterStyle(CounterStyleOrNone::None)
        }

        // If there are two `none`s, then we can't have a type or image; if there is one `none`,
        // then we can't have both a type *and* an image; if there is no `none` then we're fine as
        // long as we parsed something.
        match (any, nones, list_style_type, image) {
            (true, 2, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 1, None, Some(image)) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: image,
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 1, Some(list_style_type), None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type,
                })
            }
            (true, 1, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: list_style_image::SpecifiedValue(Either::Second(None_)),
                    list_style_type: list_style_type_none(),
                })
            }
            (true, 0, list_style_type, image) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: unwrap_or_initial!(list_style_image, image),
                    list_style_type: unwrap_or_initial!(list_style_type),
                })
            }
            _ => Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError)),
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




    
    

    /// https://drafts.csswg.org/css-box/#propdef-margin
    pub mod margin {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub margin_top:
                    longhands::margin_top::SpecifiedValue
                    ,
                pub margin_right:
                    longhands::margin_right::SpecifiedValue
                    ,
                pub margin_bottom:
                    longhands::margin_bottom::SpecifiedValue
                    ,
                pub margin_left:
                    longhands::margin_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub margin_top:
                    &'a longhands::margin_top::SpecifiedValue,
                pub margin_right:
                    &'a longhands::margin_right::SpecifiedValue,
                pub margin_bottom:
                    &'a longhands::margin_bottom::SpecifiedValue,
                pub margin_left:
                    &'a longhands::margin_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut margin_top = None;
                    let mut margin_right = None;
                    let mut margin_bottom = None;
                    let mut margin_left = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MarginTop(ref value) => {
                                margin_top = Some(value)
                            },
                            PropertyDeclaration::MarginRight(ref value) => {
                                margin_right = Some(value)
                            },
                            PropertyDeclaration::MarginBottom(ref value) => {
                                margin_bottom = Some(value)
                            },
                            PropertyDeclaration::MarginLeft(ref value) => {
                                margin_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        margin_top,
                        margin_right,
                        margin_bottom,
                        margin_left,
                ) {

                    (
                        Some(margin_top),
                        Some(margin_right),
                        Some(margin_bottom),
                        Some(margin_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            margin_top: margin_top,
                            margin_right: margin_right,
                            margin_bottom: margin_bottom,
                            margin_left: margin_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarginTop(
                        longhands.margin_top
                    ));
                    declarations.push(PropertyDeclaration::MarginRight(
                        longhands.margin_right
                    ));
                    declarations.push(PropertyDeclaration::MarginBottom(
                        longhands.margin_bottom
                    ));
                    declarations.push(PropertyDeclaration::MarginLeft(
                        longhands.margin_left
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::LengthOrPercentageOrAuto::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    margin_top: rect.0,
                    margin_right: rect.1,
                    margin_bottom: rect.2,
                    margin_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.margin_top,
                    &self.margin_right,
                    &self.margin_bottom,
                    &self.margin_left,
                );
                rect.to_css(dest)
            }
        }
    
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.fxtf.org/css-masking/#propdef-mask
    pub mod mask {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub mask_mode:
                    longhands::mask_mode::SpecifiedValue
                    ,
                pub mask_repeat:
                    longhands::mask_repeat::SpecifiedValue
                    ,
                pub mask_clip:
                    longhands::mask_clip::SpecifiedValue
                    ,
                pub mask_origin:
                    longhands::mask_origin::SpecifiedValue
                    ,
                pub mask_composite:
                    longhands::mask_composite::SpecifiedValue
                    ,
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
                pub mask_size:
                    longhands::mask_size::SpecifiedValue
                    ,
                pub mask_image:
                    longhands::mask_image::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_mode:
                    &'a longhands::mask_mode::SpecifiedValue,
                pub mask_repeat:
                    &'a longhands::mask_repeat::SpecifiedValue,
                pub mask_clip:
                    &'a longhands::mask_clip::SpecifiedValue,
                pub mask_origin:
                    &'a longhands::mask_origin::SpecifiedValue,
                pub mask_composite:
                    &'a longhands::mask_composite::SpecifiedValue,
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
                pub mask_size:
                    &'a longhands::mask_size::SpecifiedValue,
                pub mask_image:
                    &'a longhands::mask_image::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_mode = None;
                    let mut mask_repeat = None;
                    let mut mask_clip = None;
                    let mut mask_origin = None;
                    let mut mask_composite = None;
                    let mut mask_position_x = None;
                    let mut mask_position_y = None;
                    let mut mask_size = None;
                    let mut mask_image = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MaskMode(ref value) => {
                                mask_mode = Some(value)
                            },
                            PropertyDeclaration::MaskRepeat(ref value) => {
                                mask_repeat = Some(value)
                            },
                            PropertyDeclaration::MaskClip(ref value) => {
                                mask_clip = Some(value)
                            },
                            PropertyDeclaration::MaskOrigin(ref value) => {
                                mask_origin = Some(value)
                            },
                            PropertyDeclaration::MaskComposite(ref value) => {
                                mask_composite = Some(value)
                            },
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                            PropertyDeclaration::MaskSize(ref value) => {
                                mask_size = Some(value)
                            },
                            PropertyDeclaration::MaskImage(ref value) => {
                                mask_image = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_mode,
                        mask_repeat,
                        mask_clip,
                        mask_origin,
                        mask_composite,
                        mask_position_x,
                        mask_position_y,
                        mask_size,
                        mask_image,
                ) {

                    (
                        Some(mask_mode),
                        Some(mask_repeat),
                        Some(mask_clip),
                        Some(mask_origin),
                        Some(mask_composite),
                        Some(mask_position_x),
                        Some(mask_position_y),
                        Some(mask_size),
                        Some(mask_image),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_mode: mask_mode,
                            mask_repeat: mask_repeat,
                            mask_clip: mask_clip,
                            mask_origin: mask_origin,
                            mask_composite: mask_composite,
                            mask_position_x: mask_position_x,
                            mask_position_y: mask_position_y,
                            mask_size: mask_size,
                            mask_image: mask_image,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskMode(
                        longhands.mask_mode
                    ));
                    declarations.push(PropertyDeclaration::MaskRepeat(
                        longhands.mask_repeat
                    ));
                    declarations.push(PropertyDeclaration::MaskClip(
                        longhands.mask_clip
                    ));
                    declarations.push(PropertyDeclaration::MaskOrigin(
                        longhands.mask_origin
                    ));
                    declarations.push(PropertyDeclaration::MaskComposite(
                        longhands.mask_composite
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
                    declarations.push(PropertyDeclaration::MaskSize(
                        longhands.mask_size
                    ));
                    declarations.push(PropertyDeclaration::MaskImage(
                        longhands.mask_image
                    ));
            })
        }

        
    use properties::longhands::{mask_mode, mask_repeat, mask_clip, mask_origin, mask_composite, mask_position_x,
                                mask_position_y};
    use properties::longhands::{mask_size, mask_image};
    use values::specified::{Position, PositionComponent};
    use parser::Parse;

    // FIXME(emilio): These two mask types should be the same!
    impl From<mask_origin::single_value::SpecifiedValue> for mask_clip::single_value::SpecifiedValue {
        fn from(origin: mask_origin::single_value::SpecifiedValue) -> mask_clip::single_value::SpecifiedValue {
            match origin {
                mask_origin::single_value::SpecifiedValue::ContentBox =>
                    mask_clip::single_value::SpecifiedValue::ContentBox,
                mask_origin::single_value::SpecifiedValue::PaddingBox =>
                    mask_clip::single_value::SpecifiedValue::PaddingBox ,
                mask_origin::single_value::SpecifiedValue::BorderBox =>
                    mask_clip::single_value::SpecifiedValue::BorderBox,
                mask_origin::single_value::SpecifiedValue::FillBox =>
                    mask_clip::single_value::SpecifiedValue::FillBox ,
                mask_origin::single_value::SpecifiedValue::StrokeBox =>
                    mask_clip::single_value::SpecifiedValue::StrokeBox,
                mask_origin::single_value::SpecifiedValue::ViewBox=>
                    mask_clip::single_value::SpecifiedValue::ViewBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_image = mask_image::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_mode = mask_mode::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_position_x = mask_position_x::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_position_y = mask_position_y::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_size = mask_size::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_repeat = mask_repeat::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_origin = mask_origin::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_clip = mask_clip::SpecifiedValue(Vec::with_capacity(1));
            // Vec grows from 0 to 4 by default on first push().  So allocate
            // with capacity 1, so in the common case of only one item we don't
            // way overallocate.  Note that we always push at least one item if
            // parsing succeeds.
            let mut mask_composite = mask_composite::SpecifiedValue(Vec::with_capacity(1));

        input.parse_comma_separated(|input| {
                let mut image = None;
                let mut mode = None;
                let mut position = None;
                let mut size = None;
                let mut repeat = None;
                let mut origin = None;
                let mut clip = None;
                let mut composite = None;
            loop {
                if image.is_none() {
                    if let Ok(value) = input.try(|input| mask_image::single_value
                                                                   ::parse(context, input)) {
                        image = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try(|input| Position::parse(context, input)) {
                        position = Some(value);

                        // Parse mask size, if applicable.
                        size = input.try(|input| {
                            input.expect_delim('/')?;
                            mask_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if repeat.is_none() {
                        if let Ok(value) = input.try(|input| mask_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try(|input| mask_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try(|input| mask_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                    if composite.is_none() {
                        if let Ok(value) = input.try(|input| mask_composite::single_value
                                                                               ::parse(context, input)) {
                            composite = Some(value);
                            continue
                        }
                    }
                    if mode.is_none() {
                        if let Ok(value) = input.try(|input| mask_mode::single_value
                                                                               ::parse(context, input)) {
                            mode = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(mask_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || mode.is_some();
                any = any || position.is_some();
                any = any || size.is_some();
                any = any || repeat.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
                any = any || composite.is_some();
            if any {
                if let Some(position) = position {
                    mask_position_x.0.push(position.horizontal);
                    mask_position_y.0.push(position.vertical);
                } else {
                    mask_position_x.0.push(PositionComponent::zero());
                    mask_position_y.0.push(PositionComponent::zero());
                }
                    if let Some(m_image) = image {
                        mask_image.0.push(m_image);
                    } else {
                        mask_image.0.push(mask_image::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_mode) = mode {
                        mask_mode.0.push(m_mode);
                    } else {
                        mask_mode.0.push(mask_mode::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_size) = size {
                        mask_size.0.push(m_size);
                    } else {
                        mask_size.0.push(mask_size::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_repeat) = repeat {
                        mask_repeat.0.push(m_repeat);
                    } else {
                        mask_repeat.0.push(mask_repeat::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_origin) = origin {
                        mask_origin.0.push(m_origin);
                    } else {
                        mask_origin.0.push(mask_origin::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_clip) = clip {
                        mask_clip.0.push(m_clip);
                    } else {
                        mask_clip.0.push(mask_clip::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_composite) = composite {
                        mask_composite.0.push(m_composite);
                    } else {
                        mask_composite.0.push(mask_composite::single_value
                                                        ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
                mask_image: mask_image,
                mask_mode: mask_mode,
                mask_position_x: mask_position_x,
                mask_position_y: mask_position_y,
                mask_size: mask_size,
                mask_repeat: mask_repeat,
                mask_origin: mask_origin,
                mask_clip: mask_clip,
                mask_composite: mask_composite,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use properties::longhands::mask_origin::single_value::computed_value::T as Origin;
            use properties::longhands::mask_clip::single_value::computed_value::T as Clip;

            let len = self.mask_image.0.len();
            if len == 0 {
                return Ok(());
            }
                if self.mask_mode.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_x.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_y.0.len() != len {
                    return Ok(());
                }
                if self.mask_size.0.len() != len {
                    return Ok(());
                }
                if self.mask_repeat.0.len() != len {
                    return Ok(());
                }
                if self.mask_origin.0.len() != len {
                    return Ok(());
                }
                if self.mask_clip.0.len() != len {
                    return Ok(());
                }
                if self.mask_composite.0.len() != len {
                    return Ok(());
                }

            for i in 0..len {
                if i > 0 {
                    dest.write_str(", ")?;
                }

                    let image = &self.mask_image.0[i];
                    let mode = &self.mask_mode.0[i];
                    let position_x = &self.mask_position_x.0[i];
                    let position_y = &self.mask_position_y.0[i];
                    let size = &self.mask_size.0[i];
                    let repeat = &self.mask_repeat.0[i];
                    let origin = &self.mask_origin.0[i];
                    let clip = &self.mask_clip.0[i];
                    let composite = &self.mask_composite.0[i];

                image.to_css(dest)?;
                dest.write_str(" ")?;
                mode.to_css(dest)?;
                dest.write_str(" ")?;

                Position {
                    horizontal: position_x.clone(),
                    vertical: position_y.clone()
                }.to_css(dest)?;

                if *size != mask_size::single_value::get_initial_specified_value() {
                    dest.write_str(" / ")?;
                    size.to_css(dest)?;
                }
                dest.write_str(" ")?;
                repeat.to_css(dest)?;

                if *origin != Origin::BorderBox || *clip != Clip::BorderBox {
                    dest.write_str(" ")?;
                    origin.to_css(dest)?;
                    if *clip != From::from(*origin) {
                        dest.write_str(" ")?;
                        clip.to_css(dest)?;
                    }
                }

                dest.write_str(" ")?;
                composite.to_css(dest)?;
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-masks-4/#the-mask-position
    pub mod mask_position {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_position_x = None;
                    let mut mask_position_y = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_position_x,
                        mask_position_y,
                ) {

                    (
                        Some(mask_position_x),
                        Some(mask_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_position_x: mask_position_x,
                            mask_position_y: mask_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
            })
        }

        
    use properties::longhands::{mask_position_x,mask_position_y};
    use values::specified::position::Position;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate.  Note that we always push at least one item if parsing
        // succeeds.
        let mut position_x = mask_position_x::SpecifiedValue(Vec::with_capacity(1));
        let mut position_y = mask_position_y::SpecifiedValue(Vec::with_capacity(1));
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse(context, input)?;
            position_x.0.push(value.horizontal);
            position_y.0.push(value.vertical);
            any = true;
            Ok(())
        })?;
        if any == false {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            mask_position_x: position_x,
            mask_position_y: position_y,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.mask_position_x.0.len();
            if len == 0 || self.mask_position_y.0.len() != len {
                return Ok(());
            }

            for i in 0..len {
                Position {
                    horizontal: self.mask_position_x.0[i].clone(),
                    vertical: self.mask_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-ui/#propdef-outline
    pub mod outline {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub outline_width:
                    longhands::outline_width::SpecifiedValue
                    ,
                pub outline_style:
                    longhands::outline_style::SpecifiedValue
                    ,
                pub outline_color:
                    longhands::outline_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub outline_width:
                    &'a longhands::outline_width::SpecifiedValue,
                pub outline_style:
                    &'a longhands::outline_style::SpecifiedValue,
                pub outline_color:
                    &'a longhands::outline_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut outline_width = None;
                    let mut outline_style = None;
                    let mut outline_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::OutlineWidth(ref value) => {
                                outline_width = Some(value)
                            },
                            PropertyDeclaration::OutlineStyle(ref value) => {
                                outline_style = Some(value)
                            },
                            PropertyDeclaration::OutlineColor(ref value) => {
                                outline_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        outline_width,
                        outline_style,
                        outline_color,
                ) {

                    (
                        Some(outline_width),
                        Some(outline_style),
                        Some(outline_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            outline_width: outline_width,
                            outline_style: outline_style,
                            outline_color: outline_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OutlineWidth(
                        longhands.outline_width
                    ));
                    declarations.push(PropertyDeclaration::OutlineStyle(
                        longhands.outline_style
                    ));
                    declarations.push(PropertyDeclaration::OutlineColor(
                        longhands.outline_color
                    ));
            })
        }

        
    use properties::longhands::{outline_color, outline_width, outline_style};
    use values::specified;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let _unused = context;
        let mut color = None;
        let mut style = None;
        let mut width = None;
        let mut any = false;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try(|i| specified::Color::parse(context, i)) {
                    color = Some(value);
                    any = true;
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try(|input| outline_style::parse(context, input)) {
                    style = Some(value);
                    any = true;
                    continue
                }
            }
            if width.is_none() {
                if let Ok(value) = input.try(|input| outline_width::parse(context, input)) {
                    width = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }
        if any {
            Ok(expanded! {
                outline_color: unwrap_or_initial!(outline_color, color),
                outline_style: unwrap_or_initial!(outline_style, style),
                outline_width: unwrap_or_initial!(outline_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


// The -moz-outline-radius shorthand is non-standard and not on a standards track.


    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-outline-radius)
    pub mod _moz_outline_radius {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub _moz_outline_radius_topleft:
                        Box<
                    longhands::_moz_outline_radius_topleft::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_topright:
                        Box<
                    longhands::_moz_outline_radius_topright::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_bottomright:
                        Box<
                    longhands::_moz_outline_radius_bottomright::SpecifiedValue
                        >
                    ,
                pub _moz_outline_radius_bottomleft:
                        Box<
                    longhands::_moz_outline_radius_bottomleft::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub _moz_outline_radius_topleft:
                    &'a longhands::_moz_outline_radius_topleft::SpecifiedValue,
                pub _moz_outline_radius_topright:
                    &'a longhands::_moz_outline_radius_topright::SpecifiedValue,
                pub _moz_outline_radius_bottomright:
                    &'a longhands::_moz_outline_radius_bottomright::SpecifiedValue,
                pub _moz_outline_radius_bottomleft:
                    &'a longhands::_moz_outline_radius_bottomleft::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut _moz_outline_radius_topleft = None;
                    let mut _moz_outline_radius_topright = None;
                    let mut _moz_outline_radius_bottomright = None;
                    let mut _moz_outline_radius_bottomleft = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MozOutlineRadiusTopleft(ref value) => {
                                _moz_outline_radius_topleft = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                                _moz_outline_radius_topright = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusBottomright(ref value) => {
                                _moz_outline_radius_bottomright = Some(value)
                            },
                            PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) => {
                                _moz_outline_radius_bottomleft = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        _moz_outline_radius_topleft,
                        _moz_outline_radius_topright,
                        _moz_outline_radius_bottomright,
                        _moz_outline_radius_bottomleft,
                ) {

                    (
                        Some(_moz_outline_radius_topleft),
                        Some(_moz_outline_radius_topright),
                        Some(_moz_outline_radius_bottomright),
                        Some(_moz_outline_radius_bottomleft),
                    ) =>
                    Ok(LonghandsToSerialize {
                            _moz_outline_radius_topleft: _moz_outline_radius_topleft,
                            _moz_outline_radius_topright: _moz_outline_radius_topright,
                            _moz_outline_radius_bottomright: _moz_outline_radius_bottomright,
                            _moz_outline_radius_bottomleft: _moz_outline_radius_bottomleft,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MozOutlineRadiusTopleft(
                        longhands._moz_outline_radius_topleft
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusTopright(
                        longhands._moz_outline_radius_topright
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusBottomright(
                        longhands._moz_outline_radius_bottomright
                    ));
                    declarations.push(PropertyDeclaration::MozOutlineRadiusBottomleft(
                        longhands._moz_outline_radius_bottomleft
                    ));
            })
        }

        
    use values::generics::rect::Rect;
    use values::specified::border::BorderRadius;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let radii = BorderRadius::parse(context, input)?;
        Ok(expanded! {
            _moz_outline_radius_topleft: radii.top_left,
            _moz_outline_radius_topright: radii.top_right,
            _moz_outline_radius_bottomright: radii.bottom_right,
            _moz_outline_radius_bottomleft: radii.bottom_left,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use values::generics::border::BorderCornerRadius;

            let LonghandsToSerialize {
                _moz_outline_radius_topleft: &BorderCornerRadius(ref tl),
                _moz_outline_radius_topright: &BorderCornerRadius(ref tr),
                _moz_outline_radius_bottomright: &BorderCornerRadius(ref br),
                _moz_outline_radius_bottomleft: &BorderCornerRadius(ref bl),
            } = *self;

            let widths = Rect::new(tl.width(), tr.width(), br.width(), bl.width());
            let heights = Rect::new(tl.height(), tr.height(), br.height(), bl.height());

            BorderRadius::serialize_rects(widths, heights, dest)
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */




    
    

    /// https://drafts.csswg.org/css-box-3/#propdef-padding
    pub mod padding {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub padding_top:
                    longhands::padding_top::SpecifiedValue
                    ,
                pub padding_right:
                    longhands::padding_right::SpecifiedValue
                    ,
                pub padding_bottom:
                    longhands::padding_bottom::SpecifiedValue
                    ,
                pub padding_left:
                    longhands::padding_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub padding_top:
                    &'a longhands::padding_top::SpecifiedValue,
                pub padding_right:
                    &'a longhands::padding_right::SpecifiedValue,
                pub padding_bottom:
                    &'a longhands::padding_bottom::SpecifiedValue,
                pub padding_left:
                    &'a longhands::padding_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut padding_top = None;
                    let mut padding_right = None;
                    let mut padding_bottom = None;
                    let mut padding_left = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::PaddingTop(ref value) => {
                                padding_top = Some(value)
                            },
                            PropertyDeclaration::PaddingRight(ref value) => {
                                padding_right = Some(value)
                            },
                            PropertyDeclaration::PaddingBottom(ref value) => {
                                padding_bottom = Some(value)
                            },
                            PropertyDeclaration::PaddingLeft(ref value) => {
                                padding_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        padding_top,
                        padding_right,
                        padding_bottom,
                        padding_left,
                ) {

                    (
                        Some(padding_top),
                        Some(padding_right),
                        Some(padding_bottom),
                        Some(padding_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            padding_top: padding_top,
                            padding_right: padding_right,
                            padding_bottom: padding_bottom,
                            padding_left: padding_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::PaddingTop(
                        longhands.padding_top
                    ));
                    declarations.push(PropertyDeclaration::PaddingRight(
                        longhands.padding_right
                    ));
                    declarations.push(PropertyDeclaration::PaddingBottom(
                        longhands.padding_bottom
                    ));
                    declarations.push(PropertyDeclaration::PaddingLeft(
                        longhands.padding_left
                    ));
            })
        }

        
        #[allow(unused_imports)]
        use parser::Parse;
        use values::generics::rect::Rect;
        use values::specified;

        pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                   -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |_c, i| {
                specified::NonNegativeLengthOrPercentage::parse_quirky(_c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    padding_top: rect.0,
                    padding_right: rect.1,
                    padding_bottom: rect.2,
                    padding_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.padding_top,
                    &self.padding_right,
                    &self.padding_bottom,
                    &self.padding_left,
                );
                rect.to_css(dest)
            }
        }
    
    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-flexbox/#flex-flow-property
    pub mod flex_flow {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub flex_direction:
                    longhands::flex_direction::SpecifiedValue
                    ,
                pub flex_wrap:
                    longhands::flex_wrap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub flex_direction:
                    &'a longhands::flex_direction::SpecifiedValue,
                pub flex_wrap:
                    &'a longhands::flex_wrap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_direction = None;
                    let mut flex_wrap = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FlexDirection(ref value) => {
                                flex_direction = Some(value)
                            },
                            PropertyDeclaration::FlexWrap(ref value) => {
                                flex_wrap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_direction,
                        flex_wrap,
                ) {

                    (
                        Some(flex_direction),
                        Some(flex_wrap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_direction: flex_direction,
                            flex_wrap: flex_wrap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexDirection(
                        longhands.flex_direction
                    ));
                    declarations.push(PropertyDeclaration::FlexWrap(
                        longhands.flex_wrap
                    ));
            })
        }

        
    use properties::longhands::{flex_direction, flex_wrap};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut direction = None;
        let mut wrap = None;
        loop {
            if direction.is_none() {
                if let Ok(value) = input.try(|input| flex_direction::parse(context, input)) {
                    direction = Some(value);
                    continue
                }
            }
            if wrap.is_none() {
                if let Ok(value) = input.try(|input| flex_wrap::parse(context, input)) {
                    wrap = Some(value);
                    continue
                }
            }
            break
        }

        if direction.is_none() && wrap.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_direction: unwrap_or_initial!(flex_direction, direction),
            flex_wrap: unwrap_or_initial!(flex_wrap, wrap),
        })
    }

    }




    /// https://drafts.csswg.org/css-flexbox/#flex-property
    pub mod flex {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub flex_grow:
                    longhands::flex_grow::SpecifiedValue
                    ,
                pub flex_shrink:
                    longhands::flex_shrink::SpecifiedValue
                    ,
                pub flex_basis:
                    longhands::flex_basis::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub flex_grow:
                    &'a longhands::flex_grow::SpecifiedValue,
                pub flex_shrink:
                    &'a longhands::flex_shrink::SpecifiedValue,
                pub flex_basis:
                    &'a longhands::flex_basis::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_grow = None;
                    let mut flex_shrink = None;
                    let mut flex_basis = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::FlexGrow(ref value) => {
                                flex_grow = Some(value)
                            },
                            PropertyDeclaration::FlexShrink(ref value) => {
                                flex_shrink = Some(value)
                            },
                            PropertyDeclaration::FlexBasis(ref value) => {
                                flex_basis = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_grow,
                        flex_shrink,
                        flex_basis,
                ) {

                    (
                        Some(flex_grow),
                        Some(flex_shrink),
                        Some(flex_basis),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_grow: flex_grow,
                            flex_shrink: flex_shrink,
                            flex_basis: flex_basis,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexGrow(
                        longhands.flex_grow
                    ));
                    declarations.push(PropertyDeclaration::FlexShrink(
                        longhands.flex_shrink
                    ));
                    declarations.push(PropertyDeclaration::FlexBasis(
                        longhands.flex_basis
                    ));
            })
        }

        
    use parser::Parse;
    use values::specified::NonNegativeNumber;
    use properties::longhands::flex_basis::SpecifiedValue as FlexBasis;

    fn parse_flexibility<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                 -> Result<(NonNegativeNumber, Option<NonNegativeNumber>),ParseError<'i>> {
        let grow = NonNegativeNumber::parse(context, input)?;
        let shrink = input.try(|i| NonNegativeNumber::parse(context, i)).ok();
        Ok((grow, shrink))
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut grow = None;
        let mut shrink = None;
        let mut basis = None;

        if input.try(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(expanded! {
                flex_grow: NonNegativeNumber::new(0.0),
                flex_shrink: NonNegativeNumber::new(0.0),
                flex_basis: FlexBasis::auto(),
            })
        }
        loop {
            if grow.is_none() {
                if let Ok((flex_grow, flex_shrink)) = input.try(|i| parse_flexibility(context, i)) {
                    grow = Some(flex_grow);
                    shrink = flex_shrink;
                    continue
                }
            }
            if basis.is_none() {
                if let Ok(value) = input.try(|input| FlexBasis::parse(context, input)) {
                    basis = Some(value);
                    continue
                }
            }
            break
        }

        if grow.is_none() && basis.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_grow: grow.unwrap_or(NonNegativeNumber::new(1.0)),
            flex_shrink: shrink.unwrap_or(NonNegativeNumber::new(1.0)),
            // Per spec, this should be SpecifiedValue::zero(), but all
            // browsers currently agree on using `0%`. This is a spec
            // change which hasn't been adopted by browsers:
            // https://github.com/w3c/csswg-drafts/commit/2c446befdf0f686217905bdd7c92409f6bd3921b
            flex_basis: basis.unwrap_or(FlexBasis::zero_percent()),
        })
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-gap
    pub mod grid_gap {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_gap:
                    longhands::grid_row_gap::SpecifiedValue
                    ,
                pub grid_column_gap:
                    longhands::grid_column_gap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_gap:
                    &'a longhands::grid_row_gap::SpecifiedValue,
                pub grid_column_gap:
                    &'a longhands::grid_column_gap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_gap = None;
                    let mut grid_column_gap = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowGap(ref value) => {
                                grid_row_gap = Some(value)
                            },
                            PropertyDeclaration::GridColumnGap(ref value) => {
                                grid_column_gap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_gap,
                        grid_column_gap,
                ) {

                    (
                        Some(grid_row_gap),
                        Some(grid_column_gap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_gap: grid_row_gap,
                            grid_column_gap: grid_column_gap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowGap(
                        longhands.grid_row_gap
                    ));
                    declarations.push(PropertyDeclaration::GridColumnGap(
                        longhands.grid_column_gap
                    ));
            })
        }

        
  use properties::longhands::{grid_row_gap, grid_column_gap};

  pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<Longhands, ParseError<'i>> {
      let row_gap = grid_row_gap::parse(context, input)?;
      let column_gap = input.try(|input| grid_column_gap::parse(context, input)).unwrap_or(row_gap.clone());

      Ok(expanded! {
        grid_row_gap: row_gap,
        grid_column_gap: column_gap,
      })
  }

  impl<'a> ToCss for LonghandsToSerialize<'a>  {
      fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
          if self.grid_row_gap == self.grid_column_gap {
            self.grid_row_gap.to_css(dest)
          } else {
            self.grid_row_gap.to_css(dest)?;
            dest.write_str(" ")?;
            self.grid_column_gap.to_css(dest)
          }
      }
  }


    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-row
    pub mod grid_row {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_start:
                        Box<
                    longhands::grid_row_start::SpecifiedValue
                        >
                    ,
                pub grid_row_end:
                        Box<
                    longhands::grid_row_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start = None;
                    let mut grid_row_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start: grid_row_start,
                            grid_row_end: grid_row_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let start = input.try(|i| GridLine::parse(context, i))?;
        let end = if input.try(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_none() && !start.is_span {
                line.ident = start.ident.clone();       // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_row_start: start,
            grid_row_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            dest.write_str(" / ")?;
            self.grid_row_end.to_css(dest)
        }
    }

    }



    /// https://drafts.csswg.org/css-grid/#propdef-grid-column
    pub mod grid_column {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_column_start:
                        Box<
                    longhands::grid_column_start::SpecifiedValue
                        >
                    ,
                pub grid_column_end:
                        Box<
                    longhands::grid_column_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_column_start = None;
                    let mut grid_column_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_column_start: grid_column_start,
                            grid_column_end: grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let start = input.try(|i| GridLine::parse(context, i))?;
        let end = if input.try(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_none() && !start.is_span {
                line.ident = start.ident.clone();       // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_column_start: start,
            grid_column_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_column_start.to_css(dest)?;
            dest.write_str(" / ")?;
            self.grid_column_end.to_css(dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-area
    pub mod grid_area {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_row_start:
                        Box<
                    longhands::grid_row_start::SpecifiedValue
                        >
                    ,
                pub grid_row_end:
                        Box<
                    longhands::grid_row_end::SpecifiedValue
                        >
                    ,
                pub grid_column_start:
                        Box<
                    longhands::grid_column_start::SpecifiedValue
                        >
                    ,
                pub grid_column_end:
                        Box<
                    longhands::grid_column_end::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start = None;
                    let mut grid_row_end = None;
                    let mut grid_column_start = None;
                    let mut grid_column_end = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start: grid_row_start,
                            grid_row_end: grid_row_end,
                            grid_column_start: grid_column_start,
                            grid_column_end: grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        
    use values::specified::GridLine;
    use parser::Parse;

    // The code is the same as `grid-{row,column}` except that this can have four values at most.
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        fn line_with_ident_from(other: &GridLine) -> GridLine {
            let mut this = GridLine::auto();
            if other.line_num.is_none() && !other.is_span {
                this.ident = other.ident.clone();
            }

            this
        }

        let row_start = input.try(|i| GridLine::parse(context, i))?;
        let (column_start, row_end, column_end) = if input.try(|i| i.expect_delim('/')).is_ok() {
            let column_start = GridLine::parse(context, input)?;
            let (row_end, column_end) = if input.try(|i| i.expect_delim('/')).is_ok() {
                let row_end = GridLine::parse(context, input)?;
                let column_end = if input.try(|i| i.expect_delim('/')).is_ok() {
                    GridLine::parse(context, input)?
                } else {        // grid-column-end has not been given
                    line_with_ident_from(&column_start)
                };

                (row_end, column_end)
            } else {        // grid-row-start and grid-column-start has been given
                let row_end = line_with_ident_from(&row_start);
                let column_end = line_with_ident_from(&column_start);
                (row_end, column_end)
            };

            (column_start, row_end, column_end)
        } else {        // only grid-row-start is given
            let line = line_with_ident_from(&row_start);
            (line.clone(), line.clone(), line)
        };

        Ok(expanded! {
            grid_row_start: row_start,
            grid_row_end: row_end,
            grid_column_start: column_start,
            grid_column_end: column_end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            let values = [&self.grid_column_start, &self.grid_row_end, &self.grid_column_end];
            for value in &values {
                dest.write_str(" / ")?;
                value.to_css(dest)?;
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-template
    pub mod grid_template {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_template_rows:
                        Box<
                    longhands::grid_template_rows::SpecifiedValue
                        >
                    ,
                pub grid_template_columns:
                        Box<
                    longhands::grid_template_columns::SpecifiedValue
                        >
                    ,
                pub grid_template_areas:
                        Box<
                    longhands::grid_template_areas::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows = None;
                    let mut grid_template_columns = None;
                    let mut grid_template_areas = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows: grid_template_rows,
                            grid_template_columns: grid_template_columns,
                            grid_template_areas: grid_template_areas,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
            })
        }

        
    use parser::Parse;
    use values::{Either, None_};
    use values::generics::grid::{LineNameList, TrackSize, TrackList, TrackListType};
    use values::generics::grid::{TrackListValue, concat_serialize_idents};
    use values::specified::{GridTemplateComponent, GenericGridTemplateComponent};
    use values::specified::grid::parse_line_names;
    use values::specified::position::TemplateAreas;

    /// Parsing for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn parse_grid_template<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                                       -> Result<(GridTemplateComponent,
                                                  GridTemplateComponent,
                                                  Either<TemplateAreas, None_>), ParseError<'i>> {
        // Other shorthand sub properties also parse `none` and `subgrid` keywords and this
        // shorthand should know after these keywords there is nothing to parse. Otherwise it
        // gets confused and rejects the sub properties that contains `none` or `subgrid`.
        
            if let Ok(x) = input.try(|i| {
                if i.try(|i| i.expect_ident_matching("subgrid")).is_ok() {
                    if i.is_exhausted() {
                        return Ok((GenericGridTemplateComponent::Subgrid(LineNameList::default()),
                                   GenericGridTemplateComponent::Subgrid(LineNameList::default()),
                                   Either::Second(None_)))
                    } else {
                        return Err(());
                    }
                }
                Err(())
            }) {
                return Ok(x);
            }
            if let Ok(x) = input.try(|i| {
                if i.try(|i| i.expect_ident_matching("none")).is_ok() {
                    if i.is_exhausted() {
                        return Ok((GenericGridTemplateComponent::None,
                                   GenericGridTemplateComponent::None,
                                   Either::Second(None_)))
                    } else {
                        return Err(());
                    }
                }
                Err(())
            }) {
                return Ok(x);
            }

        let first_line_names = input.try(parse_line_names).unwrap_or(vec![].into_boxed_slice());
        if let Ok(mut string) = input.try(|i| i.expect_string().map(|s| s.as_ref().into())) {
            let mut strings = vec![];
            let mut values = vec![];
            let mut line_names = vec![];
            let mut names = first_line_names.into_vec();
            loop {
                line_names.push(names.into_boxed_slice());
                strings.push(string);
                let size = input.try(|i| TrackSize::parse(context, i)).unwrap_or_default();
                values.push(TrackListValue::TrackSize(size));
                names = input.try(parse_line_names).unwrap_or(vec![].into_boxed_slice()).into_vec();
                if let Ok(v) = input.try(parse_line_names) {
                    names.extend(v.into_vec());
                }

                string = match input.try(|i| i.expect_string().map(|s| s.as_ref().into())) {
                    Ok(s) => s,
                    _ => {      // only the named area determines whether we should bail out
                        line_names.push(names.into_boxed_slice());
                        break
                    },
                };
            }

            if line_names.len() == values.len() {
                // should be one longer than track sizes
                line_names.push(vec![].into_boxed_slice());
            }

            let template_areas = TemplateAreas::from_vec(strings)
                .map_err(|()| input.new_custom_error(StyleParseErrorKind::UnspecifiedError))?;
            let template_rows = TrackList {
                list_type: TrackListType::Normal,
                values: values,
                line_names: line_names.into_boxed_slice(),
                auto_repeat: None,
            };

            let template_cols = if input.try(|i| i.expect_delim('/')).is_ok() {
                let value = GridTemplateComponent::parse_without_none(context, input)?;
                if let GenericGridTemplateComponent::TrackList(ref list) = value {
                    if list.list_type != TrackListType::Explicit {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                }

                value
            } else {
                GenericGridTemplateComponent::None
            };

            Ok((GenericGridTemplateComponent::TrackList(template_rows),
                template_cols, Either::First(template_areas)))
        } else {
            let mut template_rows = GridTemplateComponent::parse(context, input)?;
            if let GenericGridTemplateComponent::TrackList(ref mut list) = template_rows {
                // Fist line names are parsed already and it shouldn't be parsed again.
                // If line names are not empty, that means given property value is not acceptable
                if list.line_names[0].is_empty() {
                    list.line_names[0] = first_line_names;      // won't panic
                } else {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
                }
            }

            input.expect_delim('/')?;
            Ok((template_rows, GridTemplateComponent::parse(context, input)?, Either::Second(None_)))
        }
    }

    #[inline]
    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let (rows, columns, areas) = parse_grid_template(context, input)?;
        Ok(expanded! {
            grid_template_rows: rows,
            grid_template_columns: columns,
            grid_template_areas: areas,
        })
    }

    /// Serialization for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn serialize_grid_template<W>(
        template_rows: &GridTemplateComponent,
        template_columns: &GridTemplateComponent,
        template_areas: &Either<TemplateAreas, None_>,
        dest: &mut CssWriter<W>,
    ) -> fmt::Result
    where
        W: Write {
        match *template_areas {
            Either::Second(_none) => {
                template_rows.to_css(dest)?;
                dest.write_str(" / ")?;
                template_columns.to_css(dest)
            },
            Either::First(ref areas) => {
                // The length of template-area and template-rows values should be equal.
                if areas.strings.len() != template_rows.track_list_len() {
                    return Ok(());
                }

                let track_list = match *template_rows {
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        // We should fail if there is a `repeat` function. `grid` and
                        // `grid-template` shorthands doesn't accept that. Only longhand accepts.
                        if list.auto_repeat.is_some() ||
                           list.values.iter().any(|v| match *v {
                               TrackListValue::TrackRepeat(_) => true,
                               _ => false,
                           }) {
                            return Ok(());
                        }
                        list
                    },
                    // Others template components shouldn't exist with normal shorthand values.
                    // But if we need to serialize a group of longhand sub-properties for
                    // the shorthand, we should be able to return empty string instead of crashing.
                    _ => return Ok(()),
                };

                // We need to check some values that longhand accepts but shorthands don't.
                match *template_columns {
                    // We should fail if there is a `repeat` function. `grid` and
                    // `grid-template` shorthands doesn't accept that. Only longhand accepts that.
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        if list.auto_repeat.is_some() ||
                           list.values.iter().any(|v| match *v {
                               TrackListValue::TrackRepeat(_) => true,
                               _ => false,
                           }) {
                            return Ok(());
                        }
                    },
                    // Also the shorthands don't accept subgrids unlike longhand.
                    // We should fail without an error here.
                    GenericGridTemplateComponent::Subgrid(_) => {
                        return Ok(());
                    },
                    _ => {},
                }

                let mut names_iter = track_list.line_names.iter();
                for (((i, string), names), value) in areas.strings.iter().enumerate()
                                                                  .zip(&mut names_iter)
                                                                  .zip(track_list.values.iter()) {
                    if i > 0 {
                        dest.write_str(" ")?;
                    }

                    if !names.is_empty() {
                        concat_serialize_idents("[", "] ", names, " ", dest)?;
                    }

                    string.to_css(dest)?;
                    dest.write_str(" ")?;
                    value.to_css(dest)?;
                }

                if let Some(names) = names_iter.next() {
                    concat_serialize_idents(" [", "]", names, " ", dest)?;
                }

                if let GenericGridTemplateComponent::TrackList(ref list) = *template_columns {
                    dest.write_str(" / ")?;
                    list.to_css(dest)?;
                }

                Ok(())
            },
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        #[inline]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            serialize_grid_template(self.grid_template_rows, self.grid_template_columns,
                                    self.grid_template_areas, dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid
    pub mod grid {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub grid_template_rows:
                        Box<
                    longhands::grid_template_rows::SpecifiedValue
                        >
                    ,
                pub grid_template_columns:
                        Box<
                    longhands::grid_template_columns::SpecifiedValue
                        >
                    ,
                pub grid_template_areas:
                        Box<
                    longhands::grid_template_areas::SpecifiedValue
                        >
                    ,
                pub grid_auto_rows:
                        Box<
                    longhands::grid_auto_rows::SpecifiedValue
                        >
                    ,
                pub grid_auto_columns:
                        Box<
                    longhands::grid_auto_columns::SpecifiedValue
                        >
                    ,
                pub grid_auto_flow:
                    longhands::grid_auto_flow::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
                pub grid_auto_rows:
                    &'a longhands::grid_auto_rows::SpecifiedValue,
                pub grid_auto_columns:
                    &'a longhands::grid_auto_columns::SpecifiedValue,
                pub grid_auto_flow:
                    &'a longhands::grid_auto_flow::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows = None;
                    let mut grid_template_columns = None;
                    let mut grid_template_areas = None;
                    let mut grid_auto_rows = None;
                    let mut grid_auto_columns = None;
                    let mut grid_auto_flow = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                            PropertyDeclaration::GridAutoRows(ref value) => {
                                grid_auto_rows = Some(value)
                            },
                            PropertyDeclaration::GridAutoColumns(ref value) => {
                                grid_auto_columns = Some(value)
                            },
                            PropertyDeclaration::GridAutoFlow(ref value) => {
                                grid_auto_flow = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                        grid_auto_rows,
                        grid_auto_columns,
                        grid_auto_flow,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                        Some(grid_auto_rows),
                        Some(grid_auto_columns),
                        Some(grid_auto_flow),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows: grid_template_rows,
                            grid_template_columns: grid_template_columns,
                            grid_template_areas: grid_template_areas,
                            grid_auto_rows: grid_auto_rows,
                            grid_auto_columns: grid_auto_columns,
                            grid_auto_flow: grid_auto_flow,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
                    declarations.push(PropertyDeclaration::GridAutoRows(
                        longhands.grid_auto_rows
                    ));
                    declarations.push(PropertyDeclaration::GridAutoColumns(
                        longhands.grid_auto_columns
                    ));
                    declarations.push(PropertyDeclaration::GridAutoFlow(
                        longhands.grid_auto_flow
                    ));
            })
        }

        
    use parser::Parse;
    use properties::longhands::{grid_auto_columns, grid_auto_rows, grid_auto_flow};
    use values::{Either, None_};
    use values::generics::grid::{GridTemplateComponent, TrackListType};
    use values::specified::{GenericGridTemplateComponent, TrackSize};
    use values::specified::position::{AutoFlow, GridAutoFlow};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let mut temp_rows = GridTemplateComponent::None;
        let mut temp_cols = GridTemplateComponent::None;
        let mut temp_areas = Either::Second(None_);
        let mut auto_rows = TrackSize::default();
        let mut auto_cols = TrackSize::default();
        let mut flow = grid_auto_flow::get_initial_value();

        fn parse_auto_flow<'i, 't>(input: &mut Parser<'i, 't>, is_row: bool)
                                   -> Result<GridAutoFlow, ParseError<'i>> {
            let mut auto_flow = None;
            let mut dense = false;
            for _ in 0..2 {
                if input.try(|i| i.expect_ident_matching("auto-flow")).is_ok() {
                    auto_flow = if is_row {
                        Some(AutoFlow::Row)
                    } else {
                        Some(AutoFlow::Column)
                    };
                } else if input.try(|i| i.expect_ident_matching("dense")).is_ok() {
                    dense = true;
                } else {
                    break
                }
            }

            auto_flow.map(|flow| {
                GridAutoFlow {
                    autoflow: flow,
                    dense: dense,
                }
            }).ok_or(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        if let Ok((rows, cols, areas)) = input.try(|i| super::grid_template::parse_grid_template(context, i)) {
            temp_rows = rows;
            temp_cols = cols;
            temp_areas = areas;
        } else if let Ok(rows) = input.try(|i| GridTemplateComponent::parse(context, i)) {
            temp_rows = rows;
            input.expect_delim('/')?;
            flow = parse_auto_flow(input, false)?;
            auto_cols = grid_auto_columns::parse(context, input).unwrap_or_default();
        } else {
            flow = parse_auto_flow(input, true)?;
            auto_rows = input.try(|i| grid_auto_rows::parse(context, i)).unwrap_or_default();
            input.expect_delim('/')?;
            temp_cols = GridTemplateComponent::parse(context, input)?;
        }

        Ok(expanded! {
            grid_template_rows: temp_rows,
            grid_template_columns: temp_cols,
            grid_template_areas: temp_areas,
            grid_auto_rows: auto_rows,
            grid_auto_columns: auto_cols,
            grid_auto_flow: flow,
        })
    }

    impl<'a> LonghandsToSerialize<'a> {
        /// Returns true if other sub properties except template-{rows,columns} are initial.
        fn is_grid_template(&self) -> bool {
            *self.grid_template_areas == Either::Second(None_) &&
            *self.grid_auto_rows == TrackSize::default() &&
            *self.grid_auto_columns == TrackSize::default() &&
            *self.grid_auto_flow == grid_auto_flow::get_initial_value()
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if *self.grid_template_areas != Either::Second(None_) ||
               (*self.grid_template_rows != GridTemplateComponent::None &&
                   *self.grid_template_columns != GridTemplateComponent::None) ||
               self.is_grid_template() {
                return super::grid_template::serialize_grid_template(self.grid_template_rows,
                                                                     self.grid_template_columns,
                                                                     self.grid_template_areas, dest);
            }

            if self.grid_auto_flow.autoflow == AutoFlow::Column {
                // It should fail to serialize if other branch of the if condition's values are set.
                if *self.grid_auto_rows != TrackSize::default() ||
                   *self.grid_template_columns != GridTemplateComponent::None {
                    return Ok(());
                }

                // It should fail to serialize if template-rows value is not Explicit.
                if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_rows {
                    if list.list_type != TrackListType::Explicit {
                        return Ok(());
                    }
                }

                self.grid_template_rows.to_css(dest)?;
                dest.write_str(" / auto-flow")?;
                if self.grid_auto_flow.dense {
                    dest.write_str(" dense")?;
                }

                if !self.grid_auto_columns.is_default() {
                    dest.write_str(" ")?;
                    self.grid_auto_columns.to_css(dest)?;
                }
            } else {
                // It should fail to serialize if other branch of the if condition's values are set.
                if *self.grid_auto_columns != TrackSize::default() ||
                   *self.grid_template_rows != GridTemplateComponent::None {
                    return Ok(());
                }

                // It should fail to serialize if template-column value is not Explicit.
                if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_columns {
                    if list.list_type != TrackListType::Explicit {
                        return Ok(());
                    }
                }

                dest.write_str("auto-flow")?;
                if self.grid_auto_flow.dense {
                    dest.write_str(" dense")?;
                }

                if !self.grid_auto_rows.is_default() {
                    dest.write_str(" ")?;
                    self.grid_auto_rows.to_css(dest)?;
                }

                dest.write_str(" / ")?;
                self.grid_template_columns.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#propdef-place-content
    pub mod place_content {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_content:
                    longhands::align_content::SpecifiedValue
                    ,
                pub justify_content:
                    longhands::justify_content::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_content:
                    &'a longhands::align_content::SpecifiedValue,
                pub justify_content:
                    &'a longhands::justify_content::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_content = None;
                    let mut justify_content = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignContent(ref value) => {
                                align_content = Some(value)
                            },
                            PropertyDeclaration::JustifyContent(ref value) => {
                                justify_content = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_content,
                        justify_content,
                ) {

                    (
                        Some(align_content),
                        Some(justify_content),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_content: align_content,
                            justify_content: justify_content,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignContent(
                        longhands.align_content
                    ));
                    declarations.push(PropertyDeclaration::JustifyContent(
                        longhands.justify_content
                    ));
            })
        }

        
    use values::specified::align::{AlignJustifyContent, FallbackAllowed};

    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align = AlignJustifyContent::parse_with_fallback(input, FallbackAllowed::No)?;
        if align.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }
        let justify =
            input.try(|input| AlignJustifyContent::parse_with_fallback(input, FallbackAllowed::No))
                .unwrap_or(align);
        if justify.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_content: align,
            justify_content: justify,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_content.to_css(dest)?;
            if self.align_content != self.justify_content {
                dest.write_str(" ")?;
                self.justify_content.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-self-property
    pub mod place_self {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_self:
                    longhands::align_self::SpecifiedValue
                    ,
                pub justify_self:
                    longhands::justify_self::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_self:
                    &'a longhands::align_self::SpecifiedValue,
                pub justify_self:
                    &'a longhands::justify_self::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_self = None;
                    let mut justify_self = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignSelf(ref value) => {
                                align_self = Some(value)
                            },
                            PropertyDeclaration::JustifySelf(ref value) => {
                                justify_self = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_self,
                        justify_self,
                ) {

                    (
                        Some(align_self),
                        Some(justify_self),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_self: align_self,
                            justify_self: justify_self,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignSelf(
                        longhands.align_self
                    ));
                    declarations.push(PropertyDeclaration::JustifySelf(
                        longhands.justify_self
                    ));
            })
        }

        
    use values::specified::align::AlignJustifySelf;
    use parser::Parse;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let align = AlignJustifySelf::parse(context, input)?;
        if align.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }
        let justify = input.try(|input| AlignJustifySelf::parse(context, input)).unwrap_or(align.clone());
        if justify.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_self: align,
            justify_self: justify,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.align_self == self.justify_self {
                self.align_self.to_css(dest)
            } else {
                self.align_self.to_css(dest)?;
                dest.write_str(" ")?;
                self.justify_self.to_css(dest)
            }
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-items-property
    pub mod place_items {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub align_items:
                    longhands::align_items::SpecifiedValue
                    ,
                pub justify_items:
                    longhands::justify_items::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_items:
                    &'a longhands::align_items::SpecifiedValue,
                pub justify_items:
                    &'a longhands::justify_items::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_items = None;
                    let mut justify_items = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::AlignItems(ref value) => {
                                align_items = Some(value)
                            },
                            PropertyDeclaration::JustifyItems(ref value) => {
                                justify_items = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_items,
                        justify_items,
                ) {

                    (
                        Some(align_items),
                        Some(justify_items),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_items: align_items,
                            justify_items: justify_items,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignItems(
                        longhands.align_items
                    ));
                    declarations.push(PropertyDeclaration::JustifyItems(
                        longhands.justify_items
                    ));
            })
        }

        
    use values::specified::align::{AlignItems, JustifyItems};
    use parser::Parse;

    impl From<AlignItems> for JustifyItems {
        fn from(align: AlignItems) -> JustifyItems {
            JustifyItems(align.0)
        }
    }

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        let align = AlignItems::parse(context, input)?;
        if align.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }
        let justify = input.try(|input| JustifyItems::parse(context, input))
                           .unwrap_or(JustifyItems::from(align));
        if justify.has_extra_flags() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            align_items: align,
            justify_items: justify,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.align_items.0 == self.justify_items.0 {
                self.align_items.to_css(dest)
            } else {
                self.align_items.to_css(dest)?;
                dest.write_str(" ")?;
                self.justify_items.to_css(dest)
            }
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://www.w3.org/TR/SVG2/painting.html#MarkerShorthand
    pub mod marker {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub marker_start:
                        Box<
                    longhands::marker_start::SpecifiedValue
                        >
                    ,
                pub marker_end:
                        Box<
                    longhands::marker_end::SpecifiedValue
                        >
                    ,
                pub marker_mid:
                        Box<
                    longhands::marker_mid::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub marker_start:
                    &'a longhands::marker_start::SpecifiedValue,
                pub marker_end:
                    &'a longhands::marker_end::SpecifiedValue,
                pub marker_mid:
                    &'a longhands::marker_mid::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut marker_start = None;
                    let mut marker_end = None;
                    let mut marker_mid = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::MarkerStart(ref value) => {
                                marker_start = Some(value)
                            },
                            PropertyDeclaration::MarkerEnd(ref value) => {
                                marker_end = Some(value)
                            },
                            PropertyDeclaration::MarkerMid(ref value) => {
                                marker_mid = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        marker_start,
                        marker_end,
                        marker_mid,
                ) {

                    (
                        Some(marker_start),
                        Some(marker_end),
                        Some(marker_mid),
                    ) =>
                    Ok(LonghandsToSerialize {
                            marker_start: marker_start,
                            marker_end: marker_end,
                            marker_mid: marker_mid,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarkerStart(
                        longhands.marker_start
                    ));
                    declarations.push(PropertyDeclaration::MarkerEnd(
                        longhands.marker_end
                    ));
                    declarations.push(PropertyDeclaration::MarkerMid(
                        longhands.marker_mid
                    ));
            })
        }

        
    use values::specified::UrlOrNone;

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
        use parser::Parse;
        let url = UrlOrNone::parse(context, input)?;

        Ok(expanded! {
            marker_start: url.clone(),
            marker_mid: url.clone(),
            marker_end: url,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.marker_start == self.marker_mid && self.marker_mid == self.marker_end {
                self.marker_start.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration
    pub mod text_decoration {
        use cssparser::Parser;
        use parser::ParserContext;
        use properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, ToCss};

        pub struct Longhands {
                pub text_decoration_line:
                    longhands::text_decoration_line::SpecifiedValue
                    ,
                pub text_decoration_style:
                    longhands::text_decoration_style::SpecifiedValue
                    ,
                pub text_decoration_color:
                    longhands::text_decoration_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub text_decoration_line:
                    &'a longhands::text_decoration_line::SpecifiedValue,
                pub text_decoration_style:
                    &'a longhands::text_decoration_style::SpecifiedValue,
                pub text_decoration_color:
                    &'a longhands::text_decoration_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter<I>(iter: I) -> Result<Self, ()>
                where I: Iterator<Item=&'a PropertyDeclaration>,
            {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_decoration_line = None;
                    let mut text_decoration_style = None;
                    let mut text_decoration_color = None;

                // Attempt to assign the incoming declarations to the expected variables
                for longhand in iter {
                    match *longhand {
                            PropertyDeclaration::TextDecorationLine(ref value) => {
                                text_decoration_line = Some(value)
                            },
                            PropertyDeclaration::TextDecorationStyle(ref value) => {
                                text_decoration_style = Some(value)
                            },
                            PropertyDeclaration::TextDecorationColor(ref value) => {
                                text_decoration_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_decoration_line,
                        text_decoration_style,
                        text_decoration_color,
                ) {

                    (
                        Some(text_decoration_line),
                        Some(text_decoration_style),
                        Some(text_decoration_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_decoration_line: text_decoration_line,
                            text_decoration_style: text_decoration_style,
                            text_decoration_color: text_decoration_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(declarations: &mut SourcePropertyDeclaration,
                                  context: &ParserContext, input: &mut Parser<'i, 't>)
                                  -> Result<(), ParseError<'i>> {
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextDecorationLine(
                        longhands.text_decoration_line
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationStyle(
                        longhands.text_decoration_style
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationColor(
                        longhands.text_decoration_color
                    ));
            })
        }

        

        use values::specified;
        use properties::longhands::{text_decoration_line, text_decoration_style, text_decoration_color};

    pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                               -> Result<Longhands, ParseError<'i>> {
            let (mut line, mut style, mut color, mut any) = (None, None, None, false);

        loop {
            macro_rules! parse_component {
                ($value:ident, $module:ident) => (
                    if $value.is_none() {
                        if let Ok(value) = input.try(|input| $module::parse(context, input)) {
                            $value = Some(value);
                            any = true;
                            continue;
                        }
                    }
                )
            }

            parse_component!(line, text_decoration_line);

                parse_component!(style, text_decoration_style);
                parse_component!(color, text_decoration_color);

            break;
        }

        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            text_decoration_line: unwrap_or_initial!(text_decoration_line, line),

                text_decoration_style: unwrap_or_initial!(text_decoration_style, style),
                text_decoration_color: unwrap_or_initial!(text_decoration_color, color),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.text_decoration_line.to_css(dest)?;

                if *self.text_decoration_style != text_decoration_style::SpecifiedValue::Solid {
                    dest.write_str(" ")?;
                    self.text_decoration_style.to_css(dest)?;
                }

                if *self.text_decoration_color != specified::Color::CurrentColor {
                    dest.write_str(" ")?;
                    self.text_decoration_color.to_css(dest)?;
                }

            Ok(())
        }
    }

    }



    // We don't defined the 'all' shorthand using the regular helpers:shorthand
    // mechanism, since it causes some very large types to be generated.
    //
    // Also, make sure logical properties appear before its physical
    // counter-parts, in order to prevent bugs like:
    //
    //   https://bugzilla.mozilla.org/show_bug.cgi?id=1410028
    //
    // FIXME(emilio): Adopt the resolution from:
    //
    //   https://github.com/w3c/csswg-drafts/issues/1898
    //
    // when there is one, whatever that is.
    
}

/// A module with all the code related to animated properties.
///
/// This needs to be "included" by mako at least after all longhand modules,
/// given they populate the global data.
pub mod animated_properties {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */





use cssparser::Parser;
#[cfg(feature = "gecko")] use gecko_bindings::bindings::RawServoAnimationValueMap;
#[cfg(feature = "gecko")] use gecko_bindings::structs::RawGeckoGfxMatrix4x4;
#[cfg(feature = "gecko")] use gecko_bindings::structs::nsCSSPropertyID;
#[cfg(feature = "gecko")] use gecko_bindings::sugar::ownership::{HasFFI, HasSimpleFFI};
use itertools::{EitherOrBoth, Itertools};
use num_traits::Zero;
use properties::{CSSWideKeyword, PropertyDeclaration};
use properties::longhands;
use properties::longhands::font_weight::computed_value::T as FontWeight;
use properties::longhands::font_stretch::computed_value::T as FontStretch;
#[cfg(feature = "gecko")]
use properties::longhands::font_variation_settings::computed_value::T as FontVariationSettings;
use properties::longhands::visibility::computed_value::T as Visibility;
#[cfg(feature = "gecko")]
use properties::PropertyId;
use properties::{LonghandId, ShorthandId};
use selectors::parser::SelectorParseErrorKind;
use servo_arc::Arc;
use smallvec::SmallVec;
use std::cmp;
use std::fmt::{self, Write};
#[cfg(feature = "gecko")] use hash::FnvHashMap;
use style_traits::{CssWriter, ParseError, ToCss};
use super::ComputedValues;
use values::{CSSFloat, CustomIdent, Either};
use values::animated::{Animate, Procedure, ToAnimatedValue, ToAnimatedZero};
use values::animated::color::RGBA as AnimatedRGBA;
use values::animated::effects::Filter as AnimatedFilter;
use values::animated::effects::FilterList as AnimatedFilterList;
use values::computed::{Angle, CalcLengthOrPercentage};
use values::computed::{ClipRect, Context, ComputedUrl};
use values::computed::{Length, LengthOrPercentage, LengthOrPercentageOrAuto};
use values::computed::{LengthOrPercentageOrNone, MaxLength};
use values::computed::{NonNegativeNumber, Number, NumberOrPercentage, Percentage};
use values::computed::length::NonNegativeLengthOrPercentage;
use values::computed::ToComputedValue;
use values::computed::transform::{DirectionVector, Matrix, Matrix3D};
use values::computed::transform::TransformOperation as ComputedTransformOperation;
use values::computed::transform::Transform as ComputedTransform;
use values::generics::transform::{self, Transform, TransformOperation};
use values::distance::{ComputeSquaredDistance, SquaredDistance};
#[cfg(feature = "gecko")] use values::generics::FontSettings as GenericFontSettings;
#[cfg(feature = "gecko")] use values::generics::FontSettingTag as GenericFontSettingTag;
#[cfg(feature = "gecko")] use values::generics::FontSettingTagFloat;
use values::generics::NonNegative;
use values::generics::effects::Filter;
use values::generics::position as generic_position;
use values::generics::svg::{SVGLength,  SvgLengthOrPercentageOrNumber, SVGPaint};
use values::generics::svg::{SVGPaintKind, SVGStrokeDashArray, SVGOpacity};

/// <https://drafts.csswg.org/css-transitions/#animtype-repeatable-list>
pub trait RepeatableListAnimatable: Animate {}

/// Returns true if this nsCSSPropertyID is one of the animatable properties.
#[cfg(feature = "gecko")]
pub fn nscsspropertyid_is_animatable(property: nsCSSPropertyID) -> bool {
    match property {
                
    nsCSSPropertyID::eCSSProperty_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_background_image => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_background_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_background_attachment => true,
                
    nsCSSPropertyID::eCSSProperty_background_clip => true,
                
    nsCSSPropertyID::eCSSProperty_background_origin => true,
                
    nsCSSPropertyID::eCSSProperty_background_size => true,
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty__moz_border_top_colors => true,
                
    nsCSSPropertyID::eCSSProperty__moz_border_left_colors => true,
                
    nsCSSPropertyID::eCSSProperty__moz_border_bottom_colors => true,
                
    nsCSSPropertyID::eCSSProperty__moz_border_right_colors => true,
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break => true,
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_source => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_outset => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_image_slice => true,
                
    nsCSSPropertyID::eCSSProperty_display => true,
                
    nsCSSPropertyID::eCSSProperty_position => true,
                
    nsCSSPropertyID::eCSSProperty_float_ => true,
                
    nsCSSPropertyID::eCSSProperty_clear => true,
                
    nsCSSPropertyID::eCSSProperty_vertical_align => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_x => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_y => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => true,
                
    nsCSSPropertyID::eCSSProperty_transform => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => true,
                
    nsCSSPropertyID::eCSSProperty_isolation => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_after => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_before => true,
                
    nsCSSPropertyID::eCSSProperty_page_break_inside => true,
                
    nsCSSPropertyID::eCSSProperty_resize => true,
                
    nsCSSPropertyID::eCSSProperty_perspective => true,
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => true,
                
    nsCSSPropertyID::eCSSProperty_backface_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_transform_box => true,
                
    nsCSSPropertyID::eCSSProperty_transform_style => true,
                
    nsCSSPropertyID::eCSSProperty_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_contain => true,
                
    nsCSSPropertyID::eCSSProperty__moz_appearance => true,
                
    nsCSSPropertyID::eCSSProperty__moz_orient => true,
                
    nsCSSPropertyID::eCSSProperty_will_change => true,
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => true,
                
    nsCSSPropertyID::eCSSProperty_shape_outside => true,
                
    nsCSSPropertyID::eCSSProperty_touch_action => true,
                
    nsCSSPropertyID::eCSSProperty_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_count => true,
                
    nsCSSPropertyID::eCSSProperty_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_column_fill => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_span => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_style => true,
                
    nsCSSPropertyID::eCSSProperty_content => true,
                
    nsCSSPropertyID::eCSSProperty_counter_increment => true,
                
    nsCSSPropertyID::eCSSProperty_counter_reset => true,
                
    nsCSSPropertyID::eCSSProperty_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_box_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_clip => true,
                
    nsCSSPropertyID::eCSSProperty_filter => true,
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => true,
                
    nsCSSPropertyID::eCSSProperty_font_family => true,
                
    nsCSSPropertyID::eCSSProperty_font_style => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps => true,
                
    nsCSSPropertyID::eCSSProperty_font_weight => true,
                
    nsCSSPropertyID::eCSSProperty_font_size => true,
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_font_synthesis => true,
                
    nsCSSPropertyID::eCSSProperty_font_stretch => true,
                
    nsCSSPropertyID::eCSSProperty_font_kerning => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant_position => true,
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings => true,
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => true,
                
    nsCSSPropertyID::eCSSProperty_font_language_override => true,
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => true,
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_writing_mode => true,
                
    nsCSSPropertyID::eCSSProperty_direction => true,
                
    nsCSSPropertyID::eCSSProperty_text_orientation => true,
                
    nsCSSPropertyID::eCSSProperty_color_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_image_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_image_orientation => true,
                
    nsCSSPropertyID::eCSSProperty_border_collapse => true,
                
    nsCSSPropertyID::eCSSProperty_empty_cells => true,
                
    nsCSSPropertyID::eCSSProperty_caption_side => true,
                
    nsCSSPropertyID::eCSSProperty_border_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_line_height => true,
                
    nsCSSPropertyID::eCSSProperty_text_transform => true,
                
    nsCSSPropertyID::eCSSProperty_hyphens => true,
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_text_indent => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap => true,
                
    nsCSSPropertyID::eCSSProperty_word_break => true,
                
    nsCSSPropertyID::eCSSProperty_text_justify => true,
                
    nsCSSPropertyID::eCSSProperty_text_align_last => true,
                
    nsCSSPropertyID::eCSSProperty_text_align => true,
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_word_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_white_space => true,
                
    nsCSSPropertyID::eCSSProperty_text_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_ruby_align => true,
                
    nsCSSPropertyID::eCSSProperty_ruby_position => true,
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright => true,
                
    nsCSSPropertyID::eCSSProperty_text_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_position => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_type => true,
                
    nsCSSPropertyID::eCSSProperty_list_style_image => true,
                
    nsCSSPropertyID::eCSSProperty_quotes => true,
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => true,
                
    nsCSSPropertyID::eCSSProperty_margin_top => true,
                
    nsCSSPropertyID::eCSSProperty_margin_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_margin_right => true,
                
    nsCSSPropertyID::eCSSProperty_outline_color => true,
                
    nsCSSPropertyID::eCSSProperty_outline_style => true,
                
    nsCSSPropertyID::eCSSProperty_outline_width => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => true,
                
    nsCSSPropertyID::eCSSProperty_outline_offset => true,
                
    nsCSSPropertyID::eCSSProperty_padding_top => true,
                
    nsCSSPropertyID::eCSSProperty_padding_left => true,
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_padding_right => true,
                
    nsCSSPropertyID::eCSSProperty_cursor => true,
                
    nsCSSPropertyID::eCSSProperty_pointer_events => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_input => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus => true,
                
    nsCSSPropertyID::eCSSProperty_caret_color => true,
                
    nsCSSPropertyID::eCSSProperty_top => true,
                
    nsCSSPropertyID::eCSSProperty_left => true,
                
    nsCSSPropertyID::eCSSProperty_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_right => true,
                
    nsCSSPropertyID::eCSSProperty_z_index => true,
                
    nsCSSPropertyID::eCSSProperty_flex_direction => true,
                
    nsCSSPropertyID::eCSSProperty_flex_wrap => true,
                
    nsCSSPropertyID::eCSSProperty_justify_content => true,
                
    nsCSSPropertyID::eCSSProperty_align_content => true,
                
    nsCSSPropertyID::eCSSProperty_align_items => true,
                
    nsCSSPropertyID::eCSSProperty_justify_items => true,
                
    nsCSSPropertyID::eCSSProperty_flex_grow => true,
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => true,
                
    nsCSSPropertyID::eCSSProperty_align_self => true,
                
    nsCSSPropertyID::eCSSProperty_justify_self => true,
                
    nsCSSPropertyID::eCSSProperty_order => true,
                
    nsCSSPropertyID::eCSSProperty_flex_basis => true,
                
    nsCSSPropertyID::eCSSProperty_width => true,
                
    nsCSSPropertyID::eCSSProperty_min_width => true,
                
    nsCSSPropertyID::eCSSProperty_max_width => true,
                
    nsCSSPropertyID::eCSSProperty_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_height => true,
                
    nsCSSPropertyID::eCSSProperty_max_height => true,
                
    nsCSSPropertyID::eCSSProperty_box_sizing => true,
                
    nsCSSPropertyID::eCSSProperty_object_fit => true,
                
    nsCSSPropertyID::eCSSProperty_object_position => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_start => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_end => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_start => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_end => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns => true,
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas => true,
                
    nsCSSPropertyID::eCSSProperty_table_layout => true,
                
    nsCSSPropertyID::eCSSProperty_text_overflow => true,
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => true,
                
    nsCSSPropertyID::eCSSProperty_initial_letter => true,
                
    nsCSSPropertyID::eCSSProperty_ime_mode => true,
                
    nsCSSPropertyID::eCSSProperty__moz_user_select => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => true,
                
    nsCSSPropertyID::eCSSProperty_text_anchor => true,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation => true,
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => true,
                
    nsCSSPropertyID::eCSSProperty_fill => true,
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_fill_rule => true,
                
    nsCSSPropertyID::eCSSProperty_shape_rendering => true,
                
    nsCSSPropertyID::eCSSProperty_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => true,
                
    nsCSSPropertyID::eCSSProperty_clip_rule => true,
                
    nsCSSPropertyID::eCSSProperty_marker_start => true,
                
    nsCSSPropertyID::eCSSProperty_marker_mid => true,
                
    nsCSSPropertyID::eCSSProperty_marker_end => true,
                
    nsCSSPropertyID::eCSSProperty_paint_order => true,
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline => true,
                
    nsCSSPropertyID::eCSSProperty_vector_effect => true,
                
    nsCSSPropertyID::eCSSProperty_stop_color => true,
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_flood_color => true,
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_lighting_color => true,
                
    nsCSSPropertyID::eCSSProperty_mask_type => true,
                
    nsCSSPropertyID::eCSSProperty_clip_path => true,
                
    nsCSSPropertyID::eCSSProperty_mask_mode => true,
                
    nsCSSPropertyID::eCSSProperty_mask_repeat => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_mask_clip => true,
                
    nsCSSPropertyID::eCSSProperty_mask_origin => true,
                
    nsCSSPropertyID::eCSSProperty_mask_size => true,
                
    nsCSSPropertyID::eCSSProperty_mask_composite => true,
                
    nsCSSPropertyID::eCSSProperty_mask_image => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_align => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack => true,
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => true,
                
    nsCSSPropertyID::eCSSProperty_background => true,
                
    nsCSSPropertyID::eCSSProperty_background_position => true,
                
    nsCSSPropertyID::eCSSProperty_border_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_style => true,
                
    nsCSSPropertyID::eCSSProperty_border_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_left => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_border_right => true,
                
    nsCSSPropertyID::eCSSProperty_border => true,
                
    nsCSSPropertyID::eCSSProperty_border_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_image => true,
                
    nsCSSPropertyID::eCSSProperty_overflow => true,
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => true,
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => true,
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => true,
                
    nsCSSPropertyID::eCSSProperty__moz_transform => true,
                
    nsCSSPropertyID::eCSSProperty_columns => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule => true,
                
    nsCSSPropertyID::eCSSProperty_font => true,
                
    nsCSSPropertyID::eCSSProperty_font_variant => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_list_style => true,
                
    nsCSSPropertyID::eCSSProperty_margin => true,
                
    nsCSSPropertyID::eCSSProperty_mask => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position => true,
                
    nsCSSPropertyID::eCSSProperty_outline => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => true,
                
    nsCSSPropertyID::eCSSProperty_padding => true,
                
    nsCSSPropertyID::eCSSProperty_flex_flow => true,
                
    nsCSSPropertyID::eCSSProperty_flex => true,
                
    nsCSSPropertyID::eCSSProperty_grid_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column => true,
                
    nsCSSPropertyID::eCSSProperty_grid_area => true,
                
    nsCSSPropertyID::eCSSProperty_grid_template => true,
                
    nsCSSPropertyID::eCSSProperty_grid => true,
                
    nsCSSPropertyID::eCSSProperty_place_content => true,
                
    nsCSSPropertyID::eCSSProperty_place_self => true,
                
    nsCSSPropertyID::eCSSProperty_place_items => true,
                
    nsCSSPropertyID::eCSSProperty_marker => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration => true,
        _ => false
    }
}

/// A given transition property, that is either `All`, a transitionable longhand property,
/// a shorthand with at least one transitionable longhand component, or an unsupported property.
// NB: This needs to be here because it needs all the longhands generated
// beforehand.
#[derive(Clone, Debug, Eq, Hash, MallocSizeOf, PartialEq)]
pub enum TransitionProperty {
    /// All, any transitionable property changing should generate a transition.
    ///
    /// FIXME(emilio): Can we remove this and just use
    /// Shorthand(ShorthandId::All)?
    All,
    /// A shorthand.
    Shorthand(ShorthandId),
    /// A longhand transitionable property.
    Longhand(LonghandId),
    /// Unrecognized property which could be any non-transitionable, custom property, or
    /// unknown property.
    Unsupported(CustomIdent),
}

impl ToCss for TransitionProperty {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            TransitionProperty::All => dest.write_str("all"),
            TransitionProperty::Shorthand(ref id) => dest.write_str(id.name()),
            TransitionProperty::Longhand(ref id) => dest.write_str(id.name()),
            TransitionProperty::Unsupported(ref id) => id.to_css(dest),
        }
    }
}

trivial_to_computed_value!(TransitionProperty);

impl TransitionProperty {
    /// Iterates over each longhand property.
    pub fn each<F: FnMut(&LonghandId) -> ()>(mut cb: F) {
                cb(&LonghandId::BackgroundColor);
                cb(&LonghandId::BackgroundPositionX);
                cb(&LonghandId::BackgroundPositionY);
                cb(&LonghandId::BackgroundSize);
                cb(&LonghandId::BorderTopColor);
                cb(&LonghandId::BorderTopWidth);
                cb(&LonghandId::BorderLeftColor);
                cb(&LonghandId::BorderLeftWidth);
                cb(&LonghandId::BorderBottomColor);
                cb(&LonghandId::BorderBottomWidth);
                cb(&LonghandId::BorderRightColor);
                cb(&LonghandId::BorderRightWidth);
                cb(&LonghandId::BorderTopLeftRadius);
                cb(&LonghandId::BorderTopRightRadius);
                cb(&LonghandId::BorderBottomRightRadius);
                cb(&LonghandId::BorderBottomLeftRadius);
                cb(&LonghandId::VerticalAlign);
                cb(&LonghandId::Transform);
                cb(&LonghandId::Perspective);
                cb(&LonghandId::PerspectiveOrigin);
                cb(&LonghandId::TransformOrigin);
                cb(&LonghandId::ShapeImageThreshold);
                cb(&LonghandId::ShapeOutside);
                cb(&LonghandId::Color);
                cb(&LonghandId::ColumnWidth);
                cb(&LonghandId::ColumnCount);
                cb(&LonghandId::ColumnGap);
                cb(&LonghandId::ColumnRuleWidth);
                cb(&LonghandId::ColumnRuleColor);
                cb(&LonghandId::Opacity);
                cb(&LonghandId::BoxShadow);
                cb(&LonghandId::Clip);
                cb(&LonghandId::Filter);
                cb(&LonghandId::FontWeight);
                cb(&LonghandId::FontSize);
                cb(&LonghandId::FontSizeAdjust);
                cb(&LonghandId::FontStretch);
                cb(&LonghandId::FontVariationSettings);
                cb(&LonghandId::MozFontSmoothingBackgroundColor);
                cb(&LonghandId::Visibility);
                cb(&LonghandId::BorderSpacing);
                cb(&LonghandId::LineHeight);
                cb(&LonghandId::TextIndent);
                cb(&LonghandId::LetterSpacing);
                cb(&LonghandId::WordSpacing);
                cb(&LonghandId::TextShadow);
                cb(&LonghandId::TextEmphasisColor);
                cb(&LonghandId::MozTabSize);
                cb(&LonghandId::WebkitTextFillColor);
                cb(&LonghandId::WebkitTextStrokeColor);
                cb(&LonghandId::MozImageRegion);
                cb(&LonghandId::MarginTop);
                cb(&LonghandId::MarginLeft);
                cb(&LonghandId::MarginBottom);
                cb(&LonghandId::MarginRight);
                cb(&LonghandId::OutlineColor);
                cb(&LonghandId::OutlineWidth);
                cb(&LonghandId::MozOutlineRadiusTopleft);
                cb(&LonghandId::MozOutlineRadiusTopright);
                cb(&LonghandId::MozOutlineRadiusBottomright);
                cb(&LonghandId::MozOutlineRadiusBottomleft);
                cb(&LonghandId::OutlineOffset);
                cb(&LonghandId::PaddingTop);
                cb(&LonghandId::PaddingLeft);
                cb(&LonghandId::PaddingBottom);
                cb(&LonghandId::PaddingRight);
                cb(&LonghandId::CaretColor);
                cb(&LonghandId::Top);
                cb(&LonghandId::Left);
                cb(&LonghandId::Bottom);
                cb(&LonghandId::Right);
                cb(&LonghandId::ZIndex);
                cb(&LonghandId::FlexGrow);
                cb(&LonghandId::FlexShrink);
                cb(&LonghandId::Order);
                cb(&LonghandId::FlexBasis);
                cb(&LonghandId::Width);
                cb(&LonghandId::MinWidth);
                cb(&LonghandId::MaxWidth);
                cb(&LonghandId::Height);
                cb(&LonghandId::MinHeight);
                cb(&LonghandId::MaxHeight);
                cb(&LonghandId::ObjectPosition);
                cb(&LonghandId::GridRowGap);
                cb(&LonghandId::GridColumnGap);
                cb(&LonghandId::TextDecorationColor);
                cb(&LonghandId::MozWindowOpacity);
                cb(&LonghandId::MozWindowTransform);
                cb(&LonghandId::MozWindowTransformOrigin);
                cb(&LonghandId::Fill);
                cb(&LonghandId::FillOpacity);
                cb(&LonghandId::Stroke);
                cb(&LonghandId::StrokeWidth);
                cb(&LonghandId::StrokeMiterlimit);
                cb(&LonghandId::StrokeOpacity);
                cb(&LonghandId::StrokeDasharray);
                cb(&LonghandId::StrokeDashoffset);
                cb(&LonghandId::StopColor);
                cb(&LonghandId::StopOpacity);
                cb(&LonghandId::FloodColor);
                cb(&LonghandId::FloodOpacity);
                cb(&LonghandId::LightingColor);
                cb(&LonghandId::ClipPath);
                cb(&LonghandId::MaskPositionX);
                cb(&LonghandId::MaskPositionY);
                cb(&LonghandId::MaskSize);
                cb(&LonghandId::MozBoxFlex);
    }

    /// Iterates over every longhand property that is not
    /// TransitionProperty::All, stopping and returning true when the provided
    /// callback returns true for the first time.
    pub fn any<F: FnMut(&LonghandId) -> bool>(mut cb: F) -> bool {
                if cb(&LonghandId::BackgroundColor) {
                    return true;
                }
                if cb(&LonghandId::BackgroundPositionX) {
                    return true;
                }
                if cb(&LonghandId::BackgroundPositionY) {
                    return true;
                }
                if cb(&LonghandId::BackgroundSize) {
                    return true;
                }
                if cb(&LonghandId::BorderTopColor) {
                    return true;
                }
                if cb(&LonghandId::BorderTopWidth) {
                    return true;
                }
                if cb(&LonghandId::BorderLeftColor) {
                    return true;
                }
                if cb(&LonghandId::BorderLeftWidth) {
                    return true;
                }
                if cb(&LonghandId::BorderBottomColor) {
                    return true;
                }
                if cb(&LonghandId::BorderBottomWidth) {
                    return true;
                }
                if cb(&LonghandId::BorderRightColor) {
                    return true;
                }
                if cb(&LonghandId::BorderRightWidth) {
                    return true;
                }
                if cb(&LonghandId::BorderTopLeftRadius) {
                    return true;
                }
                if cb(&LonghandId::BorderTopRightRadius) {
                    return true;
                }
                if cb(&LonghandId::BorderBottomRightRadius) {
                    return true;
                }
                if cb(&LonghandId::BorderBottomLeftRadius) {
                    return true;
                }
                if cb(&LonghandId::VerticalAlign) {
                    return true;
                }
                if cb(&LonghandId::Transform) {
                    return true;
                }
                if cb(&LonghandId::Perspective) {
                    return true;
                }
                if cb(&LonghandId::PerspectiveOrigin) {
                    return true;
                }
                if cb(&LonghandId::TransformOrigin) {
                    return true;
                }
                if cb(&LonghandId::ShapeImageThreshold) {
                    return true;
                }
                if cb(&LonghandId::ShapeOutside) {
                    return true;
                }
                if cb(&LonghandId::Color) {
                    return true;
                }
                if cb(&LonghandId::ColumnWidth) {
                    return true;
                }
                if cb(&LonghandId::ColumnCount) {
                    return true;
                }
                if cb(&LonghandId::ColumnGap) {
                    return true;
                }
                if cb(&LonghandId::ColumnRuleWidth) {
                    return true;
                }
                if cb(&LonghandId::ColumnRuleColor) {
                    return true;
                }
                if cb(&LonghandId::Opacity) {
                    return true;
                }
                if cb(&LonghandId::BoxShadow) {
                    return true;
                }
                if cb(&LonghandId::Clip) {
                    return true;
                }
                if cb(&LonghandId::Filter) {
                    return true;
                }
                if cb(&LonghandId::FontWeight) {
                    return true;
                }
                if cb(&LonghandId::FontSize) {
                    return true;
                }
                if cb(&LonghandId::FontSizeAdjust) {
                    return true;
                }
                if cb(&LonghandId::FontStretch) {
                    return true;
                }
                if cb(&LonghandId::FontVariationSettings) {
                    return true;
                }
                if cb(&LonghandId::MozFontSmoothingBackgroundColor) {
                    return true;
                }
                if cb(&LonghandId::Visibility) {
                    return true;
                }
                if cb(&LonghandId::BorderSpacing) {
                    return true;
                }
                if cb(&LonghandId::LineHeight) {
                    return true;
                }
                if cb(&LonghandId::TextIndent) {
                    return true;
                }
                if cb(&LonghandId::LetterSpacing) {
                    return true;
                }
                if cb(&LonghandId::WordSpacing) {
                    return true;
                }
                if cb(&LonghandId::TextShadow) {
                    return true;
                }
                if cb(&LonghandId::TextEmphasisColor) {
                    return true;
                }
                if cb(&LonghandId::MozTabSize) {
                    return true;
                }
                if cb(&LonghandId::WebkitTextFillColor) {
                    return true;
                }
                if cb(&LonghandId::WebkitTextStrokeColor) {
                    return true;
                }
                if cb(&LonghandId::MozImageRegion) {
                    return true;
                }
                if cb(&LonghandId::MarginTop) {
                    return true;
                }
                if cb(&LonghandId::MarginLeft) {
                    return true;
                }
                if cb(&LonghandId::MarginBottom) {
                    return true;
                }
                if cb(&LonghandId::MarginRight) {
                    return true;
                }
                if cb(&LonghandId::OutlineColor) {
                    return true;
                }
                if cb(&LonghandId::OutlineWidth) {
                    return true;
                }
                if cb(&LonghandId::MozOutlineRadiusTopleft) {
                    return true;
                }
                if cb(&LonghandId::MozOutlineRadiusTopright) {
                    return true;
                }
                if cb(&LonghandId::MozOutlineRadiusBottomright) {
                    return true;
                }
                if cb(&LonghandId::MozOutlineRadiusBottomleft) {
                    return true;
                }
                if cb(&LonghandId::OutlineOffset) {
                    return true;
                }
                if cb(&LonghandId::PaddingTop) {
                    return true;
                }
                if cb(&LonghandId::PaddingLeft) {
                    return true;
                }
                if cb(&LonghandId::PaddingBottom) {
                    return true;
                }
                if cb(&LonghandId::PaddingRight) {
                    return true;
                }
                if cb(&LonghandId::CaretColor) {
                    return true;
                }
                if cb(&LonghandId::Top) {
                    return true;
                }
                if cb(&LonghandId::Left) {
                    return true;
                }
                if cb(&LonghandId::Bottom) {
                    return true;
                }
                if cb(&LonghandId::Right) {
                    return true;
                }
                if cb(&LonghandId::ZIndex) {
                    return true;
                }
                if cb(&LonghandId::FlexGrow) {
                    return true;
                }
                if cb(&LonghandId::FlexShrink) {
                    return true;
                }
                if cb(&LonghandId::Order) {
                    return true;
                }
                if cb(&LonghandId::FlexBasis) {
                    return true;
                }
                if cb(&LonghandId::Width) {
                    return true;
                }
                if cb(&LonghandId::MinWidth) {
                    return true;
                }
                if cb(&LonghandId::MaxWidth) {
                    return true;
                }
                if cb(&LonghandId::Height) {
                    return true;
                }
                if cb(&LonghandId::MinHeight) {
                    return true;
                }
                if cb(&LonghandId::MaxHeight) {
                    return true;
                }
                if cb(&LonghandId::ObjectPosition) {
                    return true;
                }
                if cb(&LonghandId::GridRowGap) {
                    return true;
                }
                if cb(&LonghandId::GridColumnGap) {
                    return true;
                }
                if cb(&LonghandId::TextDecorationColor) {
                    return true;
                }
                if cb(&LonghandId::MozWindowOpacity) {
                    return true;
                }
                if cb(&LonghandId::MozWindowTransform) {
                    return true;
                }
                if cb(&LonghandId::MozWindowTransformOrigin) {
                    return true;
                }
                if cb(&LonghandId::Fill) {
                    return true;
                }
                if cb(&LonghandId::FillOpacity) {
                    return true;
                }
                if cb(&LonghandId::Stroke) {
                    return true;
                }
                if cb(&LonghandId::StrokeWidth) {
                    return true;
                }
                if cb(&LonghandId::StrokeMiterlimit) {
                    return true;
                }
                if cb(&LonghandId::StrokeOpacity) {
                    return true;
                }
                if cb(&LonghandId::StrokeDasharray) {
                    return true;
                }
                if cb(&LonghandId::StrokeDashoffset) {
                    return true;
                }
                if cb(&LonghandId::StopColor) {
                    return true;
                }
                if cb(&LonghandId::StopOpacity) {
                    return true;
                }
                if cb(&LonghandId::FloodColor) {
                    return true;
                }
                if cb(&LonghandId::FloodOpacity) {
                    return true;
                }
                if cb(&LonghandId::LightingColor) {
                    return true;
                }
                if cb(&LonghandId::ClipPath) {
                    return true;
                }
                if cb(&LonghandId::MaskPositionX) {
                    return true;
                }
                if cb(&LonghandId::MaskPositionY) {
                    return true;
                }
                if cb(&LonghandId::MaskSize) {
                    return true;
                }
                if cb(&LonghandId::MozBoxFlex) {
                    return true;
                }
        false
    }

    /// Parse a transition-property value.
    pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>> {
        let location = input.current_source_location();
        let ident = input.expect_ident()?;
        match_ignore_ascii_case! { &ident,
            "all" => Ok(TransitionProperty::All),
                "background" => Ok(TransitionProperty::Shorthand(ShorthandId::Background)),
                "background-position" => Ok(TransitionProperty::Shorthand(ShorthandId::BackgroundPosition)),
                "border-color" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderColor)),
                "border-style" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderStyle)),
                "border-width" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderWidth)),
                "border-top" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderTop)),
                "border-left" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderLeft)),
                "border-bottom" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderBottom)),
                "border-right" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderRight)),
                "border-block-start" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderBlockStart)),
                "border-block-end" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderBlockEnd)),
                "border-inline-start" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderInlineStart)),
                "border-inline-end" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderInlineEnd)),
                "border" => Ok(TransitionProperty::Shorthand(ShorthandId::Border)),
                "border-radius" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderRadius)),
                "border-image" => Ok(TransitionProperty::Shorthand(ShorthandId::BorderImage)),
                "overflow" => Ok(TransitionProperty::Shorthand(ShorthandId::Overflow)),
                "overflow-clip-box" => Ok(TransitionProperty::Shorthand(ShorthandId::OverflowClipBox)),
                "transition" => Ok(TransitionProperty::Shorthand(ShorthandId::Transition)),
                "animation" => Ok(TransitionProperty::Shorthand(ShorthandId::Animation)),
                "scroll-snap-type" => Ok(TransitionProperty::Shorthand(ShorthandId::ScrollSnapType)),
                "overscroll-behavior" => Ok(TransitionProperty::Shorthand(ShorthandId::OverscrollBehavior)),
                "-moz-transform" => Ok(TransitionProperty::Shorthand(ShorthandId::MozTransform)),
                "columns" => Ok(TransitionProperty::Shorthand(ShorthandId::Columns)),
                "column-rule" => Ok(TransitionProperty::Shorthand(ShorthandId::ColumnRule)),
                "font" => Ok(TransitionProperty::Shorthand(ShorthandId::Font)),
                "font-variant" => Ok(TransitionProperty::Shorthand(ShorthandId::FontVariant)),
                "text-emphasis" => Ok(TransitionProperty::Shorthand(ShorthandId::TextEmphasis)),
                "-webkit-text-stroke" => Ok(TransitionProperty::Shorthand(ShorthandId::WebkitTextStroke)),
                "list-style" => Ok(TransitionProperty::Shorthand(ShorthandId::ListStyle)),
                "margin" => Ok(TransitionProperty::Shorthand(ShorthandId::Margin)),
                "mask" => Ok(TransitionProperty::Shorthand(ShorthandId::Mask)),
                "mask-position" => Ok(TransitionProperty::Shorthand(ShorthandId::MaskPosition)),
                "outline" => Ok(TransitionProperty::Shorthand(ShorthandId::Outline)),
                "-moz-outline-radius" => Ok(TransitionProperty::Shorthand(ShorthandId::MozOutlineRadius)),
                "padding" => Ok(TransitionProperty::Shorthand(ShorthandId::Padding)),
                "flex-flow" => Ok(TransitionProperty::Shorthand(ShorthandId::FlexFlow)),
                "flex" => Ok(TransitionProperty::Shorthand(ShorthandId::Flex)),
                "grid-gap" => Ok(TransitionProperty::Shorthand(ShorthandId::GridGap)),
                "grid-row" => Ok(TransitionProperty::Shorthand(ShorthandId::GridRow)),
                "grid-column" => Ok(TransitionProperty::Shorthand(ShorthandId::GridColumn)),
                "grid-area" => Ok(TransitionProperty::Shorthand(ShorthandId::GridArea)),
                "grid-template" => Ok(TransitionProperty::Shorthand(ShorthandId::GridTemplate)),
                "grid" => Ok(TransitionProperty::Shorthand(ShorthandId::Grid)),
                "place-content" => Ok(TransitionProperty::Shorthand(ShorthandId::PlaceContent)),
                "place-self" => Ok(TransitionProperty::Shorthand(ShorthandId::PlaceSelf)),
                "place-items" => Ok(TransitionProperty::Shorthand(ShorthandId::PlaceItems)),
                "marker" => Ok(TransitionProperty::Shorthand(ShorthandId::Marker)),
                "text-decoration" => Ok(TransitionProperty::Shorthand(ShorthandId::TextDecoration)),
                "background-color" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundColor)),
                "background-image" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundImage)),
                "background-position-x" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundPositionX)),
                "background-position-y" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundPositionY)),
                "background-repeat" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundRepeat)),
                "background-attachment" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundAttachment)),
                "background-clip" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundClip)),
                "background-origin" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundOrigin)),
                "background-size" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundSize)),
                "background-blend-mode" => Ok(TransitionProperty::Longhand(LonghandId::BackgroundBlendMode)),
                "border-top-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderTopColor)),
                "border-top-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderTopStyle)),
                "border-top-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderTopWidth)),
                "border-left-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderLeftColor)),
                "border-left-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderLeftStyle)),
                "border-left-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderLeftWidth)),
                "border-bottom-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderBottomColor)),
                "border-bottom-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderBottomStyle)),
                "border-bottom-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderBottomWidth)),
                "border-right-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderRightColor)),
                "border-right-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderRightStyle)),
                "border-right-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderRightWidth)),
                "border-block-start-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockStartColor)),
                "border-block-start-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockStartStyle)),
                "border-block-start-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockStartWidth)),
                "border-block-end-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockEndColor)),
                "border-block-end-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockEndStyle)),
                "border-block-end-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderBlockEndWidth)),
                "border-inline-start-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineStartColor)),
                "border-inline-start-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineStartStyle)),
                "border-inline-start-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineStartWidth)),
                "border-inline-end-color" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineEndColor)),
                "border-inline-end-style" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineEndStyle)),
                "border-inline-end-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderInlineEndWidth)),
                "border-top-left-radius" => Ok(TransitionProperty::Longhand(LonghandId::BorderTopLeftRadius)),
                "border-top-right-radius" => Ok(TransitionProperty::Longhand(LonghandId::BorderTopRightRadius)),
                "border-bottom-right-radius" => Ok(TransitionProperty::Longhand(LonghandId::BorderBottomRightRadius)),
                "border-bottom-left-radius" => Ok(TransitionProperty::Longhand(LonghandId::BorderBottomLeftRadius)),
                "-moz-border-top-colors" => Ok(TransitionProperty::Longhand(LonghandId::MozBorderTopColors)),
                "-moz-border-left-colors" => Ok(TransitionProperty::Longhand(LonghandId::MozBorderLeftColors)),
                "-moz-border-bottom-colors" => Ok(TransitionProperty::Longhand(LonghandId::MozBorderBottomColors)),
                "-moz-border-right-colors" => Ok(TransitionProperty::Longhand(LonghandId::MozBorderRightColors)),
                "box-decoration-break" => Ok(TransitionProperty::Longhand(LonghandId::BoxDecorationBreak)),
                "-moz-float-edge" => Ok(TransitionProperty::Longhand(LonghandId::MozFloatEdge)),
                "border-image-source" => Ok(TransitionProperty::Longhand(LonghandId::BorderImageSource)),
                "border-image-outset" => Ok(TransitionProperty::Longhand(LonghandId::BorderImageOutset)),
                "border-image-repeat" => Ok(TransitionProperty::Longhand(LonghandId::BorderImageRepeat)),
                "border-image-width" => Ok(TransitionProperty::Longhand(LonghandId::BorderImageWidth)),
                "border-image-slice" => Ok(TransitionProperty::Longhand(LonghandId::BorderImageSlice)),
                "display" => Ok(TransitionProperty::Longhand(LonghandId::Display)),
                "-moz-top-layer" => Ok(TransitionProperty::Longhand(LonghandId::MozTopLayer)),
                "position" => Ok(TransitionProperty::Longhand(LonghandId::Position)),
                "float" => Ok(TransitionProperty::Longhand(LonghandId::Float)),
                "clear" => Ok(TransitionProperty::Longhand(LonghandId::Clear)),
                "vertical-align" => Ok(TransitionProperty::Longhand(LonghandId::VerticalAlign)),
                "overflow-clip-box-inline" => Ok(TransitionProperty::Longhand(LonghandId::OverflowClipBoxInline)),
                "overflow-clip-box-block" => Ok(TransitionProperty::Longhand(LonghandId::OverflowClipBoxBlock)),
                "overflow-x" => Ok(TransitionProperty::Longhand(LonghandId::OverflowX)),
                "overflow-y" => Ok(TransitionProperty::Longhand(LonghandId::OverflowY)),
                "transition-duration" => Ok(TransitionProperty::Longhand(LonghandId::TransitionDuration)),
                "transition-timing-function" => Ok(TransitionProperty::Longhand(LonghandId::TransitionTimingFunction)),
                "transition-property" => Ok(TransitionProperty::Longhand(LonghandId::TransitionProperty)),
                "transition-delay" => Ok(TransitionProperty::Longhand(LonghandId::TransitionDelay)),
                "animation-name" => Ok(TransitionProperty::Longhand(LonghandId::AnimationName)),
                "animation-duration" => Ok(TransitionProperty::Longhand(LonghandId::AnimationDuration)),
                "animation-timing-function" => Ok(TransitionProperty::Longhand(LonghandId::AnimationTimingFunction)),
                "animation-iteration-count" => Ok(TransitionProperty::Longhand(LonghandId::AnimationIterationCount)),
                "animation-direction" => Ok(TransitionProperty::Longhand(LonghandId::AnimationDirection)),
                "animation-play-state" => Ok(TransitionProperty::Longhand(LonghandId::AnimationPlayState)),
                "animation-fill-mode" => Ok(TransitionProperty::Longhand(LonghandId::AnimationFillMode)),
                "animation-delay" => Ok(TransitionProperty::Longhand(LonghandId::AnimationDelay)),
                "scroll-snap-points-x" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapPointsX)),
                "scroll-snap-points-y" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapPointsY)),
                "scroll-snap-destination" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapDestination)),
                "scroll-snap-coordinate" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapCoordinate)),
                "transform" => Ok(TransitionProperty::Longhand(LonghandId::Transform)),
                "scroll-behavior" => Ok(TransitionProperty::Longhand(LonghandId::ScrollBehavior)),
                "scroll-snap-type-x" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapTypeX)),
                "scroll-snap-type-y" => Ok(TransitionProperty::Longhand(LonghandId::ScrollSnapTypeY)),
                "overscroll-behavior-x" => Ok(TransitionProperty::Longhand(LonghandId::OverscrollBehaviorX)),
                "overscroll-behavior-y" => Ok(TransitionProperty::Longhand(LonghandId::OverscrollBehaviorY)),
                "isolation" => Ok(TransitionProperty::Longhand(LonghandId::Isolation)),
                "page-break-after" => Ok(TransitionProperty::Longhand(LonghandId::PageBreakAfter)),
                "page-break-before" => Ok(TransitionProperty::Longhand(LonghandId::PageBreakBefore)),
                "page-break-inside" => Ok(TransitionProperty::Longhand(LonghandId::PageBreakInside)),
                "resize" => Ok(TransitionProperty::Longhand(LonghandId::Resize)),
                "perspective" => Ok(TransitionProperty::Longhand(LonghandId::Perspective)),
                "perspective-origin" => Ok(TransitionProperty::Longhand(LonghandId::PerspectiveOrigin)),
                "backface-visibility" => Ok(TransitionProperty::Longhand(LonghandId::BackfaceVisibility)),
                "transform-box" => Ok(TransitionProperty::Longhand(LonghandId::TransformBox)),
                "transform-style" => Ok(TransitionProperty::Longhand(LonghandId::TransformStyle)),
                "transform-origin" => Ok(TransitionProperty::Longhand(LonghandId::TransformOrigin)),
                "contain" => Ok(TransitionProperty::Longhand(LonghandId::Contain)),
                "-moz-appearance" => Ok(TransitionProperty::Longhand(LonghandId::MozAppearance)),
                "-moz-binding" => Ok(TransitionProperty::Longhand(LonghandId::MozBinding)),
                "-moz-orient" => Ok(TransitionProperty::Longhand(LonghandId::MozOrient)),
                "will-change" => Ok(TransitionProperty::Longhand(LonghandId::WillChange)),
                "shape-image-threshold" => Ok(TransitionProperty::Longhand(LonghandId::ShapeImageThreshold)),
                "shape-outside" => Ok(TransitionProperty::Longhand(LonghandId::ShapeOutside)),
                "touch-action" => Ok(TransitionProperty::Longhand(LonghandId::TouchAction)),
                "color" => Ok(TransitionProperty::Longhand(LonghandId::Color)),
                "column-width" => Ok(TransitionProperty::Longhand(LonghandId::ColumnWidth)),
                "column-count" => Ok(TransitionProperty::Longhand(LonghandId::ColumnCount)),
                "column-gap" => Ok(TransitionProperty::Longhand(LonghandId::ColumnGap)),
                "column-fill" => Ok(TransitionProperty::Longhand(LonghandId::ColumnFill)),
                "column-rule-width" => Ok(TransitionProperty::Longhand(LonghandId::ColumnRuleWidth)),
                "column-rule-color" => Ok(TransitionProperty::Longhand(LonghandId::ColumnRuleColor)),
                "column-span" => Ok(TransitionProperty::Longhand(LonghandId::ColumnSpan)),
                "column-rule-style" => Ok(TransitionProperty::Longhand(LonghandId::ColumnRuleStyle)),
                "content" => Ok(TransitionProperty::Longhand(LonghandId::Content)),
                "counter-increment" => Ok(TransitionProperty::Longhand(LonghandId::CounterIncrement)),
                "counter-reset" => Ok(TransitionProperty::Longhand(LonghandId::CounterReset)),
                "opacity" => Ok(TransitionProperty::Longhand(LonghandId::Opacity)),
                "box-shadow" => Ok(TransitionProperty::Longhand(LonghandId::BoxShadow)),
                "clip" => Ok(TransitionProperty::Longhand(LonghandId::Clip)),
                "filter" => Ok(TransitionProperty::Longhand(LonghandId::Filter)),
                "mix-blend-mode" => Ok(TransitionProperty::Longhand(LonghandId::MixBlendMode)),
                "font-family" => Ok(TransitionProperty::Longhand(LonghandId::FontFamily)),
                "font-style" => Ok(TransitionProperty::Longhand(LonghandId::FontStyle)),
                "font-variant-caps" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantCaps)),
                "font-weight" => Ok(TransitionProperty::Longhand(LonghandId::FontWeight)),
                "font-size" => Ok(TransitionProperty::Longhand(LonghandId::FontSize)),
                "font-size-adjust" => Ok(TransitionProperty::Longhand(LonghandId::FontSizeAdjust)),
                "font-synthesis" => Ok(TransitionProperty::Longhand(LonghandId::FontSynthesis)),
                "font-stretch" => Ok(TransitionProperty::Longhand(LonghandId::FontStretch)),
                "font-kerning" => Ok(TransitionProperty::Longhand(LonghandId::FontKerning)),
                "font-variant-alternates" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantAlternates)),
                "font-variant-east-asian" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantEastAsian)),
                "font-variant-ligatures" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantLigatures)),
                "font-variant-numeric" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantNumeric)),
                "font-variant-position" => Ok(TransitionProperty::Longhand(LonghandId::FontVariantPosition)),
                "font-feature-settings" => Ok(TransitionProperty::Longhand(LonghandId::FontFeatureSettings)),
                "font-variation-settings" => Ok(TransitionProperty::Longhand(LonghandId::FontVariationSettings)),
                "font-language-override" => Ok(TransitionProperty::Longhand(LonghandId::FontLanguageOverride)),
                "-x-lang" => Ok(TransitionProperty::Longhand(LonghandId::XLang)),
                "-moz-script-size-multiplier" => Ok(TransitionProperty::Longhand(LonghandId::MozScriptSizeMultiplier)),
                "-moz-script-level" => Ok(TransitionProperty::Longhand(LonghandId::MozScriptLevel)),
                "-moz-math-display" => Ok(TransitionProperty::Longhand(LonghandId::MozMathDisplay)),
                "-moz-math-variant" => Ok(TransitionProperty::Longhand(LonghandId::MozMathVariant)),
                "-moz-script-min-size" => Ok(TransitionProperty::Longhand(LonghandId::MozScriptMinSize)),
                "-x-text-zoom" => Ok(TransitionProperty::Longhand(LonghandId::XTextZoom)),
                "-moz-osx-font-smoothing" => Ok(TransitionProperty::Longhand(LonghandId::MozOsxFontSmoothing)),
                "-moz-font-smoothing-background-color" => Ok(TransitionProperty::Longhand(LonghandId::MozFontSmoothingBackgroundColor)),
                "-moz-min-font-size-ratio" => Ok(TransitionProperty::Longhand(LonghandId::MozMinFontSizeRatio)),
                "visibility" => Ok(TransitionProperty::Longhand(LonghandId::Visibility)),
                "writing-mode" => Ok(TransitionProperty::Longhand(LonghandId::WritingMode)),
                "direction" => Ok(TransitionProperty::Longhand(LonghandId::Direction)),
                "text-orientation" => Ok(TransitionProperty::Longhand(LonghandId::TextOrientation)),
                "color-adjust" => Ok(TransitionProperty::Longhand(LonghandId::ColorAdjust)),
                "image-rendering" => Ok(TransitionProperty::Longhand(LonghandId::ImageRendering)),
                "image-orientation" => Ok(TransitionProperty::Longhand(LonghandId::ImageOrientation)),
                "border-collapse" => Ok(TransitionProperty::Longhand(LonghandId::BorderCollapse)),
                "empty-cells" => Ok(TransitionProperty::Longhand(LonghandId::EmptyCells)),
                "caption-side" => Ok(TransitionProperty::Longhand(LonghandId::CaptionSide)),
                "border-spacing" => Ok(TransitionProperty::Longhand(LonghandId::BorderSpacing)),
                "line-height" => Ok(TransitionProperty::Longhand(LonghandId::LineHeight)),
                "text-transform" => Ok(TransitionProperty::Longhand(LonghandId::TextTransform)),
                "hyphens" => Ok(TransitionProperty::Longhand(LonghandId::Hyphens)),
                "-moz-text-size-adjust" => Ok(TransitionProperty::Longhand(LonghandId::MozTextSizeAdjust)),
                "text-indent" => Ok(TransitionProperty::Longhand(LonghandId::TextIndent)),
                "overflow-wrap" => Ok(TransitionProperty::Longhand(LonghandId::OverflowWrap)),
                "word-break" => Ok(TransitionProperty::Longhand(LonghandId::WordBreak)),
                "text-justify" => Ok(TransitionProperty::Longhand(LonghandId::TextJustify)),
                "text-align-last" => Ok(TransitionProperty::Longhand(LonghandId::TextAlignLast)),
                "text-align" => Ok(TransitionProperty::Longhand(LonghandId::TextAlign)),
                "letter-spacing" => Ok(TransitionProperty::Longhand(LonghandId::LetterSpacing)),
                "word-spacing" => Ok(TransitionProperty::Longhand(LonghandId::WordSpacing)),
                "white-space" => Ok(TransitionProperty::Longhand(LonghandId::WhiteSpace)),
                "text-shadow" => Ok(TransitionProperty::Longhand(LonghandId::TextShadow)),
                "text-emphasis-style" => Ok(TransitionProperty::Longhand(LonghandId::TextEmphasisStyle)),
                "text-emphasis-position" => Ok(TransitionProperty::Longhand(LonghandId::TextEmphasisPosition)),
                "text-emphasis-color" => Ok(TransitionProperty::Longhand(LonghandId::TextEmphasisColor)),
                "-moz-tab-size" => Ok(TransitionProperty::Longhand(LonghandId::MozTabSize)),
                "-webkit-text-fill-color" => Ok(TransitionProperty::Longhand(LonghandId::WebkitTextFillColor)),
                "-webkit-text-stroke-color" => Ok(TransitionProperty::Longhand(LonghandId::WebkitTextStrokeColor)),
                "-webkit-text-stroke-width" => Ok(TransitionProperty::Longhand(LonghandId::WebkitTextStrokeWidth)),
                "ruby-align" => Ok(TransitionProperty::Longhand(LonghandId::RubyAlign)),
                "ruby-position" => Ok(TransitionProperty::Longhand(LonghandId::RubyPosition)),
                "text-combine-upright" => Ok(TransitionProperty::Longhand(LonghandId::TextCombineUpright)),
                "text-rendering" => Ok(TransitionProperty::Longhand(LonghandId::TextRendering)),
                "-moz-control-character-visibility" => Ok(TransitionProperty::Longhand(LonghandId::MozControlCharacterVisibility)),
                "list-style-position" => Ok(TransitionProperty::Longhand(LonghandId::ListStylePosition)),
                "list-style-type" => Ok(TransitionProperty::Longhand(LonghandId::ListStyleType)),
                "list-style-image" => Ok(TransitionProperty::Longhand(LonghandId::ListStyleImage)),
                "quotes" => Ok(TransitionProperty::Longhand(LonghandId::Quotes)),
                "-moz-image-region" => Ok(TransitionProperty::Longhand(LonghandId::MozImageRegion)),
                "margin-top" => Ok(TransitionProperty::Longhand(LonghandId::MarginTop)),
                "margin-left" => Ok(TransitionProperty::Longhand(LonghandId::MarginLeft)),
                "margin-bottom" => Ok(TransitionProperty::Longhand(LonghandId::MarginBottom)),
                "margin-right" => Ok(TransitionProperty::Longhand(LonghandId::MarginRight)),
                "margin-block-start" => Ok(TransitionProperty::Longhand(LonghandId::MarginBlockStart)),
                "margin-block-end" => Ok(TransitionProperty::Longhand(LonghandId::MarginBlockEnd)),
                "margin-inline-start" => Ok(TransitionProperty::Longhand(LonghandId::MarginInlineStart)),
                "margin-inline-end" => Ok(TransitionProperty::Longhand(LonghandId::MarginInlineEnd)),
                "outline-color" => Ok(TransitionProperty::Longhand(LonghandId::OutlineColor)),
                "outline-style" => Ok(TransitionProperty::Longhand(LonghandId::OutlineStyle)),
                "outline-width" => Ok(TransitionProperty::Longhand(LonghandId::OutlineWidth)),
                "-moz-outline-radius-topleft" => Ok(TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopleft)),
                "-moz-outline-radius-topright" => Ok(TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopright)),
                "-moz-outline-radius-bottomright" => Ok(TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomright)),
                "-moz-outline-radius-bottomleft" => Ok(TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomleft)),
                "outline-offset" => Ok(TransitionProperty::Longhand(LonghandId::OutlineOffset)),
                "padding-top" => Ok(TransitionProperty::Longhand(LonghandId::PaddingTop)),
                "padding-left" => Ok(TransitionProperty::Longhand(LonghandId::PaddingLeft)),
                "padding-bottom" => Ok(TransitionProperty::Longhand(LonghandId::PaddingBottom)),
                "padding-right" => Ok(TransitionProperty::Longhand(LonghandId::PaddingRight)),
                "padding-block-start" => Ok(TransitionProperty::Longhand(LonghandId::PaddingBlockStart)),
                "padding-block-end" => Ok(TransitionProperty::Longhand(LonghandId::PaddingBlockEnd)),
                "padding-inline-start" => Ok(TransitionProperty::Longhand(LonghandId::PaddingInlineStart)),
                "padding-inline-end" => Ok(TransitionProperty::Longhand(LonghandId::PaddingInlineEnd)),
                "cursor" => Ok(TransitionProperty::Longhand(LonghandId::Cursor)),
                "pointer-events" => Ok(TransitionProperty::Longhand(LonghandId::PointerEvents)),
                "-moz-user-input" => Ok(TransitionProperty::Longhand(LonghandId::MozUserInput)),
                "-moz-user-modify" => Ok(TransitionProperty::Longhand(LonghandId::MozUserModify)),
                "-moz-user-focus" => Ok(TransitionProperty::Longhand(LonghandId::MozUserFocus)),
                "caret-color" => Ok(TransitionProperty::Longhand(LonghandId::CaretColor)),
                "top" => Ok(TransitionProperty::Longhand(LonghandId::Top)),
                "left" => Ok(TransitionProperty::Longhand(LonghandId::Left)),
                "bottom" => Ok(TransitionProperty::Longhand(LonghandId::Bottom)),
                "right" => Ok(TransitionProperty::Longhand(LonghandId::Right)),
                "offset-block-start" => Ok(TransitionProperty::Longhand(LonghandId::OffsetBlockStart)),
                "offset-block-end" => Ok(TransitionProperty::Longhand(LonghandId::OffsetBlockEnd)),
                "offset-inline-start" => Ok(TransitionProperty::Longhand(LonghandId::OffsetInlineStart)),
                "offset-inline-end" => Ok(TransitionProperty::Longhand(LonghandId::OffsetInlineEnd)),
                "z-index" => Ok(TransitionProperty::Longhand(LonghandId::ZIndex)),
                "flex-direction" => Ok(TransitionProperty::Longhand(LonghandId::FlexDirection)),
                "flex-wrap" => Ok(TransitionProperty::Longhand(LonghandId::FlexWrap)),
                "justify-content" => Ok(TransitionProperty::Longhand(LonghandId::JustifyContent)),
                "align-content" => Ok(TransitionProperty::Longhand(LonghandId::AlignContent)),
                "align-items" => Ok(TransitionProperty::Longhand(LonghandId::AlignItems)),
                "justify-items" => Ok(TransitionProperty::Longhand(LonghandId::JustifyItems)),
                "flex-grow" => Ok(TransitionProperty::Longhand(LonghandId::FlexGrow)),
                "flex-shrink" => Ok(TransitionProperty::Longhand(LonghandId::FlexShrink)),
                "align-self" => Ok(TransitionProperty::Longhand(LonghandId::AlignSelf)),
                "justify-self" => Ok(TransitionProperty::Longhand(LonghandId::JustifySelf)),
                "order" => Ok(TransitionProperty::Longhand(LonghandId::Order)),
                "flex-basis" => Ok(TransitionProperty::Longhand(LonghandId::FlexBasis)),
                "width" => Ok(TransitionProperty::Longhand(LonghandId::Width)),
                "min-width" => Ok(TransitionProperty::Longhand(LonghandId::MinWidth)),
                "max-width" => Ok(TransitionProperty::Longhand(LonghandId::MaxWidth)),
                "height" => Ok(TransitionProperty::Longhand(LonghandId::Height)),
                "min-height" => Ok(TransitionProperty::Longhand(LonghandId::MinHeight)),
                "max-height" => Ok(TransitionProperty::Longhand(LonghandId::MaxHeight)),
                "block-size" => Ok(TransitionProperty::Longhand(LonghandId::BlockSize)),
                "min-block-size" => Ok(TransitionProperty::Longhand(LonghandId::MinBlockSize)),
                "max-block-size" => Ok(TransitionProperty::Longhand(LonghandId::MaxBlockSize)),
                "inline-size" => Ok(TransitionProperty::Longhand(LonghandId::InlineSize)),
                "min-inline-size" => Ok(TransitionProperty::Longhand(LonghandId::MinInlineSize)),
                "max-inline-size" => Ok(TransitionProperty::Longhand(LonghandId::MaxInlineSize)),
                "box-sizing" => Ok(TransitionProperty::Longhand(LonghandId::BoxSizing)),
                "object-fit" => Ok(TransitionProperty::Longhand(LonghandId::ObjectFit)),
                "object-position" => Ok(TransitionProperty::Longhand(LonghandId::ObjectPosition)),
                "grid-row-gap" => Ok(TransitionProperty::Longhand(LonghandId::GridRowGap)),
                "grid-row-start" => Ok(TransitionProperty::Longhand(LonghandId::GridRowStart)),
                "grid-row-end" => Ok(TransitionProperty::Longhand(LonghandId::GridRowEnd)),
                "grid-auto-rows" => Ok(TransitionProperty::Longhand(LonghandId::GridAutoRows)),
                "grid-template-rows" => Ok(TransitionProperty::Longhand(LonghandId::GridTemplateRows)),
                "grid-column-gap" => Ok(TransitionProperty::Longhand(LonghandId::GridColumnGap)),
                "grid-column-start" => Ok(TransitionProperty::Longhand(LonghandId::GridColumnStart)),
                "grid-column-end" => Ok(TransitionProperty::Longhand(LonghandId::GridColumnEnd)),
                "grid-auto-columns" => Ok(TransitionProperty::Longhand(LonghandId::GridAutoColumns)),
                "grid-template-columns" => Ok(TransitionProperty::Longhand(LonghandId::GridTemplateColumns)),
                "grid-auto-flow" => Ok(TransitionProperty::Longhand(LonghandId::GridAutoFlow)),
                "grid-template-areas" => Ok(TransitionProperty::Longhand(LonghandId::GridTemplateAreas)),
                "table-layout" => Ok(TransitionProperty::Longhand(LonghandId::TableLayout)),
                "-x-span" => Ok(TransitionProperty::Longhand(LonghandId::XSpan)),
                "text-overflow" => Ok(TransitionProperty::Longhand(LonghandId::TextOverflow)),
                "unicode-bidi" => Ok(TransitionProperty::Longhand(LonghandId::UnicodeBidi)),
                "text-decoration-line" => Ok(TransitionProperty::Longhand(LonghandId::TextDecorationLine)),
                "text-decoration-style" => Ok(TransitionProperty::Longhand(LonghandId::TextDecorationStyle)),
                "text-decoration-color" => Ok(TransitionProperty::Longhand(LonghandId::TextDecorationColor)),
                "initial-letter" => Ok(TransitionProperty::Longhand(LonghandId::InitialLetter)),
                "ime-mode" => Ok(TransitionProperty::Longhand(LonghandId::ImeMode)),
                "-moz-user-select" => Ok(TransitionProperty::Longhand(LonghandId::MozUserSelect)),
                "-moz-window-dragging" => Ok(TransitionProperty::Longhand(LonghandId::MozWindowDragging)),
                "-moz-window-shadow" => Ok(TransitionProperty::Longhand(LonghandId::MozWindowShadow)),
                "-moz-window-opacity" => Ok(TransitionProperty::Longhand(LonghandId::MozWindowOpacity)),
                "-moz-window-transform" => Ok(TransitionProperty::Longhand(LonghandId::MozWindowTransform)),
                "-moz-window-transform-origin" => Ok(TransitionProperty::Longhand(LonghandId::MozWindowTransformOrigin)),
                "-moz-force-broken-image-icon" => Ok(TransitionProperty::Longhand(LonghandId::MozForceBrokenImageIcon)),
                "text-anchor" => Ok(TransitionProperty::Longhand(LonghandId::TextAnchor)),
                "color-interpolation" => Ok(TransitionProperty::Longhand(LonghandId::ColorInterpolation)),
                "color-interpolation-filters" => Ok(TransitionProperty::Longhand(LonghandId::ColorInterpolationFilters)),
                "fill" => Ok(TransitionProperty::Longhand(LonghandId::Fill)),
                "fill-opacity" => Ok(TransitionProperty::Longhand(LonghandId::FillOpacity)),
                "fill-rule" => Ok(TransitionProperty::Longhand(LonghandId::FillRule)),
                "shape-rendering" => Ok(TransitionProperty::Longhand(LonghandId::ShapeRendering)),
                "stroke" => Ok(TransitionProperty::Longhand(LonghandId::Stroke)),
                "stroke-width" => Ok(TransitionProperty::Longhand(LonghandId::StrokeWidth)),
                "stroke-linecap" => Ok(TransitionProperty::Longhand(LonghandId::StrokeLinecap)),
                "stroke-linejoin" => Ok(TransitionProperty::Longhand(LonghandId::StrokeLinejoin)),
                "stroke-miterlimit" => Ok(TransitionProperty::Longhand(LonghandId::StrokeMiterlimit)),
                "stroke-opacity" => Ok(TransitionProperty::Longhand(LonghandId::StrokeOpacity)),
                "stroke-dasharray" => Ok(TransitionProperty::Longhand(LonghandId::StrokeDasharray)),
                "stroke-dashoffset" => Ok(TransitionProperty::Longhand(LonghandId::StrokeDashoffset)),
                "clip-rule" => Ok(TransitionProperty::Longhand(LonghandId::ClipRule)),
                "marker-start" => Ok(TransitionProperty::Longhand(LonghandId::MarkerStart)),
                "marker-mid" => Ok(TransitionProperty::Longhand(LonghandId::MarkerMid)),
                "marker-end" => Ok(TransitionProperty::Longhand(LonghandId::MarkerEnd)),
                "paint-order" => Ok(TransitionProperty::Longhand(LonghandId::PaintOrder)),
                "-moz-context-properties" => Ok(TransitionProperty::Longhand(LonghandId::MozContextProperties)),
                "dominant-baseline" => Ok(TransitionProperty::Longhand(LonghandId::DominantBaseline)),
                "vector-effect" => Ok(TransitionProperty::Longhand(LonghandId::VectorEffect)),
                "stop-color" => Ok(TransitionProperty::Longhand(LonghandId::StopColor)),
                "stop-opacity" => Ok(TransitionProperty::Longhand(LonghandId::StopOpacity)),
                "flood-color" => Ok(TransitionProperty::Longhand(LonghandId::FloodColor)),
                "flood-opacity" => Ok(TransitionProperty::Longhand(LonghandId::FloodOpacity)),
                "lighting-color" => Ok(TransitionProperty::Longhand(LonghandId::LightingColor)),
                "mask-type" => Ok(TransitionProperty::Longhand(LonghandId::MaskType)),
                "clip-path" => Ok(TransitionProperty::Longhand(LonghandId::ClipPath)),
                "mask-mode" => Ok(TransitionProperty::Longhand(LonghandId::MaskMode)),
                "mask-repeat" => Ok(TransitionProperty::Longhand(LonghandId::MaskRepeat)),
                "mask-position-x" => Ok(TransitionProperty::Longhand(LonghandId::MaskPositionX)),
                "mask-position-y" => Ok(TransitionProperty::Longhand(LonghandId::MaskPositionY)),
                "mask-clip" => Ok(TransitionProperty::Longhand(LonghandId::MaskClip)),
                "mask-origin" => Ok(TransitionProperty::Longhand(LonghandId::MaskOrigin)),
                "mask-size" => Ok(TransitionProperty::Longhand(LonghandId::MaskSize)),
                "mask-composite" => Ok(TransitionProperty::Longhand(LonghandId::MaskComposite)),
                "mask-image" => Ok(TransitionProperty::Longhand(LonghandId::MaskImage)),
                "-moz-box-align" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxAlign)),
                "-moz-box-direction" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxDirection)),
                "-moz-box-flex" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxFlex)),
                "-moz-box-orient" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxOrient)),
                "-moz-box-pack" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxPack)),
                "-moz-stack-sizing" => Ok(TransitionProperty::Longhand(LonghandId::MozStackSizing)),
                "-moz-box-ordinal-group" => Ok(TransitionProperty::Longhand(LonghandId::MozBoxOrdinalGroup)),
            "none" => Err(location.new_custom_error(SelectorParseErrorKind::UnexpectedIdent(ident.clone()))),
            _ => CustomIdent::from_ident(location, ident, &[]).map(TransitionProperty::Unsupported),
        }
    }


    /// Convert TransitionProperty to nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    pub fn to_nscsspropertyid(&self) -> Result<nsCSSPropertyID, ()> {
        Ok(match *self {
            TransitionProperty::All => nsCSSPropertyID::eCSSPropertyExtra_all_properties,
            TransitionProperty::Shorthand(ref id) => id.to_nscsspropertyid(),
            TransitionProperty::Longhand(ref id) => id.to_nscsspropertyid(),
            TransitionProperty::Unsupported(..) => return Err(()),
        })
    }
}

/// Convert nsCSSPropertyID to TransitionProperty
#[cfg(feature = "gecko")]
#[allow(non_upper_case_globals)]
impl From<nsCSSPropertyID> for TransitionProperty {
    fn from(property: nsCSSPropertyID) -> TransitionProperty {
        match property {
            
    nsCSSPropertyID::eCSSProperty_background_color => {
                TransitionProperty::Longhand(LonghandId::BackgroundColor)
            }
            
    nsCSSPropertyID::eCSSProperty_background_image => {
                TransitionProperty::Longhand(LonghandId::BackgroundImage)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position_x => {
                TransitionProperty::Longhand(LonghandId::BackgroundPositionX)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position_y => {
                TransitionProperty::Longhand(LonghandId::BackgroundPositionY)
            }
            
    nsCSSPropertyID::eCSSProperty_background_repeat => {
                TransitionProperty::Longhand(LonghandId::BackgroundRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_background_attachment => {
                TransitionProperty::Longhand(LonghandId::BackgroundAttachment)
            }
            
    nsCSSPropertyID::eCSSProperty_background_clip => {
                TransitionProperty::Longhand(LonghandId::BackgroundClip)
            }
            
    nsCSSPropertyID::eCSSProperty_background_origin => {
                TransitionProperty::Longhand(LonghandId::BackgroundOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_background_size => {
                TransitionProperty::Longhand(LonghandId::BackgroundSize)
            }
            
    nsCSSPropertyID::eCSSProperty_background_blend_mode => {
                TransitionProperty::Longhand(LonghandId::BackgroundBlendMode)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_color => {
                TransitionProperty::Longhand(LonghandId::BorderTopColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_style => {
                TransitionProperty::Longhand(LonghandId::BorderTopStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_width => {
                TransitionProperty::Longhand(LonghandId::BorderTopWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_color => {
                TransitionProperty::Longhand(LonghandId::BorderLeftColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_style => {
                TransitionProperty::Longhand(LonghandId::BorderLeftStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left_width => {
                TransitionProperty::Longhand(LonghandId::BorderLeftWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_color => {
                TransitionProperty::Longhand(LonghandId::BorderBottomColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_style => {
                TransitionProperty::Longhand(LonghandId::BorderBottomStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_width => {
                TransitionProperty::Longhand(LonghandId::BorderBottomWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_color => {
                TransitionProperty::Longhand(LonghandId::BorderRightColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_style => {
                TransitionProperty::Longhand(LonghandId::BorderRightStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right_width => {
                TransitionProperty::Longhand(LonghandId::BorderRightWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_color => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_style => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start_width => {
                TransitionProperty::Longhand(LonghandId::BorderBlockStartWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_color => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_style => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end_width => {
                TransitionProperty::Longhand(LonghandId::BorderBlockEndWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_color => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_style => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start_width => {
                TransitionProperty::Longhand(LonghandId::BorderInlineStartWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_color => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_style => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end_width => {
                TransitionProperty::Longhand(LonghandId::BorderInlineEndWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => {
                TransitionProperty::Longhand(LonghandId::BorderTopLeftRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => {
                TransitionProperty::Longhand(LonghandId::BorderTopRightRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => {
                TransitionProperty::Longhand(LonghandId::BorderBottomRightRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => {
                TransitionProperty::Longhand(LonghandId::BorderBottomLeftRadius)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_border_top_colors => {
                TransitionProperty::Longhand(LonghandId::MozBorderTopColors)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_border_left_colors => {
                TransitionProperty::Longhand(LonghandId::MozBorderLeftColors)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_border_bottom_colors => {
                TransitionProperty::Longhand(LonghandId::MozBorderBottomColors)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_border_right_colors => {
                TransitionProperty::Longhand(LonghandId::MozBorderRightColors)
            }
            
    nsCSSPropertyID::eCSSProperty_box_decoration_break => {
                TransitionProperty::Longhand(LonghandId::BoxDecorationBreak)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_float_edge => {
                TransitionProperty::Longhand(LonghandId::MozFloatEdge)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_source => {
                TransitionProperty::Longhand(LonghandId::BorderImageSource)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_outset => {
                TransitionProperty::Longhand(LonghandId::BorderImageOutset)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_repeat => {
                TransitionProperty::Longhand(LonghandId::BorderImageRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_width => {
                TransitionProperty::Longhand(LonghandId::BorderImageWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image_slice => {
                TransitionProperty::Longhand(LonghandId::BorderImageSlice)
            }
            
    nsCSSPropertyID::eCSSProperty_display => {
                TransitionProperty::Longhand(LonghandId::Display)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_top_layer => {
                TransitionProperty::Longhand(LonghandId::MozTopLayer)
            }
            
    nsCSSPropertyID::eCSSProperty_position => {
                TransitionProperty::Longhand(LonghandId::Position)
            }
            
    nsCSSPropertyID::eCSSProperty_float_ => {
                TransitionProperty::Longhand(LonghandId::Float)
            }
            
    nsCSSPropertyID::eCSSProperty_clear => {
                TransitionProperty::Longhand(LonghandId::Clear)
            }
            
    nsCSSPropertyID::eCSSProperty_vertical_align => {
                TransitionProperty::Longhand(LonghandId::VerticalAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => {
                TransitionProperty::Longhand(LonghandId::OverflowClipBoxInline)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => {
                TransitionProperty::Longhand(LonghandId::OverflowClipBoxBlock)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_x => {
                TransitionProperty::Longhand(LonghandId::OverflowX)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_y => {
                TransitionProperty::Longhand(LonghandId::OverflowY)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_duration => {
                TransitionProperty::Longhand(LonghandId::TransitionDuration)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_timing_function => {
                TransitionProperty::Longhand(LonghandId::TransitionTimingFunction)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_property => {
                TransitionProperty::Longhand(LonghandId::TransitionProperty)
            }
            
    nsCSSPropertyID::eCSSProperty_transition_delay => {
                TransitionProperty::Longhand(LonghandId::TransitionDelay)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_name => {
                TransitionProperty::Longhand(LonghandId::AnimationName)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_duration => {
                TransitionProperty::Longhand(LonghandId::AnimationDuration)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_timing_function => {
                TransitionProperty::Longhand(LonghandId::AnimationTimingFunction)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_iteration_count => {
                TransitionProperty::Longhand(LonghandId::AnimationIterationCount)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_direction => {
                TransitionProperty::Longhand(LonghandId::AnimationDirection)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_play_state => {
                TransitionProperty::Longhand(LonghandId::AnimationPlayState)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_fill_mode => {
                TransitionProperty::Longhand(LonghandId::AnimationFillMode)
            }
            
    nsCSSPropertyID::eCSSProperty_animation_delay => {
                TransitionProperty::Longhand(LonghandId::AnimationDelay)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapPointsX)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapPointsY)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapDestination)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapCoordinate)
            }
            
    nsCSSPropertyID::eCSSProperty_transform => {
                TransitionProperty::Longhand(LonghandId::Transform)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_behavior => {
                TransitionProperty::Longhand(LonghandId::ScrollBehavior)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapTypeX)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => {
                TransitionProperty::Longhand(LonghandId::ScrollSnapTypeY)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => {
                TransitionProperty::Longhand(LonghandId::OverscrollBehaviorX)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => {
                TransitionProperty::Longhand(LonghandId::OverscrollBehaviorY)
            }
            
    nsCSSPropertyID::eCSSProperty_isolation => {
                TransitionProperty::Longhand(LonghandId::Isolation)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_after => {
                TransitionProperty::Longhand(LonghandId::PageBreakAfter)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_before => {
                TransitionProperty::Longhand(LonghandId::PageBreakBefore)
            }
            
    nsCSSPropertyID::eCSSProperty_page_break_inside => {
                TransitionProperty::Longhand(LonghandId::PageBreakInside)
            }
            
    nsCSSPropertyID::eCSSProperty_resize => {
                TransitionProperty::Longhand(LonghandId::Resize)
            }
            
    nsCSSPropertyID::eCSSProperty_perspective => {
                TransitionProperty::Longhand(LonghandId::Perspective)
            }
            
    nsCSSPropertyID::eCSSProperty_perspective_origin => {
                TransitionProperty::Longhand(LonghandId::PerspectiveOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_backface_visibility => {
                TransitionProperty::Longhand(LonghandId::BackfaceVisibility)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_box => {
                TransitionProperty::Longhand(LonghandId::TransformBox)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_style => {
                TransitionProperty::Longhand(LonghandId::TransformStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_transform_origin => {
                TransitionProperty::Longhand(LonghandId::TransformOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_contain => {
                TransitionProperty::Longhand(LonghandId::Contain)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_appearance => {
                TransitionProperty::Longhand(LonghandId::MozAppearance)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_binding => {
                TransitionProperty::Longhand(LonghandId::MozBinding)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_orient => {
                TransitionProperty::Longhand(LonghandId::MozOrient)
            }
            
    nsCSSPropertyID::eCSSProperty_will_change => {
                TransitionProperty::Longhand(LonghandId::WillChange)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => {
                TransitionProperty::Longhand(LonghandId::ShapeImageThreshold)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_outside => {
                TransitionProperty::Longhand(LonghandId::ShapeOutside)
            }
            
    nsCSSPropertyID::eCSSProperty_touch_action => {
                TransitionProperty::Longhand(LonghandId::TouchAction)
            }
            
    nsCSSPropertyID::eCSSProperty_color => {
                TransitionProperty::Longhand(LonghandId::Color)
            }
            
    nsCSSPropertyID::eCSSProperty_column_width => {
                TransitionProperty::Longhand(LonghandId::ColumnWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_column_count => {
                TransitionProperty::Longhand(LonghandId::ColumnCount)
            }
            
    nsCSSPropertyID::eCSSProperty_column_gap => {
                TransitionProperty::Longhand(LonghandId::ColumnGap)
            }
            
    nsCSSPropertyID::eCSSProperty_column_fill => {
                TransitionProperty::Longhand(LonghandId::ColumnFill)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_width => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_color => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleColor)
            }
            
    nsCSSPropertyID::eCSSProperty_column_span => {
                TransitionProperty::Longhand(LonghandId::ColumnSpan)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule_style => {
                TransitionProperty::Longhand(LonghandId::ColumnRuleStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_content => {
                TransitionProperty::Longhand(LonghandId::Content)
            }
            
    nsCSSPropertyID::eCSSProperty_counter_increment => {
                TransitionProperty::Longhand(LonghandId::CounterIncrement)
            }
            
    nsCSSPropertyID::eCSSProperty_counter_reset => {
                TransitionProperty::Longhand(LonghandId::CounterReset)
            }
            
    nsCSSPropertyID::eCSSProperty_opacity => {
                TransitionProperty::Longhand(LonghandId::Opacity)
            }
            
    nsCSSPropertyID::eCSSProperty_box_shadow => {
                TransitionProperty::Longhand(LonghandId::BoxShadow)
            }
            
    nsCSSPropertyID::eCSSProperty_clip => {
                TransitionProperty::Longhand(LonghandId::Clip)
            }
            
    nsCSSPropertyID::eCSSProperty_filter => {
                TransitionProperty::Longhand(LonghandId::Filter)
            }
            
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => {
                TransitionProperty::Longhand(LonghandId::MixBlendMode)
            }
            
    nsCSSPropertyID::eCSSProperty_font_family => {
                TransitionProperty::Longhand(LonghandId::FontFamily)
            }
            
    nsCSSPropertyID::eCSSProperty_font_style => {
                TransitionProperty::Longhand(LonghandId::FontStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_caps => {
                TransitionProperty::Longhand(LonghandId::FontVariantCaps)
            }
            
    nsCSSPropertyID::eCSSProperty_font_weight => {
                TransitionProperty::Longhand(LonghandId::FontWeight)
            }
            
    nsCSSPropertyID::eCSSProperty_font_size => {
                TransitionProperty::Longhand(LonghandId::FontSize)
            }
            
    nsCSSPropertyID::eCSSProperty_font_size_adjust => {
                TransitionProperty::Longhand(LonghandId::FontSizeAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty_font_synthesis => {
                TransitionProperty::Longhand(LonghandId::FontSynthesis)
            }
            
    nsCSSPropertyID::eCSSProperty_font_stretch => {
                TransitionProperty::Longhand(LonghandId::FontStretch)
            }
            
    nsCSSPropertyID::eCSSProperty_font_kerning => {
                TransitionProperty::Longhand(LonghandId::FontKerning)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => {
                TransitionProperty::Longhand(LonghandId::FontVariantAlternates)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => {
                TransitionProperty::Longhand(LonghandId::FontVariantEastAsian)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => {
                TransitionProperty::Longhand(LonghandId::FontVariantLigatures)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => {
                TransitionProperty::Longhand(LonghandId::FontVariantNumeric)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant_position => {
                TransitionProperty::Longhand(LonghandId::FontVariantPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_font_feature_settings => {
                TransitionProperty::Longhand(LonghandId::FontFeatureSettings)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variation_settings => {
                TransitionProperty::Longhand(LonghandId::FontVariationSettings)
            }
            
    nsCSSPropertyID::eCSSProperty_font_language_override => {
                TransitionProperty::Longhand(LonghandId::FontLanguageOverride)
            }
            
    nsCSSPropertyID::eCSSProperty__x_lang => {
                TransitionProperty::Longhand(LonghandId::XLang)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier => {
                TransitionProperty::Longhand(LonghandId::MozScriptSizeMultiplier)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_level => {
                TransitionProperty::Longhand(LonghandId::MozScriptLevel)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_math_display => {
                TransitionProperty::Longhand(LonghandId::MozMathDisplay)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_math_variant => {
                TransitionProperty::Longhand(LonghandId::MozMathVariant)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_script_min_size => {
                TransitionProperty::Longhand(LonghandId::MozScriptMinSize)
            }
            
    nsCSSPropertyID::eCSSProperty__x_text_zoom => {
                TransitionProperty::Longhand(LonghandId::XTextZoom)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => {
                TransitionProperty::Longhand(LonghandId::MozOsxFontSmoothing)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => {
                TransitionProperty::Longhand(LonghandId::MozFontSmoothingBackgroundColor)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio => {
                TransitionProperty::Longhand(LonghandId::MozMinFontSizeRatio)
            }
            
    nsCSSPropertyID::eCSSProperty_visibility => {
                TransitionProperty::Longhand(LonghandId::Visibility)
            }
            
    nsCSSPropertyID::eCSSProperty_writing_mode => {
                TransitionProperty::Longhand(LonghandId::WritingMode)
            }
            
    nsCSSPropertyID::eCSSProperty_direction => {
                TransitionProperty::Longhand(LonghandId::Direction)
            }
            
    nsCSSPropertyID::eCSSProperty_text_orientation => {
                TransitionProperty::Longhand(LonghandId::TextOrientation)
            }
            
    nsCSSPropertyID::eCSSProperty_color_adjust => {
                TransitionProperty::Longhand(LonghandId::ColorAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty_image_rendering => {
                TransitionProperty::Longhand(LonghandId::ImageRendering)
            }
            
    nsCSSPropertyID::eCSSProperty_image_orientation => {
                TransitionProperty::Longhand(LonghandId::ImageOrientation)
            }
            
    nsCSSPropertyID::eCSSProperty_border_collapse => {
                TransitionProperty::Longhand(LonghandId::BorderCollapse)
            }
            
    nsCSSPropertyID::eCSSProperty_empty_cells => {
                TransitionProperty::Longhand(LonghandId::EmptyCells)
            }
            
    nsCSSPropertyID::eCSSProperty_caption_side => {
                TransitionProperty::Longhand(LonghandId::CaptionSide)
            }
            
    nsCSSPropertyID::eCSSProperty_border_spacing => {
                TransitionProperty::Longhand(LonghandId::BorderSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty_line_height => {
                TransitionProperty::Longhand(LonghandId::LineHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_text_transform => {
                TransitionProperty::Longhand(LonghandId::TextTransform)
            }
            
    nsCSSPropertyID::eCSSProperty_hyphens => {
                TransitionProperty::Longhand(LonghandId::Hyphens)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => {
                TransitionProperty::Longhand(LonghandId::MozTextSizeAdjust)
            }
            
    nsCSSPropertyID::eCSSProperty_text_indent => {
                TransitionProperty::Longhand(LonghandId::TextIndent)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_wrap => {
                TransitionProperty::Longhand(LonghandId::OverflowWrap)
            }
            
    nsCSSPropertyID::eCSSProperty_word_break => {
                TransitionProperty::Longhand(LonghandId::WordBreak)
            }
            
    nsCSSPropertyID::eCSSProperty_text_justify => {
                TransitionProperty::Longhand(LonghandId::TextJustify)
            }
            
    nsCSSPropertyID::eCSSProperty_text_align_last => {
                TransitionProperty::Longhand(LonghandId::TextAlignLast)
            }
            
    nsCSSPropertyID::eCSSProperty_text_align => {
                TransitionProperty::Longhand(LonghandId::TextAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_letter_spacing => {
                TransitionProperty::Longhand(LonghandId::LetterSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty_word_spacing => {
                TransitionProperty::Longhand(LonghandId::WordSpacing)
            }
            
    nsCSSPropertyID::eCSSProperty_white_space => {
                TransitionProperty::Longhand(LonghandId::WhiteSpace)
            }
            
    nsCSSPropertyID::eCSSProperty_text_shadow => {
                TransitionProperty::Longhand(LonghandId::TextShadow)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => {
                TransitionProperty::Longhand(LonghandId::TextEmphasisColor)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_tab_size => {
                TransitionProperty::Longhand(LonghandId::MozTabSize)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => {
                TransitionProperty::Longhand(LonghandId::WebkitTextFillColor)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => {
                TransitionProperty::Longhand(LonghandId::WebkitTextStrokeColor)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => {
                TransitionProperty::Longhand(LonghandId::WebkitTextStrokeWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_ruby_align => {
                TransitionProperty::Longhand(LonghandId::RubyAlign)
            }
            
    nsCSSPropertyID::eCSSProperty_ruby_position => {
                TransitionProperty::Longhand(LonghandId::RubyPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_text_combine_upright => {
                TransitionProperty::Longhand(LonghandId::TextCombineUpright)
            }
            
    nsCSSPropertyID::eCSSProperty_text_rendering => {
                TransitionProperty::Longhand(LonghandId::TextRendering)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility => {
                TransitionProperty::Longhand(LonghandId::MozControlCharacterVisibility)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_position => {
                TransitionProperty::Longhand(LonghandId::ListStylePosition)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_type => {
                TransitionProperty::Longhand(LonghandId::ListStyleType)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style_image => {
                TransitionProperty::Longhand(LonghandId::ListStyleImage)
            }
            
    nsCSSPropertyID::eCSSProperty_quotes => {
                TransitionProperty::Longhand(LonghandId::Quotes)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_image_region => {
                TransitionProperty::Longhand(LonghandId::MozImageRegion)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_top => {
                TransitionProperty::Longhand(LonghandId::MarginTop)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_left => {
                TransitionProperty::Longhand(LonghandId::MarginLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_bottom => {
                TransitionProperty::Longhand(LonghandId::MarginBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_right => {
                TransitionProperty::Longhand(LonghandId::MarginRight)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_block_start => {
                TransitionProperty::Longhand(LonghandId::MarginBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_block_end => {
                TransitionProperty::Longhand(LonghandId::MarginBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_inline_start => {
                TransitionProperty::Longhand(LonghandId::MarginInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_margin_inline_end => {
                TransitionProperty::Longhand(LonghandId::MarginInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_color => {
                TransitionProperty::Longhand(LonghandId::OutlineColor)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_style => {
                TransitionProperty::Longhand(LonghandId::OutlineStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_width => {
                TransitionProperty::Longhand(LonghandId::OutlineWidth)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopleft)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusTopright)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomright)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => {
                TransitionProperty::Longhand(LonghandId::MozOutlineRadiusBottomleft)
            }
            
    nsCSSPropertyID::eCSSProperty_outline_offset => {
                TransitionProperty::Longhand(LonghandId::OutlineOffset)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_top => {
                TransitionProperty::Longhand(LonghandId::PaddingTop)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_left => {
                TransitionProperty::Longhand(LonghandId::PaddingLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_bottom => {
                TransitionProperty::Longhand(LonghandId::PaddingBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_right => {
                TransitionProperty::Longhand(LonghandId::PaddingRight)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_block_start => {
                TransitionProperty::Longhand(LonghandId::PaddingBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_block_end => {
                TransitionProperty::Longhand(LonghandId::PaddingBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_inline_start => {
                TransitionProperty::Longhand(LonghandId::PaddingInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_padding_inline_end => {
                TransitionProperty::Longhand(LonghandId::PaddingInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_cursor => {
                TransitionProperty::Longhand(LonghandId::Cursor)
            }
            
    nsCSSPropertyID::eCSSProperty_pointer_events => {
                TransitionProperty::Longhand(LonghandId::PointerEvents)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_input => {
                TransitionProperty::Longhand(LonghandId::MozUserInput)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_modify => {
                TransitionProperty::Longhand(LonghandId::MozUserModify)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_focus => {
                TransitionProperty::Longhand(LonghandId::MozUserFocus)
            }
            
    nsCSSPropertyID::eCSSProperty_caret_color => {
                TransitionProperty::Longhand(LonghandId::CaretColor)
            }
            
    nsCSSPropertyID::eCSSProperty_top => {
                TransitionProperty::Longhand(LonghandId::Top)
            }
            
    nsCSSPropertyID::eCSSProperty_left => {
                TransitionProperty::Longhand(LonghandId::Left)
            }
            
    nsCSSPropertyID::eCSSProperty_bottom => {
                TransitionProperty::Longhand(LonghandId::Bottom)
            }
            
    nsCSSPropertyID::eCSSProperty_right => {
                TransitionProperty::Longhand(LonghandId::Right)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_block_start => {
                TransitionProperty::Longhand(LonghandId::OffsetBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_block_end => {
                TransitionProperty::Longhand(LonghandId::OffsetBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_inline_start => {
                TransitionProperty::Longhand(LonghandId::OffsetInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_offset_inline_end => {
                TransitionProperty::Longhand(LonghandId::OffsetInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_z_index => {
                TransitionProperty::Longhand(LonghandId::ZIndex)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_direction => {
                TransitionProperty::Longhand(LonghandId::FlexDirection)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_wrap => {
                TransitionProperty::Longhand(LonghandId::FlexWrap)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_content => {
                TransitionProperty::Longhand(LonghandId::JustifyContent)
            }
            
    nsCSSPropertyID::eCSSProperty_align_content => {
                TransitionProperty::Longhand(LonghandId::AlignContent)
            }
            
    nsCSSPropertyID::eCSSProperty_align_items => {
                TransitionProperty::Longhand(LonghandId::AlignItems)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_items => {
                TransitionProperty::Longhand(LonghandId::JustifyItems)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_grow => {
                TransitionProperty::Longhand(LonghandId::FlexGrow)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_shrink => {
                TransitionProperty::Longhand(LonghandId::FlexShrink)
            }
            
    nsCSSPropertyID::eCSSProperty_align_self => {
                TransitionProperty::Longhand(LonghandId::AlignSelf)
            }
            
    nsCSSPropertyID::eCSSProperty_justify_self => {
                TransitionProperty::Longhand(LonghandId::JustifySelf)
            }
            
    nsCSSPropertyID::eCSSProperty_order => {
                TransitionProperty::Longhand(LonghandId::Order)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_basis => {
                TransitionProperty::Longhand(LonghandId::FlexBasis)
            }
            
    nsCSSPropertyID::eCSSProperty_width => {
                TransitionProperty::Longhand(LonghandId::Width)
            }
            
    nsCSSPropertyID::eCSSProperty_min_width => {
                TransitionProperty::Longhand(LonghandId::MinWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_max_width => {
                TransitionProperty::Longhand(LonghandId::MaxWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_height => {
                TransitionProperty::Longhand(LonghandId::Height)
            }
            
    nsCSSPropertyID::eCSSProperty_min_height => {
                TransitionProperty::Longhand(LonghandId::MinHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_max_height => {
                TransitionProperty::Longhand(LonghandId::MaxHeight)
            }
            
    nsCSSPropertyID::eCSSProperty_block_size => {
                TransitionProperty::Longhand(LonghandId::BlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_min_block_size => {
                TransitionProperty::Longhand(LonghandId::MinBlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_max_block_size => {
                TransitionProperty::Longhand(LonghandId::MaxBlockSize)
            }
            
    nsCSSPropertyID::eCSSProperty_inline_size => {
                TransitionProperty::Longhand(LonghandId::InlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_min_inline_size => {
                TransitionProperty::Longhand(LonghandId::MinInlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_max_inline_size => {
                TransitionProperty::Longhand(LonghandId::MaxInlineSize)
            }
            
    nsCSSPropertyID::eCSSProperty_box_sizing => {
                TransitionProperty::Longhand(LonghandId::BoxSizing)
            }
            
    nsCSSPropertyID::eCSSProperty_object_fit => {
                TransitionProperty::Longhand(LonghandId::ObjectFit)
            }
            
    nsCSSPropertyID::eCSSProperty_object_position => {
                TransitionProperty::Longhand(LonghandId::ObjectPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_gap => {
                TransitionProperty::Longhand(LonghandId::GridRowGap)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_start => {
                TransitionProperty::Longhand(LonghandId::GridRowStart)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row_end => {
                TransitionProperty::Longhand(LonghandId::GridRowEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => {
                TransitionProperty::Longhand(LonghandId::GridAutoRows)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_rows => {
                TransitionProperty::Longhand(LonghandId::GridTemplateRows)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_gap => {
                TransitionProperty::Longhand(LonghandId::GridColumnGap)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_start => {
                TransitionProperty::Longhand(LonghandId::GridColumnStart)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column_end => {
                TransitionProperty::Longhand(LonghandId::GridColumnEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => {
                TransitionProperty::Longhand(LonghandId::GridAutoColumns)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_columns => {
                TransitionProperty::Longhand(LonghandId::GridTemplateColumns)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => {
                TransitionProperty::Longhand(LonghandId::GridAutoFlow)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template_areas => {
                TransitionProperty::Longhand(LonghandId::GridTemplateAreas)
            }
            
    nsCSSPropertyID::eCSSProperty_table_layout => {
                TransitionProperty::Longhand(LonghandId::TableLayout)
            }
            
    nsCSSPropertyID::eCSSProperty__x_span => {
                TransitionProperty::Longhand(LonghandId::XSpan)
            }
            
    nsCSSPropertyID::eCSSProperty_text_overflow => {
                TransitionProperty::Longhand(LonghandId::TextOverflow)
            }
            
    nsCSSPropertyID::eCSSProperty_unicode_bidi => {
                TransitionProperty::Longhand(LonghandId::UnicodeBidi)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_line => {
                TransitionProperty::Longhand(LonghandId::TextDecorationLine)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_style => {
                TransitionProperty::Longhand(LonghandId::TextDecorationStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration_color => {
                TransitionProperty::Longhand(LonghandId::TextDecorationColor)
            }
            
    nsCSSPropertyID::eCSSProperty_initial_letter => {
                TransitionProperty::Longhand(LonghandId::InitialLetter)
            }
            
    nsCSSPropertyID::eCSSProperty_ime_mode => {
                TransitionProperty::Longhand(LonghandId::ImeMode)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_user_select => {
                TransitionProperty::Longhand(LonghandId::MozUserSelect)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => {
                TransitionProperty::Longhand(LonghandId::MozWindowDragging)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => {
                TransitionProperty::Longhand(LonghandId::MozWindowShadow)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => {
                TransitionProperty::Longhand(LonghandId::MozWindowOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_transform => {
                TransitionProperty::Longhand(LonghandId::MozWindowTransform)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => {
                TransitionProperty::Longhand(LonghandId::MozWindowTransformOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => {
                TransitionProperty::Longhand(LonghandId::MozForceBrokenImageIcon)
            }
            
    nsCSSPropertyID::eCSSProperty_text_anchor => {
                TransitionProperty::Longhand(LonghandId::TextAnchor)
            }
            
    nsCSSPropertyID::eCSSProperty_color_interpolation => {
                TransitionProperty::Longhand(LonghandId::ColorInterpolation)
            }
            
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => {
                TransitionProperty::Longhand(LonghandId::ColorInterpolationFilters)
            }
            
    nsCSSPropertyID::eCSSProperty_fill => {
                TransitionProperty::Longhand(LonghandId::Fill)
            }
            
    nsCSSPropertyID::eCSSProperty_fill_opacity => {
                TransitionProperty::Longhand(LonghandId::FillOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_fill_rule => {
                TransitionProperty::Longhand(LonghandId::FillRule)
            }
            
    nsCSSPropertyID::eCSSProperty_shape_rendering => {
                TransitionProperty::Longhand(LonghandId::ShapeRendering)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke => {
                TransitionProperty::Longhand(LonghandId::Stroke)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_width => {
                TransitionProperty::Longhand(LonghandId::StrokeWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_linecap => {
                TransitionProperty::Longhand(LonghandId::StrokeLinecap)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => {
                TransitionProperty::Longhand(LonghandId::StrokeLinejoin)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => {
                TransitionProperty::Longhand(LonghandId::StrokeMiterlimit)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_opacity => {
                TransitionProperty::Longhand(LonghandId::StrokeOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => {
                TransitionProperty::Longhand(LonghandId::StrokeDasharray)
            }
            
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => {
                TransitionProperty::Longhand(LonghandId::StrokeDashoffset)
            }
            
    nsCSSPropertyID::eCSSProperty_clip_rule => {
                TransitionProperty::Longhand(LonghandId::ClipRule)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_start => {
                TransitionProperty::Longhand(LonghandId::MarkerStart)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_mid => {
                TransitionProperty::Longhand(LonghandId::MarkerMid)
            }
            
    nsCSSPropertyID::eCSSProperty_marker_end => {
                TransitionProperty::Longhand(LonghandId::MarkerEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_paint_order => {
                TransitionProperty::Longhand(LonghandId::PaintOrder)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_context_properties => {
                TransitionProperty::Longhand(LonghandId::MozContextProperties)
            }
            
    nsCSSPropertyID::eCSSProperty_dominant_baseline => {
                TransitionProperty::Longhand(LonghandId::DominantBaseline)
            }
            
    nsCSSPropertyID::eCSSProperty_vector_effect => {
                TransitionProperty::Longhand(LonghandId::VectorEffect)
            }
            
    nsCSSPropertyID::eCSSProperty_stop_color => {
                TransitionProperty::Longhand(LonghandId::StopColor)
            }
            
    nsCSSPropertyID::eCSSProperty_stop_opacity => {
                TransitionProperty::Longhand(LonghandId::StopOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_flood_color => {
                TransitionProperty::Longhand(LonghandId::FloodColor)
            }
            
    nsCSSPropertyID::eCSSProperty_flood_opacity => {
                TransitionProperty::Longhand(LonghandId::FloodOpacity)
            }
            
    nsCSSPropertyID::eCSSProperty_lighting_color => {
                TransitionProperty::Longhand(LonghandId::LightingColor)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_type => {
                TransitionProperty::Longhand(LonghandId::MaskType)
            }
            
    nsCSSPropertyID::eCSSProperty_clip_path => {
                TransitionProperty::Longhand(LonghandId::ClipPath)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_mode => {
                TransitionProperty::Longhand(LonghandId::MaskMode)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_repeat => {
                TransitionProperty::Longhand(LonghandId::MaskRepeat)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position_x => {
                TransitionProperty::Longhand(LonghandId::MaskPositionX)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position_y => {
                TransitionProperty::Longhand(LonghandId::MaskPositionY)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_clip => {
                TransitionProperty::Longhand(LonghandId::MaskClip)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_origin => {
                TransitionProperty::Longhand(LonghandId::MaskOrigin)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_size => {
                TransitionProperty::Longhand(LonghandId::MaskSize)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_composite => {
                TransitionProperty::Longhand(LonghandId::MaskComposite)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_image => {
                TransitionProperty::Longhand(LonghandId::MaskImage)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_align => {
                TransitionProperty::Longhand(LonghandId::MozBoxAlign)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_direction => {
                TransitionProperty::Longhand(LonghandId::MozBoxDirection)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_flex => {
                TransitionProperty::Longhand(LonghandId::MozBoxFlex)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_orient => {
                TransitionProperty::Longhand(LonghandId::MozBoxOrient)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_pack => {
                TransitionProperty::Longhand(LonghandId::MozBoxPack)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => {
                TransitionProperty::Longhand(LonghandId::MozStackSizing)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => {
                TransitionProperty::Longhand(LonghandId::MozBoxOrdinalGroup)
            }
            
    nsCSSPropertyID::eCSSProperty_background => {
                TransitionProperty::Shorthand(ShorthandId::Background)
            }
            
    nsCSSPropertyID::eCSSProperty_background_position => {
                TransitionProperty::Shorthand(ShorthandId::BackgroundPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_border_color => {
                TransitionProperty::Shorthand(ShorthandId::BorderColor)
            }
            
    nsCSSPropertyID::eCSSProperty_border_style => {
                TransitionProperty::Shorthand(ShorthandId::BorderStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_border_width => {
                TransitionProperty::Shorthand(ShorthandId::BorderWidth)
            }
            
    nsCSSPropertyID::eCSSProperty_border_top => {
                TransitionProperty::Shorthand(ShorthandId::BorderTop)
            }
            
    nsCSSPropertyID::eCSSProperty_border_left => {
                TransitionProperty::Shorthand(ShorthandId::BorderLeft)
            }
            
    nsCSSPropertyID::eCSSProperty_border_bottom => {
                TransitionProperty::Shorthand(ShorthandId::BorderBottom)
            }
            
    nsCSSPropertyID::eCSSProperty_border_right => {
                TransitionProperty::Shorthand(ShorthandId::BorderRight)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_start => {
                TransitionProperty::Shorthand(ShorthandId::BorderBlockStart)
            }
            
    nsCSSPropertyID::eCSSProperty_border_block_end => {
                TransitionProperty::Shorthand(ShorthandId::BorderBlockEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_start => {
                TransitionProperty::Shorthand(ShorthandId::BorderInlineStart)
            }
            
    nsCSSPropertyID::eCSSProperty_border_inline_end => {
                TransitionProperty::Shorthand(ShorthandId::BorderInlineEnd)
            }
            
    nsCSSPropertyID::eCSSProperty_border => {
                TransitionProperty::Shorthand(ShorthandId::Border)
            }
            
    nsCSSPropertyID::eCSSProperty_border_radius => {
                TransitionProperty::Shorthand(ShorthandId::BorderRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_border_image => {
                TransitionProperty::Shorthand(ShorthandId::BorderImage)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow => {
                TransitionProperty::Shorthand(ShorthandId::Overflow)
            }
            
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => {
                TransitionProperty::Shorthand(ShorthandId::OverflowClipBox)
            }
            
    nsCSSPropertyID::eCSSProperty_transition => {
                TransitionProperty::Shorthand(ShorthandId::Transition)
            }
            
    nsCSSPropertyID::eCSSProperty_animation => {
                TransitionProperty::Shorthand(ShorthandId::Animation)
            }
            
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => {
                TransitionProperty::Shorthand(ShorthandId::ScrollSnapType)
            }
            
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => {
                TransitionProperty::Shorthand(ShorthandId::OverscrollBehavior)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_transform => {
                TransitionProperty::Shorthand(ShorthandId::MozTransform)
            }
            
    nsCSSPropertyID::eCSSProperty_columns => {
                TransitionProperty::Shorthand(ShorthandId::Columns)
            }
            
    nsCSSPropertyID::eCSSProperty_column_rule => {
                TransitionProperty::Shorthand(ShorthandId::ColumnRule)
            }
            
    nsCSSPropertyID::eCSSProperty_font => {
                TransitionProperty::Shorthand(ShorthandId::Font)
            }
            
    nsCSSPropertyID::eCSSProperty_font_variant => {
                TransitionProperty::Shorthand(ShorthandId::FontVariant)
            }
            
    nsCSSPropertyID::eCSSProperty_text_emphasis => {
                TransitionProperty::Shorthand(ShorthandId::TextEmphasis)
            }
            
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => {
                TransitionProperty::Shorthand(ShorthandId::WebkitTextStroke)
            }
            
    nsCSSPropertyID::eCSSProperty_list_style => {
                TransitionProperty::Shorthand(ShorthandId::ListStyle)
            }
            
    nsCSSPropertyID::eCSSProperty_margin => {
                TransitionProperty::Shorthand(ShorthandId::Margin)
            }
            
    nsCSSPropertyID::eCSSProperty_mask => {
                TransitionProperty::Shorthand(ShorthandId::Mask)
            }
            
    nsCSSPropertyID::eCSSProperty_mask_position => {
                TransitionProperty::Shorthand(ShorthandId::MaskPosition)
            }
            
    nsCSSPropertyID::eCSSProperty_outline => {
                TransitionProperty::Shorthand(ShorthandId::Outline)
            }
            
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => {
                TransitionProperty::Shorthand(ShorthandId::MozOutlineRadius)
            }
            
    nsCSSPropertyID::eCSSProperty_padding => {
                TransitionProperty::Shorthand(ShorthandId::Padding)
            }
            
    nsCSSPropertyID::eCSSProperty_flex_flow => {
                TransitionProperty::Shorthand(ShorthandId::FlexFlow)
            }
            
    nsCSSPropertyID::eCSSProperty_flex => {
                TransitionProperty::Shorthand(ShorthandId::Flex)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_gap => {
                TransitionProperty::Shorthand(ShorthandId::GridGap)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_row => {
                TransitionProperty::Shorthand(ShorthandId::GridRow)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_column => {
                TransitionProperty::Shorthand(ShorthandId::GridColumn)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_area => {
                TransitionProperty::Shorthand(ShorthandId::GridArea)
            }
            
    nsCSSPropertyID::eCSSProperty_grid_template => {
                TransitionProperty::Shorthand(ShorthandId::GridTemplate)
            }
            
    nsCSSPropertyID::eCSSProperty_grid => {
                TransitionProperty::Shorthand(ShorthandId::Grid)
            }
            
    nsCSSPropertyID::eCSSProperty_place_content => {
                TransitionProperty::Shorthand(ShorthandId::PlaceContent)
            }
            
    nsCSSPropertyID::eCSSProperty_place_self => {
                TransitionProperty::Shorthand(ShorthandId::PlaceSelf)
            }
            
    nsCSSPropertyID::eCSSProperty_place_items => {
                TransitionProperty::Shorthand(ShorthandId::PlaceItems)
            }
            
    nsCSSPropertyID::eCSSProperty_marker => {
                TransitionProperty::Shorthand(ShorthandId::Marker)
            }
            
    nsCSSPropertyID::eCSSProperty_text_decoration => {
                TransitionProperty::Shorthand(ShorthandId::TextDecoration)
            }
            nsCSSPropertyID::eCSSPropertyExtra_all_properties => TransitionProperty::All,
            _ => {
                panic!("non-convertible nsCSSPropertyID")
            }
        }
    }
}

/// Returns true if this nsCSSPropertyID is one of the transitionable properties.
#[cfg(feature = "gecko")]
pub fn nscsspropertyid_is_transitionable(property: nsCSSPropertyID) -> bool {
    match property {
                
    nsCSSPropertyID::eCSSProperty_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_background_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_background_size => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_left_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_right_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => true,
                
    nsCSSPropertyID::eCSSProperty_vertical_align => true,
                
    nsCSSPropertyID::eCSSProperty_transform => true,
                
    nsCSSPropertyID::eCSSProperty_perspective => true,
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => true,
                
    nsCSSPropertyID::eCSSProperty_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => true,
                
    nsCSSPropertyID::eCSSProperty_shape_outside => true,
                
    nsCSSPropertyID::eCSSProperty_color => true,
                
    nsCSSPropertyID::eCSSProperty_column_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_count => true,
                
    nsCSSPropertyID::eCSSProperty_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => true,
                
    nsCSSPropertyID::eCSSProperty_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_box_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_clip => true,
                
    nsCSSPropertyID::eCSSProperty_filter => true,
                
    nsCSSPropertyID::eCSSProperty_font_weight => true,
                
    nsCSSPropertyID::eCSSProperty_font_size => true,
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => true,
                
    nsCSSPropertyID::eCSSProperty_font_stretch => true,
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => true,
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => true,
                
    nsCSSPropertyID::eCSSProperty_visibility => true,
                
    nsCSSPropertyID::eCSSProperty_border_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_line_height => true,
                
    nsCSSPropertyID::eCSSProperty_text_indent => true,
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_word_spacing => true,
                
    nsCSSPropertyID::eCSSProperty_text_shadow => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => true,
                
    nsCSSPropertyID::eCSSProperty_margin_top => true,
                
    nsCSSPropertyID::eCSSProperty_margin_left => true,
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_margin_right => true,
                
    nsCSSPropertyID::eCSSProperty_outline_color => true,
                
    nsCSSPropertyID::eCSSProperty_outline_width => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => true,
                
    nsCSSPropertyID::eCSSProperty_outline_offset => true,
                
    nsCSSPropertyID::eCSSProperty_padding_top => true,
                
    nsCSSPropertyID::eCSSProperty_padding_left => true,
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_padding_right => true,
                
    nsCSSPropertyID::eCSSProperty_caret_color => true,
                
    nsCSSPropertyID::eCSSProperty_top => true,
                
    nsCSSPropertyID::eCSSProperty_left => true,
                
    nsCSSPropertyID::eCSSProperty_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_right => true,
                
    nsCSSPropertyID::eCSSProperty_z_index => true,
                
    nsCSSPropertyID::eCSSProperty_flex_grow => true,
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => true,
                
    nsCSSPropertyID::eCSSProperty_order => true,
                
    nsCSSPropertyID::eCSSProperty_flex_basis => true,
                
    nsCSSPropertyID::eCSSProperty_width => true,
                
    nsCSSPropertyID::eCSSProperty_min_width => true,
                
    nsCSSPropertyID::eCSSProperty_max_width => true,
                
    nsCSSPropertyID::eCSSProperty_height => true,
                
    nsCSSPropertyID::eCSSProperty_min_height => true,
                
    nsCSSPropertyID::eCSSProperty_max_height => true,
                
    nsCSSPropertyID::eCSSProperty_object_position => true,
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => true,
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => true,
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => true,
                
    nsCSSPropertyID::eCSSProperty_fill => true,
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_width => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => true,
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => true,
                
    nsCSSPropertyID::eCSSProperty_stop_color => true,
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_flood_color => true,
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => true,
                
    nsCSSPropertyID::eCSSProperty_lighting_color => true,
                
    nsCSSPropertyID::eCSSProperty_clip_path => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => true,
                
    nsCSSPropertyID::eCSSProperty_mask_size => true,
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => true,
                
    nsCSSPropertyID::eCSSProperty_background => true,
                
    nsCSSPropertyID::eCSSProperty_background_position => true,
                
    nsCSSPropertyID::eCSSProperty_border_color => true,
                
    nsCSSPropertyID::eCSSProperty_border_width => true,
                
    nsCSSPropertyID::eCSSProperty_border_top => true,
                
    nsCSSPropertyID::eCSSProperty_border_left => true,
                
    nsCSSPropertyID::eCSSProperty_border_bottom => true,
                
    nsCSSPropertyID::eCSSProperty_border_right => true,
                
    nsCSSPropertyID::eCSSProperty_border => true,
                
    nsCSSPropertyID::eCSSProperty_border_radius => true,
                
    nsCSSPropertyID::eCSSProperty__moz_transform => true,
                
    nsCSSPropertyID::eCSSProperty_columns => true,
                
    nsCSSPropertyID::eCSSProperty_column_rule => true,
                
    nsCSSPropertyID::eCSSProperty_font => true,
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => true,
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => true,
                
    nsCSSPropertyID::eCSSProperty_margin => true,
                
    nsCSSPropertyID::eCSSProperty_mask => true,
                
    nsCSSPropertyID::eCSSProperty_mask_position => true,
                
    nsCSSPropertyID::eCSSProperty_outline => true,
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => true,
                
    nsCSSPropertyID::eCSSProperty_padding => true,
                
    nsCSSPropertyID::eCSSProperty_flex => true,
                
    nsCSSPropertyID::eCSSProperty_grid_gap => true,
                
    nsCSSPropertyID::eCSSProperty_text_decoration => true,
        _ => false
    }
}

/// An animated property interpolation between two computed values for that
/// property.
#[cfg(feature = "servo")]
#[derive(Clone, Debug, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum AnimatedProperty {
            
            /// background-color
            BackgroundColor(<longhands::background_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// background-image
            BackgroundImage(longhands::background_image::computed_value::T, longhands::background_image::computed_value::T),
            
            /// background-position-x
            BackgroundPositionX(longhands::background_position_x::computed_value::T, longhands::background_position_x::computed_value::T),
            
            /// background-position-y
            BackgroundPositionY(longhands::background_position_y::computed_value::T, longhands::background_position_y::computed_value::T),
            
            /// background-repeat
            BackgroundRepeat(longhands::background_repeat::computed_value::T, longhands::background_repeat::computed_value::T),
            
            /// background-attachment
            BackgroundAttachment(longhands::background_attachment::computed_value::T, longhands::background_attachment::computed_value::T),
            
            /// background-clip
            BackgroundClip(longhands::background_clip::computed_value::T, longhands::background_clip::computed_value::T),
            
            /// background-origin
            BackgroundOrigin(longhands::background_origin::computed_value::T, longhands::background_origin::computed_value::T),
            
            /// background-size
            BackgroundSize(<longhands::background_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::background_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// background-blend-mode
            BackgroundBlendMode(longhands::background_blend_mode::computed_value::T, longhands::background_blend_mode::computed_value::T),
            
            /// border-top-color
            BorderTopColor(<longhands::border_top_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-style
            BorderTopStyle(longhands::border_top_style::computed_value::T, longhands::border_top_style::computed_value::T),
            
            /// border-top-width
            BorderTopWidth(<longhands::border_top_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-left-color
            BorderLeftColor(<longhands::border_left_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_left_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-left-style
            BorderLeftStyle(longhands::border_left_style::computed_value::T, longhands::border_left_style::computed_value::T),
            
            /// border-left-width
            BorderLeftWidth(<longhands::border_left_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_left_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-color
            BorderBottomColor(<longhands::border_bottom_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-style
            BorderBottomStyle(longhands::border_bottom_style::computed_value::T, longhands::border_bottom_style::computed_value::T),
            
            /// border-bottom-width
            BorderBottomWidth(<longhands::border_bottom_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-right-color
            BorderRightColor(<longhands::border_right_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_right_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-right-style
            BorderRightStyle(longhands::border_right_style::computed_value::T, longhands::border_right_style::computed_value::T),
            
            /// border-right-width
            BorderRightWidth(<longhands::border_right_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_right_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-left-radius
            BorderTopLeftRadius(<longhands::border_top_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-top-right-radius
            BorderTopRightRadius(<longhands::border_top_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_top_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-right-radius
            BorderBottomRightRadius(<longhands::border_bottom_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// border-bottom-left-radius
            BorderBottomLeftRadius(<longhands::border_bottom_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_bottom_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-border-top-colors
            MozBorderTopColors(longhands::_moz_border_top_colors::computed_value::T, longhands::_moz_border_top_colors::computed_value::T),
            
            /// -moz-border-left-colors
            MozBorderLeftColors(longhands::_moz_border_left_colors::computed_value::T, longhands::_moz_border_left_colors::computed_value::T),
            
            /// -moz-border-bottom-colors
            MozBorderBottomColors(longhands::_moz_border_bottom_colors::computed_value::T, longhands::_moz_border_bottom_colors::computed_value::T),
            
            /// -moz-border-right-colors
            MozBorderRightColors(longhands::_moz_border_right_colors::computed_value::T, longhands::_moz_border_right_colors::computed_value::T),
            
            /// box-decoration-break
            BoxDecorationBreak(longhands::box_decoration_break::computed_value::T, longhands::box_decoration_break::computed_value::T),
            
            /// -moz-float-edge
            MozFloatEdge(longhands::_moz_float_edge::computed_value::T, longhands::_moz_float_edge::computed_value::T),
            
            /// border-image-source
            BorderImageSource(longhands::border_image_source::computed_value::T, longhands::border_image_source::computed_value::T),
            
            /// border-image-outset
            BorderImageOutset(longhands::border_image_outset::computed_value::T, longhands::border_image_outset::computed_value::T),
            
            /// border-image-repeat
            BorderImageRepeat(longhands::border_image_repeat::computed_value::T, longhands::border_image_repeat::computed_value::T),
            
            /// border-image-width
            BorderImageWidth(longhands::border_image_width::computed_value::T, longhands::border_image_width::computed_value::T),
            
            /// border-image-slice
            BorderImageSlice(longhands::border_image_slice::computed_value::T, longhands::border_image_slice::computed_value::T),
            
            /// display
            Display(longhands::display::computed_value::T, longhands::display::computed_value::T),
            
            /// position
            Position(longhands::position::computed_value::T, longhands::position::computed_value::T),
            
            /// float
            Float(longhands::float::computed_value::T, longhands::float::computed_value::T),
            
            /// clear
            Clear(longhands::clear::computed_value::T, longhands::clear::computed_value::T),
            
            /// vertical-align
            VerticalAlign(longhands::vertical_align::computed_value::T, longhands::vertical_align::computed_value::T),
            
            /// overflow-clip-box-inline
            OverflowClipBoxInline(longhands::overflow_clip_box_inline::computed_value::T, longhands::overflow_clip_box_inline::computed_value::T),
            
            /// overflow-clip-box-block
            OverflowClipBoxBlock(longhands::overflow_clip_box_block::computed_value::T, longhands::overflow_clip_box_block::computed_value::T),
            
            /// overflow-x
            OverflowX(longhands::overflow_x::computed_value::T, longhands::overflow_x::computed_value::T),
            
            /// overflow-y
            OverflowY(longhands::overflow_y::computed_value::T, longhands::overflow_y::computed_value::T),
            
            /// scroll-snap-points-x
            ScrollSnapPointsX(longhands::scroll_snap_points_x::computed_value::T, longhands::scroll_snap_points_x::computed_value::T),
            
            /// scroll-snap-points-y
            ScrollSnapPointsY(longhands::scroll_snap_points_y::computed_value::T, longhands::scroll_snap_points_y::computed_value::T),
            
            /// scroll-snap-destination
            ScrollSnapDestination(longhands::scroll_snap_destination::computed_value::T, longhands::scroll_snap_destination::computed_value::T),
            
            /// scroll-snap-coordinate
            ScrollSnapCoordinate(longhands::scroll_snap_coordinate::computed_value::T, longhands::scroll_snap_coordinate::computed_value::T),
            
            /// transform
            Transform(longhands::transform::computed_value::T, longhands::transform::computed_value::T),
            
            /// scroll-behavior
            ScrollBehavior(longhands::scroll_behavior::computed_value::T, longhands::scroll_behavior::computed_value::T),
            
            /// scroll-snap-type-x
            ScrollSnapTypeX(longhands::scroll_snap_type_x::computed_value::T, longhands::scroll_snap_type_x::computed_value::T),
            
            /// scroll-snap-type-y
            ScrollSnapTypeY(longhands::scroll_snap_type_y::computed_value::T, longhands::scroll_snap_type_y::computed_value::T),
            
            /// overscroll-behavior-x
            OverscrollBehaviorX(longhands::overscroll_behavior_x::computed_value::T, longhands::overscroll_behavior_x::computed_value::T),
            
            /// overscroll-behavior-y
            OverscrollBehaviorY(longhands::overscroll_behavior_y::computed_value::T, longhands::overscroll_behavior_y::computed_value::T),
            
            /// isolation
            Isolation(longhands::isolation::computed_value::T, longhands::isolation::computed_value::T),
            
            /// page-break-after
            PageBreakAfter(longhands::page_break_after::computed_value::T, longhands::page_break_after::computed_value::T),
            
            /// page-break-before
            PageBreakBefore(longhands::page_break_before::computed_value::T, longhands::page_break_before::computed_value::T),
            
            /// page-break-inside
            PageBreakInside(longhands::page_break_inside::computed_value::T, longhands::page_break_inside::computed_value::T),
            
            /// resize
            Resize(longhands::resize::computed_value::T, longhands::resize::computed_value::T),
            
            /// perspective
            Perspective(longhands::perspective::computed_value::T, longhands::perspective::computed_value::T),
            
            /// perspective-origin
            PerspectiveOrigin(longhands::perspective_origin::computed_value::T, longhands::perspective_origin::computed_value::T),
            
            /// backface-visibility
            BackfaceVisibility(longhands::backface_visibility::computed_value::T, longhands::backface_visibility::computed_value::T),
            
            /// transform-box
            TransformBox(longhands::transform_box::computed_value::T, longhands::transform_box::computed_value::T),
            
            /// transform-style
            TransformStyle(longhands::transform_style::computed_value::T, longhands::transform_style::computed_value::T),
            
            /// transform-origin
            TransformOrigin(longhands::transform_origin::computed_value::T, longhands::transform_origin::computed_value::T),
            
            /// contain
            Contain(longhands::contain::computed_value::T, longhands::contain::computed_value::T),
            
            /// -moz-appearance
            MozAppearance(longhands::_moz_appearance::computed_value::T, longhands::_moz_appearance::computed_value::T),
            
            /// -moz-orient
            MozOrient(longhands::_moz_orient::computed_value::T, longhands::_moz_orient::computed_value::T),
            
            /// will-change
            WillChange(longhands::will_change::computed_value::T, longhands::will_change::computed_value::T),
            
            /// shape-image-threshold
            ShapeImageThreshold(longhands::shape_image_threshold::computed_value::T, longhands::shape_image_threshold::computed_value::T),
            
            /// shape-outside
            ShapeOutside(longhands::shape_outside::computed_value::T, longhands::shape_outside::computed_value::T),
            
            /// touch-action
            TouchAction(longhands::touch_action::computed_value::T, longhands::touch_action::computed_value::T),
            
            /// color
            Color(<longhands::color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-width
            ColumnWidth(<longhands::column_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-count
            ColumnCount(<longhands::column_count::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_count::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-gap
            ColumnGap(<longhands::column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-fill
            ColumnFill(longhands::column_fill::computed_value::T, longhands::column_fill::computed_value::T),
            
            /// column-rule-width
            ColumnRuleWidth(<longhands::column_rule_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_rule_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-rule-color
            ColumnRuleColor(<longhands::column_rule_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::column_rule_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// column-span
            ColumnSpan(longhands::column_span::computed_value::T, longhands::column_span::computed_value::T),
            
            /// column-rule-style
            ColumnRuleStyle(longhands::column_rule_style::computed_value::T, longhands::column_rule_style::computed_value::T),
            
            /// content
            Content(longhands::content::computed_value::T, longhands::content::computed_value::T),
            
            /// counter-increment
            CounterIncrement(longhands::counter_increment::computed_value::T, longhands::counter_increment::computed_value::T),
            
            /// counter-reset
            CounterReset(longhands::counter_reset::computed_value::T, longhands::counter_reset::computed_value::T),
            
            /// opacity
            Opacity(longhands::opacity::computed_value::T, longhands::opacity::computed_value::T),
            
            /// box-shadow
            BoxShadow(<longhands::box_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::box_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// clip
            Clip(longhands::clip::computed_value::T, longhands::clip::computed_value::T),
            
            /// filter
            Filter(<longhands::filter::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::filter::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// mix-blend-mode
            MixBlendMode(longhands::mix_blend_mode::computed_value::T, longhands::mix_blend_mode::computed_value::T),
            
            /// font-family
            FontFamily(longhands::font_family::computed_value::T, longhands::font_family::computed_value::T),
            
            /// font-style
            FontStyle(longhands::font_style::computed_value::T, longhands::font_style::computed_value::T),
            
            /// font-variant-caps
            FontVariantCaps(longhands::font_variant_caps::computed_value::T, longhands::font_variant_caps::computed_value::T),
            
            /// font-weight
            FontWeight(longhands::font_weight::computed_value::T, longhands::font_weight::computed_value::T),
            
            /// font-size
            FontSize(<longhands::font_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::font_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// font-size-adjust
            FontSizeAdjust(longhands::font_size_adjust::computed_value::T, longhands::font_size_adjust::computed_value::T),
            
            /// font-synthesis
            FontSynthesis(longhands::font_synthesis::computed_value::T, longhands::font_synthesis::computed_value::T),
            
            /// font-stretch
            FontStretch(longhands::font_stretch::computed_value::T, longhands::font_stretch::computed_value::T),
            
            /// font-kerning
            FontKerning(longhands::font_kerning::computed_value::T, longhands::font_kerning::computed_value::T),
            
            /// font-variant-alternates
            FontVariantAlternates(longhands::font_variant_alternates::computed_value::T, longhands::font_variant_alternates::computed_value::T),
            
            /// font-variant-east-asian
            FontVariantEastAsian(longhands::font_variant_east_asian::computed_value::T, longhands::font_variant_east_asian::computed_value::T),
            
            /// font-variant-ligatures
            FontVariantLigatures(longhands::font_variant_ligatures::computed_value::T, longhands::font_variant_ligatures::computed_value::T),
            
            /// font-variant-numeric
            FontVariantNumeric(longhands::font_variant_numeric::computed_value::T, longhands::font_variant_numeric::computed_value::T),
            
            /// font-variant-position
            FontVariantPosition(longhands::font_variant_position::computed_value::T, longhands::font_variant_position::computed_value::T),
            
            /// font-feature-settings
            FontFeatureSettings(longhands::font_feature_settings::computed_value::T, longhands::font_feature_settings::computed_value::T),
            
            /// font-variation-settings
            FontVariationSettings(longhands::font_variation_settings::computed_value::T, longhands::font_variation_settings::computed_value::T),
            
            /// font-language-override
            FontLanguageOverride(longhands::font_language_override::computed_value::T, longhands::font_language_override::computed_value::T),
            
            /// -moz-osx-font-smoothing
            MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::computed_value::T, longhands::_moz_osx_font_smoothing::computed_value::T),
            
            /// -moz-font-smoothing-background-color
            MozFontSmoothingBackgroundColor(<longhands::_moz_font_smoothing_background_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_font_smoothing_background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// visibility
            Visibility(longhands::visibility::computed_value::T, longhands::visibility::computed_value::T),
            
            /// writing-mode
            WritingMode(longhands::writing_mode::computed_value::T, longhands::writing_mode::computed_value::T),
            
            /// direction
            Direction(longhands::direction::computed_value::T, longhands::direction::computed_value::T),
            
            /// text-orientation
            TextOrientation(longhands::text_orientation::computed_value::T, longhands::text_orientation::computed_value::T),
            
            /// color-adjust
            ColorAdjust(longhands::color_adjust::computed_value::T, longhands::color_adjust::computed_value::T),
            
            /// image-rendering
            ImageRendering(longhands::image_rendering::computed_value::T, longhands::image_rendering::computed_value::T),
            
            /// image-orientation
            ImageOrientation(longhands::image_orientation::computed_value::T, longhands::image_orientation::computed_value::T),
            
            /// border-collapse
            BorderCollapse(longhands::border_collapse::computed_value::T, longhands::border_collapse::computed_value::T),
            
            /// empty-cells
            EmptyCells(longhands::empty_cells::computed_value::T, longhands::empty_cells::computed_value::T),
            
            /// caption-side
            CaptionSide(longhands::caption_side::computed_value::T, longhands::caption_side::computed_value::T),
            
            /// border-spacing
            BorderSpacing(<longhands::border_spacing::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::border_spacing::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// line-height
            LineHeight(<longhands::line_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::line_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// text-transform
            TextTransform(longhands::text_transform::computed_value::T, longhands::text_transform::computed_value::T),
            
            /// hyphens
            Hyphens(longhands::hyphens::computed_value::T, longhands::hyphens::computed_value::T),
            
            /// -moz-text-size-adjust
            MozTextSizeAdjust(longhands::_moz_text_size_adjust::computed_value::T, longhands::_moz_text_size_adjust::computed_value::T),
            
            /// text-indent
            TextIndent(longhands::text_indent::computed_value::T, longhands::text_indent::computed_value::T),
            
            /// overflow-wrap
            OverflowWrap(longhands::overflow_wrap::computed_value::T, longhands::overflow_wrap::computed_value::T),
            
            /// word-break
            WordBreak(longhands::word_break::computed_value::T, longhands::word_break::computed_value::T),
            
            /// text-justify
            TextJustify(longhands::text_justify::computed_value::T, longhands::text_justify::computed_value::T),
            
            /// text-align-last
            TextAlignLast(longhands::text_align_last::computed_value::T, longhands::text_align_last::computed_value::T),
            
            /// text-align
            TextAlign(longhands::text_align::computed_value::T, longhands::text_align::computed_value::T),
            
            /// letter-spacing
            LetterSpacing(longhands::letter_spacing::computed_value::T, longhands::letter_spacing::computed_value::T),
            
            /// word-spacing
            WordSpacing(longhands::word_spacing::computed_value::T, longhands::word_spacing::computed_value::T),
            
            /// white-space
            WhiteSpace(longhands::white_space::computed_value::T, longhands::white_space::computed_value::T),
            
            /// text-shadow
            TextShadow(<longhands::text_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// text-emphasis-style
            TextEmphasisStyle(longhands::text_emphasis_style::computed_value::T, longhands::text_emphasis_style::computed_value::T),
            
            /// text-emphasis-position
            TextEmphasisPosition(longhands::text_emphasis_position::computed_value::T, longhands::text_emphasis_position::computed_value::T),
            
            /// text-emphasis-color
            TextEmphasisColor(<longhands::text_emphasis_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_emphasis_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-tab-size
            MozTabSize(<longhands::_moz_tab_size::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_tab_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-fill-color
            WebkitTextFillColor(<longhands::_webkit_text_fill_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_webkit_text_fill_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-stroke-color
            WebkitTextStrokeColor(<longhands::_webkit_text_stroke_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_webkit_text_stroke_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -webkit-text-stroke-width
            WebkitTextStrokeWidth(longhands::_webkit_text_stroke_width::computed_value::T, longhands::_webkit_text_stroke_width::computed_value::T),
            
            /// ruby-align
            RubyAlign(longhands::ruby_align::computed_value::T, longhands::ruby_align::computed_value::T),
            
            /// ruby-position
            RubyPosition(longhands::ruby_position::computed_value::T, longhands::ruby_position::computed_value::T),
            
            /// text-combine-upright
            TextCombineUpright(longhands::text_combine_upright::computed_value::T, longhands::text_combine_upright::computed_value::T),
            
            /// text-rendering
            TextRendering(longhands::text_rendering::computed_value::T, longhands::text_rendering::computed_value::T),
            
            /// list-style-position
            ListStylePosition(longhands::list_style_position::computed_value::T, longhands::list_style_position::computed_value::T),
            
            /// list-style-type
            ListStyleType(longhands::list_style_type::computed_value::T, longhands::list_style_type::computed_value::T),
            
            /// list-style-image
            ListStyleImage(longhands::list_style_image::computed_value::T, longhands::list_style_image::computed_value::T),
            
            /// quotes
            Quotes(longhands::quotes::computed_value::T, longhands::quotes::computed_value::T),
            
            /// -moz-image-region
            MozImageRegion(longhands::_moz_image_region::computed_value::T, longhands::_moz_image_region::computed_value::T),
            
            /// margin-top
            MarginTop(longhands::margin_top::computed_value::T, longhands::margin_top::computed_value::T),
            
            /// margin-left
            MarginLeft(longhands::margin_left::computed_value::T, longhands::margin_left::computed_value::T),
            
            /// margin-bottom
            MarginBottom(longhands::margin_bottom::computed_value::T, longhands::margin_bottom::computed_value::T),
            
            /// margin-right
            MarginRight(longhands::margin_right::computed_value::T, longhands::margin_right::computed_value::T),
            
            /// outline-color
            OutlineColor(<longhands::outline_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::outline_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// outline-style
            OutlineStyle(longhands::outline_style::computed_value::T, longhands::outline_style::computed_value::T),
            
            /// outline-width
            OutlineWidth(<longhands::outline_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::outline_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-topleft
            MozOutlineRadiusTopleft(<longhands::_moz_outline_radius_topleft::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_topleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-topright
            MozOutlineRadiusTopright(<longhands::_moz_outline_radius_topright::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_topright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-bottomright
            MozOutlineRadiusBottomright(<longhands::_moz_outline_radius_bottomright::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_bottomright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-outline-radius-bottomleft
            MozOutlineRadiusBottomleft(<longhands::_moz_outline_radius_bottomleft::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_outline_radius_bottomleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// outline-offset
            OutlineOffset(longhands::outline_offset::computed_value::T, longhands::outline_offset::computed_value::T),
            
            /// padding-top
            PaddingTop(<longhands::padding_top::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_top::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-left
            PaddingLeft(<longhands::padding_left::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_left::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-bottom
            PaddingBottom(<longhands::padding_bottom::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_bottom::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// padding-right
            PaddingRight(<longhands::padding_right::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::padding_right::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// cursor
            Cursor(longhands::cursor::computed_value::T, longhands::cursor::computed_value::T),
            
            /// pointer-events
            PointerEvents(longhands::pointer_events::computed_value::T, longhands::pointer_events::computed_value::T),
            
            /// -moz-user-input
            MozUserInput(longhands::_moz_user_input::computed_value::T, longhands::_moz_user_input::computed_value::T),
            
            /// -moz-user-modify
            MozUserModify(longhands::_moz_user_modify::computed_value::T, longhands::_moz_user_modify::computed_value::T),
            
            /// -moz-user-focus
            MozUserFocus(longhands::_moz_user_focus::computed_value::T, longhands::_moz_user_focus::computed_value::T),
            
            /// caret-color
            CaretColor(<longhands::caret_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::caret_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// top
            Top(longhands::top::computed_value::T, longhands::top::computed_value::T),
            
            /// left
            Left(longhands::left::computed_value::T, longhands::left::computed_value::T),
            
            /// bottom
            Bottom(longhands::bottom::computed_value::T, longhands::bottom::computed_value::T),
            
            /// right
            Right(longhands::right::computed_value::T, longhands::right::computed_value::T),
            
            /// z-index
            ZIndex(longhands::z_index::computed_value::T, longhands::z_index::computed_value::T),
            
            /// flex-direction
            FlexDirection(longhands::flex_direction::computed_value::T, longhands::flex_direction::computed_value::T),
            
            /// flex-wrap
            FlexWrap(longhands::flex_wrap::computed_value::T, longhands::flex_wrap::computed_value::T),
            
            /// justify-content
            JustifyContent(longhands::justify_content::computed_value::T, longhands::justify_content::computed_value::T),
            
            /// align-content
            AlignContent(longhands::align_content::computed_value::T, longhands::align_content::computed_value::T),
            
            /// align-items
            AlignItems(longhands::align_items::computed_value::T, longhands::align_items::computed_value::T),
            
            /// justify-items
            JustifyItems(longhands::justify_items::computed_value::T, longhands::justify_items::computed_value::T),
            
            /// flex-grow
            FlexGrow(<longhands::flex_grow::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_grow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flex-shrink
            FlexShrink(<longhands::flex_shrink::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_shrink::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// align-self
            AlignSelf(longhands::align_self::computed_value::T, longhands::align_self::computed_value::T),
            
            /// justify-self
            JustifySelf(longhands::justify_self::computed_value::T, longhands::justify_self::computed_value::T),
            
            /// order
            Order(longhands::order::computed_value::T, longhands::order::computed_value::T),
            
            /// flex-basis
            FlexBasis(<longhands::flex_basis::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flex_basis::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// width
            Width(<longhands::width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// min-width
            MinWidth(<longhands::min_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::min_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// max-width
            MaxWidth(<longhands::max_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::max_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// height
            Height(<longhands::height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// min-height
            MinHeight(<longhands::min_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::min_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// max-height
            MaxHeight(<longhands::max_height::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::max_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// box-sizing
            BoxSizing(longhands::box_sizing::computed_value::T, longhands::box_sizing::computed_value::T),
            
            /// object-fit
            ObjectFit(longhands::object_fit::computed_value::T, longhands::object_fit::computed_value::T),
            
            /// object-position
            ObjectPosition(longhands::object_position::computed_value::T, longhands::object_position::computed_value::T),
            
            /// grid-row-gap
            GridRowGap(<longhands::grid_row_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::grid_row_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// grid-row-start
            GridRowStart(longhands::grid_row_start::computed_value::T, longhands::grid_row_start::computed_value::T),
            
            /// grid-row-end
            GridRowEnd(longhands::grid_row_end::computed_value::T, longhands::grid_row_end::computed_value::T),
            
            /// grid-auto-rows
            GridAutoRows(longhands::grid_auto_rows::computed_value::T, longhands::grid_auto_rows::computed_value::T),
            
            /// grid-template-rows
            GridTemplateRows(longhands::grid_template_rows::computed_value::T, longhands::grid_template_rows::computed_value::T),
            
            /// grid-column-gap
            GridColumnGap(<longhands::grid_column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::grid_column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// grid-column-start
            GridColumnStart(longhands::grid_column_start::computed_value::T, longhands::grid_column_start::computed_value::T),
            
            /// grid-column-end
            GridColumnEnd(longhands::grid_column_end::computed_value::T, longhands::grid_column_end::computed_value::T),
            
            /// grid-auto-columns
            GridAutoColumns(longhands::grid_auto_columns::computed_value::T, longhands::grid_auto_columns::computed_value::T),
            
            /// grid-template-columns
            GridTemplateColumns(longhands::grid_template_columns::computed_value::T, longhands::grid_template_columns::computed_value::T),
            
            /// grid-auto-flow
            GridAutoFlow(longhands::grid_auto_flow::computed_value::T, longhands::grid_auto_flow::computed_value::T),
            
            /// grid-template-areas
            GridTemplateAreas(longhands::grid_template_areas::computed_value::T, longhands::grid_template_areas::computed_value::T),
            
            /// table-layout
            TableLayout(longhands::table_layout::computed_value::T, longhands::table_layout::computed_value::T),
            
            /// text-overflow
            TextOverflow(longhands::text_overflow::computed_value::T, longhands::text_overflow::computed_value::T),
            
            /// unicode-bidi
            UnicodeBidi(longhands::unicode_bidi::computed_value::T, longhands::unicode_bidi::computed_value::T),
            
            /// text-decoration-line
            TextDecorationLine(longhands::text_decoration_line::computed_value::T, longhands::text_decoration_line::computed_value::T),
            
            /// text-decoration-style
            TextDecorationStyle(longhands::text_decoration_style::computed_value::T, longhands::text_decoration_style::computed_value::T),
            
            /// text-decoration-color
            TextDecorationColor(<longhands::text_decoration_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::text_decoration_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// initial-letter
            InitialLetter(longhands::initial_letter::computed_value::T, longhands::initial_letter::computed_value::T),
            
            /// ime-mode
            ImeMode(longhands::ime_mode::computed_value::T, longhands::ime_mode::computed_value::T),
            
            /// -moz-user-select
            MozUserSelect(longhands::_moz_user_select::computed_value::T, longhands::_moz_user_select::computed_value::T),
            
            /// -moz-window-dragging
            MozWindowDragging(longhands::_moz_window_dragging::computed_value::T, longhands::_moz_window_dragging::computed_value::T),
            
            /// -moz-window-shadow
            MozWindowShadow(longhands::_moz_window_shadow::computed_value::T, longhands::_moz_window_shadow::computed_value::T),
            
            /// -moz-window-opacity
            MozWindowOpacity(longhands::_moz_window_opacity::computed_value::T, longhands::_moz_window_opacity::computed_value::T),
            
            /// -moz-window-transform
            MozWindowTransform(longhands::_moz_window_transform::computed_value::T, longhands::_moz_window_transform::computed_value::T),
            
            /// -moz-window-transform-origin
            MozWindowTransformOrigin(longhands::_moz_window_transform_origin::computed_value::T, longhands::_moz_window_transform_origin::computed_value::T),
            
            /// -moz-force-broken-image-icon
            MozForceBrokenImageIcon(longhands::_moz_force_broken_image_icon::computed_value::T, longhands::_moz_force_broken_image_icon::computed_value::T),
            
            /// text-anchor
            TextAnchor(longhands::text_anchor::computed_value::T, longhands::text_anchor::computed_value::T),
            
            /// color-interpolation
            ColorInterpolation(longhands::color_interpolation::computed_value::T, longhands::color_interpolation::computed_value::T),
            
            /// color-interpolation-filters
            ColorInterpolationFilters(longhands::color_interpolation_filters::computed_value::T, longhands::color_interpolation_filters::computed_value::T),
            
            /// fill
            Fill(<longhands::fill::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::fill::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// fill-opacity
            FillOpacity(longhands::fill_opacity::computed_value::T, longhands::fill_opacity::computed_value::T),
            
            /// fill-rule
            FillRule(longhands::fill_rule::computed_value::T, longhands::fill_rule::computed_value::T),
            
            /// shape-rendering
            ShapeRendering(longhands::shape_rendering::computed_value::T, longhands::shape_rendering::computed_value::T),
            
            /// stroke
            Stroke(<longhands::stroke::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-width
            StrokeWidth(<longhands::stroke_width::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-linecap
            StrokeLinecap(longhands::stroke_linecap::computed_value::T, longhands::stroke_linecap::computed_value::T),
            
            /// stroke-linejoin
            StrokeLinejoin(longhands::stroke_linejoin::computed_value::T, longhands::stroke_linejoin::computed_value::T),
            
            /// stroke-miterlimit
            StrokeMiterlimit(<longhands::stroke_miterlimit::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_miterlimit::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-opacity
            StrokeOpacity(longhands::stroke_opacity::computed_value::T, longhands::stroke_opacity::computed_value::T),
            
            /// stroke-dasharray
            StrokeDasharray(<longhands::stroke_dasharray::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stroke_dasharray::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stroke-dashoffset
            StrokeDashoffset(longhands::stroke_dashoffset::computed_value::T, longhands::stroke_dashoffset::computed_value::T),
            
            /// clip-rule
            ClipRule(longhands::clip_rule::computed_value::T, longhands::clip_rule::computed_value::T),
            
            /// marker-start
            MarkerStart(longhands::marker_start::computed_value::T, longhands::marker_start::computed_value::T),
            
            /// marker-mid
            MarkerMid(longhands::marker_mid::computed_value::T, longhands::marker_mid::computed_value::T),
            
            /// marker-end
            MarkerEnd(longhands::marker_end::computed_value::T, longhands::marker_end::computed_value::T),
            
            /// paint-order
            PaintOrder(longhands::paint_order::computed_value::T, longhands::paint_order::computed_value::T),
            
            /// dominant-baseline
            DominantBaseline(longhands::dominant_baseline::computed_value::T, longhands::dominant_baseline::computed_value::T),
            
            /// vector-effect
            VectorEffect(longhands::vector_effect::computed_value::T, longhands::vector_effect::computed_value::T),
            
            /// stop-color
            StopColor(<longhands::stop_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::stop_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// stop-opacity
            StopOpacity(longhands::stop_opacity::computed_value::T, longhands::stop_opacity::computed_value::T),
            
            /// flood-color
            FloodColor(<longhands::flood_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::flood_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// flood-opacity
            FloodOpacity(longhands::flood_opacity::computed_value::T, longhands::flood_opacity::computed_value::T),
            
            /// lighting-color
            LightingColor(<longhands::lighting_color::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::lighting_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// mask-type
            MaskType(longhands::mask_type::computed_value::T, longhands::mask_type::computed_value::T),
            
            /// clip-path
            ClipPath(longhands::clip_path::computed_value::T, longhands::clip_path::computed_value::T),
            
            /// mask-mode
            MaskMode(longhands::mask_mode::computed_value::T, longhands::mask_mode::computed_value::T),
            
            /// mask-repeat
            MaskRepeat(longhands::mask_repeat::computed_value::T, longhands::mask_repeat::computed_value::T),
            
            /// mask-position-x
            MaskPositionX(longhands::mask_position_x::computed_value::T, longhands::mask_position_x::computed_value::T),
            
            /// mask-position-y
            MaskPositionY(longhands::mask_position_y::computed_value::T, longhands::mask_position_y::computed_value::T),
            
            /// mask-clip
            MaskClip(longhands::mask_clip::computed_value::T, longhands::mask_clip::computed_value::T),
            
            /// mask-origin
            MaskOrigin(longhands::mask_origin::computed_value::T, longhands::mask_origin::computed_value::T),
            
            /// mask-size
            MaskSize(longhands::mask_size::computed_value::T, longhands::mask_size::computed_value::T),
            
            /// mask-composite
            MaskComposite(longhands::mask_composite::computed_value::T, longhands::mask_composite::computed_value::T),
            
            /// mask-image
            MaskImage(longhands::mask_image::computed_value::T, longhands::mask_image::computed_value::T),
            
            /// -moz-box-align
            MozBoxAlign(longhands::_moz_box_align::computed_value::T, longhands::_moz_box_align::computed_value::T),
            
            /// -moz-box-direction
            MozBoxDirection(longhands::_moz_box_direction::computed_value::T, longhands::_moz_box_direction::computed_value::T),
            
            /// -moz-box-flex
            MozBoxFlex(<longhands::_moz_box_flex::computed_value::T as ToAnimatedValue>::AnimatedValue, <longhands::_moz_box_flex::computed_value::T as ToAnimatedValue>::AnimatedValue),
            
            /// -moz-box-orient
            MozBoxOrient(longhands::_moz_box_orient::computed_value::T, longhands::_moz_box_orient::computed_value::T),
            
            /// -moz-box-pack
            MozBoxPack(longhands::_moz_box_pack::computed_value::T, longhands::_moz_box_pack::computed_value::T),
            
            /// -moz-stack-sizing
            MozStackSizing(longhands::_moz_stack_sizing::computed_value::T, longhands::_moz_stack_sizing::computed_value::T),
            
            /// -moz-box-ordinal-group
            MozBoxOrdinalGroup(longhands::_moz_box_ordinal_group::computed_value::T, longhands::_moz_box_ordinal_group::computed_value::T),
}

#[cfg(feature = "servo")]
impl AnimatedProperty {
    /// Get the name of this property.
    pub fn name(&self) -> &'static str {
        match *self {
                    AnimatedProperty::BackgroundColor(..) => "background-color",
                    AnimatedProperty::BackgroundImage(..) => "background-image",
                    AnimatedProperty::BackgroundPositionX(..) => "background-position-x",
                    AnimatedProperty::BackgroundPositionY(..) => "background-position-y",
                    AnimatedProperty::BackgroundRepeat(..) => "background-repeat",
                    AnimatedProperty::BackgroundAttachment(..) => "background-attachment",
                    AnimatedProperty::BackgroundClip(..) => "background-clip",
                    AnimatedProperty::BackgroundOrigin(..) => "background-origin",
                    AnimatedProperty::BackgroundSize(..) => "background-size",
                    AnimatedProperty::BackgroundBlendMode(..) => "background-blend-mode",
                    AnimatedProperty::BorderTopColor(..) => "border-top-color",
                    AnimatedProperty::BorderTopStyle(..) => "border-top-style",
                    AnimatedProperty::BorderTopWidth(..) => "border-top-width",
                    AnimatedProperty::BorderLeftColor(..) => "border-left-color",
                    AnimatedProperty::BorderLeftStyle(..) => "border-left-style",
                    AnimatedProperty::BorderLeftWidth(..) => "border-left-width",
                    AnimatedProperty::BorderBottomColor(..) => "border-bottom-color",
                    AnimatedProperty::BorderBottomStyle(..) => "border-bottom-style",
                    AnimatedProperty::BorderBottomWidth(..) => "border-bottom-width",
                    AnimatedProperty::BorderRightColor(..) => "border-right-color",
                    AnimatedProperty::BorderRightStyle(..) => "border-right-style",
                    AnimatedProperty::BorderRightWidth(..) => "border-right-width",
                    AnimatedProperty::BorderTopLeftRadius(..) => "border-top-left-radius",
                    AnimatedProperty::BorderTopRightRadius(..) => "border-top-right-radius",
                    AnimatedProperty::BorderBottomRightRadius(..) => "border-bottom-right-radius",
                    AnimatedProperty::BorderBottomLeftRadius(..) => "border-bottom-left-radius",
                    AnimatedProperty::MozBorderTopColors(..) => "-moz-border-top-colors",
                    AnimatedProperty::MozBorderLeftColors(..) => "-moz-border-left-colors",
                    AnimatedProperty::MozBorderBottomColors(..) => "-moz-border-bottom-colors",
                    AnimatedProperty::MozBorderRightColors(..) => "-moz-border-right-colors",
                    AnimatedProperty::BoxDecorationBreak(..) => "box-decoration-break",
                    AnimatedProperty::MozFloatEdge(..) => "-moz-float-edge",
                    AnimatedProperty::BorderImageSource(..) => "border-image-source",
                    AnimatedProperty::BorderImageOutset(..) => "border-image-outset",
                    AnimatedProperty::BorderImageRepeat(..) => "border-image-repeat",
                    AnimatedProperty::BorderImageWidth(..) => "border-image-width",
                    AnimatedProperty::BorderImageSlice(..) => "border-image-slice",
                    AnimatedProperty::Display(..) => "display",
                    AnimatedProperty::Position(..) => "position",
                    AnimatedProperty::Float(..) => "float",
                    AnimatedProperty::Clear(..) => "clear",
                    AnimatedProperty::VerticalAlign(..) => "vertical-align",
                    AnimatedProperty::OverflowClipBoxInline(..) => "overflow-clip-box-inline",
                    AnimatedProperty::OverflowClipBoxBlock(..) => "overflow-clip-box-block",
                    AnimatedProperty::OverflowX(..) => "overflow-x",
                    AnimatedProperty::OverflowY(..) => "overflow-y",
                    AnimatedProperty::ScrollSnapPointsX(..) => "scroll-snap-points-x",
                    AnimatedProperty::ScrollSnapPointsY(..) => "scroll-snap-points-y",
                    AnimatedProperty::ScrollSnapDestination(..) => "scroll-snap-destination",
                    AnimatedProperty::ScrollSnapCoordinate(..) => "scroll-snap-coordinate",
                    AnimatedProperty::Transform(..) => "transform",
                    AnimatedProperty::ScrollBehavior(..) => "scroll-behavior",
                    AnimatedProperty::ScrollSnapTypeX(..) => "scroll-snap-type-x",
                    AnimatedProperty::ScrollSnapTypeY(..) => "scroll-snap-type-y",
                    AnimatedProperty::OverscrollBehaviorX(..) => "overscroll-behavior-x",
                    AnimatedProperty::OverscrollBehaviorY(..) => "overscroll-behavior-y",
                    AnimatedProperty::Isolation(..) => "isolation",
                    AnimatedProperty::PageBreakAfter(..) => "page-break-after",
                    AnimatedProperty::PageBreakBefore(..) => "page-break-before",
                    AnimatedProperty::PageBreakInside(..) => "page-break-inside",
                    AnimatedProperty::Resize(..) => "resize",
                    AnimatedProperty::Perspective(..) => "perspective",
                    AnimatedProperty::PerspectiveOrigin(..) => "perspective-origin",
                    AnimatedProperty::BackfaceVisibility(..) => "backface-visibility",
                    AnimatedProperty::TransformBox(..) => "transform-box",
                    AnimatedProperty::TransformStyle(..) => "transform-style",
                    AnimatedProperty::TransformOrigin(..) => "transform-origin",
                    AnimatedProperty::Contain(..) => "contain",
                    AnimatedProperty::MozAppearance(..) => "-moz-appearance",
                    AnimatedProperty::MozOrient(..) => "-moz-orient",
                    AnimatedProperty::WillChange(..) => "will-change",
                    AnimatedProperty::ShapeImageThreshold(..) => "shape-image-threshold",
                    AnimatedProperty::ShapeOutside(..) => "shape-outside",
                    AnimatedProperty::TouchAction(..) => "touch-action",
                    AnimatedProperty::Color(..) => "color",
                    AnimatedProperty::ColumnWidth(..) => "column-width",
                    AnimatedProperty::ColumnCount(..) => "column-count",
                    AnimatedProperty::ColumnGap(..) => "column-gap",
                    AnimatedProperty::ColumnFill(..) => "column-fill",
                    AnimatedProperty::ColumnRuleWidth(..) => "column-rule-width",
                    AnimatedProperty::ColumnRuleColor(..) => "column-rule-color",
                    AnimatedProperty::ColumnSpan(..) => "column-span",
                    AnimatedProperty::ColumnRuleStyle(..) => "column-rule-style",
                    AnimatedProperty::Content(..) => "content",
                    AnimatedProperty::CounterIncrement(..) => "counter-increment",
                    AnimatedProperty::CounterReset(..) => "counter-reset",
                    AnimatedProperty::Opacity(..) => "opacity",
                    AnimatedProperty::BoxShadow(..) => "box-shadow",
                    AnimatedProperty::Clip(..) => "clip",
                    AnimatedProperty::Filter(..) => "filter",
                    AnimatedProperty::MixBlendMode(..) => "mix-blend-mode",
                    AnimatedProperty::FontFamily(..) => "font-family",
                    AnimatedProperty::FontStyle(..) => "font-style",
                    AnimatedProperty::FontVariantCaps(..) => "font-variant-caps",
                    AnimatedProperty::FontWeight(..) => "font-weight",
                    AnimatedProperty::FontSize(..) => "font-size",
                    AnimatedProperty::FontSizeAdjust(..) => "font-size-adjust",
                    AnimatedProperty::FontSynthesis(..) => "font-synthesis",
                    AnimatedProperty::FontStretch(..) => "font-stretch",
                    AnimatedProperty::FontKerning(..) => "font-kerning",
                    AnimatedProperty::FontVariantAlternates(..) => "font-variant-alternates",
                    AnimatedProperty::FontVariantEastAsian(..) => "font-variant-east-asian",
                    AnimatedProperty::FontVariantLigatures(..) => "font-variant-ligatures",
                    AnimatedProperty::FontVariantNumeric(..) => "font-variant-numeric",
                    AnimatedProperty::FontVariantPosition(..) => "font-variant-position",
                    AnimatedProperty::FontFeatureSettings(..) => "font-feature-settings",
                    AnimatedProperty::FontVariationSettings(..) => "font-variation-settings",
                    AnimatedProperty::FontLanguageOverride(..) => "font-language-override",
                    AnimatedProperty::MozOsxFontSmoothing(..) => "-moz-osx-font-smoothing",
                    AnimatedProperty::MozFontSmoothingBackgroundColor(..) => "-moz-font-smoothing-background-color",
                    AnimatedProperty::Visibility(..) => "visibility",
                    AnimatedProperty::WritingMode(..) => "writing-mode",
                    AnimatedProperty::Direction(..) => "direction",
                    AnimatedProperty::TextOrientation(..) => "text-orientation",
                    AnimatedProperty::ColorAdjust(..) => "color-adjust",
                    AnimatedProperty::ImageRendering(..) => "image-rendering",
                    AnimatedProperty::ImageOrientation(..) => "image-orientation",
                    AnimatedProperty::BorderCollapse(..) => "border-collapse",
                    AnimatedProperty::EmptyCells(..) => "empty-cells",
                    AnimatedProperty::CaptionSide(..) => "caption-side",
                    AnimatedProperty::BorderSpacing(..) => "border-spacing",
                    AnimatedProperty::LineHeight(..) => "line-height",
                    AnimatedProperty::TextTransform(..) => "text-transform",
                    AnimatedProperty::Hyphens(..) => "hyphens",
                    AnimatedProperty::MozTextSizeAdjust(..) => "-moz-text-size-adjust",
                    AnimatedProperty::TextIndent(..) => "text-indent",
                    AnimatedProperty::OverflowWrap(..) => "overflow-wrap",
                    AnimatedProperty::WordBreak(..) => "word-break",
                    AnimatedProperty::TextJustify(..) => "text-justify",
                    AnimatedProperty::TextAlignLast(..) => "text-align-last",
                    AnimatedProperty::TextAlign(..) => "text-align",
                    AnimatedProperty::LetterSpacing(..) => "letter-spacing",
                    AnimatedProperty::WordSpacing(..) => "word-spacing",
                    AnimatedProperty::WhiteSpace(..) => "white-space",
                    AnimatedProperty::TextShadow(..) => "text-shadow",
                    AnimatedProperty::TextEmphasisStyle(..) => "text-emphasis-style",
                    AnimatedProperty::TextEmphasisPosition(..) => "text-emphasis-position",
                    AnimatedProperty::TextEmphasisColor(..) => "text-emphasis-color",
                    AnimatedProperty::MozTabSize(..) => "-moz-tab-size",
                    AnimatedProperty::WebkitTextFillColor(..) => "-webkit-text-fill-color",
                    AnimatedProperty::WebkitTextStrokeColor(..) => "-webkit-text-stroke-color",
                    AnimatedProperty::WebkitTextStrokeWidth(..) => "-webkit-text-stroke-width",
                    AnimatedProperty::RubyAlign(..) => "ruby-align",
                    AnimatedProperty::RubyPosition(..) => "ruby-position",
                    AnimatedProperty::TextCombineUpright(..) => "text-combine-upright",
                    AnimatedProperty::TextRendering(..) => "text-rendering",
                    AnimatedProperty::ListStylePosition(..) => "list-style-position",
                    AnimatedProperty::ListStyleType(..) => "list-style-type",
                    AnimatedProperty::ListStyleImage(..) => "list-style-image",
                    AnimatedProperty::Quotes(..) => "quotes",
                    AnimatedProperty::MozImageRegion(..) => "-moz-image-region",
                    AnimatedProperty::MarginTop(..) => "margin-top",
                    AnimatedProperty::MarginLeft(..) => "margin-left",
                    AnimatedProperty::MarginBottom(..) => "margin-bottom",
                    AnimatedProperty::MarginRight(..) => "margin-right",
                    AnimatedProperty::OutlineColor(..) => "outline-color",
                    AnimatedProperty::OutlineStyle(..) => "outline-style",
                    AnimatedProperty::OutlineWidth(..) => "outline-width",
                    AnimatedProperty::MozOutlineRadiusTopleft(..) => "-moz-outline-radius-topleft",
                    AnimatedProperty::MozOutlineRadiusTopright(..) => "-moz-outline-radius-topright",
                    AnimatedProperty::MozOutlineRadiusBottomright(..) => "-moz-outline-radius-bottomright",
                    AnimatedProperty::MozOutlineRadiusBottomleft(..) => "-moz-outline-radius-bottomleft",
                    AnimatedProperty::OutlineOffset(..) => "outline-offset",
                    AnimatedProperty::PaddingTop(..) => "padding-top",
                    AnimatedProperty::PaddingLeft(..) => "padding-left",
                    AnimatedProperty::PaddingBottom(..) => "padding-bottom",
                    AnimatedProperty::PaddingRight(..) => "padding-right",
                    AnimatedProperty::Cursor(..) => "cursor",
                    AnimatedProperty::PointerEvents(..) => "pointer-events",
                    AnimatedProperty::MozUserInput(..) => "-moz-user-input",
                    AnimatedProperty::MozUserModify(..) => "-moz-user-modify",
                    AnimatedProperty::MozUserFocus(..) => "-moz-user-focus",
                    AnimatedProperty::CaretColor(..) => "caret-color",
                    AnimatedProperty::Top(..) => "top",
                    AnimatedProperty::Left(..) => "left",
                    AnimatedProperty::Bottom(..) => "bottom",
                    AnimatedProperty::Right(..) => "right",
                    AnimatedProperty::ZIndex(..) => "z-index",
                    AnimatedProperty::FlexDirection(..) => "flex-direction",
                    AnimatedProperty::FlexWrap(..) => "flex-wrap",
                    AnimatedProperty::JustifyContent(..) => "justify-content",
                    AnimatedProperty::AlignContent(..) => "align-content",
                    AnimatedProperty::AlignItems(..) => "align-items",
                    AnimatedProperty::JustifyItems(..) => "justify-items",
                    AnimatedProperty::FlexGrow(..) => "flex-grow",
                    AnimatedProperty::FlexShrink(..) => "flex-shrink",
                    AnimatedProperty::AlignSelf(..) => "align-self",
                    AnimatedProperty::JustifySelf(..) => "justify-self",
                    AnimatedProperty::Order(..) => "order",
                    AnimatedProperty::FlexBasis(..) => "flex-basis",
                    AnimatedProperty::Width(..) => "width",
                    AnimatedProperty::MinWidth(..) => "min-width",
                    AnimatedProperty::MaxWidth(..) => "max-width",
                    AnimatedProperty::Height(..) => "height",
                    AnimatedProperty::MinHeight(..) => "min-height",
                    AnimatedProperty::MaxHeight(..) => "max-height",
                    AnimatedProperty::BoxSizing(..) => "box-sizing",
                    AnimatedProperty::ObjectFit(..) => "object-fit",
                    AnimatedProperty::ObjectPosition(..) => "object-position",
                    AnimatedProperty::GridRowGap(..) => "grid-row-gap",
                    AnimatedProperty::GridRowStart(..) => "grid-row-start",
                    AnimatedProperty::GridRowEnd(..) => "grid-row-end",
                    AnimatedProperty::GridAutoRows(..) => "grid-auto-rows",
                    AnimatedProperty::GridTemplateRows(..) => "grid-template-rows",
                    AnimatedProperty::GridColumnGap(..) => "grid-column-gap",
                    AnimatedProperty::GridColumnStart(..) => "grid-column-start",
                    AnimatedProperty::GridColumnEnd(..) => "grid-column-end",
                    AnimatedProperty::GridAutoColumns(..) => "grid-auto-columns",
                    AnimatedProperty::GridTemplateColumns(..) => "grid-template-columns",
                    AnimatedProperty::GridAutoFlow(..) => "grid-auto-flow",
                    AnimatedProperty::GridTemplateAreas(..) => "grid-template-areas",
                    AnimatedProperty::TableLayout(..) => "table-layout",
                    AnimatedProperty::TextOverflow(..) => "text-overflow",
                    AnimatedProperty::UnicodeBidi(..) => "unicode-bidi",
                    AnimatedProperty::TextDecorationLine(..) => "text-decoration-line",
                    AnimatedProperty::TextDecorationStyle(..) => "text-decoration-style",
                    AnimatedProperty::TextDecorationColor(..) => "text-decoration-color",
                    AnimatedProperty::InitialLetter(..) => "initial-letter",
                    AnimatedProperty::ImeMode(..) => "ime-mode",
                    AnimatedProperty::MozUserSelect(..) => "-moz-user-select",
                    AnimatedProperty::MozWindowDragging(..) => "-moz-window-dragging",
                    AnimatedProperty::MozWindowShadow(..) => "-moz-window-shadow",
                    AnimatedProperty::MozWindowOpacity(..) => "-moz-window-opacity",
                    AnimatedProperty::MozWindowTransform(..) => "-moz-window-transform",
                    AnimatedProperty::MozWindowTransformOrigin(..) => "-moz-window-transform-origin",
                    AnimatedProperty::MozForceBrokenImageIcon(..) => "-moz-force-broken-image-icon",
                    AnimatedProperty::TextAnchor(..) => "text-anchor",
                    AnimatedProperty::ColorInterpolation(..) => "color-interpolation",
                    AnimatedProperty::ColorInterpolationFilters(..) => "color-interpolation-filters",
                    AnimatedProperty::Fill(..) => "fill",
                    AnimatedProperty::FillOpacity(..) => "fill-opacity",
                    AnimatedProperty::FillRule(..) => "fill-rule",
                    AnimatedProperty::ShapeRendering(..) => "shape-rendering",
                    AnimatedProperty::Stroke(..) => "stroke",
                    AnimatedProperty::StrokeWidth(..) => "stroke-width",
                    AnimatedProperty::StrokeLinecap(..) => "stroke-linecap",
                    AnimatedProperty::StrokeLinejoin(..) => "stroke-linejoin",
                    AnimatedProperty::StrokeMiterlimit(..) => "stroke-miterlimit",
                    AnimatedProperty::StrokeOpacity(..) => "stroke-opacity",
                    AnimatedProperty::StrokeDasharray(..) => "stroke-dasharray",
                    AnimatedProperty::StrokeDashoffset(..) => "stroke-dashoffset",
                    AnimatedProperty::ClipRule(..) => "clip-rule",
                    AnimatedProperty::MarkerStart(..) => "marker-start",
                    AnimatedProperty::MarkerMid(..) => "marker-mid",
                    AnimatedProperty::MarkerEnd(..) => "marker-end",
                    AnimatedProperty::PaintOrder(..) => "paint-order",
                    AnimatedProperty::DominantBaseline(..) => "dominant-baseline",
                    AnimatedProperty::VectorEffect(..) => "vector-effect",
                    AnimatedProperty::StopColor(..) => "stop-color",
                    AnimatedProperty::StopOpacity(..) => "stop-opacity",
                    AnimatedProperty::FloodColor(..) => "flood-color",
                    AnimatedProperty::FloodOpacity(..) => "flood-opacity",
                    AnimatedProperty::LightingColor(..) => "lighting-color",
                    AnimatedProperty::MaskType(..) => "mask-type",
                    AnimatedProperty::ClipPath(..) => "clip-path",
                    AnimatedProperty::MaskMode(..) => "mask-mode",
                    AnimatedProperty::MaskRepeat(..) => "mask-repeat",
                    AnimatedProperty::MaskPositionX(..) => "mask-position-x",
                    AnimatedProperty::MaskPositionY(..) => "mask-position-y",
                    AnimatedProperty::MaskClip(..) => "mask-clip",
                    AnimatedProperty::MaskOrigin(..) => "mask-origin",
                    AnimatedProperty::MaskSize(..) => "mask-size",
                    AnimatedProperty::MaskComposite(..) => "mask-composite",
                    AnimatedProperty::MaskImage(..) => "mask-image",
                    AnimatedProperty::MozBoxAlign(..) => "-moz-box-align",
                    AnimatedProperty::MozBoxDirection(..) => "-moz-box-direction",
                    AnimatedProperty::MozBoxFlex(..) => "-moz-box-flex",
                    AnimatedProperty::MozBoxOrient(..) => "-moz-box-orient",
                    AnimatedProperty::MozBoxPack(..) => "-moz-box-pack",
                    AnimatedProperty::MozStackSizing(..) => "-moz-stack-sizing",
                    AnimatedProperty::MozBoxOrdinalGroup(..) => "-moz-box-ordinal-group",
        }
    }

    /// Whether this interpolation does animate, that is, whether the start and
    /// end values are different.
    pub fn does_animate(&self) -> bool {
        match *self {
                    AnimatedProperty::BackgroundColor(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundImage(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundPositionX(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundPositionY(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundAttachment(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundClip(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundSize(ref from, ref to) => from != to,
                    AnimatedProperty::BackgroundBlendMode(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderLeftWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightColor(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightStyle(ref from, ref to) => from != to,
                    AnimatedProperty::BorderRightWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopLeftRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderTopRightRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomRightRadius(ref from, ref to) => from != to,
                    AnimatedProperty::BorderBottomLeftRadius(ref from, ref to) => from != to,
                    AnimatedProperty::MozBorderTopColors(ref from, ref to) => from != to,
                    AnimatedProperty::MozBorderLeftColors(ref from, ref to) => from != to,
                    AnimatedProperty::MozBorderBottomColors(ref from, ref to) => from != to,
                    AnimatedProperty::MozBorderRightColors(ref from, ref to) => from != to,
                    AnimatedProperty::BoxDecorationBreak(ref from, ref to) => from != to,
                    AnimatedProperty::MozFloatEdge(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageSource(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageOutset(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageWidth(ref from, ref to) => from != to,
                    AnimatedProperty::BorderImageSlice(ref from, ref to) => from != to,
                    AnimatedProperty::Display(ref from, ref to) => from != to,
                    AnimatedProperty::Position(ref from, ref to) => from != to,
                    AnimatedProperty::Float(ref from, ref to) => from != to,
                    AnimatedProperty::Clear(ref from, ref to) => from != to,
                    AnimatedProperty::VerticalAlign(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowClipBoxInline(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowClipBoxBlock(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowX(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowY(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapPointsX(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapPointsY(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapDestination(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapCoordinate(ref from, ref to) => from != to,
                    AnimatedProperty::Transform(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollBehavior(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapTypeX(ref from, ref to) => from != to,
                    AnimatedProperty::ScrollSnapTypeY(ref from, ref to) => from != to,
                    AnimatedProperty::OverscrollBehaviorX(ref from, ref to) => from != to,
                    AnimatedProperty::OverscrollBehaviorY(ref from, ref to) => from != to,
                    AnimatedProperty::Isolation(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakAfter(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakBefore(ref from, ref to) => from != to,
                    AnimatedProperty::PageBreakInside(ref from, ref to) => from != to,
                    AnimatedProperty::Resize(ref from, ref to) => from != to,
                    AnimatedProperty::Perspective(ref from, ref to) => from != to,
                    AnimatedProperty::PerspectiveOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::BackfaceVisibility(ref from, ref to) => from != to,
                    AnimatedProperty::TransformBox(ref from, ref to) => from != to,
                    AnimatedProperty::TransformStyle(ref from, ref to) => from != to,
                    AnimatedProperty::TransformOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::Contain(ref from, ref to) => from != to,
                    AnimatedProperty::MozAppearance(ref from, ref to) => from != to,
                    AnimatedProperty::MozOrient(ref from, ref to) => from != to,
                    AnimatedProperty::WillChange(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeImageThreshold(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeOutside(ref from, ref to) => from != to,
                    AnimatedProperty::TouchAction(ref from, ref to) => from != to,
                    AnimatedProperty::Color(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnWidth(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnCount(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnGap(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnFill(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleWidth(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleColor(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnSpan(ref from, ref to) => from != to,
                    AnimatedProperty::ColumnRuleStyle(ref from, ref to) => from != to,
                    AnimatedProperty::Content(ref from, ref to) => from != to,
                    AnimatedProperty::CounterIncrement(ref from, ref to) => from != to,
                    AnimatedProperty::CounterReset(ref from, ref to) => from != to,
                    AnimatedProperty::Opacity(ref from, ref to) => from != to,
                    AnimatedProperty::BoxShadow(ref from, ref to) => from != to,
                    AnimatedProperty::Clip(ref from, ref to) => from != to,
                    AnimatedProperty::Filter(ref from, ref to) => from != to,
                    AnimatedProperty::MixBlendMode(ref from, ref to) => from != to,
                    AnimatedProperty::FontFamily(ref from, ref to) => from != to,
                    AnimatedProperty::FontStyle(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantCaps(ref from, ref to) => from != to,
                    AnimatedProperty::FontWeight(ref from, ref to) => from != to,
                    AnimatedProperty::FontSize(ref from, ref to) => from != to,
                    AnimatedProperty::FontSizeAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::FontSynthesis(ref from, ref to) => from != to,
                    AnimatedProperty::FontStretch(ref from, ref to) => from != to,
                    AnimatedProperty::FontKerning(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantAlternates(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantEastAsian(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantLigatures(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantNumeric(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariantPosition(ref from, ref to) => from != to,
                    AnimatedProperty::FontFeatureSettings(ref from, ref to) => from != to,
                    AnimatedProperty::FontVariationSettings(ref from, ref to) => from != to,
                    AnimatedProperty::FontLanguageOverride(ref from, ref to) => from != to,
                    AnimatedProperty::MozOsxFontSmoothing(ref from, ref to) => from != to,
                    AnimatedProperty::MozFontSmoothingBackgroundColor(ref from, ref to) => from != to,
                    AnimatedProperty::Visibility(ref from, ref to) => from != to,
                    AnimatedProperty::WritingMode(ref from, ref to) => from != to,
                    AnimatedProperty::Direction(ref from, ref to) => from != to,
                    AnimatedProperty::TextOrientation(ref from, ref to) => from != to,
                    AnimatedProperty::ColorAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::ImageRendering(ref from, ref to) => from != to,
                    AnimatedProperty::ImageOrientation(ref from, ref to) => from != to,
                    AnimatedProperty::BorderCollapse(ref from, ref to) => from != to,
                    AnimatedProperty::EmptyCells(ref from, ref to) => from != to,
                    AnimatedProperty::CaptionSide(ref from, ref to) => from != to,
                    AnimatedProperty::BorderSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::LineHeight(ref from, ref to) => from != to,
                    AnimatedProperty::TextTransform(ref from, ref to) => from != to,
                    AnimatedProperty::Hyphens(ref from, ref to) => from != to,
                    AnimatedProperty::MozTextSizeAdjust(ref from, ref to) => from != to,
                    AnimatedProperty::TextIndent(ref from, ref to) => from != to,
                    AnimatedProperty::OverflowWrap(ref from, ref to) => from != to,
                    AnimatedProperty::WordBreak(ref from, ref to) => from != to,
                    AnimatedProperty::TextJustify(ref from, ref to) => from != to,
                    AnimatedProperty::TextAlignLast(ref from, ref to) => from != to,
                    AnimatedProperty::TextAlign(ref from, ref to) => from != to,
                    AnimatedProperty::LetterSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::WordSpacing(ref from, ref to) => from != to,
                    AnimatedProperty::WhiteSpace(ref from, ref to) => from != to,
                    AnimatedProperty::TextShadow(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisStyle(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisPosition(ref from, ref to) => from != to,
                    AnimatedProperty::TextEmphasisColor(ref from, ref to) => from != to,
                    AnimatedProperty::MozTabSize(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextFillColor(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextStrokeColor(ref from, ref to) => from != to,
                    AnimatedProperty::WebkitTextStrokeWidth(ref from, ref to) => from != to,
                    AnimatedProperty::RubyAlign(ref from, ref to) => from != to,
                    AnimatedProperty::RubyPosition(ref from, ref to) => from != to,
                    AnimatedProperty::TextCombineUpright(ref from, ref to) => from != to,
                    AnimatedProperty::TextRendering(ref from, ref to) => from != to,
                    AnimatedProperty::ListStylePosition(ref from, ref to) => from != to,
                    AnimatedProperty::ListStyleType(ref from, ref to) => from != to,
                    AnimatedProperty::ListStyleImage(ref from, ref to) => from != to,
                    AnimatedProperty::Quotes(ref from, ref to) => from != to,
                    AnimatedProperty::MozImageRegion(ref from, ref to) => from != to,
                    AnimatedProperty::MarginTop(ref from, ref to) => from != to,
                    AnimatedProperty::MarginLeft(ref from, ref to) => from != to,
                    AnimatedProperty::MarginBottom(ref from, ref to) => from != to,
                    AnimatedProperty::MarginRight(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineColor(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineStyle(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineWidth(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusTopleft(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusTopright(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusBottomright(ref from, ref to) => from != to,
                    AnimatedProperty::MozOutlineRadiusBottomleft(ref from, ref to) => from != to,
                    AnimatedProperty::OutlineOffset(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingTop(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingLeft(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingBottom(ref from, ref to) => from != to,
                    AnimatedProperty::PaddingRight(ref from, ref to) => from != to,
                    AnimatedProperty::Cursor(ref from, ref to) => from != to,
                    AnimatedProperty::PointerEvents(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserInput(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserModify(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserFocus(ref from, ref to) => from != to,
                    AnimatedProperty::CaretColor(ref from, ref to) => from != to,
                    AnimatedProperty::Top(ref from, ref to) => from != to,
                    AnimatedProperty::Left(ref from, ref to) => from != to,
                    AnimatedProperty::Bottom(ref from, ref to) => from != to,
                    AnimatedProperty::Right(ref from, ref to) => from != to,
                    AnimatedProperty::ZIndex(ref from, ref to) => from != to,
                    AnimatedProperty::FlexDirection(ref from, ref to) => from != to,
                    AnimatedProperty::FlexWrap(ref from, ref to) => from != to,
                    AnimatedProperty::JustifyContent(ref from, ref to) => from != to,
                    AnimatedProperty::AlignContent(ref from, ref to) => from != to,
                    AnimatedProperty::AlignItems(ref from, ref to) => from != to,
                    AnimatedProperty::JustifyItems(ref from, ref to) => from != to,
                    AnimatedProperty::FlexGrow(ref from, ref to) => from != to,
                    AnimatedProperty::FlexShrink(ref from, ref to) => from != to,
                    AnimatedProperty::AlignSelf(ref from, ref to) => from != to,
                    AnimatedProperty::JustifySelf(ref from, ref to) => from != to,
                    AnimatedProperty::Order(ref from, ref to) => from != to,
                    AnimatedProperty::FlexBasis(ref from, ref to) => from != to,
                    AnimatedProperty::Width(ref from, ref to) => from != to,
                    AnimatedProperty::MinWidth(ref from, ref to) => from != to,
                    AnimatedProperty::MaxWidth(ref from, ref to) => from != to,
                    AnimatedProperty::Height(ref from, ref to) => from != to,
                    AnimatedProperty::MinHeight(ref from, ref to) => from != to,
                    AnimatedProperty::MaxHeight(ref from, ref to) => from != to,
                    AnimatedProperty::BoxSizing(ref from, ref to) => from != to,
                    AnimatedProperty::ObjectFit(ref from, ref to) => from != to,
                    AnimatedProperty::ObjectPosition(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowGap(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowStart(ref from, ref to) => from != to,
                    AnimatedProperty::GridRowEnd(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoRows(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateRows(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnGap(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnStart(ref from, ref to) => from != to,
                    AnimatedProperty::GridColumnEnd(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoColumns(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateColumns(ref from, ref to) => from != to,
                    AnimatedProperty::GridAutoFlow(ref from, ref to) => from != to,
                    AnimatedProperty::GridTemplateAreas(ref from, ref to) => from != to,
                    AnimatedProperty::TableLayout(ref from, ref to) => from != to,
                    AnimatedProperty::TextOverflow(ref from, ref to) => from != to,
                    AnimatedProperty::UnicodeBidi(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationLine(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationStyle(ref from, ref to) => from != to,
                    AnimatedProperty::TextDecorationColor(ref from, ref to) => from != to,
                    AnimatedProperty::InitialLetter(ref from, ref to) => from != to,
                    AnimatedProperty::ImeMode(ref from, ref to) => from != to,
                    AnimatedProperty::MozUserSelect(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowDragging(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowShadow(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowTransform(ref from, ref to) => from != to,
                    AnimatedProperty::MozWindowTransformOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::MozForceBrokenImageIcon(ref from, ref to) => from != to,
                    AnimatedProperty::TextAnchor(ref from, ref to) => from != to,
                    AnimatedProperty::ColorInterpolation(ref from, ref to) => from != to,
                    AnimatedProperty::ColorInterpolationFilters(ref from, ref to) => from != to,
                    AnimatedProperty::Fill(ref from, ref to) => from != to,
                    AnimatedProperty::FillOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::FillRule(ref from, ref to) => from != to,
                    AnimatedProperty::ShapeRendering(ref from, ref to) => from != to,
                    AnimatedProperty::Stroke(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeWidth(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeLinecap(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeLinejoin(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeMiterlimit(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeDasharray(ref from, ref to) => from != to,
                    AnimatedProperty::StrokeDashoffset(ref from, ref to) => from != to,
                    AnimatedProperty::ClipRule(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerStart(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerMid(ref from, ref to) => from != to,
                    AnimatedProperty::MarkerEnd(ref from, ref to) => from != to,
                    AnimatedProperty::PaintOrder(ref from, ref to) => from != to,
                    AnimatedProperty::DominantBaseline(ref from, ref to) => from != to,
                    AnimatedProperty::VectorEffect(ref from, ref to) => from != to,
                    AnimatedProperty::StopColor(ref from, ref to) => from != to,
                    AnimatedProperty::StopOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::FloodColor(ref from, ref to) => from != to,
                    AnimatedProperty::FloodOpacity(ref from, ref to) => from != to,
                    AnimatedProperty::LightingColor(ref from, ref to) => from != to,
                    AnimatedProperty::MaskType(ref from, ref to) => from != to,
                    AnimatedProperty::ClipPath(ref from, ref to) => from != to,
                    AnimatedProperty::MaskMode(ref from, ref to) => from != to,
                    AnimatedProperty::MaskRepeat(ref from, ref to) => from != to,
                    AnimatedProperty::MaskPositionX(ref from, ref to) => from != to,
                    AnimatedProperty::MaskPositionY(ref from, ref to) => from != to,
                    AnimatedProperty::MaskClip(ref from, ref to) => from != to,
                    AnimatedProperty::MaskOrigin(ref from, ref to) => from != to,
                    AnimatedProperty::MaskSize(ref from, ref to) => from != to,
                    AnimatedProperty::MaskComposite(ref from, ref to) => from != to,
                    AnimatedProperty::MaskImage(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxAlign(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxDirection(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxFlex(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxOrient(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxPack(ref from, ref to) => from != to,
                    AnimatedProperty::MozStackSizing(ref from, ref to) => from != to,
                    AnimatedProperty::MozBoxOrdinalGroup(ref from, ref to) => from != to,
        }
    }

    /// Whether an animated property has the same end value as another.
    pub fn has_the_same_end_value_as(&self, other: &Self) -> bool {
        match (self, other) {
                    (&AnimatedProperty::BackgroundColor(_, ref this_end_value),
                     &AnimatedProperty::BackgroundColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundImage(_, ref this_end_value),
                     &AnimatedProperty::BackgroundImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundPositionX(_, ref this_end_value),
                     &AnimatedProperty::BackgroundPositionX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundPositionY(_, ref this_end_value),
                     &AnimatedProperty::BackgroundPositionY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundRepeat(_, ref this_end_value),
                     &AnimatedProperty::BackgroundRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundAttachment(_, ref this_end_value),
                     &AnimatedProperty::BackgroundAttachment(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundClip(_, ref this_end_value),
                     &AnimatedProperty::BackgroundClip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundOrigin(_, ref this_end_value),
                     &AnimatedProperty::BackgroundOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundSize(_, ref this_end_value),
                     &AnimatedProperty::BackgroundSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackgroundBlendMode(_, ref this_end_value),
                     &AnimatedProperty::BackgroundBlendMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopColor(_, ref this_end_value),
                     &AnimatedProperty::BorderTopColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderTopStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderTopWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftColor(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderLeftWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderLeftWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomColor(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightColor(_, ref this_end_value),
                     &AnimatedProperty::BorderRightColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightStyle(_, ref this_end_value),
                     &AnimatedProperty::BorderRightStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderRightWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderRightWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopLeftRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderTopLeftRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderTopRightRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderTopRightRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomRightRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomRightRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderBottomLeftRadius(_, ref this_end_value),
                     &AnimatedProperty::BorderBottomLeftRadius(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBorderTopColors(_, ref this_end_value),
                     &AnimatedProperty::MozBorderTopColors(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBorderLeftColors(_, ref this_end_value),
                     &AnimatedProperty::MozBorderLeftColors(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBorderBottomColors(_, ref this_end_value),
                     &AnimatedProperty::MozBorderBottomColors(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBorderRightColors(_, ref this_end_value),
                     &AnimatedProperty::MozBorderRightColors(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxDecorationBreak(_, ref this_end_value),
                     &AnimatedProperty::BoxDecorationBreak(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozFloatEdge(_, ref this_end_value),
                     &AnimatedProperty::MozFloatEdge(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageSource(_, ref this_end_value),
                     &AnimatedProperty::BorderImageSource(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageOutset(_, ref this_end_value),
                     &AnimatedProperty::BorderImageOutset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageRepeat(_, ref this_end_value),
                     &AnimatedProperty::BorderImageRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageWidth(_, ref this_end_value),
                     &AnimatedProperty::BorderImageWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderImageSlice(_, ref this_end_value),
                     &AnimatedProperty::BorderImageSlice(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Display(_, ref this_end_value),
                     &AnimatedProperty::Display(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Position(_, ref this_end_value),
                     &AnimatedProperty::Position(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Float(_, ref this_end_value),
                     &AnimatedProperty::Float(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Clear(_, ref this_end_value),
                     &AnimatedProperty::Clear(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::VerticalAlign(_, ref this_end_value),
                     &AnimatedProperty::VerticalAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowClipBoxInline(_, ref this_end_value),
                     &AnimatedProperty::OverflowClipBoxInline(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowClipBoxBlock(_, ref this_end_value),
                     &AnimatedProperty::OverflowClipBoxBlock(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowX(_, ref this_end_value),
                     &AnimatedProperty::OverflowX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowY(_, ref this_end_value),
                     &AnimatedProperty::OverflowY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapPointsX(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapPointsX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapPointsY(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapPointsY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapDestination(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapDestination(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapCoordinate(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapCoordinate(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Transform(_, ref this_end_value),
                     &AnimatedProperty::Transform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollBehavior(_, ref this_end_value),
                     &AnimatedProperty::ScrollBehavior(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapTypeX(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapTypeX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ScrollSnapTypeY(_, ref this_end_value),
                     &AnimatedProperty::ScrollSnapTypeY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverscrollBehaviorX(_, ref this_end_value),
                     &AnimatedProperty::OverscrollBehaviorX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverscrollBehaviorY(_, ref this_end_value),
                     &AnimatedProperty::OverscrollBehaviorY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Isolation(_, ref this_end_value),
                     &AnimatedProperty::Isolation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakAfter(_, ref this_end_value),
                     &AnimatedProperty::PageBreakAfter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakBefore(_, ref this_end_value),
                     &AnimatedProperty::PageBreakBefore(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PageBreakInside(_, ref this_end_value),
                     &AnimatedProperty::PageBreakInside(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Resize(_, ref this_end_value),
                     &AnimatedProperty::Resize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Perspective(_, ref this_end_value),
                     &AnimatedProperty::Perspective(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PerspectiveOrigin(_, ref this_end_value),
                     &AnimatedProperty::PerspectiveOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BackfaceVisibility(_, ref this_end_value),
                     &AnimatedProperty::BackfaceVisibility(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformBox(_, ref this_end_value),
                     &AnimatedProperty::TransformBox(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformStyle(_, ref this_end_value),
                     &AnimatedProperty::TransformStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TransformOrigin(_, ref this_end_value),
                     &AnimatedProperty::TransformOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Contain(_, ref this_end_value),
                     &AnimatedProperty::Contain(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozAppearance(_, ref this_end_value),
                     &AnimatedProperty::MozAppearance(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOrient(_, ref this_end_value),
                     &AnimatedProperty::MozOrient(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WillChange(_, ref this_end_value),
                     &AnimatedProperty::WillChange(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeImageThreshold(_, ref this_end_value),
                     &AnimatedProperty::ShapeImageThreshold(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeOutside(_, ref this_end_value),
                     &AnimatedProperty::ShapeOutside(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TouchAction(_, ref this_end_value),
                     &AnimatedProperty::TouchAction(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Color(_, ref this_end_value),
                     &AnimatedProperty::Color(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnWidth(_, ref this_end_value),
                     &AnimatedProperty::ColumnWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnCount(_, ref this_end_value),
                     &AnimatedProperty::ColumnCount(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnGap(_, ref this_end_value),
                     &AnimatedProperty::ColumnGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnFill(_, ref this_end_value),
                     &AnimatedProperty::ColumnFill(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleWidth(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleColor(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnSpan(_, ref this_end_value),
                     &AnimatedProperty::ColumnSpan(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColumnRuleStyle(_, ref this_end_value),
                     &AnimatedProperty::ColumnRuleStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Content(_, ref this_end_value),
                     &AnimatedProperty::Content(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CounterIncrement(_, ref this_end_value),
                     &AnimatedProperty::CounterIncrement(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CounterReset(_, ref this_end_value),
                     &AnimatedProperty::CounterReset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Opacity(_, ref this_end_value),
                     &AnimatedProperty::Opacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxShadow(_, ref this_end_value),
                     &AnimatedProperty::BoxShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Clip(_, ref this_end_value),
                     &AnimatedProperty::Clip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Filter(_, ref this_end_value),
                     &AnimatedProperty::Filter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MixBlendMode(_, ref this_end_value),
                     &AnimatedProperty::MixBlendMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontFamily(_, ref this_end_value),
                     &AnimatedProperty::FontFamily(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontStyle(_, ref this_end_value),
                     &AnimatedProperty::FontStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantCaps(_, ref this_end_value),
                     &AnimatedProperty::FontVariantCaps(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontWeight(_, ref this_end_value),
                     &AnimatedProperty::FontWeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSize(_, ref this_end_value),
                     &AnimatedProperty::FontSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSizeAdjust(_, ref this_end_value),
                     &AnimatedProperty::FontSizeAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontSynthesis(_, ref this_end_value),
                     &AnimatedProperty::FontSynthesis(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontStretch(_, ref this_end_value),
                     &AnimatedProperty::FontStretch(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontKerning(_, ref this_end_value),
                     &AnimatedProperty::FontKerning(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantAlternates(_, ref this_end_value),
                     &AnimatedProperty::FontVariantAlternates(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantEastAsian(_, ref this_end_value),
                     &AnimatedProperty::FontVariantEastAsian(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantLigatures(_, ref this_end_value),
                     &AnimatedProperty::FontVariantLigatures(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantNumeric(_, ref this_end_value),
                     &AnimatedProperty::FontVariantNumeric(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariantPosition(_, ref this_end_value),
                     &AnimatedProperty::FontVariantPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontFeatureSettings(_, ref this_end_value),
                     &AnimatedProperty::FontFeatureSettings(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontVariationSettings(_, ref this_end_value),
                     &AnimatedProperty::FontVariationSettings(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FontLanguageOverride(_, ref this_end_value),
                     &AnimatedProperty::FontLanguageOverride(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOsxFontSmoothing(_, ref this_end_value),
                     &AnimatedProperty::MozOsxFontSmoothing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozFontSmoothingBackgroundColor(_, ref this_end_value),
                     &AnimatedProperty::MozFontSmoothingBackgroundColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Visibility(_, ref this_end_value),
                     &AnimatedProperty::Visibility(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WritingMode(_, ref this_end_value),
                     &AnimatedProperty::WritingMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Direction(_, ref this_end_value),
                     &AnimatedProperty::Direction(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextOrientation(_, ref this_end_value),
                     &AnimatedProperty::TextOrientation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorAdjust(_, ref this_end_value),
                     &AnimatedProperty::ColorAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImageRendering(_, ref this_end_value),
                     &AnimatedProperty::ImageRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImageOrientation(_, ref this_end_value),
                     &AnimatedProperty::ImageOrientation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderCollapse(_, ref this_end_value),
                     &AnimatedProperty::BorderCollapse(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::EmptyCells(_, ref this_end_value),
                     &AnimatedProperty::EmptyCells(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CaptionSide(_, ref this_end_value),
                     &AnimatedProperty::CaptionSide(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BorderSpacing(_, ref this_end_value),
                     &AnimatedProperty::BorderSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LineHeight(_, ref this_end_value),
                     &AnimatedProperty::LineHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextTransform(_, ref this_end_value),
                     &AnimatedProperty::TextTransform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Hyphens(_, ref this_end_value),
                     &AnimatedProperty::Hyphens(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozTextSizeAdjust(_, ref this_end_value),
                     &AnimatedProperty::MozTextSizeAdjust(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextIndent(_, ref this_end_value),
                     &AnimatedProperty::TextIndent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OverflowWrap(_, ref this_end_value),
                     &AnimatedProperty::OverflowWrap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WordBreak(_, ref this_end_value),
                     &AnimatedProperty::WordBreak(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextJustify(_, ref this_end_value),
                     &AnimatedProperty::TextJustify(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAlignLast(_, ref this_end_value),
                     &AnimatedProperty::TextAlignLast(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAlign(_, ref this_end_value),
                     &AnimatedProperty::TextAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LetterSpacing(_, ref this_end_value),
                     &AnimatedProperty::LetterSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WordSpacing(_, ref this_end_value),
                     &AnimatedProperty::WordSpacing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WhiteSpace(_, ref this_end_value),
                     &AnimatedProperty::WhiteSpace(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextShadow(_, ref this_end_value),
                     &AnimatedProperty::TextShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisStyle(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisPosition(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextEmphasisColor(_, ref this_end_value),
                     &AnimatedProperty::TextEmphasisColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozTabSize(_, ref this_end_value),
                     &AnimatedProperty::MozTabSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextFillColor(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextFillColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextStrokeColor(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextStrokeColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::WebkitTextStrokeWidth(_, ref this_end_value),
                     &AnimatedProperty::WebkitTextStrokeWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::RubyAlign(_, ref this_end_value),
                     &AnimatedProperty::RubyAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::RubyPosition(_, ref this_end_value),
                     &AnimatedProperty::RubyPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextCombineUpright(_, ref this_end_value),
                     &AnimatedProperty::TextCombineUpright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextRendering(_, ref this_end_value),
                     &AnimatedProperty::TextRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStylePosition(_, ref this_end_value),
                     &AnimatedProperty::ListStylePosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStyleType(_, ref this_end_value),
                     &AnimatedProperty::ListStyleType(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ListStyleImage(_, ref this_end_value),
                     &AnimatedProperty::ListStyleImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Quotes(_, ref this_end_value),
                     &AnimatedProperty::Quotes(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozImageRegion(_, ref this_end_value),
                     &AnimatedProperty::MozImageRegion(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginTop(_, ref this_end_value),
                     &AnimatedProperty::MarginTop(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginLeft(_, ref this_end_value),
                     &AnimatedProperty::MarginLeft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginBottom(_, ref this_end_value),
                     &AnimatedProperty::MarginBottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarginRight(_, ref this_end_value),
                     &AnimatedProperty::MarginRight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineColor(_, ref this_end_value),
                     &AnimatedProperty::OutlineColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineStyle(_, ref this_end_value),
                     &AnimatedProperty::OutlineStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineWidth(_, ref this_end_value),
                     &AnimatedProperty::OutlineWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusTopleft(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusTopleft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusTopright(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusTopright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusBottomright(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusBottomright(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozOutlineRadiusBottomleft(_, ref this_end_value),
                     &AnimatedProperty::MozOutlineRadiusBottomleft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::OutlineOffset(_, ref this_end_value),
                     &AnimatedProperty::OutlineOffset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingTop(_, ref this_end_value),
                     &AnimatedProperty::PaddingTop(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingLeft(_, ref this_end_value),
                     &AnimatedProperty::PaddingLeft(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingBottom(_, ref this_end_value),
                     &AnimatedProperty::PaddingBottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaddingRight(_, ref this_end_value),
                     &AnimatedProperty::PaddingRight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Cursor(_, ref this_end_value),
                     &AnimatedProperty::Cursor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PointerEvents(_, ref this_end_value),
                     &AnimatedProperty::PointerEvents(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserInput(_, ref this_end_value),
                     &AnimatedProperty::MozUserInput(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserModify(_, ref this_end_value),
                     &AnimatedProperty::MozUserModify(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserFocus(_, ref this_end_value),
                     &AnimatedProperty::MozUserFocus(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::CaretColor(_, ref this_end_value),
                     &AnimatedProperty::CaretColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Top(_, ref this_end_value),
                     &AnimatedProperty::Top(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Left(_, ref this_end_value),
                     &AnimatedProperty::Left(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Bottom(_, ref this_end_value),
                     &AnimatedProperty::Bottom(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Right(_, ref this_end_value),
                     &AnimatedProperty::Right(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ZIndex(_, ref this_end_value),
                     &AnimatedProperty::ZIndex(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexDirection(_, ref this_end_value),
                     &AnimatedProperty::FlexDirection(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexWrap(_, ref this_end_value),
                     &AnimatedProperty::FlexWrap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifyContent(_, ref this_end_value),
                     &AnimatedProperty::JustifyContent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::AlignContent(_, ref this_end_value),
                     &AnimatedProperty::AlignContent(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::AlignItems(_, ref this_end_value),
                     &AnimatedProperty::AlignItems(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifyItems(_, ref this_end_value),
                     &AnimatedProperty::JustifyItems(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexGrow(_, ref this_end_value),
                     &AnimatedProperty::FlexGrow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexShrink(_, ref this_end_value),
                     &AnimatedProperty::FlexShrink(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::AlignSelf(_, ref this_end_value),
                     &AnimatedProperty::AlignSelf(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::JustifySelf(_, ref this_end_value),
                     &AnimatedProperty::JustifySelf(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Order(_, ref this_end_value),
                     &AnimatedProperty::Order(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FlexBasis(_, ref this_end_value),
                     &AnimatedProperty::FlexBasis(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Width(_, ref this_end_value),
                     &AnimatedProperty::Width(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MinWidth(_, ref this_end_value),
                     &AnimatedProperty::MinWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaxWidth(_, ref this_end_value),
                     &AnimatedProperty::MaxWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Height(_, ref this_end_value),
                     &AnimatedProperty::Height(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MinHeight(_, ref this_end_value),
                     &AnimatedProperty::MinHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaxHeight(_, ref this_end_value),
                     &AnimatedProperty::MaxHeight(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::BoxSizing(_, ref this_end_value),
                     &AnimatedProperty::BoxSizing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ObjectFit(_, ref this_end_value),
                     &AnimatedProperty::ObjectFit(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ObjectPosition(_, ref this_end_value),
                     &AnimatedProperty::ObjectPosition(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowGap(_, ref this_end_value),
                     &AnimatedProperty::GridRowGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowStart(_, ref this_end_value),
                     &AnimatedProperty::GridRowStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridRowEnd(_, ref this_end_value),
                     &AnimatedProperty::GridRowEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoRows(_, ref this_end_value),
                     &AnimatedProperty::GridAutoRows(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateRows(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateRows(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnGap(_, ref this_end_value),
                     &AnimatedProperty::GridColumnGap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnStart(_, ref this_end_value),
                     &AnimatedProperty::GridColumnStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridColumnEnd(_, ref this_end_value),
                     &AnimatedProperty::GridColumnEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoColumns(_, ref this_end_value),
                     &AnimatedProperty::GridAutoColumns(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateColumns(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateColumns(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridAutoFlow(_, ref this_end_value),
                     &AnimatedProperty::GridAutoFlow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::GridTemplateAreas(_, ref this_end_value),
                     &AnimatedProperty::GridTemplateAreas(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TableLayout(_, ref this_end_value),
                     &AnimatedProperty::TableLayout(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextOverflow(_, ref this_end_value),
                     &AnimatedProperty::TextOverflow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::UnicodeBidi(_, ref this_end_value),
                     &AnimatedProperty::UnicodeBidi(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationLine(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationLine(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationStyle(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationStyle(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextDecorationColor(_, ref this_end_value),
                     &AnimatedProperty::TextDecorationColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::InitialLetter(_, ref this_end_value),
                     &AnimatedProperty::InitialLetter(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ImeMode(_, ref this_end_value),
                     &AnimatedProperty::ImeMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozUserSelect(_, ref this_end_value),
                     &AnimatedProperty::MozUserSelect(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowDragging(_, ref this_end_value),
                     &AnimatedProperty::MozWindowDragging(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowShadow(_, ref this_end_value),
                     &AnimatedProperty::MozWindowShadow(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowOpacity(_, ref this_end_value),
                     &AnimatedProperty::MozWindowOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowTransform(_, ref this_end_value),
                     &AnimatedProperty::MozWindowTransform(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozWindowTransformOrigin(_, ref this_end_value),
                     &AnimatedProperty::MozWindowTransformOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozForceBrokenImageIcon(_, ref this_end_value),
                     &AnimatedProperty::MozForceBrokenImageIcon(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::TextAnchor(_, ref this_end_value),
                     &AnimatedProperty::TextAnchor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorInterpolation(_, ref this_end_value),
                     &AnimatedProperty::ColorInterpolation(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ColorInterpolationFilters(_, ref this_end_value),
                     &AnimatedProperty::ColorInterpolationFilters(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Fill(_, ref this_end_value),
                     &AnimatedProperty::Fill(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FillOpacity(_, ref this_end_value),
                     &AnimatedProperty::FillOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FillRule(_, ref this_end_value),
                     &AnimatedProperty::FillRule(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ShapeRendering(_, ref this_end_value),
                     &AnimatedProperty::ShapeRendering(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::Stroke(_, ref this_end_value),
                     &AnimatedProperty::Stroke(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeWidth(_, ref this_end_value),
                     &AnimatedProperty::StrokeWidth(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeLinecap(_, ref this_end_value),
                     &AnimatedProperty::StrokeLinecap(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeLinejoin(_, ref this_end_value),
                     &AnimatedProperty::StrokeLinejoin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeMiterlimit(_, ref this_end_value),
                     &AnimatedProperty::StrokeMiterlimit(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeOpacity(_, ref this_end_value),
                     &AnimatedProperty::StrokeOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeDasharray(_, ref this_end_value),
                     &AnimatedProperty::StrokeDasharray(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StrokeDashoffset(_, ref this_end_value),
                     &AnimatedProperty::StrokeDashoffset(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ClipRule(_, ref this_end_value),
                     &AnimatedProperty::ClipRule(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerStart(_, ref this_end_value),
                     &AnimatedProperty::MarkerStart(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerMid(_, ref this_end_value),
                     &AnimatedProperty::MarkerMid(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MarkerEnd(_, ref this_end_value),
                     &AnimatedProperty::MarkerEnd(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::PaintOrder(_, ref this_end_value),
                     &AnimatedProperty::PaintOrder(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::DominantBaseline(_, ref this_end_value),
                     &AnimatedProperty::DominantBaseline(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::VectorEffect(_, ref this_end_value),
                     &AnimatedProperty::VectorEffect(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StopColor(_, ref this_end_value),
                     &AnimatedProperty::StopColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::StopOpacity(_, ref this_end_value),
                     &AnimatedProperty::StopOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FloodColor(_, ref this_end_value),
                     &AnimatedProperty::FloodColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::FloodOpacity(_, ref this_end_value),
                     &AnimatedProperty::FloodOpacity(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::LightingColor(_, ref this_end_value),
                     &AnimatedProperty::LightingColor(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskType(_, ref this_end_value),
                     &AnimatedProperty::MaskType(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::ClipPath(_, ref this_end_value),
                     &AnimatedProperty::ClipPath(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskMode(_, ref this_end_value),
                     &AnimatedProperty::MaskMode(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskRepeat(_, ref this_end_value),
                     &AnimatedProperty::MaskRepeat(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskPositionX(_, ref this_end_value),
                     &AnimatedProperty::MaskPositionX(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskPositionY(_, ref this_end_value),
                     &AnimatedProperty::MaskPositionY(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskClip(_, ref this_end_value),
                     &AnimatedProperty::MaskClip(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskOrigin(_, ref this_end_value),
                     &AnimatedProperty::MaskOrigin(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskSize(_, ref this_end_value),
                     &AnimatedProperty::MaskSize(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskComposite(_, ref this_end_value),
                     &AnimatedProperty::MaskComposite(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MaskImage(_, ref this_end_value),
                     &AnimatedProperty::MaskImage(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxAlign(_, ref this_end_value),
                     &AnimatedProperty::MozBoxAlign(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxDirection(_, ref this_end_value),
                     &AnimatedProperty::MozBoxDirection(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxFlex(_, ref this_end_value),
                     &AnimatedProperty::MozBoxFlex(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxOrient(_, ref this_end_value),
                     &AnimatedProperty::MozBoxOrient(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxPack(_, ref this_end_value),
                     &AnimatedProperty::MozBoxPack(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozStackSizing(_, ref this_end_value),
                     &AnimatedProperty::MozStackSizing(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
                    (&AnimatedProperty::MozBoxOrdinalGroup(_, ref this_end_value),
                     &AnimatedProperty::MozBoxOrdinalGroup(_, ref other_end_value)) => {
                        this_end_value == other_end_value
                    }
            _ => false,
        }
    }

    /// Update `style` with the proper computed style corresponding to this
    /// animation at `progress`.
    pub fn update(&self, style: &mut ComputedValues, progress: f64) {
        match *self {
                    AnimatedProperty::BackgroundColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::background_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_background().set_background_color(value);
                    }
                    AnimatedProperty::BackgroundImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_image(value);
                    }
                    AnimatedProperty::BackgroundPositionX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_background().set_background_position_x(value);
                    }
                    AnimatedProperty::BackgroundPositionY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_background().set_background_position_y(value);
                    }
                    AnimatedProperty::BackgroundRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_repeat(value);
                    }
                    AnimatedProperty::BackgroundAttachment(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_attachment(value);
                    }
                    AnimatedProperty::BackgroundClip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_clip(value);
                    }
                    AnimatedProperty::BackgroundOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_origin(value);
                    }
                    AnimatedProperty::BackgroundSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::background_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_background().set_background_size(value);
                    }
                    AnimatedProperty::BackgroundBlendMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_background().set_background_blend_mode(value);
                    }
                    AnimatedProperty::BorderTopColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_color(value);
                    }
                    AnimatedProperty::BorderTopStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_top_style(value);
                    }
                    AnimatedProperty::BorderTopWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_width(value);
                    }
                    AnimatedProperty::BorderLeftColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_left_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_left_color(value);
                    }
                    AnimatedProperty::BorderLeftStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_left_style(value);
                    }
                    AnimatedProperty::BorderLeftWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_left_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_left_width(value);
                    }
                    AnimatedProperty::BorderBottomColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_color(value);
                    }
                    AnimatedProperty::BorderBottomStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_bottom_style(value);
                    }
                    AnimatedProperty::BorderBottomWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_width(value);
                    }
                    AnimatedProperty::BorderRightColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_right_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_right_color(value);
                    }
                    AnimatedProperty::BorderRightStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_right_style(value);
                    }
                    AnimatedProperty::BorderRightWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_right_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_right_width(value);
                    }
                    AnimatedProperty::BorderTopLeftRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_left_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_left_radius(value);
                    }
                    AnimatedProperty::BorderTopRightRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_top_right_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_top_right_radius(value);
                    }
                    AnimatedProperty::BorderBottomRightRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_right_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_right_radius(value);
                    }
                    AnimatedProperty::BorderBottomLeftRadius(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_bottom_left_radius::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_border().set_border_bottom_left_radius(value);
                    }
                    AnimatedProperty::MozBorderTopColors(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_border_top_colors(value);
                    }
                    AnimatedProperty::MozBorderLeftColors(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_border_left_colors(value);
                    }
                    AnimatedProperty::MozBorderBottomColors(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_border_bottom_colors(value);
                    }
                    AnimatedProperty::MozBorderRightColors(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_border_right_colors(value);
                    }
                    AnimatedProperty::BoxDecorationBreak(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_box_decoration_break(value);
                    }
                    AnimatedProperty::MozFloatEdge(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set__moz_float_edge(value);
                    }
                    AnimatedProperty::BorderImageSource(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_source(value);
                    }
                    AnimatedProperty::BorderImageOutset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_outset(value);
                    }
                    AnimatedProperty::BorderImageRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_repeat(value);
                    }
                    AnimatedProperty::BorderImageWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_width(value);
                    }
                    AnimatedProperty::BorderImageSlice(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_border().set_border_image_slice(value);
                    }
                    AnimatedProperty::Display(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_display(value);
                    }
                    AnimatedProperty::Position(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_position(value);
                    }
                    AnimatedProperty::Float(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_float(value);
                    }
                    AnimatedProperty::Clear(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_clear(value);
                    }
                    AnimatedProperty::VerticalAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_vertical_align(value);
                    }
                    AnimatedProperty::OverflowClipBoxInline(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_clip_box_inline(value);
                    }
                    AnimatedProperty::OverflowClipBoxBlock(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_clip_box_block(value);
                    }
                    AnimatedProperty::OverflowX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_x(value);
                    }
                    AnimatedProperty::OverflowY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overflow_y(value);
                    }
                    AnimatedProperty::ScrollSnapPointsX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_points_x(value);
                    }
                    AnimatedProperty::ScrollSnapPointsY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_points_y(value);
                    }
                    AnimatedProperty::ScrollSnapDestination(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_destination(value);
                    }
                    AnimatedProperty::ScrollSnapCoordinate(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_coordinate(value);
                    }
                    AnimatedProperty::Transform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_transform(value);
                    }
                    AnimatedProperty::ScrollBehavior(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_behavior(value);
                    }
                    AnimatedProperty::ScrollSnapTypeX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_type_x(value);
                    }
                    AnimatedProperty::ScrollSnapTypeY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_scroll_snap_type_y(value);
                    }
                    AnimatedProperty::OverscrollBehaviorX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overscroll_behavior_x(value);
                    }
                    AnimatedProperty::OverscrollBehaviorY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_overscroll_behavior_y(value);
                    }
                    AnimatedProperty::Isolation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_isolation(value);
                    }
                    AnimatedProperty::PageBreakAfter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_after(value);
                    }
                    AnimatedProperty::PageBreakBefore(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_before(value);
                    }
                    AnimatedProperty::PageBreakInside(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_page_break_inside(value);
                    }
                    AnimatedProperty::Resize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_resize(value);
                    }
                    AnimatedProperty::Perspective(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_perspective(value);
                    }
                    AnimatedProperty::PerspectiveOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_perspective_origin(value);
                    }
                    AnimatedProperty::BackfaceVisibility(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_backface_visibility(value);
                    }
                    AnimatedProperty::TransformBox(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_transform_box(value);
                    }
                    AnimatedProperty::TransformStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_transform_style(value);
                    }
                    AnimatedProperty::TransformOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_transform_origin(value);
                    }
                    AnimatedProperty::Contain(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_contain(value);
                    }
                    AnimatedProperty::MozAppearance(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set__moz_appearance(value);
                    }
                    AnimatedProperty::MozOrient(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set__moz_orient(value);
                    }
                    AnimatedProperty::WillChange(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_will_change(value);
                    }
                    AnimatedProperty::ShapeImageThreshold(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_shape_image_threshold(value);
                    }
                    AnimatedProperty::ShapeOutside(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_box().set_shape_outside(value);
                    }
                    AnimatedProperty::TouchAction(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_box().set_touch_action(value);
                    }
                    AnimatedProperty::Color(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_color().set_color(value);
                    }
                    AnimatedProperty::ColumnWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_width(value);
                    }
                    AnimatedProperty::ColumnCount(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_count::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_count(value);
                    }
                    AnimatedProperty::ColumnGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_gap(value);
                    }
                    AnimatedProperty::ColumnFill(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_fill(value);
                    }
                    AnimatedProperty::ColumnRuleWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_rule_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_rule_width(value);
                    }
                    AnimatedProperty::ColumnRuleColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::column_rule_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_column().set_column_rule_color(value);
                    }
                    AnimatedProperty::ColumnSpan(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_span(value);
                    }
                    AnimatedProperty::ColumnRuleStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_column().set_column_rule_style(value);
                    }
                    AnimatedProperty::Content(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_content(value);
                    }
                    AnimatedProperty::CounterIncrement(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_counter_increment(value);
                    }
                    AnimatedProperty::CounterReset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_counters().set_counter_reset(value);
                    }
                    AnimatedProperty::Opacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_effects().set_opacity(value);
                    }
                    AnimatedProperty::BoxShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::box_shadow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_effects().set_box_shadow(value);
                    }
                    AnimatedProperty::Clip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_effects().set_clip(value);
                    }
                    AnimatedProperty::Filter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::filter::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_effects().set_filter(value);
                    }
                    AnimatedProperty::MixBlendMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_effects().set_mix_blend_mode(value);
                    }
                    AnimatedProperty::FontFamily(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_family(value);
                    }
                    AnimatedProperty::FontStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_style(value);
                    }
                    AnimatedProperty::FontVariantCaps(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_caps(value);
                    }
                    AnimatedProperty::FontWeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_weight(value);
                    }
                    AnimatedProperty::FontSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::font_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_font().set_font_size(value);
                    }
                    AnimatedProperty::FontSizeAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_size_adjust(value);
                    }
                    AnimatedProperty::FontSynthesis(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_synthesis(value);
                    }
                    AnimatedProperty::FontStretch(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_stretch(value);
                    }
                    AnimatedProperty::FontKerning(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_kerning(value);
                    }
                    AnimatedProperty::FontVariantAlternates(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_alternates(value);
                    }
                    AnimatedProperty::FontVariantEastAsian(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_east_asian(value);
                    }
                    AnimatedProperty::FontVariantLigatures(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_ligatures(value);
                    }
                    AnimatedProperty::FontVariantNumeric(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_numeric(value);
                    }
                    AnimatedProperty::FontVariantPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_variant_position(value);
                    }
                    AnimatedProperty::FontFeatureSettings(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_feature_settings(value);
                    }
                    AnimatedProperty::FontVariationSettings(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_font().set_font_variation_settings(value);
                    }
                    AnimatedProperty::FontLanguageOverride(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set_font_language_override(value);
                    }
                    AnimatedProperty::MozOsxFontSmoothing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_font().set__moz_osx_font_smoothing(value);
                    }
                    AnimatedProperty::MozFontSmoothingBackgroundColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_font_smoothing_background_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_font().set__moz_font_smoothing_background_color(value);
                    }
                    AnimatedProperty::Visibility(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedbox().set_visibility(value);
                    }
                    AnimatedProperty::WritingMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_writing_mode(value);
                    }
                    AnimatedProperty::Direction(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_direction(value);
                    }
                    AnimatedProperty::TextOrientation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_text_orientation(value);
                    }
                    AnimatedProperty::ColorAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_color_adjust(value);
                    }
                    AnimatedProperty::ImageRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_image_rendering(value);
                    }
                    AnimatedProperty::ImageOrientation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedbox().set_image_orientation(value);
                    }
                    AnimatedProperty::BorderCollapse(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_border_collapse(value);
                    }
                    AnimatedProperty::EmptyCells(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_empty_cells(value);
                    }
                    AnimatedProperty::CaptionSide(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtable().set_caption_side(value);
                    }
                    AnimatedProperty::BorderSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::border_spacing::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtable().set_border_spacing(value);
                    }
                    AnimatedProperty::LineHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::line_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_line_height(value);
                    }
                    AnimatedProperty::TextTransform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_transform(value);
                    }
                    AnimatedProperty::Hyphens(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_hyphens(value);
                    }
                    AnimatedProperty::MozTextSizeAdjust(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set__moz_text_size_adjust(value);
                    }
                    AnimatedProperty::TextIndent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_text_indent(value);
                    }
                    AnimatedProperty::OverflowWrap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_overflow_wrap(value);
                    }
                    AnimatedProperty::WordBreak(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_word_break(value);
                    }
                    AnimatedProperty::TextJustify(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_justify(value);
                    }
                    AnimatedProperty::TextAlignLast(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_align_last(value);
                    }
                    AnimatedProperty::TextAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_align(value);
                    }
                    AnimatedProperty::LetterSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_letter_spacing(value);
                    }
                    AnimatedProperty::WordSpacing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedtext().set_word_spacing(value);
                    }
                    AnimatedProperty::WhiteSpace(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_white_space(value);
                    }
                    AnimatedProperty::TextShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_shadow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_text_shadow(value);
                    }
                    AnimatedProperty::TextEmphasisStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_emphasis_style(value);
                    }
                    AnimatedProperty::TextEmphasisPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_emphasis_position(value);
                    }
                    AnimatedProperty::TextEmphasisColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_emphasis_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set_text_emphasis_color(value);
                    }
                    AnimatedProperty::MozTabSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_tab_size::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__moz_tab_size(value);
                    }
                    AnimatedProperty::WebkitTextFillColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_webkit_text_fill_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__webkit_text_fill_color(value);
                    }
                    AnimatedProperty::WebkitTextStrokeColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_webkit_text_stroke_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedtext().set__webkit_text_stroke_color(value);
                    }
                    AnimatedProperty::WebkitTextStrokeWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set__webkit_text_stroke_width(value);
                    }
                    AnimatedProperty::RubyAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_ruby_align(value);
                    }
                    AnimatedProperty::RubyPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_ruby_position(value);
                    }
                    AnimatedProperty::TextCombineUpright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_combine_upright(value);
                    }
                    AnimatedProperty::TextRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedtext().set_text_rendering(value);
                    }
                    AnimatedProperty::ListStylePosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_position(value);
                    }
                    AnimatedProperty::ListStyleType(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_type(value);
                    }
                    AnimatedProperty::ListStyleImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_list_style_image(value);
                    }
                    AnimatedProperty::Quotes(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_list().set_quotes(value);
                    }
                    AnimatedProperty::MozImageRegion(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_list().set__moz_image_region(value);
                    }
                    AnimatedProperty::MarginTop(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_top(value);
                    }
                    AnimatedProperty::MarginLeft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_left(value);
                    }
                    AnimatedProperty::MarginBottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_bottom(value);
                    }
                    AnimatedProperty::MarginRight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_margin().set_margin_right(value);
                    }
                    AnimatedProperty::OutlineColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::outline_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set_outline_color(value);
                    }
                    AnimatedProperty::OutlineStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_outline().set_outline_style(value);
                    }
                    AnimatedProperty::OutlineWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::outline_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set_outline_width(value);
                    }
                    AnimatedProperty::MozOutlineRadiusTopleft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_topleft::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_topleft(value);
                    }
                    AnimatedProperty::MozOutlineRadiusTopright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_topright::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_topright(value);
                    }
                    AnimatedProperty::MozOutlineRadiusBottomright(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_bottomright::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_bottomright(value);
                    }
                    AnimatedProperty::MozOutlineRadiusBottomleft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_outline_radius_bottomleft::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_outline().set__moz_outline_radius_bottomleft(value);
                    }
                    AnimatedProperty::OutlineOffset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_outline().set_outline_offset(value);
                    }
                    AnimatedProperty::PaddingTop(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_top::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_top(value);
                    }
                    AnimatedProperty::PaddingLeft(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_left::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_left(value);
                    }
                    AnimatedProperty::PaddingBottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_bottom::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_bottom(value);
                    }
                    AnimatedProperty::PaddingRight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::padding_right::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_padding().set_padding_right(value);
                    }
                    AnimatedProperty::Cursor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set_cursor(value);
                    }
                    AnimatedProperty::PointerEvents(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set_pointer_events(value);
                    }
                    AnimatedProperty::MozUserInput(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_input(value);
                    }
                    AnimatedProperty::MozUserModify(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_modify(value);
                    }
                    AnimatedProperty::MozUserFocus(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_pointing().set__moz_user_focus(value);
                    }
                    AnimatedProperty::CaretColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::caret_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_pointing().set_caret_color(value);
                    }
                    AnimatedProperty::Top(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_top(value);
                    }
                    AnimatedProperty::Left(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_left(value);
                    }
                    AnimatedProperty::Bottom(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_bottom(value);
                    }
                    AnimatedProperty::Right(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_right(value);
                    }
                    AnimatedProperty::ZIndex(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_z_index(value);
                    }
                    AnimatedProperty::FlexDirection(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_flex_direction(value);
                    }
                    AnimatedProperty::FlexWrap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_flex_wrap(value);
                    }
                    AnimatedProperty::JustifyContent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_content(value);
                    }
                    AnimatedProperty::AlignContent(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_content(value);
                    }
                    AnimatedProperty::AlignItems(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_items(value);
                    }
                    AnimatedProperty::JustifyItems(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_items(value);
                    }
                    AnimatedProperty::FlexGrow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_grow::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_grow(value);
                    }
                    AnimatedProperty::FlexShrink(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_shrink::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_shrink(value);
                    }
                    AnimatedProperty::AlignSelf(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_align_self(value);
                    }
                    AnimatedProperty::JustifySelf(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_justify_self(value);
                    }
                    AnimatedProperty::Order(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_order(value);
                    }
                    AnimatedProperty::FlexBasis(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flex_basis::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_flex_basis(value);
                    }
                    AnimatedProperty::Width(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_width(value);
                    }
                    AnimatedProperty::MinWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::min_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_min_width(value);
                    }
                    AnimatedProperty::MaxWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::max_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_max_width(value);
                    }
                    AnimatedProperty::Height(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_height(value);
                    }
                    AnimatedProperty::MinHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::min_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_min_height(value);
                    }
                    AnimatedProperty::MaxHeight(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::max_height::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_max_height(value);
                    }
                    AnimatedProperty::BoxSizing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_box_sizing(value);
                    }
                    AnimatedProperty::ObjectFit(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_object_fit(value);
                    }
                    AnimatedProperty::ObjectPosition(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_position().set_object_position(value);
                    }
                    AnimatedProperty::GridRowGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::grid_row_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_grid_row_gap(value);
                    }
                    AnimatedProperty::GridRowStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_row_start(value);
                    }
                    AnimatedProperty::GridRowEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_row_end(value);
                    }
                    AnimatedProperty::GridAutoRows(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_rows(value);
                    }
                    AnimatedProperty::GridTemplateRows(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_rows(value);
                    }
                    AnimatedProperty::GridColumnGap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::grid_column_gap::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_position().set_grid_column_gap(value);
                    }
                    AnimatedProperty::GridColumnStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_column_start(value);
                    }
                    AnimatedProperty::GridColumnEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_column_end(value);
                    }
                    AnimatedProperty::GridAutoColumns(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_columns(value);
                    }
                    AnimatedProperty::GridTemplateColumns(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_columns(value);
                    }
                    AnimatedProperty::GridAutoFlow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_auto_flow(value);
                    }
                    AnimatedProperty::GridTemplateAreas(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_position().set_grid_template_areas(value);
                    }
                    AnimatedProperty::TableLayout(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_table().set_table_layout(value);
                    }
                    AnimatedProperty::TextOverflow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_overflow(value);
                    }
                    AnimatedProperty::UnicodeBidi(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_unicode_bidi(value);
                    }
                    AnimatedProperty::TextDecorationLine(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_decoration_line(value);
                    }
                    AnimatedProperty::TextDecorationStyle(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_text_decoration_style(value);
                    }
                    AnimatedProperty::TextDecorationColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::text_decoration_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_text().set_text_decoration_color(value);
                    }
                    AnimatedProperty::InitialLetter(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_text().set_initial_letter(value);
                    }
                    AnimatedProperty::ImeMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set_ime_mode(value);
                    }
                    AnimatedProperty::MozUserSelect(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_user_select(value);
                    }
                    AnimatedProperty::MozWindowDragging(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_window_dragging(value);
                    }
                    AnimatedProperty::MozWindowShadow(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_window_shadow(value);
                    }
                    AnimatedProperty::MozWindowOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_opacity(value);
                    }
                    AnimatedProperty::MozWindowTransform(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_transform(value);
                    }
                    AnimatedProperty::MozWindowTransformOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_ui().set__moz_window_transform_origin(value);
                    }
                    AnimatedProperty::MozForceBrokenImageIcon(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_ui().set__moz_force_broken_image_icon(value);
                    }
                    AnimatedProperty::TextAnchor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_text_anchor(value);
                    }
                    AnimatedProperty::ColorInterpolation(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_color_interpolation(value);
                    }
                    AnimatedProperty::ColorInterpolationFilters(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_color_interpolation_filters(value);
                    }
                    AnimatedProperty::Fill(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::fill::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_fill(value);
                    }
                    AnimatedProperty::FillOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_fill_opacity(value);
                    }
                    AnimatedProperty::FillRule(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_fill_rule(value);
                    }
                    AnimatedProperty::ShapeRendering(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_shape_rendering(value);
                    }
                    AnimatedProperty::Stroke(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke(value);
                    }
                    AnimatedProperty::StrokeWidth(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_width::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_width(value);
                    }
                    AnimatedProperty::StrokeLinecap(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_stroke_linecap(value);
                    }
                    AnimatedProperty::StrokeLinejoin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_stroke_linejoin(value);
                    }
                    AnimatedProperty::StrokeMiterlimit(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_miterlimit::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_miterlimit(value);
                    }
                    AnimatedProperty::StrokeOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_stroke_opacity(value);
                    }
                    AnimatedProperty::StrokeDasharray(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stroke_dasharray::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_inheritedsvg().set_stroke_dasharray(value);
                    }
                    AnimatedProperty::StrokeDashoffset(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_inheritedsvg().set_stroke_dashoffset(value);
                    }
                    AnimatedProperty::ClipRule(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_clip_rule(value);
                    }
                    AnimatedProperty::MarkerStart(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_start(value);
                    }
                    AnimatedProperty::MarkerMid(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_mid(value);
                    }
                    AnimatedProperty::MarkerEnd(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_marker_end(value);
                    }
                    AnimatedProperty::PaintOrder(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_inheritedsvg().set_paint_order(value);
                    }
                    AnimatedProperty::DominantBaseline(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_dominant_baseline(value);
                    }
                    AnimatedProperty::VectorEffect(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_vector_effect(value);
                    }
                    AnimatedProperty::StopColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::stop_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_stop_color(value);
                    }
                    AnimatedProperty::StopOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_stop_opacity(value);
                    }
                    AnimatedProperty::FloodColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::flood_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_flood_color(value);
                    }
                    AnimatedProperty::FloodOpacity(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_flood_opacity(value);
                    }
                    AnimatedProperty::LightingColor(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::lighting_color::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_svg().set_lighting_color(value);
                    }
                    AnimatedProperty::MaskType(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_type(value);
                    }
                    AnimatedProperty::ClipPath(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_clip_path(value);
                    }
                    AnimatedProperty::MaskMode(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_mode(value);
                    }
                    AnimatedProperty::MaskRepeat(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_repeat(value);
                    }
                    AnimatedProperty::MaskPositionX(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_position_x(value);
                    }
                    AnimatedProperty::MaskPositionY(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_position_y(value);
                    }
                    AnimatedProperty::MaskClip(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_clip(value);
                    }
                    AnimatedProperty::MaskOrigin(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_origin(value);
                    }
                    AnimatedProperty::MaskSize(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                        style.mutate_svg().set_mask_size(value);
                    }
                    AnimatedProperty::MaskComposite(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_composite(value);
                    }
                    AnimatedProperty::MaskImage(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_svg().set_mask_image(value);
                    }
                    AnimatedProperty::MozBoxAlign(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_align(value);
                    }
                    AnimatedProperty::MozBoxDirection(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_direction(value);
                    }
                    AnimatedProperty::MozBoxFlex(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = match from.animate(to, Procedure::Interpolate { progress }) {
                                Ok(value) => value,
                                Err(()) => return,
                            };
                            let value: longhands::_moz_box_flex::computed_value::T =
                                ToAnimatedValue::from_animated_value(value);
                        style.mutate_xul().set__moz_box_flex(value);
                    }
                    AnimatedProperty::MozBoxOrient(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_orient(value);
                    }
                    AnimatedProperty::MozBoxPack(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_pack(value);
                    }
                    AnimatedProperty::MozStackSizing(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_stack_sizing(value);
                    }
                    AnimatedProperty::MozBoxOrdinalGroup(ref from, ref to) => {
                        // https://drafts.csswg.org/web-animations/#discrete-animation-type
                            let value = if progress < 0.5 { from.clone() } else { to.clone() };
                        style.mutate_xul().set__moz_box_ordinal_group(value);
                    }
        }
    }

    /// Get an animatable value from a transition-property, an old style, and a
    /// new style.
    pub fn from_longhand(
        property: &LonghandId,
        old_style: &ComputedValues,
        new_style: &ComputedValues,
    ) -> Option<AnimatedProperty> {
        Some(match *property {
                LonghandId::BackgroundColor => {
                    let old_computed = old_style.get_background().clone_background_color();
                    let new_computed = new_style.get_background().clone_background_color();
                    AnimatedProperty::BackgroundColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BackgroundImage => {
                    let old_computed = old_style.get_background().clone_background_image();
                    let new_computed = new_style.get_background().clone_background_image();
                    AnimatedProperty::BackgroundImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundPositionX => {
                    let old_computed = old_style.get_background().clone_background_position_x();
                    let new_computed = new_style.get_background().clone_background_position_x();
                    AnimatedProperty::BackgroundPositionX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundPositionY => {
                    let old_computed = old_style.get_background().clone_background_position_y();
                    let new_computed = new_style.get_background().clone_background_position_y();
                    AnimatedProperty::BackgroundPositionY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundRepeat => {
                    let old_computed = old_style.get_background().clone_background_repeat();
                    let new_computed = new_style.get_background().clone_background_repeat();
                    AnimatedProperty::BackgroundRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundAttachment => {
                    let old_computed = old_style.get_background().clone_background_attachment();
                    let new_computed = new_style.get_background().clone_background_attachment();
                    AnimatedProperty::BackgroundAttachment(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundClip => {
                    let old_computed = old_style.get_background().clone_background_clip();
                    let new_computed = new_style.get_background().clone_background_clip();
                    AnimatedProperty::BackgroundClip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundOrigin => {
                    let old_computed = old_style.get_background().clone_background_origin();
                    let new_computed = new_style.get_background().clone_background_origin();
                    AnimatedProperty::BackgroundOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackgroundSize => {
                    let old_computed = old_style.get_background().clone_background_size();
                    let new_computed = new_style.get_background().clone_background_size();
                    AnimatedProperty::BackgroundSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BackgroundBlendMode => {
                    let old_computed = old_style.get_background().clone_background_blend_mode();
                    let new_computed = new_style.get_background().clone_background_blend_mode();
                    AnimatedProperty::BackgroundBlendMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderTopColor => {
                    let old_computed = old_style.get_border().clone_border_top_color();
                    let new_computed = new_style.get_border().clone_border_top_color();
                    AnimatedProperty::BorderTopColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopStyle => {
                    let old_computed = old_style.get_border().clone_border_top_style();
                    let new_computed = new_style.get_border().clone_border_top_style();
                    AnimatedProperty::BorderTopStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderTopWidth => {
                    let old_computed = old_style.get_border().clone_border_top_width();
                    let new_computed = new_style.get_border().clone_border_top_width();
                    AnimatedProperty::BorderTopWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderLeftColor => {
                    let old_computed = old_style.get_border().clone_border_left_color();
                    let new_computed = new_style.get_border().clone_border_left_color();
                    AnimatedProperty::BorderLeftColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderLeftStyle => {
                    let old_computed = old_style.get_border().clone_border_left_style();
                    let new_computed = new_style.get_border().clone_border_left_style();
                    AnimatedProperty::BorderLeftStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderLeftWidth => {
                    let old_computed = old_style.get_border().clone_border_left_width();
                    let new_computed = new_style.get_border().clone_border_left_width();
                    AnimatedProperty::BorderLeftWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomColor => {
                    let old_computed = old_style.get_border().clone_border_bottom_color();
                    let new_computed = new_style.get_border().clone_border_bottom_color();
                    AnimatedProperty::BorderBottomColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomStyle => {
                    let old_computed = old_style.get_border().clone_border_bottom_style();
                    let new_computed = new_style.get_border().clone_border_bottom_style();
                    AnimatedProperty::BorderBottomStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderBottomWidth => {
                    let old_computed = old_style.get_border().clone_border_bottom_width();
                    let new_computed = new_style.get_border().clone_border_bottom_width();
                    AnimatedProperty::BorderBottomWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderRightColor => {
                    let old_computed = old_style.get_border().clone_border_right_color();
                    let new_computed = new_style.get_border().clone_border_right_color();
                    AnimatedProperty::BorderRightColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderRightStyle => {
                    let old_computed = old_style.get_border().clone_border_right_style();
                    let new_computed = new_style.get_border().clone_border_right_style();
                    AnimatedProperty::BorderRightStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderRightWidth => {
                    let old_computed = old_style.get_border().clone_border_right_width();
                    let new_computed = new_style.get_border().clone_border_right_width();
                    AnimatedProperty::BorderRightWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopLeftRadius => {
                    let old_computed = old_style.get_border().clone_border_top_left_radius();
                    let new_computed = new_style.get_border().clone_border_top_left_radius();
                    AnimatedProperty::BorderTopLeftRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderTopRightRadius => {
                    let old_computed = old_style.get_border().clone_border_top_right_radius();
                    let new_computed = new_style.get_border().clone_border_top_right_radius();
                    AnimatedProperty::BorderTopRightRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomRightRadius => {
                    let old_computed = old_style.get_border().clone_border_bottom_right_radius();
                    let new_computed = new_style.get_border().clone_border_bottom_right_radius();
                    AnimatedProperty::BorderBottomRightRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BorderBottomLeftRadius => {
                    let old_computed = old_style.get_border().clone_border_bottom_left_radius();
                    let new_computed = new_style.get_border().clone_border_bottom_left_radius();
                    AnimatedProperty::BorderBottomLeftRadius(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozBorderTopColors => {
                    let old_computed = old_style.get_border().clone__moz_border_top_colors();
                    let new_computed = new_style.get_border().clone__moz_border_top_colors();
                    AnimatedProperty::MozBorderTopColors(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBorderLeftColors => {
                    let old_computed = old_style.get_border().clone__moz_border_left_colors();
                    let new_computed = new_style.get_border().clone__moz_border_left_colors();
                    AnimatedProperty::MozBorderLeftColors(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBorderBottomColors => {
                    let old_computed = old_style.get_border().clone__moz_border_bottom_colors();
                    let new_computed = new_style.get_border().clone__moz_border_bottom_colors();
                    AnimatedProperty::MozBorderBottomColors(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBorderRightColors => {
                    let old_computed = old_style.get_border().clone__moz_border_right_colors();
                    let new_computed = new_style.get_border().clone__moz_border_right_colors();
                    AnimatedProperty::MozBorderRightColors(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BoxDecorationBreak => {
                    let old_computed = old_style.get_border().clone_box_decoration_break();
                    let new_computed = new_style.get_border().clone_box_decoration_break();
                    AnimatedProperty::BoxDecorationBreak(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozFloatEdge => {
                    let old_computed = old_style.get_border().clone__moz_float_edge();
                    let new_computed = new_style.get_border().clone__moz_float_edge();
                    AnimatedProperty::MozFloatEdge(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageSource => {
                    let old_computed = old_style.get_border().clone_border_image_source();
                    let new_computed = new_style.get_border().clone_border_image_source();
                    AnimatedProperty::BorderImageSource(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageOutset => {
                    let old_computed = old_style.get_border().clone_border_image_outset();
                    let new_computed = new_style.get_border().clone_border_image_outset();
                    AnimatedProperty::BorderImageOutset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageRepeat => {
                    let old_computed = old_style.get_border().clone_border_image_repeat();
                    let new_computed = new_style.get_border().clone_border_image_repeat();
                    AnimatedProperty::BorderImageRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageWidth => {
                    let old_computed = old_style.get_border().clone_border_image_width();
                    let new_computed = new_style.get_border().clone_border_image_width();
                    AnimatedProperty::BorderImageWidth(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderImageSlice => {
                    let old_computed = old_style.get_border().clone_border_image_slice();
                    let new_computed = new_style.get_border().clone_border_image_slice();
                    AnimatedProperty::BorderImageSlice(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Display => {
                    let old_computed = old_style.get_box().clone_display();
                    let new_computed = new_style.get_box().clone_display();
                    AnimatedProperty::Display(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Position => {
                    let old_computed = old_style.get_box().clone_position();
                    let new_computed = new_style.get_box().clone_position();
                    AnimatedProperty::Position(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Float => {
                    let old_computed = old_style.get_box().clone_float();
                    let new_computed = new_style.get_box().clone_float();
                    AnimatedProperty::Float(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Clear => {
                    let old_computed = old_style.get_box().clone_clear();
                    let new_computed = new_style.get_box().clone_clear();
                    AnimatedProperty::Clear(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::VerticalAlign => {
                    let old_computed = old_style.get_box().clone_vertical_align();
                    let new_computed = new_style.get_box().clone_vertical_align();
                    AnimatedProperty::VerticalAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowClipBoxInline => {
                    let old_computed = old_style.get_box().clone_overflow_clip_box_inline();
                    let new_computed = new_style.get_box().clone_overflow_clip_box_inline();
                    AnimatedProperty::OverflowClipBoxInline(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowClipBoxBlock => {
                    let old_computed = old_style.get_box().clone_overflow_clip_box_block();
                    let new_computed = new_style.get_box().clone_overflow_clip_box_block();
                    AnimatedProperty::OverflowClipBoxBlock(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowX => {
                    let old_computed = old_style.get_box().clone_overflow_x();
                    let new_computed = new_style.get_box().clone_overflow_x();
                    AnimatedProperty::OverflowX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowY => {
                    let old_computed = old_style.get_box().clone_overflow_y();
                    let new_computed = new_style.get_box().clone_overflow_y();
                    AnimatedProperty::OverflowY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapPointsX => {
                    let old_computed = old_style.get_box().clone_scroll_snap_points_x();
                    let new_computed = new_style.get_box().clone_scroll_snap_points_x();
                    AnimatedProperty::ScrollSnapPointsX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapPointsY => {
                    let old_computed = old_style.get_box().clone_scroll_snap_points_y();
                    let new_computed = new_style.get_box().clone_scroll_snap_points_y();
                    AnimatedProperty::ScrollSnapPointsY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapDestination => {
                    let old_computed = old_style.get_box().clone_scroll_snap_destination();
                    let new_computed = new_style.get_box().clone_scroll_snap_destination();
                    AnimatedProperty::ScrollSnapDestination(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapCoordinate => {
                    let old_computed = old_style.get_box().clone_scroll_snap_coordinate();
                    let new_computed = new_style.get_box().clone_scroll_snap_coordinate();
                    AnimatedProperty::ScrollSnapCoordinate(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Transform => {
                    let old_computed = old_style.get_box().clone_transform();
                    let new_computed = new_style.get_box().clone_transform();
                    AnimatedProperty::Transform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollBehavior => {
                    let old_computed = old_style.get_box().clone_scroll_behavior();
                    let new_computed = new_style.get_box().clone_scroll_behavior();
                    AnimatedProperty::ScrollBehavior(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapTypeX => {
                    let old_computed = old_style.get_box().clone_scroll_snap_type_x();
                    let new_computed = new_style.get_box().clone_scroll_snap_type_x();
                    AnimatedProperty::ScrollSnapTypeX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ScrollSnapTypeY => {
                    let old_computed = old_style.get_box().clone_scroll_snap_type_y();
                    let new_computed = new_style.get_box().clone_scroll_snap_type_y();
                    AnimatedProperty::ScrollSnapTypeY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverscrollBehaviorX => {
                    let old_computed = old_style.get_box().clone_overscroll_behavior_x();
                    let new_computed = new_style.get_box().clone_overscroll_behavior_x();
                    AnimatedProperty::OverscrollBehaviorX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverscrollBehaviorY => {
                    let old_computed = old_style.get_box().clone_overscroll_behavior_y();
                    let new_computed = new_style.get_box().clone_overscroll_behavior_y();
                    AnimatedProperty::OverscrollBehaviorY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Isolation => {
                    let old_computed = old_style.get_box().clone_isolation();
                    let new_computed = new_style.get_box().clone_isolation();
                    AnimatedProperty::Isolation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakAfter => {
                    let old_computed = old_style.get_box().clone_page_break_after();
                    let new_computed = new_style.get_box().clone_page_break_after();
                    AnimatedProperty::PageBreakAfter(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakBefore => {
                    let old_computed = old_style.get_box().clone_page_break_before();
                    let new_computed = new_style.get_box().clone_page_break_before();
                    AnimatedProperty::PageBreakBefore(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PageBreakInside => {
                    let old_computed = old_style.get_box().clone_page_break_inside();
                    let new_computed = new_style.get_box().clone_page_break_inside();
                    AnimatedProperty::PageBreakInside(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Resize => {
                    let old_computed = old_style.get_box().clone_resize();
                    let new_computed = new_style.get_box().clone_resize();
                    AnimatedProperty::Resize(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Perspective => {
                    let old_computed = old_style.get_box().clone_perspective();
                    let new_computed = new_style.get_box().clone_perspective();
                    AnimatedProperty::Perspective(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PerspectiveOrigin => {
                    let old_computed = old_style.get_box().clone_perspective_origin();
                    let new_computed = new_style.get_box().clone_perspective_origin();
                    AnimatedProperty::PerspectiveOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BackfaceVisibility => {
                    let old_computed = old_style.get_box().clone_backface_visibility();
                    let new_computed = new_style.get_box().clone_backface_visibility();
                    AnimatedProperty::BackfaceVisibility(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformBox => {
                    let old_computed = old_style.get_box().clone_transform_box();
                    let new_computed = new_style.get_box().clone_transform_box();
                    AnimatedProperty::TransformBox(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformStyle => {
                    let old_computed = old_style.get_box().clone_transform_style();
                    let new_computed = new_style.get_box().clone_transform_style();
                    AnimatedProperty::TransformStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TransformOrigin => {
                    let old_computed = old_style.get_box().clone_transform_origin();
                    let new_computed = new_style.get_box().clone_transform_origin();
                    AnimatedProperty::TransformOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Contain => {
                    let old_computed = old_style.get_box().clone_contain();
                    let new_computed = new_style.get_box().clone_contain();
                    AnimatedProperty::Contain(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozAppearance => {
                    let old_computed = old_style.get_box().clone__moz_appearance();
                    let new_computed = new_style.get_box().clone__moz_appearance();
                    AnimatedProperty::MozAppearance(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozOrient => {
                    let old_computed = old_style.get_box().clone__moz_orient();
                    let new_computed = new_style.get_box().clone__moz_orient();
                    AnimatedProperty::MozOrient(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WillChange => {
                    let old_computed = old_style.get_box().clone_will_change();
                    let new_computed = new_style.get_box().clone_will_change();
                    AnimatedProperty::WillChange(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeImageThreshold => {
                    let old_computed = old_style.get_box().clone_shape_image_threshold();
                    let new_computed = new_style.get_box().clone_shape_image_threshold();
                    AnimatedProperty::ShapeImageThreshold(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeOutside => {
                    let old_computed = old_style.get_box().clone_shape_outside();
                    let new_computed = new_style.get_box().clone_shape_outside();
                    AnimatedProperty::ShapeOutside(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TouchAction => {
                    let old_computed = old_style.get_box().clone_touch_action();
                    let new_computed = new_style.get_box().clone_touch_action();
                    AnimatedProperty::TouchAction(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Color => {
                    let old_computed = old_style.get_color().clone_color();
                    let new_computed = new_style.get_color().clone_color();
                    AnimatedProperty::Color(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnWidth => {
                    let old_computed = old_style.get_column().clone_column_width();
                    let new_computed = new_style.get_column().clone_column_width();
                    AnimatedProperty::ColumnWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnCount => {
                    let old_computed = old_style.get_column().clone_column_count();
                    let new_computed = new_style.get_column().clone_column_count();
                    AnimatedProperty::ColumnCount(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnGap => {
                    let old_computed = old_style.get_column().clone_column_gap();
                    let new_computed = new_style.get_column().clone_column_gap();
                    AnimatedProperty::ColumnGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnFill => {
                    let old_computed = old_style.get_column().clone_column_fill();
                    let new_computed = new_style.get_column().clone_column_fill();
                    AnimatedProperty::ColumnFill(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColumnRuleWidth => {
                    let old_computed = old_style.get_column().clone_column_rule_width();
                    let new_computed = new_style.get_column().clone_column_rule_width();
                    AnimatedProperty::ColumnRuleWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnRuleColor => {
                    let old_computed = old_style.get_column().clone_column_rule_color();
                    let new_computed = new_style.get_column().clone_column_rule_color();
                    AnimatedProperty::ColumnRuleColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::ColumnSpan => {
                    let old_computed = old_style.get_column().clone_column_span();
                    let new_computed = new_style.get_column().clone_column_span();
                    AnimatedProperty::ColumnSpan(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColumnRuleStyle => {
                    let old_computed = old_style.get_column().clone_column_rule_style();
                    let new_computed = new_style.get_column().clone_column_rule_style();
                    AnimatedProperty::ColumnRuleStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Content => {
                    let old_computed = old_style.get_counters().clone_content();
                    let new_computed = new_style.get_counters().clone_content();
                    AnimatedProperty::Content(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CounterIncrement => {
                    let old_computed = old_style.get_counters().clone_counter_increment();
                    let new_computed = new_style.get_counters().clone_counter_increment();
                    AnimatedProperty::CounterIncrement(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CounterReset => {
                    let old_computed = old_style.get_counters().clone_counter_reset();
                    let new_computed = new_style.get_counters().clone_counter_reset();
                    AnimatedProperty::CounterReset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Opacity => {
                    let old_computed = old_style.get_effects().clone_opacity();
                    let new_computed = new_style.get_effects().clone_opacity();
                    AnimatedProperty::Opacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BoxShadow => {
                    let old_computed = old_style.get_effects().clone_box_shadow();
                    let new_computed = new_style.get_effects().clone_box_shadow();
                    AnimatedProperty::BoxShadow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Clip => {
                    let old_computed = old_style.get_effects().clone_clip();
                    let new_computed = new_style.get_effects().clone_clip();
                    AnimatedProperty::Clip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Filter => {
                    let old_computed = old_style.get_effects().clone_filter();
                    let new_computed = new_style.get_effects().clone_filter();
                    AnimatedProperty::Filter(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MixBlendMode => {
                    let old_computed = old_style.get_effects().clone_mix_blend_mode();
                    let new_computed = new_style.get_effects().clone_mix_blend_mode();
                    AnimatedProperty::MixBlendMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontFamily => {
                    let old_computed = old_style.get_font().clone_font_family();
                    let new_computed = new_style.get_font().clone_font_family();
                    AnimatedProperty::FontFamily(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontStyle => {
                    let old_computed = old_style.get_font().clone_font_style();
                    let new_computed = new_style.get_font().clone_font_style();
                    AnimatedProperty::FontStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantCaps => {
                    let old_computed = old_style.get_font().clone_font_variant_caps();
                    let new_computed = new_style.get_font().clone_font_variant_caps();
                    AnimatedProperty::FontVariantCaps(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontWeight => {
                    let old_computed = old_style.get_font().clone_font_weight();
                    let new_computed = new_style.get_font().clone_font_weight();
                    AnimatedProperty::FontWeight(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontSize => {
                    let old_computed = old_style.get_font().clone_font_size();
                    let new_computed = new_style.get_font().clone_font_size();
                    AnimatedProperty::FontSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FontSizeAdjust => {
                    let old_computed = old_style.get_font().clone_font_size_adjust();
                    let new_computed = new_style.get_font().clone_font_size_adjust();
                    AnimatedProperty::FontSizeAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontSynthesis => {
                    let old_computed = old_style.get_font().clone_font_synthesis();
                    let new_computed = new_style.get_font().clone_font_synthesis();
                    AnimatedProperty::FontSynthesis(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontStretch => {
                    let old_computed = old_style.get_font().clone_font_stretch();
                    let new_computed = new_style.get_font().clone_font_stretch();
                    AnimatedProperty::FontStretch(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontKerning => {
                    let old_computed = old_style.get_font().clone_font_kerning();
                    let new_computed = new_style.get_font().clone_font_kerning();
                    AnimatedProperty::FontKerning(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantAlternates => {
                    let old_computed = old_style.get_font().clone_font_variant_alternates();
                    let new_computed = new_style.get_font().clone_font_variant_alternates();
                    AnimatedProperty::FontVariantAlternates(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantEastAsian => {
                    let old_computed = old_style.get_font().clone_font_variant_east_asian();
                    let new_computed = new_style.get_font().clone_font_variant_east_asian();
                    AnimatedProperty::FontVariantEastAsian(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantLigatures => {
                    let old_computed = old_style.get_font().clone_font_variant_ligatures();
                    let new_computed = new_style.get_font().clone_font_variant_ligatures();
                    AnimatedProperty::FontVariantLigatures(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantNumeric => {
                    let old_computed = old_style.get_font().clone_font_variant_numeric();
                    let new_computed = new_style.get_font().clone_font_variant_numeric();
                    AnimatedProperty::FontVariantNumeric(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariantPosition => {
                    let old_computed = old_style.get_font().clone_font_variant_position();
                    let new_computed = new_style.get_font().clone_font_variant_position();
                    AnimatedProperty::FontVariantPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontFeatureSettings => {
                    let old_computed = old_style.get_font().clone_font_feature_settings();
                    let new_computed = new_style.get_font().clone_font_feature_settings();
                    AnimatedProperty::FontFeatureSettings(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontVariationSettings => {
                    let old_computed = old_style.get_font().clone_font_variation_settings();
                    let new_computed = new_style.get_font().clone_font_variation_settings();
                    AnimatedProperty::FontVariationSettings(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FontLanguageOverride => {
                    let old_computed = old_style.get_font().clone_font_language_override();
                    let new_computed = new_style.get_font().clone_font_language_override();
                    AnimatedProperty::FontLanguageOverride(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozOsxFontSmoothing => {
                    let old_computed = old_style.get_font().clone__moz_osx_font_smoothing();
                    let new_computed = new_style.get_font().clone__moz_osx_font_smoothing();
                    AnimatedProperty::MozOsxFontSmoothing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozFontSmoothingBackgroundColor => {
                    let old_computed = old_style.get_font().clone__moz_font_smoothing_background_color();
                    let new_computed = new_style.get_font().clone__moz_font_smoothing_background_color();
                    AnimatedProperty::MozFontSmoothingBackgroundColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Visibility => {
                    let old_computed = old_style.get_inheritedbox().clone_visibility();
                    let new_computed = new_style.get_inheritedbox().clone_visibility();
                    AnimatedProperty::Visibility(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WritingMode => {
                    let old_computed = old_style.get_inheritedbox().clone_writing_mode();
                    let new_computed = new_style.get_inheritedbox().clone_writing_mode();
                    AnimatedProperty::WritingMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Direction => {
                    let old_computed = old_style.get_inheritedbox().clone_direction();
                    let new_computed = new_style.get_inheritedbox().clone_direction();
                    AnimatedProperty::Direction(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextOrientation => {
                    let old_computed = old_style.get_inheritedbox().clone_text_orientation();
                    let new_computed = new_style.get_inheritedbox().clone_text_orientation();
                    AnimatedProperty::TextOrientation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorAdjust => {
                    let old_computed = old_style.get_inheritedbox().clone_color_adjust();
                    let new_computed = new_style.get_inheritedbox().clone_color_adjust();
                    AnimatedProperty::ColorAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImageRendering => {
                    let old_computed = old_style.get_inheritedbox().clone_image_rendering();
                    let new_computed = new_style.get_inheritedbox().clone_image_rendering();
                    AnimatedProperty::ImageRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImageOrientation => {
                    let old_computed = old_style.get_inheritedbox().clone_image_orientation();
                    let new_computed = new_style.get_inheritedbox().clone_image_orientation();
                    AnimatedProperty::ImageOrientation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderCollapse => {
                    let old_computed = old_style.get_inheritedtable().clone_border_collapse();
                    let new_computed = new_style.get_inheritedtable().clone_border_collapse();
                    AnimatedProperty::BorderCollapse(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::EmptyCells => {
                    let old_computed = old_style.get_inheritedtable().clone_empty_cells();
                    let new_computed = new_style.get_inheritedtable().clone_empty_cells();
                    AnimatedProperty::EmptyCells(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CaptionSide => {
                    let old_computed = old_style.get_inheritedtable().clone_caption_side();
                    let new_computed = new_style.get_inheritedtable().clone_caption_side();
                    AnimatedProperty::CaptionSide(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::BorderSpacing => {
                    let old_computed = old_style.get_inheritedtable().clone_border_spacing();
                    let new_computed = new_style.get_inheritedtable().clone_border_spacing();
                    AnimatedProperty::BorderSpacing(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::LineHeight => {
                    let old_computed = old_style.get_inheritedtext().clone_line_height();
                    let new_computed = new_style.get_inheritedtext().clone_line_height();
                    AnimatedProperty::LineHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::TextTransform => {
                    let old_computed = old_style.get_inheritedtext().clone_text_transform();
                    let new_computed = new_style.get_inheritedtext().clone_text_transform();
                    AnimatedProperty::TextTransform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Hyphens => {
                    let old_computed = old_style.get_inheritedtext().clone_hyphens();
                    let new_computed = new_style.get_inheritedtext().clone_hyphens();
                    AnimatedProperty::Hyphens(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozTextSizeAdjust => {
                    let old_computed = old_style.get_inheritedtext().clone__moz_text_size_adjust();
                    let new_computed = new_style.get_inheritedtext().clone__moz_text_size_adjust();
                    AnimatedProperty::MozTextSizeAdjust(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextIndent => {
                    let old_computed = old_style.get_inheritedtext().clone_text_indent();
                    let new_computed = new_style.get_inheritedtext().clone_text_indent();
                    AnimatedProperty::TextIndent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OverflowWrap => {
                    let old_computed = old_style.get_inheritedtext().clone_overflow_wrap();
                    let new_computed = new_style.get_inheritedtext().clone_overflow_wrap();
                    AnimatedProperty::OverflowWrap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WordBreak => {
                    let old_computed = old_style.get_inheritedtext().clone_word_break();
                    let new_computed = new_style.get_inheritedtext().clone_word_break();
                    AnimatedProperty::WordBreak(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextJustify => {
                    let old_computed = old_style.get_inheritedtext().clone_text_justify();
                    let new_computed = new_style.get_inheritedtext().clone_text_justify();
                    AnimatedProperty::TextJustify(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextAlignLast => {
                    let old_computed = old_style.get_inheritedtext().clone_text_align_last();
                    let new_computed = new_style.get_inheritedtext().clone_text_align_last();
                    AnimatedProperty::TextAlignLast(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextAlign => {
                    let old_computed = old_style.get_inheritedtext().clone_text_align();
                    let new_computed = new_style.get_inheritedtext().clone_text_align();
                    AnimatedProperty::TextAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::LetterSpacing => {
                    let old_computed = old_style.get_inheritedtext().clone_letter_spacing();
                    let new_computed = new_style.get_inheritedtext().clone_letter_spacing();
                    AnimatedProperty::LetterSpacing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WordSpacing => {
                    let old_computed = old_style.get_inheritedtext().clone_word_spacing();
                    let new_computed = new_style.get_inheritedtext().clone_word_spacing();
                    AnimatedProperty::WordSpacing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::WhiteSpace => {
                    let old_computed = old_style.get_inheritedtext().clone_white_space();
                    let new_computed = new_style.get_inheritedtext().clone_white_space();
                    AnimatedProperty::WhiteSpace(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextShadow => {
                    let old_computed = old_style.get_inheritedtext().clone_text_shadow();
                    let new_computed = new_style.get_inheritedtext().clone_text_shadow();
                    AnimatedProperty::TextShadow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::TextEmphasisStyle => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_style();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_style();
                    AnimatedProperty::TextEmphasisStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextEmphasisPosition => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_position();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_position();
                    AnimatedProperty::TextEmphasisPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextEmphasisColor => {
                    let old_computed = old_style.get_inheritedtext().clone_text_emphasis_color();
                    let new_computed = new_style.get_inheritedtext().clone_text_emphasis_color();
                    AnimatedProperty::TextEmphasisColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozTabSize => {
                    let old_computed = old_style.get_inheritedtext().clone__moz_tab_size();
                    let new_computed = new_style.get_inheritedtext().clone__moz_tab_size();
                    AnimatedProperty::MozTabSize(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextFillColor => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_fill_color();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_fill_color();
                    AnimatedProperty::WebkitTextFillColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextStrokeColor => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_stroke_color();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_stroke_color();
                    AnimatedProperty::WebkitTextStrokeColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::WebkitTextStrokeWidth => {
                    let old_computed = old_style.get_inheritedtext().clone__webkit_text_stroke_width();
                    let new_computed = new_style.get_inheritedtext().clone__webkit_text_stroke_width();
                    AnimatedProperty::WebkitTextStrokeWidth(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::RubyAlign => {
                    let old_computed = old_style.get_inheritedtext().clone_ruby_align();
                    let new_computed = new_style.get_inheritedtext().clone_ruby_align();
                    AnimatedProperty::RubyAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::RubyPosition => {
                    let old_computed = old_style.get_inheritedtext().clone_ruby_position();
                    let new_computed = new_style.get_inheritedtext().clone_ruby_position();
                    AnimatedProperty::RubyPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextCombineUpright => {
                    let old_computed = old_style.get_inheritedtext().clone_text_combine_upright();
                    let new_computed = new_style.get_inheritedtext().clone_text_combine_upright();
                    AnimatedProperty::TextCombineUpright(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextRendering => {
                    let old_computed = old_style.get_inheritedtext().clone_text_rendering();
                    let new_computed = new_style.get_inheritedtext().clone_text_rendering();
                    AnimatedProperty::TextRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ListStylePosition => {
                    let old_computed = old_style.get_list().clone_list_style_position();
                    let new_computed = new_style.get_list().clone_list_style_position();
                    AnimatedProperty::ListStylePosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ListStyleType => {
                    let old_computed = old_style.get_list().clone_list_style_type();
                    let new_computed = new_style.get_list().clone_list_style_type();
                    AnimatedProperty::ListStyleType(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ListStyleImage => {
                    let old_computed = old_style.get_list().clone_list_style_image();
                    let new_computed = new_style.get_list().clone_list_style_image();
                    AnimatedProperty::ListStyleImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Quotes => {
                    let old_computed = old_style.get_list().clone_quotes();
                    let new_computed = new_style.get_list().clone_quotes();
                    AnimatedProperty::Quotes(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozImageRegion => {
                    let old_computed = old_style.get_list().clone__moz_image_region();
                    let new_computed = new_style.get_list().clone__moz_image_region();
                    AnimatedProperty::MozImageRegion(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginTop => {
                    let old_computed = old_style.get_margin().clone_margin_top();
                    let new_computed = new_style.get_margin().clone_margin_top();
                    AnimatedProperty::MarginTop(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginLeft => {
                    let old_computed = old_style.get_margin().clone_margin_left();
                    let new_computed = new_style.get_margin().clone_margin_left();
                    AnimatedProperty::MarginLeft(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginBottom => {
                    let old_computed = old_style.get_margin().clone_margin_bottom();
                    let new_computed = new_style.get_margin().clone_margin_bottom();
                    AnimatedProperty::MarginBottom(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarginRight => {
                    let old_computed = old_style.get_margin().clone_margin_right();
                    let new_computed = new_style.get_margin().clone_margin_right();
                    AnimatedProperty::MarginRight(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OutlineColor => {
                    let old_computed = old_style.get_outline().clone_outline_color();
                    let new_computed = new_style.get_outline().clone_outline_color();
                    AnimatedProperty::OutlineColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::OutlineStyle => {
                    let old_computed = old_style.get_outline().clone_outline_style();
                    let new_computed = new_style.get_outline().clone_outline_style();
                    AnimatedProperty::OutlineStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::OutlineWidth => {
                    let old_computed = old_style.get_outline().clone_outline_width();
                    let new_computed = new_style.get_outline().clone_outline_width();
                    AnimatedProperty::OutlineWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusTopleft => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_topleft();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_topleft();
                    AnimatedProperty::MozOutlineRadiusTopleft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusTopright => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_topright();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_topright();
                    AnimatedProperty::MozOutlineRadiusTopright(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusBottomright => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_bottomright();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_bottomright();
                    AnimatedProperty::MozOutlineRadiusBottomright(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozOutlineRadiusBottomleft => {
                    let old_computed = old_style.get_outline().clone__moz_outline_radius_bottomleft();
                    let new_computed = new_style.get_outline().clone__moz_outline_radius_bottomleft();
                    AnimatedProperty::MozOutlineRadiusBottomleft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::OutlineOffset => {
                    let old_computed = old_style.get_outline().clone_outline_offset();
                    let new_computed = new_style.get_outline().clone_outline_offset();
                    AnimatedProperty::OutlineOffset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PaddingTop => {
                    let old_computed = old_style.get_padding().clone_padding_top();
                    let new_computed = new_style.get_padding().clone_padding_top();
                    AnimatedProperty::PaddingTop(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingLeft => {
                    let old_computed = old_style.get_padding().clone_padding_left();
                    let new_computed = new_style.get_padding().clone_padding_left();
                    AnimatedProperty::PaddingLeft(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingBottom => {
                    let old_computed = old_style.get_padding().clone_padding_bottom();
                    let new_computed = new_style.get_padding().clone_padding_bottom();
                    AnimatedProperty::PaddingBottom(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::PaddingRight => {
                    let old_computed = old_style.get_padding().clone_padding_right();
                    let new_computed = new_style.get_padding().clone_padding_right();
                    AnimatedProperty::PaddingRight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Cursor => {
                    let old_computed = old_style.get_pointing().clone_cursor();
                    let new_computed = new_style.get_pointing().clone_cursor();
                    AnimatedProperty::Cursor(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PointerEvents => {
                    let old_computed = old_style.get_pointing().clone_pointer_events();
                    let new_computed = new_style.get_pointing().clone_pointer_events();
                    AnimatedProperty::PointerEvents(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserInput => {
                    let old_computed = old_style.get_pointing().clone__moz_user_input();
                    let new_computed = new_style.get_pointing().clone__moz_user_input();
                    AnimatedProperty::MozUserInput(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserModify => {
                    let old_computed = old_style.get_pointing().clone__moz_user_modify();
                    let new_computed = new_style.get_pointing().clone__moz_user_modify();
                    AnimatedProperty::MozUserModify(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserFocus => {
                    let old_computed = old_style.get_pointing().clone__moz_user_focus();
                    let new_computed = new_style.get_pointing().clone__moz_user_focus();
                    AnimatedProperty::MozUserFocus(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::CaretColor => {
                    let old_computed = old_style.get_pointing().clone_caret_color();
                    let new_computed = new_style.get_pointing().clone_caret_color();
                    AnimatedProperty::CaretColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Top => {
                    let old_computed = old_style.get_position().clone_top();
                    let new_computed = new_style.get_position().clone_top();
                    AnimatedProperty::Top(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Left => {
                    let old_computed = old_style.get_position().clone_left();
                    let new_computed = new_style.get_position().clone_left();
                    AnimatedProperty::Left(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Bottom => {
                    let old_computed = old_style.get_position().clone_bottom();
                    let new_computed = new_style.get_position().clone_bottom();
                    AnimatedProperty::Bottom(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Right => {
                    let old_computed = old_style.get_position().clone_right();
                    let new_computed = new_style.get_position().clone_right();
                    AnimatedProperty::Right(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ZIndex => {
                    let old_computed = old_style.get_position().clone_z_index();
                    let new_computed = new_style.get_position().clone_z_index();
                    AnimatedProperty::ZIndex(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexDirection => {
                    let old_computed = old_style.get_position().clone_flex_direction();
                    let new_computed = new_style.get_position().clone_flex_direction();
                    AnimatedProperty::FlexDirection(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexWrap => {
                    let old_computed = old_style.get_position().clone_flex_wrap();
                    let new_computed = new_style.get_position().clone_flex_wrap();
                    AnimatedProperty::FlexWrap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifyContent => {
                    let old_computed = old_style.get_position().clone_justify_content();
                    let new_computed = new_style.get_position().clone_justify_content();
                    AnimatedProperty::JustifyContent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::AlignContent => {
                    let old_computed = old_style.get_position().clone_align_content();
                    let new_computed = new_style.get_position().clone_align_content();
                    AnimatedProperty::AlignContent(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::AlignItems => {
                    let old_computed = old_style.get_position().clone_align_items();
                    let new_computed = new_style.get_position().clone_align_items();
                    AnimatedProperty::AlignItems(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifyItems => {
                    let old_computed = old_style.get_position().clone_justify_items();
                    let new_computed = new_style.get_position().clone_justify_items();
                    AnimatedProperty::JustifyItems(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexGrow => {
                    let old_computed = old_style.get_position().clone_flex_grow();
                    let new_computed = new_style.get_position().clone_flex_grow();
                    AnimatedProperty::FlexGrow(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FlexShrink => {
                    let old_computed = old_style.get_position().clone_flex_shrink();
                    let new_computed = new_style.get_position().clone_flex_shrink();
                    AnimatedProperty::FlexShrink(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::AlignSelf => {
                    let old_computed = old_style.get_position().clone_align_self();
                    let new_computed = new_style.get_position().clone_align_self();
                    AnimatedProperty::AlignSelf(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::JustifySelf => {
                    let old_computed = old_style.get_position().clone_justify_self();
                    let new_computed = new_style.get_position().clone_justify_self();
                    AnimatedProperty::JustifySelf(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Order => {
                    let old_computed = old_style.get_position().clone_order();
                    let new_computed = new_style.get_position().clone_order();
                    AnimatedProperty::Order(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FlexBasis => {
                    let old_computed = old_style.get_position().clone_flex_basis();
                    let new_computed = new_style.get_position().clone_flex_basis();
                    AnimatedProperty::FlexBasis(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Width => {
                    let old_computed = old_style.get_position().clone_width();
                    let new_computed = new_style.get_position().clone_width();
                    AnimatedProperty::Width(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MinWidth => {
                    let old_computed = old_style.get_position().clone_min_width();
                    let new_computed = new_style.get_position().clone_min_width();
                    AnimatedProperty::MinWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MaxWidth => {
                    let old_computed = old_style.get_position().clone_max_width();
                    let new_computed = new_style.get_position().clone_max_width();
                    AnimatedProperty::MaxWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::Height => {
                    let old_computed = old_style.get_position().clone_height();
                    let new_computed = new_style.get_position().clone_height();
                    AnimatedProperty::Height(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MinHeight => {
                    let old_computed = old_style.get_position().clone_min_height();
                    let new_computed = new_style.get_position().clone_min_height();
                    AnimatedProperty::MinHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MaxHeight => {
                    let old_computed = old_style.get_position().clone_max_height();
                    let new_computed = new_style.get_position().clone_max_height();
                    AnimatedProperty::MaxHeight(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::BoxSizing => {
                    let old_computed = old_style.get_position().clone_box_sizing();
                    let new_computed = new_style.get_position().clone_box_sizing();
                    AnimatedProperty::BoxSizing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ObjectFit => {
                    let old_computed = old_style.get_position().clone_object_fit();
                    let new_computed = new_style.get_position().clone_object_fit();
                    AnimatedProperty::ObjectFit(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ObjectPosition => {
                    let old_computed = old_style.get_position().clone_object_position();
                    let new_computed = new_style.get_position().clone_object_position();
                    AnimatedProperty::ObjectPosition(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridRowGap => {
                    let old_computed = old_style.get_position().clone_grid_row_gap();
                    let new_computed = new_style.get_position().clone_grid_row_gap();
                    AnimatedProperty::GridRowGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::GridRowStart => {
                    let old_computed = old_style.get_position().clone_grid_row_start();
                    let new_computed = new_style.get_position().clone_grid_row_start();
                    AnimatedProperty::GridRowStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridRowEnd => {
                    let old_computed = old_style.get_position().clone_grid_row_end();
                    let new_computed = new_style.get_position().clone_grid_row_end();
                    AnimatedProperty::GridRowEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridAutoRows => {
                    let old_computed = old_style.get_position().clone_grid_auto_rows();
                    let new_computed = new_style.get_position().clone_grid_auto_rows();
                    AnimatedProperty::GridAutoRows(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateRows => {
                    let old_computed = old_style.get_position().clone_grid_template_rows();
                    let new_computed = new_style.get_position().clone_grid_template_rows();
                    AnimatedProperty::GridTemplateRows(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridColumnGap => {
                    let old_computed = old_style.get_position().clone_grid_column_gap();
                    let new_computed = new_style.get_position().clone_grid_column_gap();
                    AnimatedProperty::GridColumnGap(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::GridColumnStart => {
                    let old_computed = old_style.get_position().clone_grid_column_start();
                    let new_computed = new_style.get_position().clone_grid_column_start();
                    AnimatedProperty::GridColumnStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridColumnEnd => {
                    let old_computed = old_style.get_position().clone_grid_column_end();
                    let new_computed = new_style.get_position().clone_grid_column_end();
                    AnimatedProperty::GridColumnEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridAutoColumns => {
                    let old_computed = old_style.get_position().clone_grid_auto_columns();
                    let new_computed = new_style.get_position().clone_grid_auto_columns();
                    AnimatedProperty::GridAutoColumns(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateColumns => {
                    let old_computed = old_style.get_position().clone_grid_template_columns();
                    let new_computed = new_style.get_position().clone_grid_template_columns();
                    AnimatedProperty::GridTemplateColumns(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridAutoFlow => {
                    let old_computed = old_style.get_position().clone_grid_auto_flow();
                    let new_computed = new_style.get_position().clone_grid_auto_flow();
                    AnimatedProperty::GridAutoFlow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::GridTemplateAreas => {
                    let old_computed = old_style.get_position().clone_grid_template_areas();
                    let new_computed = new_style.get_position().clone_grid_template_areas();
                    AnimatedProperty::GridTemplateAreas(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TableLayout => {
                    let old_computed = old_style.get_table().clone_table_layout();
                    let new_computed = new_style.get_table().clone_table_layout();
                    AnimatedProperty::TableLayout(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextOverflow => {
                    let old_computed = old_style.get_text().clone_text_overflow();
                    let new_computed = new_style.get_text().clone_text_overflow();
                    AnimatedProperty::TextOverflow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::UnicodeBidi => {
                    let old_computed = old_style.get_text().clone_unicode_bidi();
                    let new_computed = new_style.get_text().clone_unicode_bidi();
                    AnimatedProperty::UnicodeBidi(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextDecorationLine => {
                    let old_computed = old_style.get_text().clone_text_decoration_line();
                    let new_computed = new_style.get_text().clone_text_decoration_line();
                    AnimatedProperty::TextDecorationLine(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextDecorationStyle => {
                    let old_computed = old_style.get_text().clone_text_decoration_style();
                    let new_computed = new_style.get_text().clone_text_decoration_style();
                    AnimatedProperty::TextDecorationStyle(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextDecorationColor => {
                    let old_computed = old_style.get_text().clone_text_decoration_color();
                    let new_computed = new_style.get_text().clone_text_decoration_color();
                    AnimatedProperty::TextDecorationColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::InitialLetter => {
                    let old_computed = old_style.get_text().clone_initial_letter();
                    let new_computed = new_style.get_text().clone_initial_letter();
                    AnimatedProperty::InitialLetter(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ImeMode => {
                    let old_computed = old_style.get_ui().clone_ime_mode();
                    let new_computed = new_style.get_ui().clone_ime_mode();
                    AnimatedProperty::ImeMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozUserSelect => {
                    let old_computed = old_style.get_ui().clone__moz_user_select();
                    let new_computed = new_style.get_ui().clone__moz_user_select();
                    AnimatedProperty::MozUserSelect(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowDragging => {
                    let old_computed = old_style.get_ui().clone__moz_window_dragging();
                    let new_computed = new_style.get_ui().clone__moz_window_dragging();
                    AnimatedProperty::MozWindowDragging(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowShadow => {
                    let old_computed = old_style.get_ui().clone__moz_window_shadow();
                    let new_computed = new_style.get_ui().clone__moz_window_shadow();
                    AnimatedProperty::MozWindowShadow(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowOpacity => {
                    let old_computed = old_style.get_ui().clone__moz_window_opacity();
                    let new_computed = new_style.get_ui().clone__moz_window_opacity();
                    AnimatedProperty::MozWindowOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowTransform => {
                    let old_computed = old_style.get_ui().clone__moz_window_transform();
                    let new_computed = new_style.get_ui().clone__moz_window_transform();
                    AnimatedProperty::MozWindowTransform(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozWindowTransformOrigin => {
                    let old_computed = old_style.get_ui().clone__moz_window_transform_origin();
                    let new_computed = new_style.get_ui().clone__moz_window_transform_origin();
                    AnimatedProperty::MozWindowTransformOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozForceBrokenImageIcon => {
                    let old_computed = old_style.get_ui().clone__moz_force_broken_image_icon();
                    let new_computed = new_style.get_ui().clone__moz_force_broken_image_icon();
                    AnimatedProperty::MozForceBrokenImageIcon(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::TextAnchor => {
                    let old_computed = old_style.get_inheritedsvg().clone_text_anchor();
                    let new_computed = new_style.get_inheritedsvg().clone_text_anchor();
                    AnimatedProperty::TextAnchor(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorInterpolation => {
                    let old_computed = old_style.get_inheritedsvg().clone_color_interpolation();
                    let new_computed = new_style.get_inheritedsvg().clone_color_interpolation();
                    AnimatedProperty::ColorInterpolation(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ColorInterpolationFilters => {
                    let old_computed = old_style.get_inheritedsvg().clone_color_interpolation_filters();
                    let new_computed = new_style.get_inheritedsvg().clone_color_interpolation_filters();
                    AnimatedProperty::ColorInterpolationFilters(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Fill => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill();
                    let new_computed = new_style.get_inheritedsvg().clone_fill();
                    AnimatedProperty::Fill(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FillOpacity => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill_opacity();
                    let new_computed = new_style.get_inheritedsvg().clone_fill_opacity();
                    AnimatedProperty::FillOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FillRule => {
                    let old_computed = old_style.get_inheritedsvg().clone_fill_rule();
                    let new_computed = new_style.get_inheritedsvg().clone_fill_rule();
                    AnimatedProperty::FillRule(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ShapeRendering => {
                    let old_computed = old_style.get_inheritedsvg().clone_shape_rendering();
                    let new_computed = new_style.get_inheritedsvg().clone_shape_rendering();
                    AnimatedProperty::ShapeRendering(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::Stroke => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke();
                    AnimatedProperty::Stroke(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeWidth => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_width();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_width();
                    AnimatedProperty::StrokeWidth(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeLinecap => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_linecap();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_linecap();
                    AnimatedProperty::StrokeLinecap(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeLinejoin => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_linejoin();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_linejoin();
                    AnimatedProperty::StrokeLinejoin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeMiterlimit => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_miterlimit();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_miterlimit();
                    AnimatedProperty::StrokeMiterlimit(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeOpacity => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_opacity();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_opacity();
                    AnimatedProperty::StrokeOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StrokeDasharray => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_dasharray();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_dasharray();
                    AnimatedProperty::StrokeDasharray(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StrokeDashoffset => {
                    let old_computed = old_style.get_inheritedsvg().clone_stroke_dashoffset();
                    let new_computed = new_style.get_inheritedsvg().clone_stroke_dashoffset();
                    AnimatedProperty::StrokeDashoffset(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ClipRule => {
                    let old_computed = old_style.get_inheritedsvg().clone_clip_rule();
                    let new_computed = new_style.get_inheritedsvg().clone_clip_rule();
                    AnimatedProperty::ClipRule(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarkerStart => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_start();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_start();
                    AnimatedProperty::MarkerStart(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarkerMid => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_mid();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_mid();
                    AnimatedProperty::MarkerMid(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MarkerEnd => {
                    let old_computed = old_style.get_inheritedsvg().clone_marker_end();
                    let new_computed = new_style.get_inheritedsvg().clone_marker_end();
                    AnimatedProperty::MarkerEnd(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::PaintOrder => {
                    let old_computed = old_style.get_inheritedsvg().clone_paint_order();
                    let new_computed = new_style.get_inheritedsvg().clone_paint_order();
                    AnimatedProperty::PaintOrder(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::DominantBaseline => {
                    let old_computed = old_style.get_svg().clone_dominant_baseline();
                    let new_computed = new_style.get_svg().clone_dominant_baseline();
                    AnimatedProperty::DominantBaseline(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::VectorEffect => {
                    let old_computed = old_style.get_svg().clone_vector_effect();
                    let new_computed = new_style.get_svg().clone_vector_effect();
                    AnimatedProperty::VectorEffect(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::StopColor => {
                    let old_computed = old_style.get_svg().clone_stop_color();
                    let new_computed = new_style.get_svg().clone_stop_color();
                    AnimatedProperty::StopColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::StopOpacity => {
                    let old_computed = old_style.get_svg().clone_stop_opacity();
                    let new_computed = new_style.get_svg().clone_stop_opacity();
                    AnimatedProperty::StopOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::FloodColor => {
                    let old_computed = old_style.get_svg().clone_flood_color();
                    let new_computed = new_style.get_svg().clone_flood_color();
                    AnimatedProperty::FloodColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::FloodOpacity => {
                    let old_computed = old_style.get_svg().clone_flood_opacity();
                    let new_computed = new_style.get_svg().clone_flood_opacity();
                    AnimatedProperty::FloodOpacity(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::LightingColor => {
                    let old_computed = old_style.get_svg().clone_lighting_color();
                    let new_computed = new_style.get_svg().clone_lighting_color();
                    AnimatedProperty::LightingColor(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MaskType => {
                    let old_computed = old_style.get_svg().clone_mask_type();
                    let new_computed = new_style.get_svg().clone_mask_type();
                    AnimatedProperty::MaskType(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::ClipPath => {
                    let old_computed = old_style.get_svg().clone_clip_path();
                    let new_computed = new_style.get_svg().clone_clip_path();
                    AnimatedProperty::ClipPath(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskMode => {
                    let old_computed = old_style.get_svg().clone_mask_mode();
                    let new_computed = new_style.get_svg().clone_mask_mode();
                    AnimatedProperty::MaskMode(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskRepeat => {
                    let old_computed = old_style.get_svg().clone_mask_repeat();
                    let new_computed = new_style.get_svg().clone_mask_repeat();
                    AnimatedProperty::MaskRepeat(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskPositionX => {
                    let old_computed = old_style.get_svg().clone_mask_position_x();
                    let new_computed = new_style.get_svg().clone_mask_position_x();
                    AnimatedProperty::MaskPositionX(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskPositionY => {
                    let old_computed = old_style.get_svg().clone_mask_position_y();
                    let new_computed = new_style.get_svg().clone_mask_position_y();
                    AnimatedProperty::MaskPositionY(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskClip => {
                    let old_computed = old_style.get_svg().clone_mask_clip();
                    let new_computed = new_style.get_svg().clone_mask_clip();
                    AnimatedProperty::MaskClip(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskOrigin => {
                    let old_computed = old_style.get_svg().clone_mask_origin();
                    let new_computed = new_style.get_svg().clone_mask_origin();
                    AnimatedProperty::MaskOrigin(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskSize => {
                    let old_computed = old_style.get_svg().clone_mask_size();
                    let new_computed = new_style.get_svg().clone_mask_size();
                    AnimatedProperty::MaskSize(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskComposite => {
                    let old_computed = old_style.get_svg().clone_mask_composite();
                    let new_computed = new_style.get_svg().clone_mask_composite();
                    AnimatedProperty::MaskComposite(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MaskImage => {
                    let old_computed = old_style.get_svg().clone_mask_image();
                    let new_computed = new_style.get_svg().clone_mask_image();
                    AnimatedProperty::MaskImage(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxAlign => {
                    let old_computed = old_style.get_xul().clone__moz_box_align();
                    let new_computed = new_style.get_xul().clone__moz_box_align();
                    AnimatedProperty::MozBoxAlign(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxDirection => {
                    let old_computed = old_style.get_xul().clone__moz_box_direction();
                    let new_computed = new_style.get_xul().clone__moz_box_direction();
                    AnimatedProperty::MozBoxDirection(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxFlex => {
                    let old_computed = old_style.get_xul().clone__moz_box_flex();
                    let new_computed = new_style.get_xul().clone__moz_box_flex();
                    AnimatedProperty::MozBoxFlex(
                        old_computed.to_animated_value(),
                        new_computed.to_animated_value(),
                    )
                }
                LonghandId::MozBoxOrient => {
                    let old_computed = old_style.get_xul().clone__moz_box_orient();
                    let new_computed = new_style.get_xul().clone__moz_box_orient();
                    AnimatedProperty::MozBoxOrient(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxPack => {
                    let old_computed = old_style.get_xul().clone__moz_box_pack();
                    let new_computed = new_style.get_xul().clone__moz_box_pack();
                    AnimatedProperty::MozBoxPack(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozStackSizing => {
                    let old_computed = old_style.get_xul().clone__moz_stack_sizing();
                    let new_computed = new_style.get_xul().clone__moz_stack_sizing();
                    AnimatedProperty::MozStackSizing(
                        old_computed,
                        new_computed,
                    )
                }
                LonghandId::MozBoxOrdinalGroup => {
                    let old_computed = old_style.get_xul().clone__moz_box_ordinal_group();
                    let new_computed = new_style.get_xul().clone__moz_box_ordinal_group();
                    AnimatedProperty::MozBoxOrdinalGroup(
                        old_computed,
                        new_computed,
                    )
                }
            _ => return None,
        })
    }
}

/// A collection of AnimationValue that were composed on an element.
/// This HashMap stores the values that are the last AnimationValue to be
/// composed for each TransitionProperty.
#[cfg(feature = "gecko")]
pub type AnimationValueMap = FnvHashMap<LonghandId, AnimationValue>;
#[cfg(feature = "gecko")]
unsafe impl HasFFI for AnimationValueMap {
    type FFIType = RawServoAnimationValueMap;
}
#[cfg(feature = "gecko")]
unsafe impl HasSimpleFFI for AnimationValueMap {}

/// An enum to represent a single computed value belonging to an animated
/// property in order to be interpolated with another one. When interpolating,
/// both values need to belong to the same property.
///
/// This is different to AnimatedProperty in the sense that AnimatedProperty
/// also knows the final value to be used during the animation.
///
/// This is to be used in Gecko integration code.
///
/// FIXME: We need to add a path for custom properties, but that's trivial after
/// this (is a similar path to that of PropertyDeclaration).
#[derive(Clone, Debug, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum AnimationValue {
            /// background-color
                BackgroundColor(<longhands::background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// background-image
                BackgroundImage(longhands::background_image::computed_value::T),
            /// background-position-x
                BackgroundPositionX(longhands::background_position_x::computed_value::T),
            /// background-position-y
                BackgroundPositionY(longhands::background_position_y::computed_value::T),
            /// background-repeat
                BackgroundRepeat(longhands::background_repeat::computed_value::T),
            /// background-attachment
                BackgroundAttachment(longhands::background_attachment::computed_value::T),
            /// background-clip
                BackgroundClip(longhands::background_clip::computed_value::T),
            /// background-origin
                BackgroundOrigin(longhands::background_origin::computed_value::T),
            /// background-size
                BackgroundSize(<longhands::background_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// background-blend-mode
                BackgroundBlendMode(longhands::background_blend_mode::computed_value::T),
            /// border-top-color
                BorderTopColor(<longhands::border_top_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-top-style
                BorderTopStyle(longhands::border_top_style::computed_value::T),
            /// border-top-width
                BorderTopWidth(<longhands::border_top_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-left-color
                BorderLeftColor(<longhands::border_left_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-left-style
                BorderLeftStyle(longhands::border_left_style::computed_value::T),
            /// border-left-width
                BorderLeftWidth(<longhands::border_left_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-bottom-color
                BorderBottomColor(<longhands::border_bottom_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-bottom-style
                BorderBottomStyle(longhands::border_bottom_style::computed_value::T),
            /// border-bottom-width
                BorderBottomWidth(<longhands::border_bottom_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-right-color
                BorderRightColor(<longhands::border_right_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-right-style
                BorderRightStyle(longhands::border_right_style::computed_value::T),
            /// border-right-width
                BorderRightWidth(<longhands::border_right_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-top-left-radius
                BorderTopLeftRadius(<longhands::border_top_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-top-right-radius
                BorderTopRightRadius(<longhands::border_top_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-bottom-right-radius
                BorderBottomRightRadius(<longhands::border_bottom_right_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// border-bottom-left-radius
                BorderBottomLeftRadius(<longhands::border_bottom_left_radius::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-border-top-colors
                MozBorderTopColors(longhands::_moz_border_top_colors::computed_value::T),
            /// -moz-border-left-colors
                MozBorderLeftColors(longhands::_moz_border_left_colors::computed_value::T),
            /// -moz-border-bottom-colors
                MozBorderBottomColors(longhands::_moz_border_bottom_colors::computed_value::T),
            /// -moz-border-right-colors
                MozBorderRightColors(longhands::_moz_border_right_colors::computed_value::T),
            /// box-decoration-break
                BoxDecorationBreak(longhands::box_decoration_break::computed_value::T),
            /// -moz-float-edge
                MozFloatEdge(longhands::_moz_float_edge::computed_value::T),
            /// border-image-source
                BorderImageSource(longhands::border_image_source::computed_value::T),
            /// border-image-outset
                BorderImageOutset(longhands::border_image_outset::computed_value::T),
            /// border-image-repeat
                BorderImageRepeat(longhands::border_image_repeat::computed_value::T),
            /// border-image-width
                BorderImageWidth(longhands::border_image_width::computed_value::T),
            /// border-image-slice
                BorderImageSlice(longhands::border_image_slice::computed_value::T),
            /// display
                Display(longhands::display::computed_value::T),
            /// position
                Position(longhands::position::computed_value::T),
            /// float
                Float(longhands::float::computed_value::T),
            /// clear
                Clear(longhands::clear::computed_value::T),
            /// vertical-align
                VerticalAlign(longhands::vertical_align::computed_value::T),
            /// overflow-clip-box-inline
                OverflowClipBoxInline(longhands::overflow_clip_box_inline::computed_value::T),
            /// overflow-clip-box-block
                OverflowClipBoxBlock(longhands::overflow_clip_box_block::computed_value::T),
            /// overflow-x
                OverflowX(longhands::overflow_x::computed_value::T),
            /// overflow-y
                OverflowY(longhands::overflow_y::computed_value::T),
            /// scroll-snap-points-x
                ScrollSnapPointsX(longhands::scroll_snap_points_x::computed_value::T),
            /// scroll-snap-points-y
                ScrollSnapPointsY(longhands::scroll_snap_points_y::computed_value::T),
            /// scroll-snap-destination
                ScrollSnapDestination(longhands::scroll_snap_destination::computed_value::T),
            /// scroll-snap-coordinate
                ScrollSnapCoordinate(longhands::scroll_snap_coordinate::computed_value::T),
            /// transform
                Transform(longhands::transform::computed_value::T),
            /// scroll-behavior
                ScrollBehavior(longhands::scroll_behavior::computed_value::T),
            /// scroll-snap-type-x
                ScrollSnapTypeX(longhands::scroll_snap_type_x::computed_value::T),
            /// scroll-snap-type-y
                ScrollSnapTypeY(longhands::scroll_snap_type_y::computed_value::T),
            /// overscroll-behavior-x
                OverscrollBehaviorX(longhands::overscroll_behavior_x::computed_value::T),
            /// overscroll-behavior-y
                OverscrollBehaviorY(longhands::overscroll_behavior_y::computed_value::T),
            /// isolation
                Isolation(longhands::isolation::computed_value::T),
            /// page-break-after
                PageBreakAfter(longhands::page_break_after::computed_value::T),
            /// page-break-before
                PageBreakBefore(longhands::page_break_before::computed_value::T),
            /// page-break-inside
                PageBreakInside(longhands::page_break_inside::computed_value::T),
            /// resize
                Resize(longhands::resize::computed_value::T),
            /// perspective
                Perspective(longhands::perspective::computed_value::T),
            /// perspective-origin
                PerspectiveOrigin(longhands::perspective_origin::computed_value::T),
            /// backface-visibility
                BackfaceVisibility(longhands::backface_visibility::computed_value::T),
            /// transform-box
                TransformBox(longhands::transform_box::computed_value::T),
            /// transform-style
                TransformStyle(longhands::transform_style::computed_value::T),
            /// transform-origin
                TransformOrigin(longhands::transform_origin::computed_value::T),
            /// contain
                Contain(longhands::contain::computed_value::T),
            /// -moz-appearance
                MozAppearance(longhands::_moz_appearance::computed_value::T),
            /// -moz-orient
                MozOrient(longhands::_moz_orient::computed_value::T),
            /// will-change
                WillChange(longhands::will_change::computed_value::T),
            /// shape-image-threshold
                ShapeImageThreshold(longhands::shape_image_threshold::computed_value::T),
            /// shape-outside
                ShapeOutside(longhands::shape_outside::computed_value::T),
            /// touch-action
                TouchAction(longhands::touch_action::computed_value::T),
            /// color
                Color(<longhands::color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-width
                ColumnWidth(<longhands::column_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-count
                ColumnCount(<longhands::column_count::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-gap
                ColumnGap(<longhands::column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-fill
                ColumnFill(longhands::column_fill::computed_value::T),
            /// column-rule-width
                ColumnRuleWidth(<longhands::column_rule_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-rule-color
                ColumnRuleColor(<longhands::column_rule_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// column-span
                ColumnSpan(longhands::column_span::computed_value::T),
            /// column-rule-style
                ColumnRuleStyle(longhands::column_rule_style::computed_value::T),
            /// content
                Content(longhands::content::computed_value::T),
            /// counter-increment
                CounterIncrement(longhands::counter_increment::computed_value::T),
            /// counter-reset
                CounterReset(longhands::counter_reset::computed_value::T),
            /// opacity
                Opacity(longhands::opacity::computed_value::T),
            /// box-shadow
                BoxShadow(<longhands::box_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// clip
                Clip(longhands::clip::computed_value::T),
            /// filter
                Filter(<longhands::filter::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// mix-blend-mode
                MixBlendMode(longhands::mix_blend_mode::computed_value::T),
            /// font-family
                FontFamily(longhands::font_family::computed_value::T),
            /// font-style
                FontStyle(longhands::font_style::computed_value::T),
            /// font-variant-caps
                FontVariantCaps(longhands::font_variant_caps::computed_value::T),
            /// font-weight
                FontWeight(longhands::font_weight::computed_value::T),
            /// font-size
                FontSize(<longhands::font_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// font-size-adjust
                FontSizeAdjust(longhands::font_size_adjust::computed_value::T),
            /// font-synthesis
                FontSynthesis(longhands::font_synthesis::computed_value::T),
            /// font-stretch
                FontStretch(longhands::font_stretch::computed_value::T),
            /// font-kerning
                FontKerning(longhands::font_kerning::computed_value::T),
            /// font-variant-alternates
                FontVariantAlternates(longhands::font_variant_alternates::computed_value::T),
            /// font-variant-east-asian
                FontVariantEastAsian(longhands::font_variant_east_asian::computed_value::T),
            /// font-variant-ligatures
                FontVariantLigatures(longhands::font_variant_ligatures::computed_value::T),
            /// font-variant-numeric
                FontVariantNumeric(longhands::font_variant_numeric::computed_value::T),
            /// font-variant-position
                FontVariantPosition(longhands::font_variant_position::computed_value::T),
            /// font-feature-settings
                FontFeatureSettings(longhands::font_feature_settings::computed_value::T),
            /// font-variation-settings
                FontVariationSettings(longhands::font_variation_settings::computed_value::T),
            /// font-language-override
                FontLanguageOverride(longhands::font_language_override::computed_value::T),
            /// -moz-osx-font-smoothing
                MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::computed_value::T),
            /// -moz-font-smoothing-background-color
                MozFontSmoothingBackgroundColor(<longhands::_moz_font_smoothing_background_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// visibility
                Visibility(longhands::visibility::computed_value::T),
            /// writing-mode
                WritingMode(longhands::writing_mode::computed_value::T),
            /// direction
                Direction(longhands::direction::computed_value::T),
            /// text-orientation
                TextOrientation(longhands::text_orientation::computed_value::T),
            /// color-adjust
                ColorAdjust(longhands::color_adjust::computed_value::T),
            /// image-rendering
                ImageRendering(longhands::image_rendering::computed_value::T),
            /// image-orientation
                ImageOrientation(longhands::image_orientation::computed_value::T),
            /// border-collapse
                BorderCollapse(longhands::border_collapse::computed_value::T),
            /// empty-cells
                EmptyCells(longhands::empty_cells::computed_value::T),
            /// caption-side
                CaptionSide(longhands::caption_side::computed_value::T),
            /// border-spacing
                BorderSpacing(<longhands::border_spacing::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// line-height
                LineHeight(<longhands::line_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// text-transform
                TextTransform(longhands::text_transform::computed_value::T),
            /// hyphens
                Hyphens(longhands::hyphens::computed_value::T),
            /// -moz-text-size-adjust
                MozTextSizeAdjust(longhands::_moz_text_size_adjust::computed_value::T),
            /// text-indent
                TextIndent(longhands::text_indent::computed_value::T),
            /// overflow-wrap
                OverflowWrap(longhands::overflow_wrap::computed_value::T),
            /// word-break
                WordBreak(longhands::word_break::computed_value::T),
            /// text-justify
                TextJustify(longhands::text_justify::computed_value::T),
            /// text-align-last
                TextAlignLast(longhands::text_align_last::computed_value::T),
            /// text-align
                TextAlign(longhands::text_align::computed_value::T),
            /// letter-spacing
                LetterSpacing(longhands::letter_spacing::computed_value::T),
            /// word-spacing
                WordSpacing(longhands::word_spacing::computed_value::T),
            /// white-space
                WhiteSpace(longhands::white_space::computed_value::T),
            /// text-shadow
                TextShadow(<longhands::text_shadow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// text-emphasis-style
                TextEmphasisStyle(longhands::text_emphasis_style::computed_value::T),
            /// text-emphasis-position
                TextEmphasisPosition(longhands::text_emphasis_position::computed_value::T),
            /// text-emphasis-color
                TextEmphasisColor(<longhands::text_emphasis_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-tab-size
                MozTabSize(<longhands::_moz_tab_size::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -webkit-text-fill-color
                WebkitTextFillColor(<longhands::_webkit_text_fill_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -webkit-text-stroke-color
                WebkitTextStrokeColor(<longhands::_webkit_text_stroke_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -webkit-text-stroke-width
                WebkitTextStrokeWidth(longhands::_webkit_text_stroke_width::computed_value::T),
            /// ruby-align
                RubyAlign(longhands::ruby_align::computed_value::T),
            /// ruby-position
                RubyPosition(longhands::ruby_position::computed_value::T),
            /// text-combine-upright
                TextCombineUpright(longhands::text_combine_upright::computed_value::T),
            /// text-rendering
                TextRendering(longhands::text_rendering::computed_value::T),
            /// list-style-position
                ListStylePosition(longhands::list_style_position::computed_value::T),
            /// list-style-type
                ListStyleType(longhands::list_style_type::computed_value::T),
            /// list-style-image
                ListStyleImage(longhands::list_style_image::computed_value::T),
            /// quotes
                Quotes(longhands::quotes::computed_value::T),
            /// -moz-image-region
                MozImageRegion(longhands::_moz_image_region::computed_value::T),
            /// margin-top
                MarginTop(longhands::margin_top::computed_value::T),
            /// margin-left
                MarginLeft(longhands::margin_left::computed_value::T),
            /// margin-bottom
                MarginBottom(longhands::margin_bottom::computed_value::T),
            /// margin-right
                MarginRight(longhands::margin_right::computed_value::T),
            /// outline-color
                OutlineColor(<longhands::outline_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// outline-style
                OutlineStyle(longhands::outline_style::computed_value::T),
            /// outline-width
                OutlineWidth(<longhands::outline_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-outline-radius-topleft
                MozOutlineRadiusTopleft(<longhands::_moz_outline_radius_topleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-outline-radius-topright
                MozOutlineRadiusTopright(<longhands::_moz_outline_radius_topright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-outline-radius-bottomright
                MozOutlineRadiusBottomright(<longhands::_moz_outline_radius_bottomright::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-outline-radius-bottomleft
                MozOutlineRadiusBottomleft(<longhands::_moz_outline_radius_bottomleft::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// outline-offset
                OutlineOffset(longhands::outline_offset::computed_value::T),
            /// padding-top
                PaddingTop(<longhands::padding_top::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// padding-left
                PaddingLeft(<longhands::padding_left::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// padding-bottom
                PaddingBottom(<longhands::padding_bottom::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// padding-right
                PaddingRight(<longhands::padding_right::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// cursor
                Cursor(longhands::cursor::computed_value::T),
            /// pointer-events
                PointerEvents(longhands::pointer_events::computed_value::T),
            /// -moz-user-input
                MozUserInput(longhands::_moz_user_input::computed_value::T),
            /// -moz-user-modify
                MozUserModify(longhands::_moz_user_modify::computed_value::T),
            /// -moz-user-focus
                MozUserFocus(longhands::_moz_user_focus::computed_value::T),
            /// caret-color
                CaretColor(<longhands::caret_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// top
                Top(longhands::top::computed_value::T),
            /// left
                Left(longhands::left::computed_value::T),
            /// bottom
                Bottom(longhands::bottom::computed_value::T),
            /// right
                Right(longhands::right::computed_value::T),
            /// z-index
                ZIndex(longhands::z_index::computed_value::T),
            /// flex-direction
                FlexDirection(longhands::flex_direction::computed_value::T),
            /// flex-wrap
                FlexWrap(longhands::flex_wrap::computed_value::T),
            /// justify-content
                JustifyContent(longhands::justify_content::computed_value::T),
            /// align-content
                AlignContent(longhands::align_content::computed_value::T),
            /// align-items
                AlignItems(longhands::align_items::computed_value::T),
            /// justify-items
                JustifyItems(longhands::justify_items::computed_value::T),
            /// flex-grow
                FlexGrow(<longhands::flex_grow::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// flex-shrink
                FlexShrink(<longhands::flex_shrink::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// align-self
                AlignSelf(longhands::align_self::computed_value::T),
            /// justify-self
                JustifySelf(longhands::justify_self::computed_value::T),
            /// order
                Order(longhands::order::computed_value::T),
            /// flex-basis
                FlexBasis(<longhands::flex_basis::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// width
                Width(<longhands::width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// min-width
                MinWidth(<longhands::min_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// max-width
                MaxWidth(<longhands::max_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// height
                Height(<longhands::height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// min-height
                MinHeight(<longhands::min_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// max-height
                MaxHeight(<longhands::max_height::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// box-sizing
                BoxSizing(longhands::box_sizing::computed_value::T),
            /// object-fit
                ObjectFit(longhands::object_fit::computed_value::T),
            /// object-position
                ObjectPosition(longhands::object_position::computed_value::T),
            /// grid-row-gap
                GridRowGap(<longhands::grid_row_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// grid-row-start
                GridRowStart(longhands::grid_row_start::computed_value::T),
            /// grid-row-end
                GridRowEnd(longhands::grid_row_end::computed_value::T),
            /// grid-auto-rows
                GridAutoRows(longhands::grid_auto_rows::computed_value::T),
            /// grid-template-rows
                GridTemplateRows(longhands::grid_template_rows::computed_value::T),
            /// grid-column-gap
                GridColumnGap(<longhands::grid_column_gap::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// grid-column-start
                GridColumnStart(longhands::grid_column_start::computed_value::T),
            /// grid-column-end
                GridColumnEnd(longhands::grid_column_end::computed_value::T),
            /// grid-auto-columns
                GridAutoColumns(longhands::grid_auto_columns::computed_value::T),
            /// grid-template-columns
                GridTemplateColumns(longhands::grid_template_columns::computed_value::T),
            /// grid-auto-flow
                GridAutoFlow(longhands::grid_auto_flow::computed_value::T),
            /// grid-template-areas
                GridTemplateAreas(longhands::grid_template_areas::computed_value::T),
            /// table-layout
                TableLayout(longhands::table_layout::computed_value::T),
            /// text-overflow
                TextOverflow(longhands::text_overflow::computed_value::T),
            /// unicode-bidi
                UnicodeBidi(longhands::unicode_bidi::computed_value::T),
            /// text-decoration-line
                TextDecorationLine(longhands::text_decoration_line::computed_value::T),
            /// text-decoration-style
                TextDecorationStyle(longhands::text_decoration_style::computed_value::T),
            /// text-decoration-color
                TextDecorationColor(<longhands::text_decoration_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// initial-letter
                InitialLetter(longhands::initial_letter::computed_value::T),
            /// ime-mode
                ImeMode(longhands::ime_mode::computed_value::T),
            /// -moz-user-select
                MozUserSelect(longhands::_moz_user_select::computed_value::T),
            /// -moz-window-dragging
                MozWindowDragging(longhands::_moz_window_dragging::computed_value::T),
            /// -moz-window-shadow
                MozWindowShadow(longhands::_moz_window_shadow::computed_value::T),
            /// -moz-window-opacity
                MozWindowOpacity(longhands::_moz_window_opacity::computed_value::T),
            /// -moz-window-transform
                MozWindowTransform(longhands::_moz_window_transform::computed_value::T),
            /// -moz-window-transform-origin
                MozWindowTransformOrigin(longhands::_moz_window_transform_origin::computed_value::T),
            /// -moz-force-broken-image-icon
                MozForceBrokenImageIcon(longhands::_moz_force_broken_image_icon::computed_value::T),
            /// text-anchor
                TextAnchor(longhands::text_anchor::computed_value::T),
            /// color-interpolation
                ColorInterpolation(longhands::color_interpolation::computed_value::T),
            /// color-interpolation-filters
                ColorInterpolationFilters(longhands::color_interpolation_filters::computed_value::T),
            /// fill
                Fill(<longhands::fill::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// fill-opacity
                FillOpacity(longhands::fill_opacity::computed_value::T),
            /// fill-rule
                FillRule(longhands::fill_rule::computed_value::T),
            /// shape-rendering
                ShapeRendering(longhands::shape_rendering::computed_value::T),
            /// stroke
                Stroke(<longhands::stroke::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// stroke-width
                StrokeWidth(<longhands::stroke_width::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// stroke-linecap
                StrokeLinecap(longhands::stroke_linecap::computed_value::T),
            /// stroke-linejoin
                StrokeLinejoin(longhands::stroke_linejoin::computed_value::T),
            /// stroke-miterlimit
                StrokeMiterlimit(<longhands::stroke_miterlimit::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// stroke-opacity
                StrokeOpacity(longhands::stroke_opacity::computed_value::T),
            /// stroke-dasharray
                StrokeDasharray(<longhands::stroke_dasharray::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// stroke-dashoffset
                StrokeDashoffset(longhands::stroke_dashoffset::computed_value::T),
            /// clip-rule
                ClipRule(longhands::clip_rule::computed_value::T),
            /// marker-start
                MarkerStart(longhands::marker_start::computed_value::T),
            /// marker-mid
                MarkerMid(longhands::marker_mid::computed_value::T),
            /// marker-end
                MarkerEnd(longhands::marker_end::computed_value::T),
            /// paint-order
                PaintOrder(longhands::paint_order::computed_value::T),
            /// dominant-baseline
                DominantBaseline(longhands::dominant_baseline::computed_value::T),
            /// vector-effect
                VectorEffect(longhands::vector_effect::computed_value::T),
            /// stop-color
                StopColor(<longhands::stop_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// stop-opacity
                StopOpacity(longhands::stop_opacity::computed_value::T),
            /// flood-color
                FloodColor(<longhands::flood_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// flood-opacity
                FloodOpacity(longhands::flood_opacity::computed_value::T),
            /// lighting-color
                LightingColor(<longhands::lighting_color::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// mask-type
                MaskType(longhands::mask_type::computed_value::T),
            /// clip-path
                ClipPath(longhands::clip_path::computed_value::T),
            /// mask-mode
                MaskMode(longhands::mask_mode::computed_value::T),
            /// mask-repeat
                MaskRepeat(longhands::mask_repeat::computed_value::T),
            /// mask-position-x
                MaskPositionX(longhands::mask_position_x::computed_value::T),
            /// mask-position-y
                MaskPositionY(longhands::mask_position_y::computed_value::T),
            /// mask-clip
                MaskClip(longhands::mask_clip::computed_value::T),
            /// mask-origin
                MaskOrigin(longhands::mask_origin::computed_value::T),
            /// mask-size
                MaskSize(longhands::mask_size::computed_value::T),
            /// mask-composite
                MaskComposite(longhands::mask_composite::computed_value::T),
            /// mask-image
                MaskImage(longhands::mask_image::computed_value::T),
            /// -moz-box-align
                MozBoxAlign(longhands::_moz_box_align::computed_value::T),
            /// -moz-box-direction
                MozBoxDirection(longhands::_moz_box_direction::computed_value::T),
            /// -moz-box-flex
                MozBoxFlex(<longhands::_moz_box_flex::computed_value::T as ToAnimatedValue>::AnimatedValue),
            /// -moz-box-orient
                MozBoxOrient(longhands::_moz_box_orient::computed_value::T),
            /// -moz-box-pack
                MozBoxPack(longhands::_moz_box_pack::computed_value::T),
            /// -moz-stack-sizing
                MozStackSizing(longhands::_moz_stack_sizing::computed_value::T),
            /// -moz-box-ordinal-group
                MozBoxOrdinalGroup(longhands::_moz_box_ordinal_group::computed_value::T),
}

impl AnimationValue {
    /// Returns the longhand id this animated value corresponds to.
    pub fn id(&self) -> LonghandId {
        match *self {
                AnimationValue::BackgroundColor(..) => LonghandId::BackgroundColor,
                AnimationValue::BackgroundImage(..) => LonghandId::BackgroundImage,
                AnimationValue::BackgroundPositionX(..) => LonghandId::BackgroundPositionX,
                AnimationValue::BackgroundPositionY(..) => LonghandId::BackgroundPositionY,
                AnimationValue::BackgroundRepeat(..) => LonghandId::BackgroundRepeat,
                AnimationValue::BackgroundAttachment(..) => LonghandId::BackgroundAttachment,
                AnimationValue::BackgroundClip(..) => LonghandId::BackgroundClip,
                AnimationValue::BackgroundOrigin(..) => LonghandId::BackgroundOrigin,
                AnimationValue::BackgroundSize(..) => LonghandId::BackgroundSize,
                AnimationValue::BackgroundBlendMode(..) => LonghandId::BackgroundBlendMode,
                AnimationValue::BorderTopColor(..) => LonghandId::BorderTopColor,
                AnimationValue::BorderTopStyle(..) => LonghandId::BorderTopStyle,
                AnimationValue::BorderTopWidth(..) => LonghandId::BorderTopWidth,
                AnimationValue::BorderLeftColor(..) => LonghandId::BorderLeftColor,
                AnimationValue::BorderLeftStyle(..) => LonghandId::BorderLeftStyle,
                AnimationValue::BorderLeftWidth(..) => LonghandId::BorderLeftWidth,
                AnimationValue::BorderBottomColor(..) => LonghandId::BorderBottomColor,
                AnimationValue::BorderBottomStyle(..) => LonghandId::BorderBottomStyle,
                AnimationValue::BorderBottomWidth(..) => LonghandId::BorderBottomWidth,
                AnimationValue::BorderRightColor(..) => LonghandId::BorderRightColor,
                AnimationValue::BorderRightStyle(..) => LonghandId::BorderRightStyle,
                AnimationValue::BorderRightWidth(..) => LonghandId::BorderRightWidth,
                AnimationValue::BorderTopLeftRadius(..) => LonghandId::BorderTopLeftRadius,
                AnimationValue::BorderTopRightRadius(..) => LonghandId::BorderTopRightRadius,
                AnimationValue::BorderBottomRightRadius(..) => LonghandId::BorderBottomRightRadius,
                AnimationValue::BorderBottomLeftRadius(..) => LonghandId::BorderBottomLeftRadius,
                AnimationValue::MozBorderTopColors(..) => LonghandId::MozBorderTopColors,
                AnimationValue::MozBorderLeftColors(..) => LonghandId::MozBorderLeftColors,
                AnimationValue::MozBorderBottomColors(..) => LonghandId::MozBorderBottomColors,
                AnimationValue::MozBorderRightColors(..) => LonghandId::MozBorderRightColors,
                AnimationValue::BoxDecorationBreak(..) => LonghandId::BoxDecorationBreak,
                AnimationValue::MozFloatEdge(..) => LonghandId::MozFloatEdge,
                AnimationValue::BorderImageSource(..) => LonghandId::BorderImageSource,
                AnimationValue::BorderImageOutset(..) => LonghandId::BorderImageOutset,
                AnimationValue::BorderImageRepeat(..) => LonghandId::BorderImageRepeat,
                AnimationValue::BorderImageWidth(..) => LonghandId::BorderImageWidth,
                AnimationValue::BorderImageSlice(..) => LonghandId::BorderImageSlice,
                AnimationValue::Display(..) => LonghandId::Display,
                AnimationValue::Position(..) => LonghandId::Position,
                AnimationValue::Float(..) => LonghandId::Float,
                AnimationValue::Clear(..) => LonghandId::Clear,
                AnimationValue::VerticalAlign(..) => LonghandId::VerticalAlign,
                AnimationValue::OverflowClipBoxInline(..) => LonghandId::OverflowClipBoxInline,
                AnimationValue::OverflowClipBoxBlock(..) => LonghandId::OverflowClipBoxBlock,
                AnimationValue::OverflowX(..) => LonghandId::OverflowX,
                AnimationValue::OverflowY(..) => LonghandId::OverflowY,
                AnimationValue::ScrollSnapPointsX(..) => LonghandId::ScrollSnapPointsX,
                AnimationValue::ScrollSnapPointsY(..) => LonghandId::ScrollSnapPointsY,
                AnimationValue::ScrollSnapDestination(..) => LonghandId::ScrollSnapDestination,
                AnimationValue::ScrollSnapCoordinate(..) => LonghandId::ScrollSnapCoordinate,
                AnimationValue::Transform(..) => LonghandId::Transform,
                AnimationValue::ScrollBehavior(..) => LonghandId::ScrollBehavior,
                AnimationValue::ScrollSnapTypeX(..) => LonghandId::ScrollSnapTypeX,
                AnimationValue::ScrollSnapTypeY(..) => LonghandId::ScrollSnapTypeY,
                AnimationValue::OverscrollBehaviorX(..) => LonghandId::OverscrollBehaviorX,
                AnimationValue::OverscrollBehaviorY(..) => LonghandId::OverscrollBehaviorY,
                AnimationValue::Isolation(..) => LonghandId::Isolation,
                AnimationValue::PageBreakAfter(..) => LonghandId::PageBreakAfter,
                AnimationValue::PageBreakBefore(..) => LonghandId::PageBreakBefore,
                AnimationValue::PageBreakInside(..) => LonghandId::PageBreakInside,
                AnimationValue::Resize(..) => LonghandId::Resize,
                AnimationValue::Perspective(..) => LonghandId::Perspective,
                AnimationValue::PerspectiveOrigin(..) => LonghandId::PerspectiveOrigin,
                AnimationValue::BackfaceVisibility(..) => LonghandId::BackfaceVisibility,
                AnimationValue::TransformBox(..) => LonghandId::TransformBox,
                AnimationValue::TransformStyle(..) => LonghandId::TransformStyle,
                AnimationValue::TransformOrigin(..) => LonghandId::TransformOrigin,
                AnimationValue::Contain(..) => LonghandId::Contain,
                AnimationValue::MozAppearance(..) => LonghandId::MozAppearance,
                AnimationValue::MozOrient(..) => LonghandId::MozOrient,
                AnimationValue::WillChange(..) => LonghandId::WillChange,
                AnimationValue::ShapeImageThreshold(..) => LonghandId::ShapeImageThreshold,
                AnimationValue::ShapeOutside(..) => LonghandId::ShapeOutside,
                AnimationValue::TouchAction(..) => LonghandId::TouchAction,
                AnimationValue::Color(..) => LonghandId::Color,
                AnimationValue::ColumnWidth(..) => LonghandId::ColumnWidth,
                AnimationValue::ColumnCount(..) => LonghandId::ColumnCount,
                AnimationValue::ColumnGap(..) => LonghandId::ColumnGap,
                AnimationValue::ColumnFill(..) => LonghandId::ColumnFill,
                AnimationValue::ColumnRuleWidth(..) => LonghandId::ColumnRuleWidth,
                AnimationValue::ColumnRuleColor(..) => LonghandId::ColumnRuleColor,
                AnimationValue::ColumnSpan(..) => LonghandId::ColumnSpan,
                AnimationValue::ColumnRuleStyle(..) => LonghandId::ColumnRuleStyle,
                AnimationValue::Content(..) => LonghandId::Content,
                AnimationValue::CounterIncrement(..) => LonghandId::CounterIncrement,
                AnimationValue::CounterReset(..) => LonghandId::CounterReset,
                AnimationValue::Opacity(..) => LonghandId::Opacity,
                AnimationValue::BoxShadow(..) => LonghandId::BoxShadow,
                AnimationValue::Clip(..) => LonghandId::Clip,
                AnimationValue::Filter(..) => LonghandId::Filter,
                AnimationValue::MixBlendMode(..) => LonghandId::MixBlendMode,
                AnimationValue::FontFamily(..) => LonghandId::FontFamily,
                AnimationValue::FontStyle(..) => LonghandId::FontStyle,
                AnimationValue::FontVariantCaps(..) => LonghandId::FontVariantCaps,
                AnimationValue::FontWeight(..) => LonghandId::FontWeight,
                AnimationValue::FontSize(..) => LonghandId::FontSize,
                AnimationValue::FontSizeAdjust(..) => LonghandId::FontSizeAdjust,
                AnimationValue::FontSynthesis(..) => LonghandId::FontSynthesis,
                AnimationValue::FontStretch(..) => LonghandId::FontStretch,
                AnimationValue::FontKerning(..) => LonghandId::FontKerning,
                AnimationValue::FontVariantAlternates(..) => LonghandId::FontVariantAlternates,
                AnimationValue::FontVariantEastAsian(..) => LonghandId::FontVariantEastAsian,
                AnimationValue::FontVariantLigatures(..) => LonghandId::FontVariantLigatures,
                AnimationValue::FontVariantNumeric(..) => LonghandId::FontVariantNumeric,
                AnimationValue::FontVariantPosition(..) => LonghandId::FontVariantPosition,
                AnimationValue::FontFeatureSettings(..) => LonghandId::FontFeatureSettings,
                AnimationValue::FontVariationSettings(..) => LonghandId::FontVariationSettings,
                AnimationValue::FontLanguageOverride(..) => LonghandId::FontLanguageOverride,
                AnimationValue::MozOsxFontSmoothing(..) => LonghandId::MozOsxFontSmoothing,
                AnimationValue::MozFontSmoothingBackgroundColor(..) => LonghandId::MozFontSmoothingBackgroundColor,
                AnimationValue::Visibility(..) => LonghandId::Visibility,
                AnimationValue::WritingMode(..) => LonghandId::WritingMode,
                AnimationValue::Direction(..) => LonghandId::Direction,
                AnimationValue::TextOrientation(..) => LonghandId::TextOrientation,
                AnimationValue::ColorAdjust(..) => LonghandId::ColorAdjust,
                AnimationValue::ImageRendering(..) => LonghandId::ImageRendering,
                AnimationValue::ImageOrientation(..) => LonghandId::ImageOrientation,
                AnimationValue::BorderCollapse(..) => LonghandId::BorderCollapse,
                AnimationValue::EmptyCells(..) => LonghandId::EmptyCells,
                AnimationValue::CaptionSide(..) => LonghandId::CaptionSide,
                AnimationValue::BorderSpacing(..) => LonghandId::BorderSpacing,
                AnimationValue::LineHeight(..) => LonghandId::LineHeight,
                AnimationValue::TextTransform(..) => LonghandId::TextTransform,
                AnimationValue::Hyphens(..) => LonghandId::Hyphens,
                AnimationValue::MozTextSizeAdjust(..) => LonghandId::MozTextSizeAdjust,
                AnimationValue::TextIndent(..) => LonghandId::TextIndent,
                AnimationValue::OverflowWrap(..) => LonghandId::OverflowWrap,
                AnimationValue::WordBreak(..) => LonghandId::WordBreak,
                AnimationValue::TextJustify(..) => LonghandId::TextJustify,
                AnimationValue::TextAlignLast(..) => LonghandId::TextAlignLast,
                AnimationValue::TextAlign(..) => LonghandId::TextAlign,
                AnimationValue::LetterSpacing(..) => LonghandId::LetterSpacing,
                AnimationValue::WordSpacing(..) => LonghandId::WordSpacing,
                AnimationValue::WhiteSpace(..) => LonghandId::WhiteSpace,
                AnimationValue::TextShadow(..) => LonghandId::TextShadow,
                AnimationValue::TextEmphasisStyle(..) => LonghandId::TextEmphasisStyle,
                AnimationValue::TextEmphasisPosition(..) => LonghandId::TextEmphasisPosition,
                AnimationValue::TextEmphasisColor(..) => LonghandId::TextEmphasisColor,
                AnimationValue::MozTabSize(..) => LonghandId::MozTabSize,
                AnimationValue::WebkitTextFillColor(..) => LonghandId::WebkitTextFillColor,
                AnimationValue::WebkitTextStrokeColor(..) => LonghandId::WebkitTextStrokeColor,
                AnimationValue::WebkitTextStrokeWidth(..) => LonghandId::WebkitTextStrokeWidth,
                AnimationValue::RubyAlign(..) => LonghandId::RubyAlign,
                AnimationValue::RubyPosition(..) => LonghandId::RubyPosition,
                AnimationValue::TextCombineUpright(..) => LonghandId::TextCombineUpright,
                AnimationValue::TextRendering(..) => LonghandId::TextRendering,
                AnimationValue::ListStylePosition(..) => LonghandId::ListStylePosition,
                AnimationValue::ListStyleType(..) => LonghandId::ListStyleType,
                AnimationValue::ListStyleImage(..) => LonghandId::ListStyleImage,
                AnimationValue::Quotes(..) => LonghandId::Quotes,
                AnimationValue::MozImageRegion(..) => LonghandId::MozImageRegion,
                AnimationValue::MarginTop(..) => LonghandId::MarginTop,
                AnimationValue::MarginLeft(..) => LonghandId::MarginLeft,
                AnimationValue::MarginBottom(..) => LonghandId::MarginBottom,
                AnimationValue::MarginRight(..) => LonghandId::MarginRight,
                AnimationValue::OutlineColor(..) => LonghandId::OutlineColor,
                AnimationValue::OutlineStyle(..) => LonghandId::OutlineStyle,
                AnimationValue::OutlineWidth(..) => LonghandId::OutlineWidth,
                AnimationValue::MozOutlineRadiusTopleft(..) => LonghandId::MozOutlineRadiusTopleft,
                AnimationValue::MozOutlineRadiusTopright(..) => LonghandId::MozOutlineRadiusTopright,
                AnimationValue::MozOutlineRadiusBottomright(..) => LonghandId::MozOutlineRadiusBottomright,
                AnimationValue::MozOutlineRadiusBottomleft(..) => LonghandId::MozOutlineRadiusBottomleft,
                AnimationValue::OutlineOffset(..) => LonghandId::OutlineOffset,
                AnimationValue::PaddingTop(..) => LonghandId::PaddingTop,
                AnimationValue::PaddingLeft(..) => LonghandId::PaddingLeft,
                AnimationValue::PaddingBottom(..) => LonghandId::PaddingBottom,
                AnimationValue::PaddingRight(..) => LonghandId::PaddingRight,
                AnimationValue::Cursor(..) => LonghandId::Cursor,
                AnimationValue::PointerEvents(..) => LonghandId::PointerEvents,
                AnimationValue::MozUserInput(..) => LonghandId::MozUserInput,
                AnimationValue::MozUserModify(..) => LonghandId::MozUserModify,
                AnimationValue::MozUserFocus(..) => LonghandId::MozUserFocus,
                AnimationValue::CaretColor(..) => LonghandId::CaretColor,
                AnimationValue::Top(..) => LonghandId::Top,
                AnimationValue::Left(..) => LonghandId::Left,
                AnimationValue::Bottom(..) => LonghandId::Bottom,
                AnimationValue::Right(..) => LonghandId::Right,
                AnimationValue::ZIndex(..) => LonghandId::ZIndex,
                AnimationValue::FlexDirection(..) => LonghandId::FlexDirection,
                AnimationValue::FlexWrap(..) => LonghandId::FlexWrap,
                AnimationValue::JustifyContent(..) => LonghandId::JustifyContent,
                AnimationValue::AlignContent(..) => LonghandId::AlignContent,
                AnimationValue::AlignItems(..) => LonghandId::AlignItems,
                AnimationValue::JustifyItems(..) => LonghandId::JustifyItems,
                AnimationValue::FlexGrow(..) => LonghandId::FlexGrow,
                AnimationValue::FlexShrink(..) => LonghandId::FlexShrink,
                AnimationValue::AlignSelf(..) => LonghandId::AlignSelf,
                AnimationValue::JustifySelf(..) => LonghandId::JustifySelf,
                AnimationValue::Order(..) => LonghandId::Order,
                AnimationValue::FlexBasis(..) => LonghandId::FlexBasis,
                AnimationValue::Width(..) => LonghandId::Width,
                AnimationValue::MinWidth(..) => LonghandId::MinWidth,
                AnimationValue::MaxWidth(..) => LonghandId::MaxWidth,
                AnimationValue::Height(..) => LonghandId::Height,
                AnimationValue::MinHeight(..) => LonghandId::MinHeight,
                AnimationValue::MaxHeight(..) => LonghandId::MaxHeight,
                AnimationValue::BoxSizing(..) => LonghandId::BoxSizing,
                AnimationValue::ObjectFit(..) => LonghandId::ObjectFit,
                AnimationValue::ObjectPosition(..) => LonghandId::ObjectPosition,
                AnimationValue::GridRowGap(..) => LonghandId::GridRowGap,
                AnimationValue::GridRowStart(..) => LonghandId::GridRowStart,
                AnimationValue::GridRowEnd(..) => LonghandId::GridRowEnd,
                AnimationValue::GridAutoRows(..) => LonghandId::GridAutoRows,
                AnimationValue::GridTemplateRows(..) => LonghandId::GridTemplateRows,
                AnimationValue::GridColumnGap(..) => LonghandId::GridColumnGap,
                AnimationValue::GridColumnStart(..) => LonghandId::GridColumnStart,
                AnimationValue::GridColumnEnd(..) => LonghandId::GridColumnEnd,
                AnimationValue::GridAutoColumns(..) => LonghandId::GridAutoColumns,
                AnimationValue::GridTemplateColumns(..) => LonghandId::GridTemplateColumns,
                AnimationValue::GridAutoFlow(..) => LonghandId::GridAutoFlow,
                AnimationValue::GridTemplateAreas(..) => LonghandId::GridTemplateAreas,
                AnimationValue::TableLayout(..) => LonghandId::TableLayout,
                AnimationValue::TextOverflow(..) => LonghandId::TextOverflow,
                AnimationValue::UnicodeBidi(..) => LonghandId::UnicodeBidi,
                AnimationValue::TextDecorationLine(..) => LonghandId::TextDecorationLine,
                AnimationValue::TextDecorationStyle(..) => LonghandId::TextDecorationStyle,
                AnimationValue::TextDecorationColor(..) => LonghandId::TextDecorationColor,
                AnimationValue::InitialLetter(..) => LonghandId::InitialLetter,
                AnimationValue::ImeMode(..) => LonghandId::ImeMode,
                AnimationValue::MozUserSelect(..) => LonghandId::MozUserSelect,
                AnimationValue::MozWindowDragging(..) => LonghandId::MozWindowDragging,
                AnimationValue::MozWindowShadow(..) => LonghandId::MozWindowShadow,
                AnimationValue::MozWindowOpacity(..) => LonghandId::MozWindowOpacity,
                AnimationValue::MozWindowTransform(..) => LonghandId::MozWindowTransform,
                AnimationValue::MozWindowTransformOrigin(..) => LonghandId::MozWindowTransformOrigin,
                AnimationValue::MozForceBrokenImageIcon(..) => LonghandId::MozForceBrokenImageIcon,
                AnimationValue::TextAnchor(..) => LonghandId::TextAnchor,
                AnimationValue::ColorInterpolation(..) => LonghandId::ColorInterpolation,
                AnimationValue::ColorInterpolationFilters(..) => LonghandId::ColorInterpolationFilters,
                AnimationValue::Fill(..) => LonghandId::Fill,
                AnimationValue::FillOpacity(..) => LonghandId::FillOpacity,
                AnimationValue::FillRule(..) => LonghandId::FillRule,
                AnimationValue::ShapeRendering(..) => LonghandId::ShapeRendering,
                AnimationValue::Stroke(..) => LonghandId::Stroke,
                AnimationValue::StrokeWidth(..) => LonghandId::StrokeWidth,
                AnimationValue::StrokeLinecap(..) => LonghandId::StrokeLinecap,
                AnimationValue::StrokeLinejoin(..) => LonghandId::StrokeLinejoin,
                AnimationValue::StrokeMiterlimit(..) => LonghandId::StrokeMiterlimit,
                AnimationValue::StrokeOpacity(..) => LonghandId::StrokeOpacity,
                AnimationValue::StrokeDasharray(..) => LonghandId::StrokeDasharray,
                AnimationValue::StrokeDashoffset(..) => LonghandId::StrokeDashoffset,
                AnimationValue::ClipRule(..) => LonghandId::ClipRule,
                AnimationValue::MarkerStart(..) => LonghandId::MarkerStart,
                AnimationValue::MarkerMid(..) => LonghandId::MarkerMid,
                AnimationValue::MarkerEnd(..) => LonghandId::MarkerEnd,
                AnimationValue::PaintOrder(..) => LonghandId::PaintOrder,
                AnimationValue::DominantBaseline(..) => LonghandId::DominantBaseline,
                AnimationValue::VectorEffect(..) => LonghandId::VectorEffect,
                AnimationValue::StopColor(..) => LonghandId::StopColor,
                AnimationValue::StopOpacity(..) => LonghandId::StopOpacity,
                AnimationValue::FloodColor(..) => LonghandId::FloodColor,
                AnimationValue::FloodOpacity(..) => LonghandId::FloodOpacity,
                AnimationValue::LightingColor(..) => LonghandId::LightingColor,
                AnimationValue::MaskType(..) => LonghandId::MaskType,
                AnimationValue::ClipPath(..) => LonghandId::ClipPath,
                AnimationValue::MaskMode(..) => LonghandId::MaskMode,
                AnimationValue::MaskRepeat(..) => LonghandId::MaskRepeat,
                AnimationValue::MaskPositionX(..) => LonghandId::MaskPositionX,
                AnimationValue::MaskPositionY(..) => LonghandId::MaskPositionY,
                AnimationValue::MaskClip(..) => LonghandId::MaskClip,
                AnimationValue::MaskOrigin(..) => LonghandId::MaskOrigin,
                AnimationValue::MaskSize(..) => LonghandId::MaskSize,
                AnimationValue::MaskComposite(..) => LonghandId::MaskComposite,
                AnimationValue::MaskImage(..) => LonghandId::MaskImage,
                AnimationValue::MozBoxAlign(..) => LonghandId::MozBoxAlign,
                AnimationValue::MozBoxDirection(..) => LonghandId::MozBoxDirection,
                AnimationValue::MozBoxFlex(..) => LonghandId::MozBoxFlex,
                AnimationValue::MozBoxOrient(..) => LonghandId::MozBoxOrient,
                AnimationValue::MozBoxPack(..) => LonghandId::MozBoxPack,
                AnimationValue::MozStackSizing(..) => LonghandId::MozStackSizing,
                AnimationValue::MozBoxOrdinalGroup(..) => LonghandId::MozBoxOrdinalGroup,
        }
    }

    /// "Uncompute" this animation value in order to be used inside the CSS
    /// cascade.
    pub fn uncompute(&self) -> PropertyDeclaration {
        use properties::longhands;
        match *self {
                    AnimationValue::BackgroundColor(ref from) => {
                        PropertyDeclaration::BackgroundColor(
                                longhands::background_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BackgroundImage(ref from) => {
                        PropertyDeclaration::BackgroundImage(
                                longhands::background_image::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundPositionX(ref from) => {
                        PropertyDeclaration::BackgroundPositionX(
                                longhands::background_position_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundPositionY(ref from) => {
                        PropertyDeclaration::BackgroundPositionY(
                                longhands::background_position_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundRepeat(ref from) => {
                        PropertyDeclaration::BackgroundRepeat(
                                longhands::background_repeat::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundAttachment(ref from) => {
                        PropertyDeclaration::BackgroundAttachment(
                                longhands::background_attachment::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundClip(ref from) => {
                        PropertyDeclaration::BackgroundClip(
                                longhands::background_clip::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundOrigin(ref from) => {
                        PropertyDeclaration::BackgroundOrigin(
                                longhands::background_origin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BackgroundSize(ref from) => {
                        PropertyDeclaration::BackgroundSize(
                                longhands::background_size::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BackgroundBlendMode(ref from) => {
                        PropertyDeclaration::BackgroundBlendMode(
                                longhands::background_blend_mode::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderTopColor(ref from) => {
                        PropertyDeclaration::BorderTopColor(
                                longhands::border_top_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderTopStyle(ref from) => {
                        PropertyDeclaration::BorderTopStyle(
                                longhands::border_top_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderTopWidth(ref from) => {
                        PropertyDeclaration::BorderTopWidth(
                                longhands::border_top_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderLeftColor(ref from) => {
                        PropertyDeclaration::BorderLeftColor(
                                longhands::border_left_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderLeftStyle(ref from) => {
                        PropertyDeclaration::BorderLeftStyle(
                                longhands::border_left_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderLeftWidth(ref from) => {
                        PropertyDeclaration::BorderLeftWidth(
                                longhands::border_left_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderBottomColor(ref from) => {
                        PropertyDeclaration::BorderBottomColor(
                                longhands::border_bottom_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderBottomStyle(ref from) => {
                        PropertyDeclaration::BorderBottomStyle(
                                longhands::border_bottom_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderBottomWidth(ref from) => {
                        PropertyDeclaration::BorderBottomWidth(
                                longhands::border_bottom_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderRightColor(ref from) => {
                        PropertyDeclaration::BorderRightColor(
                                longhands::border_right_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderRightStyle(ref from) => {
                        PropertyDeclaration::BorderRightStyle(
                                longhands::border_right_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderRightWidth(ref from) => {
                        PropertyDeclaration::BorderRightWidth(
                                longhands::border_right_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BorderTopLeftRadius(ref from) => {
                        PropertyDeclaration::BorderTopLeftRadius(
                            Box::new(
                                longhands::border_top_left_radius::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::BorderTopRightRadius(ref from) => {
                        PropertyDeclaration::BorderTopRightRadius(
                            Box::new(
                                longhands::border_top_right_radius::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::BorderBottomRightRadius(ref from) => {
                        PropertyDeclaration::BorderBottomRightRadius(
                            Box::new(
                                longhands::border_bottom_right_radius::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::BorderBottomLeftRadius(ref from) => {
                        PropertyDeclaration::BorderBottomLeftRadius(
                            Box::new(
                                longhands::border_bottom_left_radius::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::MozBorderTopColors(ref from) => {
                        PropertyDeclaration::MozBorderTopColors(
                                longhands::_moz_border_top_colors::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBorderLeftColors(ref from) => {
                        PropertyDeclaration::MozBorderLeftColors(
                                longhands::_moz_border_left_colors::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBorderBottomColors(ref from) => {
                        PropertyDeclaration::MozBorderBottomColors(
                                longhands::_moz_border_bottom_colors::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBorderRightColors(ref from) => {
                        PropertyDeclaration::MozBorderRightColors(
                                longhands::_moz_border_right_colors::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BoxDecorationBreak(ref from) => {
                        PropertyDeclaration::BoxDecorationBreak(
                                longhands::box_decoration_break::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozFloatEdge(ref from) => {
                        PropertyDeclaration::MozFloatEdge(
                                longhands::_moz_float_edge::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderImageSource(ref from) => {
                        PropertyDeclaration::BorderImageSource(
                            Box::new(
                                longhands::border_image_source::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::BorderImageOutset(ref from) => {
                        PropertyDeclaration::BorderImageOutset(
                            Box::new(
                                longhands::border_image_outset::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::BorderImageRepeat(ref from) => {
                        PropertyDeclaration::BorderImageRepeat(
                                longhands::border_image_repeat::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderImageWidth(ref from) => {
                        PropertyDeclaration::BorderImageWidth(
                            Box::new(
                                longhands::border_image_width::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::BorderImageSlice(ref from) => {
                        PropertyDeclaration::BorderImageSlice(
                            Box::new(
                                longhands::border_image_slice::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::Display(ref from) => {
                        PropertyDeclaration::Display(
                                longhands::display::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Position(ref from) => {
                        PropertyDeclaration::Position(
                                longhands::position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Float(ref from) => {
                        PropertyDeclaration::Float(
                                longhands::float::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Clear(ref from) => {
                        PropertyDeclaration::Clear(
                                longhands::clear::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::VerticalAlign(ref from) => {
                        PropertyDeclaration::VerticalAlign(
                                longhands::vertical_align::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverflowClipBoxInline(ref from) => {
                        PropertyDeclaration::OverflowClipBoxInline(
                                longhands::overflow_clip_box_inline::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverflowClipBoxBlock(ref from) => {
                        PropertyDeclaration::OverflowClipBoxBlock(
                                longhands::overflow_clip_box_block::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverflowX(ref from) => {
                        PropertyDeclaration::OverflowX(
                                longhands::overflow_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverflowY(ref from) => {
                        PropertyDeclaration::OverflowY(
                                longhands::overflow_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollSnapPointsX(ref from) => {
                        PropertyDeclaration::ScrollSnapPointsX(
                                longhands::scroll_snap_points_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollSnapPointsY(ref from) => {
                        PropertyDeclaration::ScrollSnapPointsY(
                                longhands::scroll_snap_points_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollSnapDestination(ref from) => {
                        PropertyDeclaration::ScrollSnapDestination(
                            Box::new(
                                longhands::scroll_snap_destination::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::ScrollSnapCoordinate(ref from) => {
                        PropertyDeclaration::ScrollSnapCoordinate(
                                longhands::scroll_snap_coordinate::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Transform(ref from) => {
                        PropertyDeclaration::Transform(
                                longhands::transform::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollBehavior(ref from) => {
                        PropertyDeclaration::ScrollBehavior(
                                longhands::scroll_behavior::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollSnapTypeX(ref from) => {
                        PropertyDeclaration::ScrollSnapTypeX(
                                longhands::scroll_snap_type_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ScrollSnapTypeY(ref from) => {
                        PropertyDeclaration::ScrollSnapTypeY(
                                longhands::scroll_snap_type_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverscrollBehaviorX(ref from) => {
                        PropertyDeclaration::OverscrollBehaviorX(
                                longhands::overscroll_behavior_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverscrollBehaviorY(ref from) => {
                        PropertyDeclaration::OverscrollBehaviorY(
                                longhands::overscroll_behavior_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Isolation(ref from) => {
                        PropertyDeclaration::Isolation(
                                longhands::isolation::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PageBreakAfter(ref from) => {
                        PropertyDeclaration::PageBreakAfter(
                                longhands::page_break_after::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PageBreakBefore(ref from) => {
                        PropertyDeclaration::PageBreakBefore(
                                longhands::page_break_before::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PageBreakInside(ref from) => {
                        PropertyDeclaration::PageBreakInside(
                                longhands::page_break_inside::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Resize(ref from) => {
                        PropertyDeclaration::Resize(
                                longhands::resize::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Perspective(ref from) => {
                        PropertyDeclaration::Perspective(
                                longhands::perspective::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PerspectiveOrigin(ref from) => {
                        PropertyDeclaration::PerspectiveOrigin(
                            Box::new(
                                longhands::perspective_origin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::BackfaceVisibility(ref from) => {
                        PropertyDeclaration::BackfaceVisibility(
                                longhands::backface_visibility::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TransformBox(ref from) => {
                        PropertyDeclaration::TransformBox(
                                longhands::transform_box::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TransformStyle(ref from) => {
                        PropertyDeclaration::TransformStyle(
                                longhands::transform_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TransformOrigin(ref from) => {
                        PropertyDeclaration::TransformOrigin(
                            Box::new(
                                longhands::transform_origin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::Contain(ref from) => {
                        PropertyDeclaration::Contain(
                                longhands::contain::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozAppearance(ref from) => {
                        PropertyDeclaration::MozAppearance(
                                longhands::_moz_appearance::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozOrient(ref from) => {
                        PropertyDeclaration::MozOrient(
                                longhands::_moz_orient::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::WillChange(ref from) => {
                        PropertyDeclaration::WillChange(
                                longhands::will_change::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ShapeImageThreshold(ref from) => {
                        PropertyDeclaration::ShapeImageThreshold(
                                longhands::shape_image_threshold::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ShapeOutside(ref from) => {
                        PropertyDeclaration::ShapeOutside(
                            Box::new(
                                longhands::shape_outside::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::TouchAction(ref from) => {
                        PropertyDeclaration::TouchAction(
                                longhands::touch_action::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Color(ref from) => {
                        PropertyDeclaration::Color(
                                longhands::color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnWidth(ref from) => {
                        PropertyDeclaration::ColumnWidth(
                                longhands::column_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnCount(ref from) => {
                        PropertyDeclaration::ColumnCount(
                                longhands::column_count::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnGap(ref from) => {
                        PropertyDeclaration::ColumnGap(
                                longhands::column_gap::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnFill(ref from) => {
                        PropertyDeclaration::ColumnFill(
                                longhands::column_fill::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ColumnRuleWidth(ref from) => {
                        PropertyDeclaration::ColumnRuleWidth(
                                longhands::column_rule_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnRuleColor(ref from) => {
                        PropertyDeclaration::ColumnRuleColor(
                                longhands::column_rule_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::ColumnSpan(ref from) => {
                        PropertyDeclaration::ColumnSpan(
                                longhands::column_span::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ColumnRuleStyle(ref from) => {
                        PropertyDeclaration::ColumnRuleStyle(
                                longhands::column_rule_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Content(ref from) => {
                        PropertyDeclaration::Content(
                            Box::new(
                                longhands::content::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::CounterIncrement(ref from) => {
                        PropertyDeclaration::CounterIncrement(
                                longhands::counter_increment::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::CounterReset(ref from) => {
                        PropertyDeclaration::CounterReset(
                                longhands::counter_reset::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Opacity(ref from) => {
                        PropertyDeclaration::Opacity(
                                longhands::opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BoxShadow(ref from) => {
                        PropertyDeclaration::BoxShadow(
                                longhands::box_shadow::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Clip(ref from) => {
                        PropertyDeclaration::Clip(
                            Box::new(
                                longhands::clip::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::Filter(ref from) => {
                        PropertyDeclaration::Filter(
                                longhands::filter::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MixBlendMode(ref from) => {
                        PropertyDeclaration::MixBlendMode(
                                longhands::mix_blend_mode::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontFamily(ref from) => {
                        PropertyDeclaration::FontFamily(
                                longhands::font_family::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontStyle(ref from) => {
                        PropertyDeclaration::FontStyle(
                                longhands::font_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantCaps(ref from) => {
                        PropertyDeclaration::FontVariantCaps(
                                longhands::font_variant_caps::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontWeight(ref from) => {
                        PropertyDeclaration::FontWeight(
                                longhands::font_weight::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontSize(ref from) => {
                        PropertyDeclaration::FontSize(
                                longhands::font_size::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::FontSizeAdjust(ref from) => {
                        PropertyDeclaration::FontSizeAdjust(
                                longhands::font_size_adjust::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontSynthesis(ref from) => {
                        PropertyDeclaration::FontSynthesis(
                                longhands::font_synthesis::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontStretch(ref from) => {
                        PropertyDeclaration::FontStretch(
                                longhands::font_stretch::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontKerning(ref from) => {
                        PropertyDeclaration::FontKerning(
                                longhands::font_kerning::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantAlternates(ref from) => {
                        PropertyDeclaration::FontVariantAlternates(
                                longhands::font_variant_alternates::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantEastAsian(ref from) => {
                        PropertyDeclaration::FontVariantEastAsian(
                                longhands::font_variant_east_asian::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantLigatures(ref from) => {
                        PropertyDeclaration::FontVariantLigatures(
                                longhands::font_variant_ligatures::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantNumeric(ref from) => {
                        PropertyDeclaration::FontVariantNumeric(
                                longhands::font_variant_numeric::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontVariantPosition(ref from) => {
                        PropertyDeclaration::FontVariantPosition(
                                longhands::font_variant_position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontFeatureSettings(ref from) => {
                        PropertyDeclaration::FontFeatureSettings(
                            Box::new(
                                longhands::font_feature_settings::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::FontVariationSettings(ref from) => {
                        PropertyDeclaration::FontVariationSettings(
                                longhands::font_variation_settings::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FontLanguageOverride(ref from) => {
                        PropertyDeclaration::FontLanguageOverride(
                                longhands::font_language_override::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozOsxFontSmoothing(ref from) => {
                        PropertyDeclaration::MozOsxFontSmoothing(
                                longhands::_moz_osx_font_smoothing::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozFontSmoothingBackgroundColor(ref from) => {
                        PropertyDeclaration::MozFontSmoothingBackgroundColor(
                                longhands::_moz_font_smoothing_background_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Visibility(ref from) => {
                        PropertyDeclaration::Visibility(
                                longhands::visibility::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::WritingMode(ref from) => {
                        PropertyDeclaration::WritingMode(
                                longhands::writing_mode::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Direction(ref from) => {
                        PropertyDeclaration::Direction(
                                longhands::direction::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextOrientation(ref from) => {
                        PropertyDeclaration::TextOrientation(
                                longhands::text_orientation::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ColorAdjust(ref from) => {
                        PropertyDeclaration::ColorAdjust(
                                longhands::color_adjust::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ImageRendering(ref from) => {
                        PropertyDeclaration::ImageRendering(
                                longhands::image_rendering::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ImageOrientation(ref from) => {
                        PropertyDeclaration::ImageOrientation(
                                longhands::image_orientation::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderCollapse(ref from) => {
                        PropertyDeclaration::BorderCollapse(
                                longhands::border_collapse::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::EmptyCells(ref from) => {
                        PropertyDeclaration::EmptyCells(
                                longhands::empty_cells::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::CaptionSide(ref from) => {
                        PropertyDeclaration::CaptionSide(
                                longhands::caption_side::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::BorderSpacing(ref from) => {
                        PropertyDeclaration::BorderSpacing(
                            Box::new(
                                longhands::border_spacing::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::LineHeight(ref from) => {
                        PropertyDeclaration::LineHeight(
                                longhands::line_height::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::TextTransform(ref from) => {
                        PropertyDeclaration::TextTransform(
                                longhands::text_transform::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Hyphens(ref from) => {
                        PropertyDeclaration::Hyphens(
                                longhands::hyphens::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozTextSizeAdjust(ref from) => {
                        PropertyDeclaration::MozTextSizeAdjust(
                                longhands::_moz_text_size_adjust::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextIndent(ref from) => {
                        PropertyDeclaration::TextIndent(
                                longhands::text_indent::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OverflowWrap(ref from) => {
                        PropertyDeclaration::OverflowWrap(
                                longhands::overflow_wrap::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::WordBreak(ref from) => {
                        PropertyDeclaration::WordBreak(
                                longhands::word_break::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextJustify(ref from) => {
                        PropertyDeclaration::TextJustify(
                                longhands::text_justify::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextAlignLast(ref from) => {
                        PropertyDeclaration::TextAlignLast(
                                longhands::text_align_last::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextAlign(ref from) => {
                        PropertyDeclaration::TextAlign(
                                longhands::text_align::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::LetterSpacing(ref from) => {
                        PropertyDeclaration::LetterSpacing(
                                longhands::letter_spacing::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::WordSpacing(ref from) => {
                        PropertyDeclaration::WordSpacing(
                                longhands::word_spacing::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::WhiteSpace(ref from) => {
                        PropertyDeclaration::WhiteSpace(
                                longhands::white_space::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextShadow(ref from) => {
                        PropertyDeclaration::TextShadow(
                                longhands::text_shadow::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::TextEmphasisStyle(ref from) => {
                        PropertyDeclaration::TextEmphasisStyle(
                            Box::new(
                                longhands::text_emphasis_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::TextEmphasisPosition(ref from) => {
                        PropertyDeclaration::TextEmphasisPosition(
                                longhands::text_emphasis_position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextEmphasisColor(ref from) => {
                        PropertyDeclaration::TextEmphasisColor(
                                longhands::text_emphasis_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MozTabSize(ref from) => {
                        PropertyDeclaration::MozTabSize(
                                longhands::_moz_tab_size::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::WebkitTextFillColor(ref from) => {
                        PropertyDeclaration::WebkitTextFillColor(
                                longhands::_webkit_text_fill_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::WebkitTextStrokeColor(ref from) => {
                        PropertyDeclaration::WebkitTextStrokeColor(
                                longhands::_webkit_text_stroke_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::WebkitTextStrokeWidth(ref from) => {
                        PropertyDeclaration::WebkitTextStrokeWidth(
                                longhands::_webkit_text_stroke_width::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::RubyAlign(ref from) => {
                        PropertyDeclaration::RubyAlign(
                                longhands::ruby_align::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::RubyPosition(ref from) => {
                        PropertyDeclaration::RubyPosition(
                                longhands::ruby_position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextCombineUpright(ref from) => {
                        PropertyDeclaration::TextCombineUpright(
                                longhands::text_combine_upright::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextRendering(ref from) => {
                        PropertyDeclaration::TextRendering(
                                longhands::text_rendering::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ListStylePosition(ref from) => {
                        PropertyDeclaration::ListStylePosition(
                                longhands::list_style_position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ListStyleType(ref from) => {
                        PropertyDeclaration::ListStyleType(
                            Box::new(
                                longhands::list_style_type::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::ListStyleImage(ref from) => {
                        PropertyDeclaration::ListStyleImage(
                            Box::new(
                                longhands::list_style_image::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::Quotes(ref from) => {
                        PropertyDeclaration::Quotes(
                                longhands::quotes::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozImageRegion(ref from) => {
                        PropertyDeclaration::MozImageRegion(
                            Box::new(
                                longhands::_moz_image_region::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::MarginTop(ref from) => {
                        PropertyDeclaration::MarginTop(
                                longhands::margin_top::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MarginLeft(ref from) => {
                        PropertyDeclaration::MarginLeft(
                                longhands::margin_left::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MarginBottom(ref from) => {
                        PropertyDeclaration::MarginBottom(
                                longhands::margin_bottom::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MarginRight(ref from) => {
                        PropertyDeclaration::MarginRight(
                                longhands::margin_right::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OutlineColor(ref from) => {
                        PropertyDeclaration::OutlineColor(
                                longhands::outline_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::OutlineStyle(ref from) => {
                        PropertyDeclaration::OutlineStyle(
                                longhands::outline_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::OutlineWidth(ref from) => {
                        PropertyDeclaration::OutlineWidth(
                                longhands::outline_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MozOutlineRadiusTopleft(ref from) => {
                        PropertyDeclaration::MozOutlineRadiusTopleft(
                            Box::new(
                                longhands::_moz_outline_radius_topleft::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::MozOutlineRadiusTopright(ref from) => {
                        PropertyDeclaration::MozOutlineRadiusTopright(
                            Box::new(
                                longhands::_moz_outline_radius_topright::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::MozOutlineRadiusBottomright(ref from) => {
                        PropertyDeclaration::MozOutlineRadiusBottomright(
                            Box::new(
                                longhands::_moz_outline_radius_bottomright::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::MozOutlineRadiusBottomleft(ref from) => {
                        PropertyDeclaration::MozOutlineRadiusBottomleft(
                            Box::new(
                                longhands::_moz_outline_radius_bottomleft::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::OutlineOffset(ref from) => {
                        PropertyDeclaration::OutlineOffset(
                                longhands::outline_offset::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PaddingTop(ref from) => {
                        PropertyDeclaration::PaddingTop(
                                longhands::padding_top::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::PaddingLeft(ref from) => {
                        PropertyDeclaration::PaddingLeft(
                                longhands::padding_left::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::PaddingBottom(ref from) => {
                        PropertyDeclaration::PaddingBottom(
                                longhands::padding_bottom::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::PaddingRight(ref from) => {
                        PropertyDeclaration::PaddingRight(
                                longhands::padding_right::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Cursor(ref from) => {
                        PropertyDeclaration::Cursor(
                                longhands::cursor::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::PointerEvents(ref from) => {
                        PropertyDeclaration::PointerEvents(
                                longhands::pointer_events::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozUserInput(ref from) => {
                        PropertyDeclaration::MozUserInput(
                                longhands::_moz_user_input::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozUserModify(ref from) => {
                        PropertyDeclaration::MozUserModify(
                                longhands::_moz_user_modify::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozUserFocus(ref from) => {
                        PropertyDeclaration::MozUserFocus(
                                longhands::_moz_user_focus::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::CaretColor(ref from) => {
                        PropertyDeclaration::CaretColor(
                                longhands::caret_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Top(ref from) => {
                        PropertyDeclaration::Top(
                                longhands::top::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Left(ref from) => {
                        PropertyDeclaration::Left(
                                longhands::left::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Bottom(ref from) => {
                        PropertyDeclaration::Bottom(
                                longhands::bottom::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Right(ref from) => {
                        PropertyDeclaration::Right(
                                longhands::right::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ZIndex(ref from) => {
                        PropertyDeclaration::ZIndex(
                                longhands::z_index::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FlexDirection(ref from) => {
                        PropertyDeclaration::FlexDirection(
                                longhands::flex_direction::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FlexWrap(ref from) => {
                        PropertyDeclaration::FlexWrap(
                                longhands::flex_wrap::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::JustifyContent(ref from) => {
                        PropertyDeclaration::JustifyContent(
                                longhands::justify_content::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::AlignContent(ref from) => {
                        PropertyDeclaration::AlignContent(
                                longhands::align_content::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::AlignItems(ref from) => {
                        PropertyDeclaration::AlignItems(
                                longhands::align_items::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::JustifyItems(ref from) => {
                        PropertyDeclaration::JustifyItems(
                                longhands::justify_items::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FlexGrow(ref from) => {
                        PropertyDeclaration::FlexGrow(
                                longhands::flex_grow::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::FlexShrink(ref from) => {
                        PropertyDeclaration::FlexShrink(
                                longhands::flex_shrink::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::AlignSelf(ref from) => {
                        PropertyDeclaration::AlignSelf(
                                longhands::align_self::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::JustifySelf(ref from) => {
                        PropertyDeclaration::JustifySelf(
                                longhands::justify_self::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Order(ref from) => {
                        PropertyDeclaration::Order(
                                longhands::order::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FlexBasis(ref from) => {
                        PropertyDeclaration::FlexBasis(
                                longhands::flex_basis::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Width(ref from) => {
                        PropertyDeclaration::Width(
                                longhands::width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MinWidth(ref from) => {
                        PropertyDeclaration::MinWidth(
                                longhands::min_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MaxWidth(ref from) => {
                        PropertyDeclaration::MaxWidth(
                                longhands::max_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::Height(ref from) => {
                        PropertyDeclaration::Height(
                                longhands::height::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MinHeight(ref from) => {
                        PropertyDeclaration::MinHeight(
                                longhands::min_height::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MaxHeight(ref from) => {
                        PropertyDeclaration::MaxHeight(
                                longhands::max_height::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::BoxSizing(ref from) => {
                        PropertyDeclaration::BoxSizing(
                                longhands::box_sizing::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ObjectFit(ref from) => {
                        PropertyDeclaration::ObjectFit(
                                longhands::object_fit::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ObjectPosition(ref from) => {
                        PropertyDeclaration::ObjectPosition(
                            Box::new(
                                longhands::object_position::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridRowGap(ref from) => {
                        PropertyDeclaration::GridRowGap(
                                longhands::grid_row_gap::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::GridRowStart(ref from) => {
                        PropertyDeclaration::GridRowStart(
                            Box::new(
                                longhands::grid_row_start::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridRowEnd(ref from) => {
                        PropertyDeclaration::GridRowEnd(
                            Box::new(
                                longhands::grid_row_end::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridAutoRows(ref from) => {
                        PropertyDeclaration::GridAutoRows(
                            Box::new(
                                longhands::grid_auto_rows::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridTemplateRows(ref from) => {
                        PropertyDeclaration::GridTemplateRows(
                            Box::new(
                                longhands::grid_template_rows::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridColumnGap(ref from) => {
                        PropertyDeclaration::GridColumnGap(
                                longhands::grid_column_gap::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::GridColumnStart(ref from) => {
                        PropertyDeclaration::GridColumnStart(
                            Box::new(
                                longhands::grid_column_start::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridColumnEnd(ref from) => {
                        PropertyDeclaration::GridColumnEnd(
                            Box::new(
                                longhands::grid_column_end::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridAutoColumns(ref from) => {
                        PropertyDeclaration::GridAutoColumns(
                            Box::new(
                                longhands::grid_auto_columns::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridTemplateColumns(ref from) => {
                        PropertyDeclaration::GridTemplateColumns(
                            Box::new(
                                longhands::grid_template_columns::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::GridAutoFlow(ref from) => {
                        PropertyDeclaration::GridAutoFlow(
                                longhands::grid_auto_flow::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::GridTemplateAreas(ref from) => {
                        PropertyDeclaration::GridTemplateAreas(
                            Box::new(
                                longhands::grid_template_areas::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::TableLayout(ref from) => {
                        PropertyDeclaration::TableLayout(
                                longhands::table_layout::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextOverflow(ref from) => {
                        PropertyDeclaration::TextOverflow(
                            Box::new(
                                longhands::text_overflow::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::UnicodeBidi(ref from) => {
                        PropertyDeclaration::UnicodeBidi(
                                longhands::unicode_bidi::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextDecorationLine(ref from) => {
                        PropertyDeclaration::TextDecorationLine(
                                longhands::text_decoration_line::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextDecorationStyle(ref from) => {
                        PropertyDeclaration::TextDecorationStyle(
                                longhands::text_decoration_style::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextDecorationColor(ref from) => {
                        PropertyDeclaration::TextDecorationColor(
                                longhands::text_decoration_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::InitialLetter(ref from) => {
                        PropertyDeclaration::InitialLetter(
                                longhands::initial_letter::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ImeMode(ref from) => {
                        PropertyDeclaration::ImeMode(
                                longhands::ime_mode::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozUserSelect(ref from) => {
                        PropertyDeclaration::MozUserSelect(
                                longhands::_moz_user_select::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozWindowDragging(ref from) => {
                        PropertyDeclaration::MozWindowDragging(
                                longhands::_moz_window_dragging::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozWindowShadow(ref from) => {
                        PropertyDeclaration::MozWindowShadow(
                                longhands::_moz_window_shadow::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozWindowOpacity(ref from) => {
                        PropertyDeclaration::MozWindowOpacity(
                                longhands::_moz_window_opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozWindowTransform(ref from) => {
                        PropertyDeclaration::MozWindowTransform(
                                longhands::_moz_window_transform::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozWindowTransformOrigin(ref from) => {
                        PropertyDeclaration::MozWindowTransformOrigin(
                            Box::new(
                                longhands::_moz_window_transform_origin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::MozForceBrokenImageIcon(ref from) => {
                        PropertyDeclaration::MozForceBrokenImageIcon(
                                longhands::_moz_force_broken_image_icon::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::TextAnchor(ref from) => {
                        PropertyDeclaration::TextAnchor(
                                longhands::text_anchor::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ColorInterpolation(ref from) => {
                        PropertyDeclaration::ColorInterpolation(
                                longhands::color_interpolation::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ColorInterpolationFilters(ref from) => {
                        PropertyDeclaration::ColorInterpolationFilters(
                                longhands::color_interpolation_filters::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Fill(ref from) => {
                        PropertyDeclaration::Fill(
                            Box::new(
                                longhands::fill::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::FillOpacity(ref from) => {
                        PropertyDeclaration::FillOpacity(
                                longhands::fill_opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FillRule(ref from) => {
                        PropertyDeclaration::FillRule(
                                longhands::fill_rule::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ShapeRendering(ref from) => {
                        PropertyDeclaration::ShapeRendering(
                                longhands::shape_rendering::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::Stroke(ref from) => {
                        PropertyDeclaration::Stroke(
                            Box::new(
                                longhands::stroke::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                            )
                    }
                    AnimationValue::StrokeWidth(ref from) => {
                        PropertyDeclaration::StrokeWidth(
                                longhands::stroke_width::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::StrokeLinecap(ref from) => {
                        PropertyDeclaration::StrokeLinecap(
                                longhands::stroke_linecap::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::StrokeLinejoin(ref from) => {
                        PropertyDeclaration::StrokeLinejoin(
                                longhands::stroke_linejoin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::StrokeMiterlimit(ref from) => {
                        PropertyDeclaration::StrokeMiterlimit(
                                longhands::stroke_miterlimit::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::StrokeOpacity(ref from) => {
                        PropertyDeclaration::StrokeOpacity(
                                longhands::stroke_opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::StrokeDasharray(ref from) => {
                        PropertyDeclaration::StrokeDasharray(
                                longhands::stroke_dasharray::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::StrokeDashoffset(ref from) => {
                        PropertyDeclaration::StrokeDashoffset(
                                longhands::stroke_dashoffset::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ClipRule(ref from) => {
                        PropertyDeclaration::ClipRule(
                                longhands::clip_rule::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MarkerStart(ref from) => {
                        PropertyDeclaration::MarkerStart(
                            Box::new(
                                longhands::marker_start::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::MarkerMid(ref from) => {
                        PropertyDeclaration::MarkerMid(
                            Box::new(
                                longhands::marker_mid::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::MarkerEnd(ref from) => {
                        PropertyDeclaration::MarkerEnd(
                            Box::new(
                                longhands::marker_end::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::PaintOrder(ref from) => {
                        PropertyDeclaration::PaintOrder(
                                longhands::paint_order::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::DominantBaseline(ref from) => {
                        PropertyDeclaration::DominantBaseline(
                                longhands::dominant_baseline::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::VectorEffect(ref from) => {
                        PropertyDeclaration::VectorEffect(
                                longhands::vector_effect::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::StopColor(ref from) => {
                        PropertyDeclaration::StopColor(
                                longhands::stop_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::StopOpacity(ref from) => {
                        PropertyDeclaration::StopOpacity(
                                longhands::stop_opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::FloodColor(ref from) => {
                        PropertyDeclaration::FloodColor(
                                longhands::flood_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::FloodOpacity(ref from) => {
                        PropertyDeclaration::FloodOpacity(
                                longhands::flood_opacity::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::LightingColor(ref from) => {
                        PropertyDeclaration::LightingColor(
                                longhands::lighting_color::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MaskType(ref from) => {
                        PropertyDeclaration::MaskType(
                                longhands::mask_type::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::ClipPath(ref from) => {
                        PropertyDeclaration::ClipPath(
                            Box::new(
                                longhands::clip_path::SpecifiedValue::from_computed_value(
                                    from
                                ))
                            )
                    }
                    AnimationValue::MaskMode(ref from) => {
                        PropertyDeclaration::MaskMode(
                                longhands::mask_mode::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskRepeat(ref from) => {
                        PropertyDeclaration::MaskRepeat(
                                longhands::mask_repeat::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskPositionX(ref from) => {
                        PropertyDeclaration::MaskPositionX(
                                longhands::mask_position_x::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskPositionY(ref from) => {
                        PropertyDeclaration::MaskPositionY(
                                longhands::mask_position_y::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskClip(ref from) => {
                        PropertyDeclaration::MaskClip(
                                longhands::mask_clip::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskOrigin(ref from) => {
                        PropertyDeclaration::MaskOrigin(
                                longhands::mask_origin::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskSize(ref from) => {
                        PropertyDeclaration::MaskSize(
                                longhands::mask_size::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskComposite(ref from) => {
                        PropertyDeclaration::MaskComposite(
                                longhands::mask_composite::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MaskImage(ref from) => {
                        PropertyDeclaration::MaskImage(
                                longhands::mask_image::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBoxAlign(ref from) => {
                        PropertyDeclaration::MozBoxAlign(
                                longhands::_moz_box_align::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBoxDirection(ref from) => {
                        PropertyDeclaration::MozBoxDirection(
                                longhands::_moz_box_direction::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBoxFlex(ref from) => {
                        PropertyDeclaration::MozBoxFlex(
                                longhands::_moz_box_flex::SpecifiedValue::from_computed_value(
                                    &ToAnimatedValue::from_animated_value(from.clone())
                                ))
                    }
                    AnimationValue::MozBoxOrient(ref from) => {
                        PropertyDeclaration::MozBoxOrient(
                                longhands::_moz_box_orient::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBoxPack(ref from) => {
                        PropertyDeclaration::MozBoxPack(
                                longhands::_moz_box_pack::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozStackSizing(ref from) => {
                        PropertyDeclaration::MozStackSizing(
                                longhands::_moz_stack_sizing::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
                    AnimationValue::MozBoxOrdinalGroup(ref from) => {
                        PropertyDeclaration::MozBoxOrdinalGroup(
                                longhands::_moz_box_ordinal_group::SpecifiedValue::from_computed_value(
                                    from
                                ))
                    }
        }
    }

    /// Construct an AnimationValue from a property declaration.
    pub fn from_declaration(
        decl: &PropertyDeclaration,
        context: &mut Context,
        extra_custom_properties: Option<&Arc<::custom_properties::CustomPropertiesMap>>,
        initial: &ComputedValues
    ) -> Option<Self> {
        use properties::LonghandId;

        let animatable = match *decl {
            PropertyDeclaration::BackgroundColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundColor);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BackgroundImage(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundImage);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundImage(
                computed
            )
            },
            PropertyDeclaration::BackgroundPositionX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundPositionX);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundPositionX(
                computed
            )
            },
            PropertyDeclaration::BackgroundPositionY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundPositionY);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundPositionY(
                computed
            )
            },
            PropertyDeclaration::BackgroundRepeat(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundRepeat);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundRepeat(
                computed
            )
            },
            PropertyDeclaration::BackgroundAttachment(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundAttachment);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundAttachment(
                computed
            )
            },
            PropertyDeclaration::BackgroundClip(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundClip);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundClip(
                computed
            )
            },
            PropertyDeclaration::BackgroundOrigin(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundOrigin);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundOrigin(
                computed
            )
            },
            PropertyDeclaration::BackgroundSize(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundSize);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundSize(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BackgroundBlendMode(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackgroundBlendMode);
            let computed = val.to_computed_value(context);
            AnimationValue::BackgroundBlendMode(
                computed
            )
            },
            PropertyDeclaration::BorderTopColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderTopColor);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderTopColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderTopStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderTopStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderTopStyle(
                computed
            )
            },
            PropertyDeclaration::BorderTopWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderTopWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderTopWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderLeftColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderLeftColor);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderLeftColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderLeftStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderLeftStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderLeftStyle(
                computed
            )
            },
            PropertyDeclaration::BorderLeftWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderLeftWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderLeftWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderBottomColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderBottomColor);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderBottomColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderBottomStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderBottomStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderBottomStyle(
                computed
            )
            },
            PropertyDeclaration::BorderBottomWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderBottomWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderBottomWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderRightColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderRightColor);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderRightColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderRightStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderRightStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderRightStyle(
                computed
            )
            },
            PropertyDeclaration::BorderRightWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderRightWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderRightWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderTopLeftRadius(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderTopLeftRadius);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderTopLeftRadius(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderTopRightRadius(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderTopRightRadius);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderTopRightRadius(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderBottomRightRadius(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderBottomRightRadius);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderBottomRightRadius(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BorderBottomLeftRadius(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderBottomLeftRadius);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderBottomLeftRadius(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozBorderTopColors(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBorderTopColors);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBorderTopColors(
                computed
            )
            },
            PropertyDeclaration::MozBorderLeftColors(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBorderLeftColors);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBorderLeftColors(
                computed
            )
            },
            PropertyDeclaration::MozBorderBottomColors(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBorderBottomColors);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBorderBottomColors(
                computed
            )
            },
            PropertyDeclaration::MozBorderRightColors(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBorderRightColors);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBorderRightColors(
                computed
            )
            },
            PropertyDeclaration::BoxDecorationBreak(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BoxDecorationBreak);
            let computed = val.to_computed_value(context);
            AnimationValue::BoxDecorationBreak(
                computed
            )
            },
            PropertyDeclaration::MozFloatEdge(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozFloatEdge);
            let computed = val.to_computed_value(context);
            AnimationValue::MozFloatEdge(
                computed
            )
            },
            PropertyDeclaration::BorderImageSource(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderImageSource);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderImageSource(
                computed
            )
            },
            PropertyDeclaration::BorderImageOutset(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderImageOutset);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderImageOutset(
                computed
            )
            },
            PropertyDeclaration::BorderImageRepeat(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderImageRepeat);
            let computed = val.to_computed_value(context);
            AnimationValue::BorderImageRepeat(
                computed
            )
            },
            PropertyDeclaration::BorderImageWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderImageWidth);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderImageWidth(
                computed
            )
            },
            PropertyDeclaration::BorderImageSlice(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BorderImageSlice);
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderImageSlice(
                computed
            )
            },
            PropertyDeclaration::Display(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Display);
            let computed = val.to_computed_value(context);
            AnimationValue::Display(
                computed
            )
            },
            PropertyDeclaration::Position(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Position);
            let computed = val.to_computed_value(context);
            AnimationValue::Position(
                computed
            )
            },
            PropertyDeclaration::Float(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Float);
            let computed = val.to_computed_value(context);
            AnimationValue::Float(
                computed
            )
            },
            PropertyDeclaration::Clear(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Clear);
            let computed = val.to_computed_value(context);
            AnimationValue::Clear(
                computed
            )
            },
            PropertyDeclaration::VerticalAlign(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::VerticalAlign);
            let computed = val.to_computed_value(context);
            AnimationValue::VerticalAlign(
                computed
            )
            },
            PropertyDeclaration::OverflowClipBoxInline(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverflowClipBoxInline);
            let computed = val.to_computed_value(context);
            AnimationValue::OverflowClipBoxInline(
                computed
            )
            },
            PropertyDeclaration::OverflowClipBoxBlock(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverflowClipBoxBlock);
            let computed = val.to_computed_value(context);
            AnimationValue::OverflowClipBoxBlock(
                computed
            )
            },
            PropertyDeclaration::OverflowX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverflowX);
            let computed = val.to_computed_value(context);
            AnimationValue::OverflowX(
                computed
            )
            },
            PropertyDeclaration::OverflowY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverflowY);
            let computed = val.to_computed_value(context);
            AnimationValue::OverflowY(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapPointsX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapPointsX);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollSnapPointsX(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapPointsY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapPointsY);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollSnapPointsY(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapDestination(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapDestination);
            let computed = (**val).to_computed_value(context);
            AnimationValue::ScrollSnapDestination(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapCoordinate(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapCoordinate);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollSnapCoordinate(
                computed
            )
            },
            PropertyDeclaration::Transform(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Transform);
            let computed = val.to_computed_value(context);
            AnimationValue::Transform(
                computed
            )
            },
            PropertyDeclaration::ScrollBehavior(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollBehavior);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollBehavior(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapTypeX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapTypeX);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollSnapTypeX(
                computed
            )
            },
            PropertyDeclaration::ScrollSnapTypeY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ScrollSnapTypeY);
            let computed = val.to_computed_value(context);
            AnimationValue::ScrollSnapTypeY(
                computed
            )
            },
            PropertyDeclaration::OverscrollBehaviorX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverscrollBehaviorX);
            let computed = val.to_computed_value(context);
            AnimationValue::OverscrollBehaviorX(
                computed
            )
            },
            PropertyDeclaration::OverscrollBehaviorY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OverscrollBehaviorY);
            let computed = val.to_computed_value(context);
            AnimationValue::OverscrollBehaviorY(
                computed
            )
            },
            PropertyDeclaration::Isolation(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Isolation);
            let computed = val.to_computed_value(context);
            AnimationValue::Isolation(
                computed
            )
            },
            PropertyDeclaration::PageBreakAfter(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PageBreakAfter);
            let computed = val.to_computed_value(context);
            AnimationValue::PageBreakAfter(
                computed
            )
            },
            PropertyDeclaration::PageBreakBefore(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PageBreakBefore);
            let computed = val.to_computed_value(context);
            AnimationValue::PageBreakBefore(
                computed
            )
            },
            PropertyDeclaration::PageBreakInside(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PageBreakInside);
            let computed = val.to_computed_value(context);
            AnimationValue::PageBreakInside(
                computed
            )
            },
            PropertyDeclaration::Resize(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Resize);
            let computed = val.to_computed_value(context);
            AnimationValue::Resize(
                computed
            )
            },
            PropertyDeclaration::Perspective(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Perspective);
            let computed = val.to_computed_value(context);
            AnimationValue::Perspective(
                computed
            )
            },
            PropertyDeclaration::PerspectiveOrigin(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PerspectiveOrigin);
            let computed = (**val).to_computed_value(context);
            AnimationValue::PerspectiveOrigin(
                computed
            )
            },
            PropertyDeclaration::BackfaceVisibility(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BackfaceVisibility);
            let computed = val.to_computed_value(context);
            AnimationValue::BackfaceVisibility(
                computed
            )
            },
            PropertyDeclaration::TransformBox(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TransformBox);
            let computed = val.to_computed_value(context);
            AnimationValue::TransformBox(
                computed
            )
            },
            PropertyDeclaration::TransformStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TransformStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::TransformStyle(
                computed
            )
            },
            PropertyDeclaration::TransformOrigin(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TransformOrigin);
            let computed = (**val).to_computed_value(context);
            AnimationValue::TransformOrigin(
                computed
            )
            },
            PropertyDeclaration::Contain(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Contain);
            let computed = val.to_computed_value(context);
            AnimationValue::Contain(
                computed
            )
            },
            PropertyDeclaration::MozAppearance(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozAppearance);
            let computed = val.to_computed_value(context);
            AnimationValue::MozAppearance(
                computed
            )
            },
            PropertyDeclaration::MozOrient(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozOrient);
            let computed = val.to_computed_value(context);
            AnimationValue::MozOrient(
                computed
            )
            },
            PropertyDeclaration::WillChange(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::WillChange);
            let computed = val.to_computed_value(context);
            AnimationValue::WillChange(
                computed
            )
            },
            PropertyDeclaration::ShapeImageThreshold(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ShapeImageThreshold);
            let computed = val.to_computed_value(context);
            AnimationValue::ShapeImageThreshold(
                computed
            )
            },
            PropertyDeclaration::ShapeOutside(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ShapeOutside);
            let computed = (**val).to_computed_value(context);
            AnimationValue::ShapeOutside(
                computed
            )
            },
            PropertyDeclaration::TouchAction(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TouchAction);
            let computed = val.to_computed_value(context);
            AnimationValue::TouchAction(
                computed
            )
            },
            PropertyDeclaration::Color(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Color(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnCount(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnCount);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnCount(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnGap(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnGap);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnGap(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnFill(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnFill);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnFill(
                computed
            )
            },
            PropertyDeclaration::ColumnRuleWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnRuleWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnRuleWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnRuleColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnRuleColor);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnRuleColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::ColumnSpan(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnSpan);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnSpan(
                computed
            )
            },
            PropertyDeclaration::ColumnRuleStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ColumnRuleStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::ColumnRuleStyle(
                computed
            )
            },
            PropertyDeclaration::Content(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Content);
            let computed = (**val).to_computed_value(context);
            AnimationValue::Content(
                computed
            )
            },
            PropertyDeclaration::CounterIncrement(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::CounterIncrement);
            let computed = val.to_computed_value(context);
            AnimationValue::CounterIncrement(
                computed
            )
            },
            PropertyDeclaration::CounterReset(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::CounterReset);
            let computed = val.to_computed_value(context);
            AnimationValue::CounterReset(
                computed
            )
            },
            PropertyDeclaration::Opacity(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Opacity);
            let computed = val.to_computed_value(context);
            AnimationValue::Opacity(
                computed
            )
            },
            PropertyDeclaration::BoxShadow(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BoxShadow);
            let computed = val.to_computed_value(context);
            AnimationValue::BoxShadow(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Clip(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Clip);
            let computed = (**val).to_computed_value(context);
            AnimationValue::Clip(
                computed
            )
            },
            PropertyDeclaration::Filter(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Filter);
            let computed = val.to_computed_value(context);
            AnimationValue::Filter(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MixBlendMode(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MixBlendMode);
            let computed = val.to_computed_value(context);
            AnimationValue::MixBlendMode(
                computed
            )
            },
            PropertyDeclaration::FontFamily(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontFamily(
                computed
            )
            },
            PropertyDeclaration::FontStyle(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontStyle(
                computed
            )
            },
            PropertyDeclaration::FontVariantCaps(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantCaps(
                computed
            )
            },
            PropertyDeclaration::FontWeight(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontWeight(
                computed
            )
            },
            PropertyDeclaration::FontSize(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontSize(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::FontSizeAdjust(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontSizeAdjust(
                computed
            )
            },
            PropertyDeclaration::FontSynthesis(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::FontSynthesis(
                computed
            )
            },
            PropertyDeclaration::FontStretch(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontStretch(
                computed
            )
            },
            PropertyDeclaration::FontKerning(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontKerning(
                computed
            )
            },
            PropertyDeclaration::FontVariantAlternates(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantAlternates(
                computed
            )
            },
            PropertyDeclaration::FontVariantEastAsian(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantEastAsian(
                computed
            )
            },
            PropertyDeclaration::FontVariantLigatures(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantLigatures(
                computed
            )
            },
            PropertyDeclaration::FontVariantNumeric(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantNumeric(
                computed
            )
            },
            PropertyDeclaration::FontVariantPosition(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariantPosition(
                computed
            )
            },
            PropertyDeclaration::FontFeatureSettings(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = (**val).to_computed_value(context);
            AnimationValue::FontFeatureSettings(
                computed
            )
            },
            PropertyDeclaration::FontVariationSettings(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::FontVariationSettings(
                computed
            )
            },
            PropertyDeclaration::FontLanguageOverride(ref val) => {
                context.for_non_inherited_property =
                        None;
                if let Some(sf) = val.get_system() {
                    longhands::system_font::resolve_system_font(sf, context);
                }
            let computed = val.to_computed_value(context);
            AnimationValue::FontLanguageOverride(
                computed
            )
            },
            PropertyDeclaration::MozOsxFontSmoothing(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozOsxFontSmoothing(
                computed
            )
            },
            PropertyDeclaration::MozFontSmoothingBackgroundColor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozFontSmoothingBackgroundColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Visibility(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Visibility(
                computed
            )
            },
            PropertyDeclaration::WritingMode(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WritingMode(
                computed
            )
            },
            PropertyDeclaration::Direction(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Direction(
                computed
            )
            },
            PropertyDeclaration::TextOrientation(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextOrientation(
                computed
            )
            },
            PropertyDeclaration::ColorAdjust(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ColorAdjust(
                computed
            )
            },
            PropertyDeclaration::ImageRendering(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ImageRendering(
                computed
            )
            },
            PropertyDeclaration::ImageOrientation(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ImageOrientation(
                computed
            )
            },
            PropertyDeclaration::BorderCollapse(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::BorderCollapse(
                computed
            )
            },
            PropertyDeclaration::EmptyCells(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::EmptyCells(
                computed
            )
            },
            PropertyDeclaration::CaptionSide(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::CaptionSide(
                computed
            )
            },
            PropertyDeclaration::BorderSpacing(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::BorderSpacing(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::LineHeight(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::LineHeight(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::TextTransform(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextTransform(
                computed
            )
            },
            PropertyDeclaration::Hyphens(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Hyphens(
                computed
            )
            },
            PropertyDeclaration::MozTextSizeAdjust(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozTextSizeAdjust(
                computed
            )
            },
            PropertyDeclaration::TextIndent(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextIndent(
                computed
            )
            },
            PropertyDeclaration::OverflowWrap(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::OverflowWrap(
                computed
            )
            },
            PropertyDeclaration::WordBreak(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WordBreak(
                computed
            )
            },
            PropertyDeclaration::TextJustify(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextJustify(
                computed
            )
            },
            PropertyDeclaration::TextAlignLast(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextAlignLast(
                computed
            )
            },
            PropertyDeclaration::TextAlign(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextAlign(
                computed
            )
            },
            PropertyDeclaration::LetterSpacing(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::LetterSpacing(
                computed
            )
            },
            PropertyDeclaration::WordSpacing(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WordSpacing(
                computed
            )
            },
            PropertyDeclaration::WhiteSpace(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WhiteSpace(
                computed
            )
            },
            PropertyDeclaration::TextShadow(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextShadow(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::TextEmphasisStyle(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::TextEmphasisStyle(
                computed
            )
            },
            PropertyDeclaration::TextEmphasisPosition(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextEmphasisPosition(
                computed
            )
            },
            PropertyDeclaration::TextEmphasisColor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextEmphasisColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozTabSize(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozTabSize(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::WebkitTextFillColor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WebkitTextFillColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::WebkitTextStrokeColor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WebkitTextStrokeColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::WebkitTextStrokeWidth(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::WebkitTextStrokeWidth(
                computed
            )
            },
            PropertyDeclaration::RubyAlign(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::RubyAlign(
                computed
            )
            },
            PropertyDeclaration::RubyPosition(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::RubyPosition(
                computed
            )
            },
            PropertyDeclaration::TextCombineUpright(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextCombineUpright(
                computed
            )
            },
            PropertyDeclaration::TextRendering(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextRendering(
                computed
            )
            },
            PropertyDeclaration::ListStylePosition(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ListStylePosition(
                computed
            )
            },
            PropertyDeclaration::ListStyleType(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::ListStyleType(
                computed
            )
            },
            PropertyDeclaration::ListStyleImage(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::ListStyleImage(
                computed
            )
            },
            PropertyDeclaration::Quotes(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Quotes(
                computed
            )
            },
            PropertyDeclaration::MozImageRegion(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozImageRegion(
                computed
            )
            },
            PropertyDeclaration::MarginTop(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MarginTop);
            let computed = val.to_computed_value(context);
            AnimationValue::MarginTop(
                computed
            )
            },
            PropertyDeclaration::MarginLeft(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MarginLeft);
            let computed = val.to_computed_value(context);
            AnimationValue::MarginLeft(
                computed
            )
            },
            PropertyDeclaration::MarginBottom(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MarginBottom);
            let computed = val.to_computed_value(context);
            AnimationValue::MarginBottom(
                computed
            )
            },
            PropertyDeclaration::MarginRight(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MarginRight);
            let computed = val.to_computed_value(context);
            AnimationValue::MarginRight(
                computed
            )
            },
            PropertyDeclaration::OutlineColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OutlineColor);
            let computed = val.to_computed_value(context);
            AnimationValue::OutlineColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::OutlineStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OutlineStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::OutlineStyle(
                computed
            )
            },
            PropertyDeclaration::OutlineWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OutlineWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::OutlineWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozOutlineRadiusTopleft(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozOutlineRadiusTopleft);
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozOutlineRadiusTopleft(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozOutlineRadiusTopright(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozOutlineRadiusTopright);
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozOutlineRadiusTopright(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozOutlineRadiusBottomright(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozOutlineRadiusBottomright);
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozOutlineRadiusBottomright(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozOutlineRadiusBottomleft(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozOutlineRadiusBottomleft);
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozOutlineRadiusBottomleft(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::OutlineOffset(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::OutlineOffset);
            let computed = val.to_computed_value(context);
            AnimationValue::OutlineOffset(
                computed
            )
            },
            PropertyDeclaration::PaddingTop(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PaddingTop);
            let computed = val.to_computed_value(context);
            AnimationValue::PaddingTop(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::PaddingLeft(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PaddingLeft);
            let computed = val.to_computed_value(context);
            AnimationValue::PaddingLeft(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::PaddingBottom(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PaddingBottom);
            let computed = val.to_computed_value(context);
            AnimationValue::PaddingBottom(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::PaddingRight(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::PaddingRight);
            let computed = val.to_computed_value(context);
            AnimationValue::PaddingRight(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Cursor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::Cursor(
                computed
            )
            },
            PropertyDeclaration::PointerEvents(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::PointerEvents(
                computed
            )
            },
            PropertyDeclaration::MozUserInput(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozUserInput(
                computed
            )
            },
            PropertyDeclaration::MozUserModify(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozUserModify(
                computed
            )
            },
            PropertyDeclaration::MozUserFocus(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::MozUserFocus(
                computed
            )
            },
            PropertyDeclaration::CaretColor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::CaretColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Top(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Top);
            let computed = val.to_computed_value(context);
            AnimationValue::Top(
                computed
            )
            },
            PropertyDeclaration::Left(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Left);
            let computed = val.to_computed_value(context);
            AnimationValue::Left(
                computed
            )
            },
            PropertyDeclaration::Bottom(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Bottom);
            let computed = val.to_computed_value(context);
            AnimationValue::Bottom(
                computed
            )
            },
            PropertyDeclaration::Right(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Right);
            let computed = val.to_computed_value(context);
            AnimationValue::Right(
                computed
            )
            },
            PropertyDeclaration::ZIndex(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ZIndex);
            let computed = val.to_computed_value(context);
            AnimationValue::ZIndex(
                computed
            )
            },
            PropertyDeclaration::FlexDirection(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FlexDirection);
            let computed = val.to_computed_value(context);
            AnimationValue::FlexDirection(
                computed
            )
            },
            PropertyDeclaration::FlexWrap(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FlexWrap);
            let computed = val.to_computed_value(context);
            AnimationValue::FlexWrap(
                computed
            )
            },
            PropertyDeclaration::JustifyContent(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::JustifyContent);
            let computed = val.to_computed_value(context);
            AnimationValue::JustifyContent(
                computed
            )
            },
            PropertyDeclaration::AlignContent(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::AlignContent);
            let computed = val.to_computed_value(context);
            AnimationValue::AlignContent(
                computed
            )
            },
            PropertyDeclaration::AlignItems(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::AlignItems);
            let computed = val.to_computed_value(context);
            AnimationValue::AlignItems(
                computed
            )
            },
            PropertyDeclaration::JustifyItems(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::JustifyItems);
            let computed = val.to_computed_value(context);
            AnimationValue::JustifyItems(
                computed
            )
            },
            PropertyDeclaration::FlexGrow(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FlexGrow);
            let computed = val.to_computed_value(context);
            AnimationValue::FlexGrow(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::FlexShrink(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FlexShrink);
            let computed = val.to_computed_value(context);
            AnimationValue::FlexShrink(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::AlignSelf(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::AlignSelf);
            let computed = val.to_computed_value(context);
            AnimationValue::AlignSelf(
                computed
            )
            },
            PropertyDeclaration::JustifySelf(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::JustifySelf);
            let computed = val.to_computed_value(context);
            AnimationValue::JustifySelf(
                computed
            )
            },
            PropertyDeclaration::Order(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Order);
            let computed = val.to_computed_value(context);
            AnimationValue::Order(
                computed
            )
            },
            PropertyDeclaration::FlexBasis(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FlexBasis);
            let computed = val.to_computed_value(context);
            AnimationValue::FlexBasis(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Width(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Width);
            let computed = val.to_computed_value(context);
            AnimationValue::Width(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MinWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MinWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::MinWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MaxWidth(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaxWidth);
            let computed = val.to_computed_value(context);
            AnimationValue::MaxWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::Height(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::Height);
            let computed = val.to_computed_value(context);
            AnimationValue::Height(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MinHeight(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MinHeight);
            let computed = val.to_computed_value(context);
            AnimationValue::MinHeight(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MaxHeight(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaxHeight);
            let computed = val.to_computed_value(context);
            AnimationValue::MaxHeight(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::BoxSizing(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::BoxSizing);
            let computed = val.to_computed_value(context);
            AnimationValue::BoxSizing(
                computed
            )
            },
            PropertyDeclaration::ObjectFit(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ObjectFit);
            let computed = val.to_computed_value(context);
            AnimationValue::ObjectFit(
                computed
            )
            },
            PropertyDeclaration::ObjectPosition(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ObjectPosition);
            let computed = (**val).to_computed_value(context);
            AnimationValue::ObjectPosition(
                computed
            )
            },
            PropertyDeclaration::GridRowGap(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridRowGap);
            let computed = val.to_computed_value(context);
            AnimationValue::GridRowGap(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::GridRowStart(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridRowStart);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridRowStart(
                computed
            )
            },
            PropertyDeclaration::GridRowEnd(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridRowEnd);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridRowEnd(
                computed
            )
            },
            PropertyDeclaration::GridAutoRows(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridAutoRows);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridAutoRows(
                computed
            )
            },
            PropertyDeclaration::GridTemplateRows(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridTemplateRows);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridTemplateRows(
                computed
            )
            },
            PropertyDeclaration::GridColumnGap(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridColumnGap);
            let computed = val.to_computed_value(context);
            AnimationValue::GridColumnGap(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::GridColumnStart(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridColumnStart);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridColumnStart(
                computed
            )
            },
            PropertyDeclaration::GridColumnEnd(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridColumnEnd);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridColumnEnd(
                computed
            )
            },
            PropertyDeclaration::GridAutoColumns(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridAutoColumns);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridAutoColumns(
                computed
            )
            },
            PropertyDeclaration::GridTemplateColumns(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridTemplateColumns);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridTemplateColumns(
                computed
            )
            },
            PropertyDeclaration::GridAutoFlow(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridAutoFlow);
            let computed = val.to_computed_value(context);
            AnimationValue::GridAutoFlow(
                computed
            )
            },
            PropertyDeclaration::GridTemplateAreas(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::GridTemplateAreas);
            let computed = (**val).to_computed_value(context);
            AnimationValue::GridTemplateAreas(
                computed
            )
            },
            PropertyDeclaration::TableLayout(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TableLayout);
            let computed = val.to_computed_value(context);
            AnimationValue::TableLayout(
                computed
            )
            },
            PropertyDeclaration::TextOverflow(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TextOverflow);
            let computed = (**val).to_computed_value(context);
            AnimationValue::TextOverflow(
                computed
            )
            },
            PropertyDeclaration::UnicodeBidi(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::UnicodeBidi);
            let computed = val.to_computed_value(context);
            AnimationValue::UnicodeBidi(
                computed
            )
            },
            PropertyDeclaration::TextDecorationLine(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TextDecorationLine);
            let computed = val.to_computed_value(context);
            AnimationValue::TextDecorationLine(
                computed
            )
            },
            PropertyDeclaration::TextDecorationStyle(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TextDecorationStyle);
            let computed = val.to_computed_value(context);
            AnimationValue::TextDecorationStyle(
                computed
            )
            },
            PropertyDeclaration::TextDecorationColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::TextDecorationColor);
            let computed = val.to_computed_value(context);
            AnimationValue::TextDecorationColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::InitialLetter(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::InitialLetter);
            let computed = val.to_computed_value(context);
            AnimationValue::InitialLetter(
                computed
            )
            },
            PropertyDeclaration::ImeMode(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ImeMode);
            let computed = val.to_computed_value(context);
            AnimationValue::ImeMode(
                computed
            )
            },
            PropertyDeclaration::MozUserSelect(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozUserSelect);
            let computed = val.to_computed_value(context);
            AnimationValue::MozUserSelect(
                computed
            )
            },
            PropertyDeclaration::MozWindowDragging(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozWindowDragging);
            let computed = val.to_computed_value(context);
            AnimationValue::MozWindowDragging(
                computed
            )
            },
            PropertyDeclaration::MozWindowShadow(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozWindowShadow);
            let computed = val.to_computed_value(context);
            AnimationValue::MozWindowShadow(
                computed
            )
            },
            PropertyDeclaration::MozWindowOpacity(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozWindowOpacity);
            let computed = val.to_computed_value(context);
            AnimationValue::MozWindowOpacity(
                computed
            )
            },
            PropertyDeclaration::MozWindowTransform(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozWindowTransform);
            let computed = val.to_computed_value(context);
            AnimationValue::MozWindowTransform(
                computed
            )
            },
            PropertyDeclaration::MozWindowTransformOrigin(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozWindowTransformOrigin);
            let computed = (**val).to_computed_value(context);
            AnimationValue::MozWindowTransformOrigin(
                computed
            )
            },
            PropertyDeclaration::MozForceBrokenImageIcon(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozForceBrokenImageIcon);
            let computed = val.to_computed_value(context);
            AnimationValue::MozForceBrokenImageIcon(
                computed
            )
            },
            PropertyDeclaration::TextAnchor(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::TextAnchor(
                computed
            )
            },
            PropertyDeclaration::ColorInterpolation(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ColorInterpolation(
                computed
            )
            },
            PropertyDeclaration::ColorInterpolationFilters(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ColorInterpolationFilters(
                computed
            )
            },
            PropertyDeclaration::Fill(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::Fill(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::FillOpacity(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::FillOpacity(
                computed
            )
            },
            PropertyDeclaration::FillRule(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::FillRule(
                computed
            )
            },
            PropertyDeclaration::ShapeRendering(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ShapeRendering(
                computed
            )
            },
            PropertyDeclaration::Stroke(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::Stroke(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::StrokeWidth(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeWidth(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::StrokeLinecap(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeLinecap(
                computed
            )
            },
            PropertyDeclaration::StrokeLinejoin(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeLinejoin(
                computed
            )
            },
            PropertyDeclaration::StrokeMiterlimit(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeMiterlimit(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::StrokeOpacity(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeOpacity(
                computed
            )
            },
            PropertyDeclaration::StrokeDasharray(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeDasharray(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::StrokeDashoffset(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::StrokeDashoffset(
                computed
            )
            },
            PropertyDeclaration::ClipRule(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::ClipRule(
                computed
            )
            },
            PropertyDeclaration::MarkerStart(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::MarkerStart(
                computed
            )
            },
            PropertyDeclaration::MarkerMid(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::MarkerMid(
                computed
            )
            },
            PropertyDeclaration::MarkerEnd(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = (**val).to_computed_value(context);
            AnimationValue::MarkerEnd(
                computed
            )
            },
            PropertyDeclaration::PaintOrder(ref val) => {
                context.for_non_inherited_property =
                        None;
            let computed = val.to_computed_value(context);
            AnimationValue::PaintOrder(
                computed
            )
            },
            PropertyDeclaration::DominantBaseline(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::DominantBaseline);
            let computed = val.to_computed_value(context);
            AnimationValue::DominantBaseline(
                computed
            )
            },
            PropertyDeclaration::VectorEffect(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::VectorEffect);
            let computed = val.to_computed_value(context);
            AnimationValue::VectorEffect(
                computed
            )
            },
            PropertyDeclaration::StopColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::StopColor);
            let computed = val.to_computed_value(context);
            AnimationValue::StopColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::StopOpacity(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::StopOpacity);
            let computed = val.to_computed_value(context);
            AnimationValue::StopOpacity(
                computed
            )
            },
            PropertyDeclaration::FloodColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FloodColor);
            let computed = val.to_computed_value(context);
            AnimationValue::FloodColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::FloodOpacity(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::FloodOpacity);
            let computed = val.to_computed_value(context);
            AnimationValue::FloodOpacity(
                computed
            )
            },
            PropertyDeclaration::LightingColor(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::LightingColor);
            let computed = val.to_computed_value(context);
            AnimationValue::LightingColor(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MaskType(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskType);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskType(
                computed
            )
            },
            PropertyDeclaration::ClipPath(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::ClipPath);
            let computed = (**val).to_computed_value(context);
            AnimationValue::ClipPath(
                computed
            )
            },
            PropertyDeclaration::MaskMode(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskMode);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskMode(
                computed
            )
            },
            PropertyDeclaration::MaskRepeat(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskRepeat);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskRepeat(
                computed
            )
            },
            PropertyDeclaration::MaskPositionX(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskPositionX);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskPositionX(
                computed
            )
            },
            PropertyDeclaration::MaskPositionY(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskPositionY);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskPositionY(
                computed
            )
            },
            PropertyDeclaration::MaskClip(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskClip);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskClip(
                computed
            )
            },
            PropertyDeclaration::MaskOrigin(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskOrigin);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskOrigin(
                computed
            )
            },
            PropertyDeclaration::MaskSize(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskSize);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskSize(
                computed
            )
            },
            PropertyDeclaration::MaskComposite(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskComposite);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskComposite(
                computed
            )
            },
            PropertyDeclaration::MaskImage(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MaskImage);
            let computed = val.to_computed_value(context);
            AnimationValue::MaskImage(
                computed
            )
            },
            PropertyDeclaration::MozBoxAlign(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxAlign);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxAlign(
                computed
            )
            },
            PropertyDeclaration::MozBoxDirection(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxDirection);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxDirection(
                computed
            )
            },
            PropertyDeclaration::MozBoxFlex(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxFlex);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxFlex(
                computed.to_animated_value()
            )
            },
            PropertyDeclaration::MozBoxOrient(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxOrient);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxOrient(
                computed
            )
            },
            PropertyDeclaration::MozBoxPack(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxPack);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxPack(
                computed
            )
            },
            PropertyDeclaration::MozStackSizing(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozStackSizing);
            let computed = val.to_computed_value(context);
            AnimationValue::MozStackSizing(
                computed
            )
            },
            PropertyDeclaration::MozBoxOrdinalGroup(ref val) => {
                context.for_non_inherited_property =
                        Some(LonghandId::MozBoxOrdinalGroup);
            let computed = val.to_computed_value(context);
            AnimationValue::MozBoxOrdinalGroup(
                computed
            )
            },
            PropertyDeclaration::CSSWideKeyword(id, keyword) => {
                match id {
                    // We put all the animatable properties first in the hopes
                    // that it might increase match locality.
                    LonghandId::BackgroundColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundColor(computed)
                    },
                    LonghandId::BackgroundImage => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_image();
                        AnimationValue::BackgroundImage(computed)
                    },
                    LonghandId::BackgroundPositionX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_position_x();
                        AnimationValue::BackgroundPositionX(computed)
                    },
                    LonghandId::BackgroundPositionY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_position_y();
                        AnimationValue::BackgroundPositionY(computed)
                    },
                    LonghandId::BackgroundRepeat => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_repeat();
                        AnimationValue::BackgroundRepeat(computed)
                    },
                    LonghandId::BackgroundAttachment => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_attachment();
                        AnimationValue::BackgroundAttachment(computed)
                    },
                    LonghandId::BackgroundClip => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_clip();
                        AnimationValue::BackgroundClip(computed)
                    },
                    LonghandId::BackgroundOrigin => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_origin();
                        AnimationValue::BackgroundOrigin(computed)
                    },
                    LonghandId::BackgroundSize => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundSize(computed)
                    },
                    LonghandId::BackgroundBlendMode => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct.clone_background_blend_mode();
                        AnimationValue::BackgroundBlendMode(computed)
                    },
                    LonghandId::BorderTopColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopColor(computed)
                    },
                    LonghandId::BorderTopStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_style();
                        AnimationValue::BorderTopStyle(computed)
                    },
                    LonghandId::BorderTopWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopWidth(computed)
                    },
                    LonghandId::BorderLeftColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftColor(computed)
                    },
                    LonghandId::BorderLeftStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_style();
                        AnimationValue::BorderLeftStyle(computed)
                    },
                    LonghandId::BorderLeftWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_left_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftWidth(computed)
                    },
                    LonghandId::BorderBottomColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomColor(computed)
                    },
                    LonghandId::BorderBottomStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_style();
                        AnimationValue::BorderBottomStyle(computed)
                    },
                    LonghandId::BorderBottomWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomWidth(computed)
                    },
                    LonghandId::BorderRightColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightColor(computed)
                    },
                    LonghandId::BorderRightStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_style();
                        AnimationValue::BorderRightStyle(computed)
                    },
                    LonghandId::BorderRightWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_right_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightWidth(computed)
                    },
                    LonghandId::BorderTopLeftRadius => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_left_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopLeftRadius(computed)
                    },
                    LonghandId::BorderTopRightRadius => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_top_right_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopRightRadius(computed)
                    },
                    LonghandId::BorderBottomRightRadius => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_right_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomRightRadius(computed)
                    },
                    LonghandId::BorderBottomLeftRadius => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_bottom_left_radius();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomLeftRadius(computed)
                    },
                    LonghandId::MozBorderTopColors => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_border_top_colors();
                        AnimationValue::MozBorderTopColors(computed)
                    },
                    LonghandId::MozBorderLeftColors => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_border_left_colors();
                        AnimationValue::MozBorderLeftColors(computed)
                    },
                    LonghandId::MozBorderBottomColors => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_border_bottom_colors();
                        AnimationValue::MozBorderBottomColors(computed)
                    },
                    LonghandId::MozBorderRightColors => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_border_right_colors();
                        AnimationValue::MozBorderRightColors(computed)
                    },
                    LonghandId::BoxDecorationBreak => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_box_decoration_break();
                        AnimationValue::BoxDecorationBreak(computed)
                    },
                    LonghandId::MozFloatEdge => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone__moz_float_edge();
                        AnimationValue::MozFloatEdge(computed)
                    },
                    LonghandId::BorderImageSource => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_source();
                        AnimationValue::BorderImageSource(computed)
                    },
                    LonghandId::BorderImageOutset => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_outset();
                        AnimationValue::BorderImageOutset(computed)
                    },
                    LonghandId::BorderImageRepeat => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_repeat();
                        AnimationValue::BorderImageRepeat(computed)
                    },
                    LonghandId::BorderImageWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_width();
                        AnimationValue::BorderImageWidth(computed)
                    },
                    LonghandId::BorderImageSlice => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct.clone_border_image_slice();
                        AnimationValue::BorderImageSlice(computed)
                    },
                    LonghandId::Display => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_display();
                        AnimationValue::Display(computed)
                    },
                    LonghandId::Position => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_position();
                        AnimationValue::Position(computed)
                    },
                    LonghandId::Float => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_float();
                        AnimationValue::Float(computed)
                    },
                    LonghandId::Clear => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_clear();
                        AnimationValue::Clear(computed)
                    },
                    LonghandId::VerticalAlign => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_vertical_align();
                        AnimationValue::VerticalAlign(computed)
                    },
                    LonghandId::OverflowClipBoxInline => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_clip_box_inline();
                        AnimationValue::OverflowClipBoxInline(computed)
                    },
                    LonghandId::OverflowClipBoxBlock => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_clip_box_block();
                        AnimationValue::OverflowClipBoxBlock(computed)
                    },
                    LonghandId::OverflowX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_x();
                        AnimationValue::OverflowX(computed)
                    },
                    LonghandId::OverflowY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overflow_y();
                        AnimationValue::OverflowY(computed)
                    },
                    LonghandId::ScrollSnapPointsX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_points_x();
                        AnimationValue::ScrollSnapPointsX(computed)
                    },
                    LonghandId::ScrollSnapPointsY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_points_y();
                        AnimationValue::ScrollSnapPointsY(computed)
                    },
                    LonghandId::ScrollSnapDestination => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_destination();
                        AnimationValue::ScrollSnapDestination(computed)
                    },
                    LonghandId::ScrollSnapCoordinate => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_coordinate();
                        AnimationValue::ScrollSnapCoordinate(computed)
                    },
                    LonghandId::Transform => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform();
                        AnimationValue::Transform(computed)
                    },
                    LonghandId::ScrollBehavior => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_behavior();
                        AnimationValue::ScrollBehavior(computed)
                    },
                    LonghandId::ScrollSnapTypeX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_type_x();
                        AnimationValue::ScrollSnapTypeX(computed)
                    },
                    LonghandId::ScrollSnapTypeY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_scroll_snap_type_y();
                        AnimationValue::ScrollSnapTypeY(computed)
                    },
                    LonghandId::OverscrollBehaviorX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overscroll_behavior_x();
                        AnimationValue::OverscrollBehaviorX(computed)
                    },
                    LonghandId::OverscrollBehaviorY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_overscroll_behavior_y();
                        AnimationValue::OverscrollBehaviorY(computed)
                    },
                    LonghandId::Isolation => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_isolation();
                        AnimationValue::Isolation(computed)
                    },
                    LonghandId::PageBreakAfter => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_after();
                        AnimationValue::PageBreakAfter(computed)
                    },
                    LonghandId::PageBreakBefore => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_before();
                        AnimationValue::PageBreakBefore(computed)
                    },
                    LonghandId::PageBreakInside => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_page_break_inside();
                        AnimationValue::PageBreakInside(computed)
                    },
                    LonghandId::Resize => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_resize();
                        AnimationValue::Resize(computed)
                    },
                    LonghandId::Perspective => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_perspective();
                        AnimationValue::Perspective(computed)
                    },
                    LonghandId::PerspectiveOrigin => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_perspective_origin();
                        AnimationValue::PerspectiveOrigin(computed)
                    },
                    LonghandId::BackfaceVisibility => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_backface_visibility();
                        AnimationValue::BackfaceVisibility(computed)
                    },
                    LonghandId::TransformBox => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_box();
                        AnimationValue::TransformBox(computed)
                    },
                    LonghandId::TransformStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_style();
                        AnimationValue::TransformStyle(computed)
                    },
                    LonghandId::TransformOrigin => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_transform_origin();
                        AnimationValue::TransformOrigin(computed)
                    },
                    LonghandId::Contain => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_contain();
                        AnimationValue::Contain(computed)
                    },
                    LonghandId::MozAppearance => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone__moz_appearance();
                        AnimationValue::MozAppearance(computed)
                    },
                    LonghandId::MozOrient => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone__moz_orient();
                        AnimationValue::MozOrient(computed)
                    },
                    LonghandId::WillChange => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_will_change();
                        AnimationValue::WillChange(computed)
                    },
                    LonghandId::ShapeImageThreshold => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_shape_image_threshold();
                        AnimationValue::ShapeImageThreshold(computed)
                    },
                    LonghandId::ShapeOutside => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_shape_outside();
                        AnimationValue::ShapeOutside(computed)
                    },
                    LonghandId::TouchAction => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct.clone_touch_action();
                        AnimationValue::TouchAction(computed)
                    },
                    LonghandId::Color => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_color()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_color()
                            },
                        };
                        let computed = style_struct.clone_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::Color(computed)
                    },
                    LonghandId::ColumnWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnWidth(computed)
                    },
                    LonghandId::ColumnCount => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_count();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnCount(computed)
                    },
                    LonghandId::ColumnGap => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnGap(computed)
                    },
                    LonghandId::ColumnFill => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_fill();
                        AnimationValue::ColumnFill(computed)
                    },
                    LonghandId::ColumnRuleWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleWidth(computed)
                    },
                    LonghandId::ColumnRuleColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleColor(computed)
                    },
                    LonghandId::ColumnSpan => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_span();
                        AnimationValue::ColumnSpan(computed)
                    },
                    LonghandId::ColumnRuleStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct.clone_column_rule_style();
                        AnimationValue::ColumnRuleStyle(computed)
                    },
                    LonghandId::Content => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_content();
                        AnimationValue::Content(computed)
                    },
                    LonghandId::CounterIncrement => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_counter_increment();
                        AnimationValue::CounterIncrement(computed)
                    },
                    LonghandId::CounterReset => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct.clone_counter_reset();
                        AnimationValue::CounterReset(computed)
                    },
                    LonghandId::Opacity => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_opacity();
                        AnimationValue::Opacity(computed)
                    },
                    LonghandId::BoxShadow => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_box_shadow();
                        let computed = computed.to_animated_value();
                        AnimationValue::BoxShadow(computed)
                    },
                    LonghandId::Clip => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_clip();
                        AnimationValue::Clip(computed)
                    },
                    LonghandId::Filter => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_filter();
                        let computed = computed.to_animated_value();
                        AnimationValue::Filter(computed)
                    },
                    LonghandId::MixBlendMode => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct.clone_mix_blend_mode();
                        AnimationValue::MixBlendMode(computed)
                    },
                    LonghandId::FontFamily => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_family();
                        AnimationValue::FontFamily(computed)
                    },
                    LonghandId::FontStyle => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_style();
                        AnimationValue::FontStyle(computed)
                    },
                    LonghandId::FontVariantCaps => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_caps();
                        AnimationValue::FontVariantCaps(computed)
                    },
                    LonghandId::FontWeight => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_weight();
                        AnimationValue::FontWeight(computed)
                    },
                    LonghandId::FontSize => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::FontSize(computed)
                    },
                    LonghandId::FontSizeAdjust => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_size_adjust();
                        AnimationValue::FontSizeAdjust(computed)
                    },
                    LonghandId::FontSynthesis => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_synthesis();
                        AnimationValue::FontSynthesis(computed)
                    },
                    LonghandId::FontStretch => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_stretch();
                        AnimationValue::FontStretch(computed)
                    },
                    LonghandId::FontKerning => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_kerning();
                        AnimationValue::FontKerning(computed)
                    },
                    LonghandId::FontVariantAlternates => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_alternates();
                        AnimationValue::FontVariantAlternates(computed)
                    },
                    LonghandId::FontVariantEastAsian => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_east_asian();
                        AnimationValue::FontVariantEastAsian(computed)
                    },
                    LonghandId::FontVariantLigatures => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_ligatures();
                        AnimationValue::FontVariantLigatures(computed)
                    },
                    LonghandId::FontVariantNumeric => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_numeric();
                        AnimationValue::FontVariantNumeric(computed)
                    },
                    LonghandId::FontVariantPosition => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variant_position();
                        AnimationValue::FontVariantPosition(computed)
                    },
                    LonghandId::FontFeatureSettings => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_feature_settings();
                        AnimationValue::FontFeatureSettings(computed)
                    },
                    LonghandId::FontVariationSettings => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_variation_settings();
                        AnimationValue::FontVariationSettings(computed)
                    },
                    LonghandId::FontLanguageOverride => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone_font_language_override();
                        AnimationValue::FontLanguageOverride(computed)
                    },
                    LonghandId::MozOsxFontSmoothing => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone__moz_osx_font_smoothing();
                        AnimationValue::MozOsxFontSmoothing(computed)
                    },
                    LonghandId::MozFontSmoothingBackgroundColor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct.clone__moz_font_smoothing_background_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozFontSmoothingBackgroundColor(computed)
                    },
                    LonghandId::Visibility => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_visibility();
                        AnimationValue::Visibility(computed)
                    },
                    LonghandId::WritingMode => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_writing_mode();
                        AnimationValue::WritingMode(computed)
                    },
                    LonghandId::Direction => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_direction();
                        AnimationValue::Direction(computed)
                    },
                    LonghandId::TextOrientation => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_text_orientation();
                        AnimationValue::TextOrientation(computed)
                    },
                    LonghandId::ColorAdjust => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_color_adjust();
                        AnimationValue::ColorAdjust(computed)
                    },
                    LonghandId::ImageRendering => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_image_rendering();
                        AnimationValue::ImageRendering(computed)
                    },
                    LonghandId::ImageOrientation => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedbox()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedbox()
                            },
                        };
                        let computed = style_struct.clone_image_orientation();
                        AnimationValue::ImageOrientation(computed)
                    },
                    LonghandId::BorderCollapse => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_border_collapse();
                        AnimationValue::BorderCollapse(computed)
                    },
                    LonghandId::EmptyCells => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_empty_cells();
                        AnimationValue::EmptyCells(computed)
                    },
                    LonghandId::CaptionSide => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_caption_side();
                        AnimationValue::CaptionSide(computed)
                    },
                    LonghandId::BorderSpacing => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtable()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtable()
                            },
                        };
                        let computed = style_struct.clone_border_spacing();
                        let computed = computed.to_animated_value();
                        AnimationValue::BorderSpacing(computed)
                    },
                    LonghandId::LineHeight => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_line_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::LineHeight(computed)
                    },
                    LonghandId::TextTransform => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_transform();
                        AnimationValue::TextTransform(computed)
                    },
                    LonghandId::Hyphens => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_hyphens();
                        AnimationValue::Hyphens(computed)
                    },
                    LonghandId::MozTextSizeAdjust => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__moz_text_size_adjust();
                        AnimationValue::MozTextSizeAdjust(computed)
                    },
                    LonghandId::TextIndent => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_indent();
                        AnimationValue::TextIndent(computed)
                    },
                    LonghandId::OverflowWrap => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_overflow_wrap();
                        AnimationValue::OverflowWrap(computed)
                    },
                    LonghandId::WordBreak => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_word_break();
                        AnimationValue::WordBreak(computed)
                    },
                    LonghandId::TextJustify => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_justify();
                        AnimationValue::TextJustify(computed)
                    },
                    LonghandId::TextAlignLast => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_align_last();
                        AnimationValue::TextAlignLast(computed)
                    },
                    LonghandId::TextAlign => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_align();
                        AnimationValue::TextAlign(computed)
                    },
                    LonghandId::LetterSpacing => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_letter_spacing();
                        AnimationValue::LetterSpacing(computed)
                    },
                    LonghandId::WordSpacing => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_word_spacing();
                        AnimationValue::WordSpacing(computed)
                    },
                    LonghandId::WhiteSpace => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_white_space();
                        AnimationValue::WhiteSpace(computed)
                    },
                    LonghandId::TextShadow => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_shadow();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextShadow(computed)
                    },
                    LonghandId::TextEmphasisStyle => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_style();
                        AnimationValue::TextEmphasisStyle(computed)
                    },
                    LonghandId::TextEmphasisPosition => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_position();
                        AnimationValue::TextEmphasisPosition(computed)
                    },
                    LonghandId::TextEmphasisColor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_emphasis_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextEmphasisColor(computed)
                    },
                    LonghandId::MozTabSize => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__moz_tab_size();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozTabSize(computed)
                    },
                    LonghandId::WebkitTextFillColor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_fill_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextFillColor(computed)
                    },
                    LonghandId::WebkitTextStrokeColor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_stroke_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextStrokeColor(computed)
                    },
                    LonghandId::WebkitTextStrokeWidth => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone__webkit_text_stroke_width();
                        AnimationValue::WebkitTextStrokeWidth(computed)
                    },
                    LonghandId::RubyAlign => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_ruby_align();
                        AnimationValue::RubyAlign(computed)
                    },
                    LonghandId::RubyPosition => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_ruby_position();
                        AnimationValue::RubyPosition(computed)
                    },
                    LonghandId::TextCombineUpright => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_combine_upright();
                        AnimationValue::TextCombineUpright(computed)
                    },
                    LonghandId::TextRendering => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedtext()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedtext()
                            },
                        };
                        let computed = style_struct.clone_text_rendering();
                        AnimationValue::TextRendering(computed)
                    },
                    LonghandId::ListStylePosition => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_position();
                        AnimationValue::ListStylePosition(computed)
                    },
                    LonghandId::ListStyleType => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_type();
                        AnimationValue::ListStyleType(computed)
                    },
                    LonghandId::ListStyleImage => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_list_style_image();
                        AnimationValue::ListStyleImage(computed)
                    },
                    LonghandId::Quotes => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone_quotes();
                        AnimationValue::Quotes(computed)
                    },
                    LonghandId::MozImageRegion => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct.clone__moz_image_region();
                        AnimationValue::MozImageRegion(computed)
                    },
                    LonghandId::MarginTop => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_top();
                        AnimationValue::MarginTop(computed)
                    },
                    LonghandId::MarginLeft => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_left();
                        AnimationValue::MarginLeft(computed)
                    },
                    LonghandId::MarginBottom => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_bottom();
                        AnimationValue::MarginBottom(computed)
                    },
                    LonghandId::MarginRight => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct.clone_margin_right();
                        AnimationValue::MarginRight(computed)
                    },
                    LonghandId::OutlineColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineColor(computed)
                    },
                    LonghandId::OutlineStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_style();
                        AnimationValue::OutlineStyle(computed)
                    },
                    LonghandId::OutlineWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineWidth(computed)
                    },
                    LonghandId::MozOutlineRadiusTopleft => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_topleft();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusTopleft(computed)
                    },
                    LonghandId::MozOutlineRadiusTopright => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_topright();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusTopright(computed)
                    },
                    LonghandId::MozOutlineRadiusBottomright => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_bottomright();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusBottomright(computed)
                    },
                    LonghandId::MozOutlineRadiusBottomleft => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone__moz_outline_radius_bottomleft();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozOutlineRadiusBottomleft(computed)
                    },
                    LonghandId::OutlineOffset => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct.clone_outline_offset();
                        AnimationValue::OutlineOffset(computed)
                    },
                    LonghandId::PaddingTop => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_top();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingTop(computed)
                    },
                    LonghandId::PaddingLeft => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_left();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingLeft(computed)
                    },
                    LonghandId::PaddingBottom => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_bottom();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingBottom(computed)
                    },
                    LonghandId::PaddingRight => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct.clone_padding_right();
                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingRight(computed)
                    },
                    LonghandId::Cursor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_cursor();
                        AnimationValue::Cursor(computed)
                    },
                    LonghandId::PointerEvents => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_pointer_events();
                        AnimationValue::PointerEvents(computed)
                    },
                    LonghandId::MozUserInput => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_input();
                        AnimationValue::MozUserInput(computed)
                    },
                    LonghandId::MozUserModify => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_modify();
                        AnimationValue::MozUserModify(computed)
                    },
                    LonghandId::MozUserFocus => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone__moz_user_focus();
                        AnimationValue::MozUserFocus(computed)
                    },
                    LonghandId::CaretColor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_pointing()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_pointing()
                            },
                        };
                        let computed = style_struct.clone_caret_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::CaretColor(computed)
                    },
                    LonghandId::Top => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_top();
                        AnimationValue::Top(computed)
                    },
                    LonghandId::Left => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_left();
                        AnimationValue::Left(computed)
                    },
                    LonghandId::Bottom => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_bottom();
                        AnimationValue::Bottom(computed)
                    },
                    LonghandId::Right => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_right();
                        AnimationValue::Right(computed)
                    },
                    LonghandId::ZIndex => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_z_index();
                        AnimationValue::ZIndex(computed)
                    },
                    LonghandId::FlexDirection => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_direction();
                        AnimationValue::FlexDirection(computed)
                    },
                    LonghandId::FlexWrap => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_wrap();
                        AnimationValue::FlexWrap(computed)
                    },
                    LonghandId::JustifyContent => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_content();
                        AnimationValue::JustifyContent(computed)
                    },
                    LonghandId::AlignContent => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_content();
                        AnimationValue::AlignContent(computed)
                    },
                    LonghandId::AlignItems => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_items();
                        AnimationValue::AlignItems(computed)
                    },
                    LonghandId::JustifyItems => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_items();
                        AnimationValue::JustifyItems(computed)
                    },
                    LonghandId::FlexGrow => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_grow();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexGrow(computed)
                    },
                    LonghandId::FlexShrink => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_shrink();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexShrink(computed)
                    },
                    LonghandId::AlignSelf => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_align_self();
                        AnimationValue::AlignSelf(computed)
                    },
                    LonghandId::JustifySelf => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_justify_self();
                        AnimationValue::JustifySelf(computed)
                    },
                    LonghandId::Order => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_order();
                        AnimationValue::Order(computed)
                    },
                    LonghandId::FlexBasis => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_flex_basis();
                        let computed = computed.to_animated_value();
                        AnimationValue::FlexBasis(computed)
                    },
                    LonghandId::Width => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::Width(computed)
                    },
                    LonghandId::MinWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_min_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::MinWidth(computed)
                    },
                    LonghandId::MaxWidth => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_max_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::MaxWidth(computed)
                    },
                    LonghandId::Height => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::Height(computed)
                    },
                    LonghandId::MinHeight => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_min_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::MinHeight(computed)
                    },
                    LonghandId::MaxHeight => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_max_height();
                        let computed = computed.to_animated_value();
                        AnimationValue::MaxHeight(computed)
                    },
                    LonghandId::BoxSizing => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_box_sizing();
                        AnimationValue::BoxSizing(computed)
                    },
                    LonghandId::ObjectFit => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_object_fit();
                        AnimationValue::ObjectFit(computed)
                    },
                    LonghandId::ObjectPosition => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_object_position();
                        AnimationValue::ObjectPosition(computed)
                    },
                    LonghandId::GridRowGap => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::GridRowGap(computed)
                    },
                    LonghandId::GridRowStart => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_start();
                        AnimationValue::GridRowStart(computed)
                    },
                    LonghandId::GridRowEnd => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_row_end();
                        AnimationValue::GridRowEnd(computed)
                    },
                    LonghandId::GridAutoRows => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_rows();
                        AnimationValue::GridAutoRows(computed)
                    },
                    LonghandId::GridTemplateRows => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_rows();
                        AnimationValue::GridTemplateRows(computed)
                    },
                    LonghandId::GridColumnGap => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_gap();
                        let computed = computed.to_animated_value();
                        AnimationValue::GridColumnGap(computed)
                    },
                    LonghandId::GridColumnStart => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_start();
                        AnimationValue::GridColumnStart(computed)
                    },
                    LonghandId::GridColumnEnd => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_column_end();
                        AnimationValue::GridColumnEnd(computed)
                    },
                    LonghandId::GridAutoColumns => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_columns();
                        AnimationValue::GridAutoColumns(computed)
                    },
                    LonghandId::GridTemplateColumns => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_columns();
                        AnimationValue::GridTemplateColumns(computed)
                    },
                    LonghandId::GridAutoFlow => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_auto_flow();
                        AnimationValue::GridAutoFlow(computed)
                    },
                    LonghandId::GridTemplateAreas => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct.clone_grid_template_areas();
                        AnimationValue::GridTemplateAreas(computed)
                    },
                    LonghandId::TableLayout => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_table()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_table()
                            },
                        };
                        let computed = style_struct.clone_table_layout();
                        AnimationValue::TableLayout(computed)
                    },
                    LonghandId::TextOverflow => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_overflow();
                        AnimationValue::TextOverflow(computed)
                    },
                    LonghandId::UnicodeBidi => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_unicode_bidi();
                        AnimationValue::UnicodeBidi(computed)
                    },
                    LonghandId::TextDecorationLine => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_line();
                        AnimationValue::TextDecorationLine(computed)
                    },
                    LonghandId::TextDecorationStyle => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_style();
                        AnimationValue::TextDecorationStyle(computed)
                    },
                    LonghandId::TextDecorationColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_text_decoration_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::TextDecorationColor(computed)
                    },
                    LonghandId::InitialLetter => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct.clone_initial_letter();
                        AnimationValue::InitialLetter(computed)
                    },
                    LonghandId::ImeMode => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone_ime_mode();
                        AnimationValue::ImeMode(computed)
                    },
                    LonghandId::MozUserSelect => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_user_select();
                        AnimationValue::MozUserSelect(computed)
                    },
                    LonghandId::MozWindowDragging => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_dragging();
                        AnimationValue::MozWindowDragging(computed)
                    },
                    LonghandId::MozWindowShadow => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_shadow();
                        AnimationValue::MozWindowShadow(computed)
                    },
                    LonghandId::MozWindowOpacity => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_opacity();
                        AnimationValue::MozWindowOpacity(computed)
                    },
                    LonghandId::MozWindowTransform => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_transform();
                        AnimationValue::MozWindowTransform(computed)
                    },
                    LonghandId::MozWindowTransformOrigin => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_window_transform_origin();
                        AnimationValue::MozWindowTransformOrigin(computed)
                    },
                    LonghandId::MozForceBrokenImageIcon => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct.clone__moz_force_broken_image_icon();
                        AnimationValue::MozForceBrokenImageIcon(computed)
                    },
                    LonghandId::TextAnchor => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_text_anchor();
                        AnimationValue::TextAnchor(computed)
                    },
                    LonghandId::ColorInterpolation => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_color_interpolation();
                        AnimationValue::ColorInterpolation(computed)
                    },
                    LonghandId::ColorInterpolationFilters => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_color_interpolation_filters();
                        AnimationValue::ColorInterpolationFilters(computed)
                    },
                    LonghandId::Fill => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill();
                        let computed = computed.to_animated_value();
                        AnimationValue::Fill(computed)
                    },
                    LonghandId::FillOpacity => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill_opacity();
                        AnimationValue::FillOpacity(computed)
                    },
                    LonghandId::FillRule => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_fill_rule();
                        AnimationValue::FillRule(computed)
                    },
                    LonghandId::ShapeRendering => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_shape_rendering();
                        AnimationValue::ShapeRendering(computed)
                    },
                    LonghandId::Stroke => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke();
                        let computed = computed.to_animated_value();
                        AnimationValue::Stroke(computed)
                    },
                    LonghandId::StrokeWidth => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_width();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeWidth(computed)
                    },
                    LonghandId::StrokeLinecap => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_linecap();
                        AnimationValue::StrokeLinecap(computed)
                    },
                    LonghandId::StrokeLinejoin => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_linejoin();
                        AnimationValue::StrokeLinejoin(computed)
                    },
                    LonghandId::StrokeMiterlimit => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_miterlimit();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeMiterlimit(computed)
                    },
                    LonghandId::StrokeOpacity => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_opacity();
                        AnimationValue::StrokeOpacity(computed)
                    },
                    LonghandId::StrokeDasharray => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_dasharray();
                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeDasharray(computed)
                    },
                    LonghandId::StrokeDashoffset => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_stroke_dashoffset();
                        AnimationValue::StrokeDashoffset(computed)
                    },
                    LonghandId::ClipRule => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_clip_rule();
                        AnimationValue::ClipRule(computed)
                    },
                    LonghandId::MarkerStart => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_start();
                        AnimationValue::MarkerStart(computed)
                    },
                    LonghandId::MarkerMid => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_mid();
                        AnimationValue::MarkerMid(computed)
                    },
                    LonghandId::MarkerEnd => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_marker_end();
                        AnimationValue::MarkerEnd(computed)
                    },
                    LonghandId::PaintOrder => {
                        let style_struct = match keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inheritedsvg()
                            },
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inheritedsvg()
                            },
                        };
                        let computed = style_struct.clone_paint_order();
                        AnimationValue::PaintOrder(computed)
                    },
                    LonghandId::DominantBaseline => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_dominant_baseline();
                        AnimationValue::DominantBaseline(computed)
                    },
                    LonghandId::VectorEffect => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_vector_effect();
                        AnimationValue::VectorEffect(computed)
                    },
                    LonghandId::StopColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_stop_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::StopColor(computed)
                    },
                    LonghandId::StopOpacity => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_stop_opacity();
                        AnimationValue::StopOpacity(computed)
                    },
                    LonghandId::FloodColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_flood_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::FloodColor(computed)
                    },
                    LonghandId::FloodOpacity => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_flood_opacity();
                        AnimationValue::FloodOpacity(computed)
                    },
                    LonghandId::LightingColor => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_lighting_color();
                        let computed = computed.to_animated_value();
                        AnimationValue::LightingColor(computed)
                    },
                    LonghandId::MaskType => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_type();
                        AnimationValue::MaskType(computed)
                    },
                    LonghandId::ClipPath => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_clip_path();
                        AnimationValue::ClipPath(computed)
                    },
                    LonghandId::MaskMode => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_mode();
                        AnimationValue::MaskMode(computed)
                    },
                    LonghandId::MaskRepeat => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_repeat();
                        AnimationValue::MaskRepeat(computed)
                    },
                    LonghandId::MaskPositionX => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_position_x();
                        AnimationValue::MaskPositionX(computed)
                    },
                    LonghandId::MaskPositionY => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_position_y();
                        AnimationValue::MaskPositionY(computed)
                    },
                    LonghandId::MaskClip => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_clip();
                        AnimationValue::MaskClip(computed)
                    },
                    LonghandId::MaskOrigin => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_origin();
                        AnimationValue::MaskOrigin(computed)
                    },
                    LonghandId::MaskSize => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_size();
                        AnimationValue::MaskSize(computed)
                    },
                    LonghandId::MaskComposite => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_composite();
                        AnimationValue::MaskComposite(computed)
                    },
                    LonghandId::MaskImage => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct.clone_mask_image();
                        AnimationValue::MaskImage(computed)
                    },
                    LonghandId::MozBoxAlign => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_align();
                        AnimationValue::MozBoxAlign(computed)
                    },
                    LonghandId::MozBoxDirection => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_direction();
                        AnimationValue::MozBoxDirection(computed)
                    },
                    LonghandId::MozBoxFlex => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_flex();
                        let computed = computed.to_animated_value();
                        AnimationValue::MozBoxFlex(computed)
                    },
                    LonghandId::MozBoxOrient => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_orient();
                        AnimationValue::MozBoxOrient(computed)
                    },
                    LonghandId::MozBoxPack => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_pack();
                        AnimationValue::MozBoxPack(computed)
                    },
                    LonghandId::MozStackSizing => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_stack_sizing();
                        AnimationValue::MozStackSizing(computed)
                    },
                    LonghandId::MozBoxOrdinalGroup => {
                        let style_struct = match keyword {
                                CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct.clone__moz_box_ordinal_group();
                        AnimationValue::MozBoxOrdinalGroup(computed)
                    },
                    LonghandId::BorderBlockStartColor => return None,
                    LonghandId::BorderBlockStartStyle => return None,
                    LonghandId::BorderBlockStartWidth => return None,
                    LonghandId::BorderBlockEndColor => return None,
                    LonghandId::BorderBlockEndStyle => return None,
                    LonghandId::BorderBlockEndWidth => return None,
                    LonghandId::BorderInlineStartColor => return None,
                    LonghandId::BorderInlineStartStyle => return None,
                    LonghandId::BorderInlineStartWidth => return None,
                    LonghandId::BorderInlineEndColor => return None,
                    LonghandId::BorderInlineEndStyle => return None,
                    LonghandId::BorderInlineEndWidth => return None,
                    LonghandId::MozTopLayer => return None,
                    LonghandId::TransitionDuration => return None,
                    LonghandId::TransitionTimingFunction => return None,
                    LonghandId::TransitionProperty => return None,
                    LonghandId::TransitionDelay => return None,
                    LonghandId::AnimationName => return None,
                    LonghandId::AnimationDuration => return None,
                    LonghandId::AnimationTimingFunction => return None,
                    LonghandId::AnimationIterationCount => return None,
                    LonghandId::AnimationDirection => return None,
                    LonghandId::AnimationPlayState => return None,
                    LonghandId::AnimationFillMode => return None,
                    LonghandId::AnimationDelay => return None,
                    LonghandId::MozBinding => return None,
                    LonghandId::XLang => return None,
                    LonghandId::MozScriptSizeMultiplier => return None,
                    LonghandId::MozScriptLevel => return None,
                    LonghandId::MozMathDisplay => return None,
                    LonghandId::MozMathVariant => return None,
                    LonghandId::MozScriptMinSize => return None,
                    LonghandId::XTextZoom => return None,
                    LonghandId::MozMinFontSizeRatio => return None,
                    LonghandId::MozControlCharacterVisibility => return None,
                    LonghandId::MarginBlockStart => return None,
                    LonghandId::MarginBlockEnd => return None,
                    LonghandId::MarginInlineStart => return None,
                    LonghandId::MarginInlineEnd => return None,
                    LonghandId::PaddingBlockStart => return None,
                    LonghandId::PaddingBlockEnd => return None,
                    LonghandId::PaddingInlineStart => return None,
                    LonghandId::PaddingInlineEnd => return None,
                    LonghandId::OffsetBlockStart => return None,
                    LonghandId::OffsetBlockEnd => return None,
                    LonghandId::OffsetInlineStart => return None,
                    LonghandId::OffsetInlineEnd => return None,
                    LonghandId::BlockSize => return None,
                    LonghandId::MinBlockSize => return None,
                    LonghandId::MaxBlockSize => return None,
                    LonghandId::InlineSize => return None,
                    LonghandId::MinInlineSize => return None,
                    LonghandId::MaxInlineSize => return None,
                    LonghandId::XSpan => return None,
                    LonghandId::MozContextProperties => return None,
                }
            },
            PropertyDeclaration::WithVariables(id, ref unparsed) => {
                let substituted = {
                    let custom_properties =
                        extra_custom_properties.or_else(|| context.style().custom_properties());

                    unparsed.substitute_variables(
                        id,
                        custom_properties,
                        context.quirks_mode
                    )
                };
                return AnimationValue::from_declaration(
                    &substituted,
                    context,
                    extra_custom_properties,
                    initial,
                )
            },
            _ => return None // non animatable properties will get included because of shorthands. ignore.
        };
        Some(animatable)
    }

    /// Get an AnimationValue for an AnimatableLonghand from a given computed values.
    pub fn from_computed_values(
        property: &LonghandId,
        computed_values: &ComputedValues
    ) -> Option<Self> {
        Some(match *property {
            LonghandId::BackgroundColor => {
                let computed = computed_values
                    .get_background()
                    .clone_background_color();
                AnimationValue::BackgroundColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BackgroundImage => {
                let computed = computed_values
                    .get_background()
                    .clone_background_image();
                AnimationValue::BackgroundImage(
                    computed
                )
            }
            LonghandId::BackgroundPositionX => {
                let computed = computed_values
                    .get_background()
                    .clone_background_position_x();
                AnimationValue::BackgroundPositionX(
                    computed
                )
            }
            LonghandId::BackgroundPositionY => {
                let computed = computed_values
                    .get_background()
                    .clone_background_position_y();
                AnimationValue::BackgroundPositionY(
                    computed
                )
            }
            LonghandId::BackgroundRepeat => {
                let computed = computed_values
                    .get_background()
                    .clone_background_repeat();
                AnimationValue::BackgroundRepeat(
                    computed
                )
            }
            LonghandId::BackgroundAttachment => {
                let computed = computed_values
                    .get_background()
                    .clone_background_attachment();
                AnimationValue::BackgroundAttachment(
                    computed
                )
            }
            LonghandId::BackgroundClip => {
                let computed = computed_values
                    .get_background()
                    .clone_background_clip();
                AnimationValue::BackgroundClip(
                    computed
                )
            }
            LonghandId::BackgroundOrigin => {
                let computed = computed_values
                    .get_background()
                    .clone_background_origin();
                AnimationValue::BackgroundOrigin(
                    computed
                )
            }
            LonghandId::BackgroundSize => {
                let computed = computed_values
                    .get_background()
                    .clone_background_size();
                AnimationValue::BackgroundSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::BackgroundBlendMode => {
                let computed = computed_values
                    .get_background()
                    .clone_background_blend_mode();
                AnimationValue::BackgroundBlendMode(
                    computed
                )
            }
            LonghandId::BorderTopColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_color();
                AnimationValue::BorderTopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_style();
                AnimationValue::BorderTopStyle(
                    computed
                )
            }
            LonghandId::BorderTopWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_width();
                AnimationValue::BorderTopWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_color();
                AnimationValue::BorderLeftColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_style();
                AnimationValue::BorderLeftStyle(
                    computed
                )
            }
            LonghandId::BorderLeftWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_left_width();
                AnimationValue::BorderLeftWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_color();
                AnimationValue::BorderBottomColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_style();
                AnimationValue::BorderBottomStyle(
                    computed
                )
            }
            LonghandId::BorderBottomWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_width();
                AnimationValue::BorderBottomWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightColor => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_color();
                AnimationValue::BorderRightColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightStyle => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_style();
                AnimationValue::BorderRightStyle(
                    computed
                )
            }
            LonghandId::BorderRightWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_right_width();
                AnimationValue::BorderRightWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopLeftRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_left_radius();
                AnimationValue::BorderTopLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopRightRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_top_right_radius();
                AnimationValue::BorderTopRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomRightRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_right_radius();
                AnimationValue::BorderBottomRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomLeftRadius => {
                let computed = computed_values
                    .get_border()
                    .clone_border_bottom_left_radius();
                AnimationValue::BorderBottomLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozBorderTopColors => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_border_top_colors();
                AnimationValue::MozBorderTopColors(
                    computed
                )
            }
            LonghandId::MozBorderLeftColors => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_border_left_colors();
                AnimationValue::MozBorderLeftColors(
                    computed
                )
            }
            LonghandId::MozBorderBottomColors => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_border_bottom_colors();
                AnimationValue::MozBorderBottomColors(
                    computed
                )
            }
            LonghandId::MozBorderRightColors => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_border_right_colors();
                AnimationValue::MozBorderRightColors(
                    computed
                )
            }
            LonghandId::BoxDecorationBreak => {
                let computed = computed_values
                    .get_border()
                    .clone_box_decoration_break();
                AnimationValue::BoxDecorationBreak(
                    computed
                )
            }
            LonghandId::MozFloatEdge => {
                let computed = computed_values
                    .get_border()
                    .clone__moz_float_edge();
                AnimationValue::MozFloatEdge(
                    computed
                )
            }
            LonghandId::BorderImageSource => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_source();
                AnimationValue::BorderImageSource(
                    computed
                )
            }
            LonghandId::BorderImageOutset => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_outset();
                AnimationValue::BorderImageOutset(
                    computed
                )
            }
            LonghandId::BorderImageRepeat => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_repeat();
                AnimationValue::BorderImageRepeat(
                    computed
                )
            }
            LonghandId::BorderImageWidth => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_width();
                AnimationValue::BorderImageWidth(
                    computed
                )
            }
            LonghandId::BorderImageSlice => {
                let computed = computed_values
                    .get_border()
                    .clone_border_image_slice();
                AnimationValue::BorderImageSlice(
                    computed
                )
            }
            LonghandId::Display => {
                let computed = computed_values
                    .get_box()
                    .clone_display();
                AnimationValue::Display(
                    computed
                )
            }
            LonghandId::Position => {
                let computed = computed_values
                    .get_box()
                    .clone_position();
                AnimationValue::Position(
                    computed
                )
            }
            LonghandId::Float => {
                let computed = computed_values
                    .get_box()
                    .clone_float();
                AnimationValue::Float(
                    computed
                )
            }
            LonghandId::Clear => {
                let computed = computed_values
                    .get_box()
                    .clone_clear();
                AnimationValue::Clear(
                    computed
                )
            }
            LonghandId::VerticalAlign => {
                let computed = computed_values
                    .get_box()
                    .clone_vertical_align();
                AnimationValue::VerticalAlign(
                    computed
                )
            }
            LonghandId::OverflowClipBoxInline => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_clip_box_inline();
                AnimationValue::OverflowClipBoxInline(
                    computed
                )
            }
            LonghandId::OverflowClipBoxBlock => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_clip_box_block();
                AnimationValue::OverflowClipBoxBlock(
                    computed
                )
            }
            LonghandId::OverflowX => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_x();
                AnimationValue::OverflowX(
                    computed
                )
            }
            LonghandId::OverflowY => {
                let computed = computed_values
                    .get_box()
                    .clone_overflow_y();
                AnimationValue::OverflowY(
                    computed
                )
            }
            LonghandId::ScrollSnapPointsX => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_points_x();
                AnimationValue::ScrollSnapPointsX(
                    computed
                )
            }
            LonghandId::ScrollSnapPointsY => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_points_y();
                AnimationValue::ScrollSnapPointsY(
                    computed
                )
            }
            LonghandId::ScrollSnapDestination => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_destination();
                AnimationValue::ScrollSnapDestination(
                    computed
                )
            }
            LonghandId::ScrollSnapCoordinate => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_coordinate();
                AnimationValue::ScrollSnapCoordinate(
                    computed
                )
            }
            LonghandId::Transform => {
                let computed = computed_values
                    .get_box()
                    .clone_transform();
                AnimationValue::Transform(
                    computed
                )
            }
            LonghandId::ScrollBehavior => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_behavior();
                AnimationValue::ScrollBehavior(
                    computed
                )
            }
            LonghandId::ScrollSnapTypeX => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_type_x();
                AnimationValue::ScrollSnapTypeX(
                    computed
                )
            }
            LonghandId::ScrollSnapTypeY => {
                let computed = computed_values
                    .get_box()
                    .clone_scroll_snap_type_y();
                AnimationValue::ScrollSnapTypeY(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorX => {
                let computed = computed_values
                    .get_box()
                    .clone_overscroll_behavior_x();
                AnimationValue::OverscrollBehaviorX(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorY => {
                let computed = computed_values
                    .get_box()
                    .clone_overscroll_behavior_y();
                AnimationValue::OverscrollBehaviorY(
                    computed
                )
            }
            LonghandId::Isolation => {
                let computed = computed_values
                    .get_box()
                    .clone_isolation();
                AnimationValue::Isolation(
                    computed
                )
            }
            LonghandId::PageBreakAfter => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_after();
                AnimationValue::PageBreakAfter(
                    computed
                )
            }
            LonghandId::PageBreakBefore => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_before();
                AnimationValue::PageBreakBefore(
                    computed
                )
            }
            LonghandId::PageBreakInside => {
                let computed = computed_values
                    .get_box()
                    .clone_page_break_inside();
                AnimationValue::PageBreakInside(
                    computed
                )
            }
            LonghandId::Resize => {
                let computed = computed_values
                    .get_box()
                    .clone_resize();
                AnimationValue::Resize(
                    computed
                )
            }
            LonghandId::Perspective => {
                let computed = computed_values
                    .get_box()
                    .clone_perspective();
                AnimationValue::Perspective(
                    computed
                )
            }
            LonghandId::PerspectiveOrigin => {
                let computed = computed_values
                    .get_box()
                    .clone_perspective_origin();
                AnimationValue::PerspectiveOrigin(
                    computed
                )
            }
            LonghandId::BackfaceVisibility => {
                let computed = computed_values
                    .get_box()
                    .clone_backface_visibility();
                AnimationValue::BackfaceVisibility(
                    computed
                )
            }
            LonghandId::TransformBox => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_box();
                AnimationValue::TransformBox(
                    computed
                )
            }
            LonghandId::TransformStyle => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_style();
                AnimationValue::TransformStyle(
                    computed
                )
            }
            LonghandId::TransformOrigin => {
                let computed = computed_values
                    .get_box()
                    .clone_transform_origin();
                AnimationValue::TransformOrigin(
                    computed
                )
            }
            LonghandId::Contain => {
                let computed = computed_values
                    .get_box()
                    .clone_contain();
                AnimationValue::Contain(
                    computed
                )
            }
            LonghandId::MozAppearance => {
                let computed = computed_values
                    .get_box()
                    .clone__moz_appearance();
                AnimationValue::MozAppearance(
                    computed
                )
            }
            LonghandId::MozOrient => {
                let computed = computed_values
                    .get_box()
                    .clone__moz_orient();
                AnimationValue::MozOrient(
                    computed
                )
            }
            LonghandId::WillChange => {
                let computed = computed_values
                    .get_box()
                    .clone_will_change();
                AnimationValue::WillChange(
                    computed
                )
            }
            LonghandId::ShapeImageThreshold => {
                let computed = computed_values
                    .get_box()
                    .clone_shape_image_threshold();
                AnimationValue::ShapeImageThreshold(
                    computed
                )
            }
            LonghandId::ShapeOutside => {
                let computed = computed_values
                    .get_box()
                    .clone_shape_outside();
                AnimationValue::ShapeOutside(
                    computed
                )
            }
            LonghandId::TouchAction => {
                let computed = computed_values
                    .get_box()
                    .clone_touch_action();
                AnimationValue::TouchAction(
                    computed
                )
            }
            LonghandId::Color => {
                let computed = computed_values
                    .get_color()
                    .clone_color();
                AnimationValue::Color(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnWidth => {
                let computed = computed_values
                    .get_column()
                    .clone_column_width();
                AnimationValue::ColumnWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnCount => {
                let computed = computed_values
                    .get_column()
                    .clone_column_count();
                AnimationValue::ColumnCount(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnGap => {
                let computed = computed_values
                    .get_column()
                    .clone_column_gap();
                AnimationValue::ColumnGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnFill => {
                let computed = computed_values
                    .get_column()
                    .clone_column_fill();
                AnimationValue::ColumnFill(
                    computed
                )
            }
            LonghandId::ColumnRuleWidth => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_width();
                AnimationValue::ColumnRuleWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnRuleColor => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_color();
                AnimationValue::ColumnRuleColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnSpan => {
                let computed = computed_values
                    .get_column()
                    .clone_column_span();
                AnimationValue::ColumnSpan(
                    computed
                )
            }
            LonghandId::ColumnRuleStyle => {
                let computed = computed_values
                    .get_column()
                    .clone_column_rule_style();
                AnimationValue::ColumnRuleStyle(
                    computed
                )
            }
            LonghandId::Content => {
                let computed = computed_values
                    .get_counters()
                    .clone_content();
                AnimationValue::Content(
                    computed
                )
            }
            LonghandId::CounterIncrement => {
                let computed = computed_values
                    .get_counters()
                    .clone_counter_increment();
                AnimationValue::CounterIncrement(
                    computed
                )
            }
            LonghandId::CounterReset => {
                let computed = computed_values
                    .get_counters()
                    .clone_counter_reset();
                AnimationValue::CounterReset(
                    computed
                )
            }
            LonghandId::Opacity => {
                let computed = computed_values
                    .get_effects()
                    .clone_opacity();
                AnimationValue::Opacity(
                    computed
                )
            }
            LonghandId::BoxShadow => {
                let computed = computed_values
                    .get_effects()
                    .clone_box_shadow();
                AnimationValue::BoxShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::Clip => {
                let computed = computed_values
                    .get_effects()
                    .clone_clip();
                AnimationValue::Clip(
                    computed
                )
            }
            LonghandId::Filter => {
                let computed = computed_values
                    .get_effects()
                    .clone_filter();
                AnimationValue::Filter(
                    computed.to_animated_value()
                )
            }
            LonghandId::MixBlendMode => {
                let computed = computed_values
                    .get_effects()
                    .clone_mix_blend_mode();
                AnimationValue::MixBlendMode(
                    computed
                )
            }
            LonghandId::FontFamily => {
                let computed = computed_values
                    .get_font()
                    .clone_font_family();
                AnimationValue::FontFamily(
                    computed
                )
            }
            LonghandId::FontStyle => {
                let computed = computed_values
                    .get_font()
                    .clone_font_style();
                AnimationValue::FontStyle(
                    computed
                )
            }
            LonghandId::FontVariantCaps => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_caps();
                AnimationValue::FontVariantCaps(
                    computed
                )
            }
            LonghandId::FontWeight => {
                let computed = computed_values
                    .get_font()
                    .clone_font_weight();
                AnimationValue::FontWeight(
                    computed
                )
            }
            LonghandId::FontSize => {
                let computed = computed_values
                    .get_font()
                    .clone_font_size();
                AnimationValue::FontSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontSizeAdjust => {
                let computed = computed_values
                    .get_font()
                    .clone_font_size_adjust();
                AnimationValue::FontSizeAdjust(
                    computed
                )
            }
            LonghandId::FontSynthesis => {
                let computed = computed_values
                    .get_font()
                    .clone_font_synthesis();
                AnimationValue::FontSynthesis(
                    computed
                )
            }
            LonghandId::FontStretch => {
                let computed = computed_values
                    .get_font()
                    .clone_font_stretch();
                AnimationValue::FontStretch(
                    computed
                )
            }
            LonghandId::FontKerning => {
                let computed = computed_values
                    .get_font()
                    .clone_font_kerning();
                AnimationValue::FontKerning(
                    computed
                )
            }
            LonghandId::FontVariantAlternates => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_alternates();
                AnimationValue::FontVariantAlternates(
                    computed
                )
            }
            LonghandId::FontVariantEastAsian => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_east_asian();
                AnimationValue::FontVariantEastAsian(
                    computed
                )
            }
            LonghandId::FontVariantLigatures => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_ligatures();
                AnimationValue::FontVariantLigatures(
                    computed
                )
            }
            LonghandId::FontVariantNumeric => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_numeric();
                AnimationValue::FontVariantNumeric(
                    computed
                )
            }
            LonghandId::FontVariantPosition => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variant_position();
                AnimationValue::FontVariantPosition(
                    computed
                )
            }
            LonghandId::FontFeatureSettings => {
                let computed = computed_values
                    .get_font()
                    .clone_font_feature_settings();
                AnimationValue::FontFeatureSettings(
                    computed
                )
            }
            LonghandId::FontVariationSettings => {
                let computed = computed_values
                    .get_font()
                    .clone_font_variation_settings();
                AnimationValue::FontVariationSettings(
                    computed
                )
            }
            LonghandId::FontLanguageOverride => {
                let computed = computed_values
                    .get_font()
                    .clone_font_language_override();
                AnimationValue::FontLanguageOverride(
                    computed
                )
            }
            LonghandId::MozOsxFontSmoothing => {
                let computed = computed_values
                    .get_font()
                    .clone__moz_osx_font_smoothing();
                AnimationValue::MozOsxFontSmoothing(
                    computed
                )
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                let computed = computed_values
                    .get_font()
                    .clone__moz_font_smoothing_background_color();
                AnimationValue::MozFontSmoothingBackgroundColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::Visibility => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_visibility();
                AnimationValue::Visibility(
                    computed
                )
            }
            LonghandId::WritingMode => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_writing_mode();
                AnimationValue::WritingMode(
                    computed
                )
            }
            LonghandId::Direction => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_direction();
                AnimationValue::Direction(
                    computed
                )
            }
            LonghandId::TextOrientation => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_text_orientation();
                AnimationValue::TextOrientation(
                    computed
                )
            }
            LonghandId::ColorAdjust => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_color_adjust();
                AnimationValue::ColorAdjust(
                    computed
                )
            }
            LonghandId::ImageRendering => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_image_rendering();
                AnimationValue::ImageRendering(
                    computed
                )
            }
            LonghandId::ImageOrientation => {
                let computed = computed_values
                    .get_inheritedbox()
                    .clone_image_orientation();
                AnimationValue::ImageOrientation(
                    computed
                )
            }
            LonghandId::BorderCollapse => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_border_collapse();
                AnimationValue::BorderCollapse(
                    computed
                )
            }
            LonghandId::EmptyCells => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_empty_cells();
                AnimationValue::EmptyCells(
                    computed
                )
            }
            LonghandId::CaptionSide => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_caption_side();
                AnimationValue::CaptionSide(
                    computed
                )
            }
            LonghandId::BorderSpacing => {
                let computed = computed_values
                    .get_inheritedtable()
                    .clone_border_spacing();
                AnimationValue::BorderSpacing(
                    computed.to_animated_value()
                )
            }
            LonghandId::LineHeight => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_line_height();
                AnimationValue::LineHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextTransform => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_transform();
                AnimationValue::TextTransform(
                    computed
                )
            }
            LonghandId::Hyphens => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_hyphens();
                AnimationValue::Hyphens(
                    computed
                )
            }
            LonghandId::MozTextSizeAdjust => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__moz_text_size_adjust();
                AnimationValue::MozTextSizeAdjust(
                    computed
                )
            }
            LonghandId::TextIndent => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_indent();
                AnimationValue::TextIndent(
                    computed
                )
            }
            LonghandId::OverflowWrap => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_overflow_wrap();
                AnimationValue::OverflowWrap(
                    computed
                )
            }
            LonghandId::WordBreak => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_word_break();
                AnimationValue::WordBreak(
                    computed
                )
            }
            LonghandId::TextJustify => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_justify();
                AnimationValue::TextJustify(
                    computed
                )
            }
            LonghandId::TextAlignLast => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_align_last();
                AnimationValue::TextAlignLast(
                    computed
                )
            }
            LonghandId::TextAlign => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_align();
                AnimationValue::TextAlign(
                    computed
                )
            }
            LonghandId::LetterSpacing => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_letter_spacing();
                AnimationValue::LetterSpacing(
                    computed
                )
            }
            LonghandId::WordSpacing => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_word_spacing();
                AnimationValue::WordSpacing(
                    computed
                )
            }
            LonghandId::WhiteSpace => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_white_space();
                AnimationValue::WhiteSpace(
                    computed
                )
            }
            LonghandId::TextShadow => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_shadow();
                AnimationValue::TextShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextEmphasisStyle => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_style();
                AnimationValue::TextEmphasisStyle(
                    computed
                )
            }
            LonghandId::TextEmphasisPosition => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_position();
                AnimationValue::TextEmphasisPosition(
                    computed
                )
            }
            LonghandId::TextEmphasisColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_emphasis_color();
                AnimationValue::TextEmphasisColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozTabSize => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__moz_tab_size();
                AnimationValue::MozTabSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextFillColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_fill_color();
                AnimationValue::WebkitTextFillColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextStrokeColor => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_stroke_color();
                AnimationValue::WebkitTextStrokeColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextStrokeWidth => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone__webkit_text_stroke_width();
                AnimationValue::WebkitTextStrokeWidth(
                    computed
                )
            }
            LonghandId::RubyAlign => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_ruby_align();
                AnimationValue::RubyAlign(
                    computed
                )
            }
            LonghandId::RubyPosition => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_ruby_position();
                AnimationValue::RubyPosition(
                    computed
                )
            }
            LonghandId::TextCombineUpright => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_combine_upright();
                AnimationValue::TextCombineUpright(
                    computed
                )
            }
            LonghandId::TextRendering => {
                let computed = computed_values
                    .get_inheritedtext()
                    .clone_text_rendering();
                AnimationValue::TextRendering(
                    computed
                )
            }
            LonghandId::ListStylePosition => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_position();
                AnimationValue::ListStylePosition(
                    computed
                )
            }
            LonghandId::ListStyleType => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_type();
                AnimationValue::ListStyleType(
                    computed
                )
            }
            LonghandId::ListStyleImage => {
                let computed = computed_values
                    .get_list()
                    .clone_list_style_image();
                AnimationValue::ListStyleImage(
                    computed
                )
            }
            LonghandId::Quotes => {
                let computed = computed_values
                    .get_list()
                    .clone_quotes();
                AnimationValue::Quotes(
                    computed
                )
            }
            LonghandId::MozImageRegion => {
                let computed = computed_values
                    .get_list()
                    .clone__moz_image_region();
                AnimationValue::MozImageRegion(
                    computed
                )
            }
            LonghandId::MarginTop => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_top();
                AnimationValue::MarginTop(
                    computed
                )
            }
            LonghandId::MarginLeft => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_left();
                AnimationValue::MarginLeft(
                    computed
                )
            }
            LonghandId::MarginBottom => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_bottom();
                AnimationValue::MarginBottom(
                    computed
                )
            }
            LonghandId::MarginRight => {
                let computed = computed_values
                    .get_margin()
                    .clone_margin_right();
                AnimationValue::MarginRight(
                    computed
                )
            }
            LonghandId::OutlineColor => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_color();
                AnimationValue::OutlineColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineStyle => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_style();
                AnimationValue::OutlineStyle(
                    computed
                )
            }
            LonghandId::OutlineWidth => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_width();
                AnimationValue::OutlineWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusTopleft => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_topleft();
                AnimationValue::MozOutlineRadiusTopleft(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusTopright => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_topright();
                AnimationValue::MozOutlineRadiusTopright(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusBottomright => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_bottomright();
                AnimationValue::MozOutlineRadiusBottomright(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                let computed = computed_values
                    .get_outline()
                    .clone__moz_outline_radius_bottomleft();
                AnimationValue::MozOutlineRadiusBottomleft(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineOffset => {
                let computed = computed_values
                    .get_outline()
                    .clone_outline_offset();
                AnimationValue::OutlineOffset(
                    computed
                )
            }
            LonghandId::PaddingTop => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_top();
                AnimationValue::PaddingTop(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingLeft => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_left();
                AnimationValue::PaddingLeft(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingBottom => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_bottom();
                AnimationValue::PaddingBottom(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingRight => {
                let computed = computed_values
                    .get_padding()
                    .clone_padding_right();
                AnimationValue::PaddingRight(
                    computed.to_animated_value()
                )
            }
            LonghandId::Cursor => {
                let computed = computed_values
                    .get_pointing()
                    .clone_cursor();
                AnimationValue::Cursor(
                    computed
                )
            }
            LonghandId::PointerEvents => {
                let computed = computed_values
                    .get_pointing()
                    .clone_pointer_events();
                AnimationValue::PointerEvents(
                    computed
                )
            }
            LonghandId::MozUserInput => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_input();
                AnimationValue::MozUserInput(
                    computed
                )
            }
            LonghandId::MozUserModify => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_modify();
                AnimationValue::MozUserModify(
                    computed
                )
            }
            LonghandId::MozUserFocus => {
                let computed = computed_values
                    .get_pointing()
                    .clone__moz_user_focus();
                AnimationValue::MozUserFocus(
                    computed
                )
            }
            LonghandId::CaretColor => {
                let computed = computed_values
                    .get_pointing()
                    .clone_caret_color();
                AnimationValue::CaretColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::Top => {
                let computed = computed_values
                    .get_position()
                    .clone_top();
                AnimationValue::Top(
                    computed
                )
            }
            LonghandId::Left => {
                let computed = computed_values
                    .get_position()
                    .clone_left();
                AnimationValue::Left(
                    computed
                )
            }
            LonghandId::Bottom => {
                let computed = computed_values
                    .get_position()
                    .clone_bottom();
                AnimationValue::Bottom(
                    computed
                )
            }
            LonghandId::Right => {
                let computed = computed_values
                    .get_position()
                    .clone_right();
                AnimationValue::Right(
                    computed
                )
            }
            LonghandId::ZIndex => {
                let computed = computed_values
                    .get_position()
                    .clone_z_index();
                AnimationValue::ZIndex(
                    computed
                )
            }
            LonghandId::FlexDirection => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_direction();
                AnimationValue::FlexDirection(
                    computed
                )
            }
            LonghandId::FlexWrap => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_wrap();
                AnimationValue::FlexWrap(
                    computed
                )
            }
            LonghandId::JustifyContent => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_content();
                AnimationValue::JustifyContent(
                    computed
                )
            }
            LonghandId::AlignContent => {
                let computed = computed_values
                    .get_position()
                    .clone_align_content();
                AnimationValue::AlignContent(
                    computed
                )
            }
            LonghandId::AlignItems => {
                let computed = computed_values
                    .get_position()
                    .clone_align_items();
                AnimationValue::AlignItems(
                    computed
                )
            }
            LonghandId::JustifyItems => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_items();
                AnimationValue::JustifyItems(
                    computed
                )
            }
            LonghandId::FlexGrow => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_grow();
                AnimationValue::FlexGrow(
                    computed.to_animated_value()
                )
            }
            LonghandId::FlexShrink => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_shrink();
                AnimationValue::FlexShrink(
                    computed.to_animated_value()
                )
            }
            LonghandId::AlignSelf => {
                let computed = computed_values
                    .get_position()
                    .clone_align_self();
                AnimationValue::AlignSelf(
                    computed
                )
            }
            LonghandId::JustifySelf => {
                let computed = computed_values
                    .get_position()
                    .clone_justify_self();
                AnimationValue::JustifySelf(
                    computed
                )
            }
            LonghandId::Order => {
                let computed = computed_values
                    .get_position()
                    .clone_order();
                AnimationValue::Order(
                    computed
                )
            }
            LonghandId::FlexBasis => {
                let computed = computed_values
                    .get_position()
                    .clone_flex_basis();
                AnimationValue::FlexBasis(
                    computed.to_animated_value()
                )
            }
            LonghandId::Width => {
                let computed = computed_values
                    .get_position()
                    .clone_width();
                AnimationValue::Width(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinWidth => {
                let computed = computed_values
                    .get_position()
                    .clone_min_width();
                AnimationValue::MinWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::MaxWidth => {
                let computed = computed_values
                    .get_position()
                    .clone_max_width();
                AnimationValue::MaxWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Height => {
                let computed = computed_values
                    .get_position()
                    .clone_height();
                AnimationValue::Height(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinHeight => {
                let computed = computed_values
                    .get_position()
                    .clone_min_height();
                AnimationValue::MinHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::MaxHeight => {
                let computed = computed_values
                    .get_position()
                    .clone_max_height();
                AnimationValue::MaxHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::BoxSizing => {
                let computed = computed_values
                    .get_position()
                    .clone_box_sizing();
                AnimationValue::BoxSizing(
                    computed
                )
            }
            LonghandId::ObjectFit => {
                let computed = computed_values
                    .get_position()
                    .clone_object_fit();
                AnimationValue::ObjectFit(
                    computed
                )
            }
            LonghandId::ObjectPosition => {
                let computed = computed_values
                    .get_position()
                    .clone_object_position();
                AnimationValue::ObjectPosition(
                    computed
                )
            }
            LonghandId::GridRowGap => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_gap();
                AnimationValue::GridRowGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridRowStart => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_start();
                AnimationValue::GridRowStart(
                    computed
                )
            }
            LonghandId::GridRowEnd => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_row_end();
                AnimationValue::GridRowEnd(
                    computed
                )
            }
            LonghandId::GridAutoRows => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_rows();
                AnimationValue::GridAutoRows(
                    computed
                )
            }
            LonghandId::GridTemplateRows => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_rows();
                AnimationValue::GridTemplateRows(
                    computed
                )
            }
            LonghandId::GridColumnGap => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_gap();
                AnimationValue::GridColumnGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridColumnStart => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_start();
                AnimationValue::GridColumnStart(
                    computed
                )
            }
            LonghandId::GridColumnEnd => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_column_end();
                AnimationValue::GridColumnEnd(
                    computed
                )
            }
            LonghandId::GridAutoColumns => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_columns();
                AnimationValue::GridAutoColumns(
                    computed
                )
            }
            LonghandId::GridTemplateColumns => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_columns();
                AnimationValue::GridTemplateColumns(
                    computed
                )
            }
            LonghandId::GridAutoFlow => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_auto_flow();
                AnimationValue::GridAutoFlow(
                    computed
                )
            }
            LonghandId::GridTemplateAreas => {
                let computed = computed_values
                    .get_position()
                    .clone_grid_template_areas();
                AnimationValue::GridTemplateAreas(
                    computed
                )
            }
            LonghandId::TableLayout => {
                let computed = computed_values
                    .get_table()
                    .clone_table_layout();
                AnimationValue::TableLayout(
                    computed
                )
            }
            LonghandId::TextOverflow => {
                let computed = computed_values
                    .get_text()
                    .clone_text_overflow();
                AnimationValue::TextOverflow(
                    computed
                )
            }
            LonghandId::UnicodeBidi => {
                let computed = computed_values
                    .get_text()
                    .clone_unicode_bidi();
                AnimationValue::UnicodeBidi(
                    computed
                )
            }
            LonghandId::TextDecorationLine => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_line();
                AnimationValue::TextDecorationLine(
                    computed
                )
            }
            LonghandId::TextDecorationStyle => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_style();
                AnimationValue::TextDecorationStyle(
                    computed
                )
            }
            LonghandId::TextDecorationColor => {
                let computed = computed_values
                    .get_text()
                    .clone_text_decoration_color();
                AnimationValue::TextDecorationColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::InitialLetter => {
                let computed = computed_values
                    .get_text()
                    .clone_initial_letter();
                AnimationValue::InitialLetter(
                    computed
                )
            }
            LonghandId::ImeMode => {
                let computed = computed_values
                    .get_ui()
                    .clone_ime_mode();
                AnimationValue::ImeMode(
                    computed
                )
            }
            LonghandId::MozUserSelect => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_user_select();
                AnimationValue::MozUserSelect(
                    computed
                )
            }
            LonghandId::MozWindowDragging => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_dragging();
                AnimationValue::MozWindowDragging(
                    computed
                )
            }
            LonghandId::MozWindowShadow => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_shadow();
                AnimationValue::MozWindowShadow(
                    computed
                )
            }
            LonghandId::MozWindowOpacity => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_opacity();
                AnimationValue::MozWindowOpacity(
                    computed
                )
            }
            LonghandId::MozWindowTransform => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_transform();
                AnimationValue::MozWindowTransform(
                    computed
                )
            }
            LonghandId::MozWindowTransformOrigin => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_window_transform_origin();
                AnimationValue::MozWindowTransformOrigin(
                    computed
                )
            }
            LonghandId::MozForceBrokenImageIcon => {
                let computed = computed_values
                    .get_ui()
                    .clone__moz_force_broken_image_icon();
                AnimationValue::MozForceBrokenImageIcon(
                    computed
                )
            }
            LonghandId::TextAnchor => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_text_anchor();
                AnimationValue::TextAnchor(
                    computed
                )
            }
            LonghandId::ColorInterpolation => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_color_interpolation();
                AnimationValue::ColorInterpolation(
                    computed
                )
            }
            LonghandId::ColorInterpolationFilters => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_color_interpolation_filters();
                AnimationValue::ColorInterpolationFilters(
                    computed
                )
            }
            LonghandId::Fill => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill();
                AnimationValue::Fill(
                    computed.to_animated_value()
                )
            }
            LonghandId::FillOpacity => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill_opacity();
                AnimationValue::FillOpacity(
                    computed
                )
            }
            LonghandId::FillRule => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_fill_rule();
                AnimationValue::FillRule(
                    computed
                )
            }
            LonghandId::ShapeRendering => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_shape_rendering();
                AnimationValue::ShapeRendering(
                    computed
                )
            }
            LonghandId::Stroke => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke();
                AnimationValue::Stroke(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeWidth => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_width();
                AnimationValue::StrokeWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeLinecap => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_linecap();
                AnimationValue::StrokeLinecap(
                    computed
                )
            }
            LonghandId::StrokeLinejoin => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_linejoin();
                AnimationValue::StrokeLinejoin(
                    computed
                )
            }
            LonghandId::StrokeMiterlimit => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_miterlimit();
                AnimationValue::StrokeMiterlimit(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeOpacity => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_opacity();
                AnimationValue::StrokeOpacity(
                    computed
                )
            }
            LonghandId::StrokeDasharray => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_dasharray();
                AnimationValue::StrokeDasharray(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeDashoffset => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_stroke_dashoffset();
                AnimationValue::StrokeDashoffset(
                    computed
                )
            }
            LonghandId::ClipRule => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_clip_rule();
                AnimationValue::ClipRule(
                    computed
                )
            }
            LonghandId::MarkerStart => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_start();
                AnimationValue::MarkerStart(
                    computed
                )
            }
            LonghandId::MarkerMid => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_mid();
                AnimationValue::MarkerMid(
                    computed
                )
            }
            LonghandId::MarkerEnd => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_marker_end();
                AnimationValue::MarkerEnd(
                    computed
                )
            }
            LonghandId::PaintOrder => {
                let computed = computed_values
                    .get_inheritedsvg()
                    .clone_paint_order();
                AnimationValue::PaintOrder(
                    computed
                )
            }
            LonghandId::DominantBaseline => {
                let computed = computed_values
                    .get_svg()
                    .clone_dominant_baseline();
                AnimationValue::DominantBaseline(
                    computed
                )
            }
            LonghandId::VectorEffect => {
                let computed = computed_values
                    .get_svg()
                    .clone_vector_effect();
                AnimationValue::VectorEffect(
                    computed
                )
            }
            LonghandId::StopColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_stop_color();
                AnimationValue::StopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::StopOpacity => {
                let computed = computed_values
                    .get_svg()
                    .clone_stop_opacity();
                AnimationValue::StopOpacity(
                    computed
                )
            }
            LonghandId::FloodColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_flood_color();
                AnimationValue::FloodColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::FloodOpacity => {
                let computed = computed_values
                    .get_svg()
                    .clone_flood_opacity();
                AnimationValue::FloodOpacity(
                    computed
                )
            }
            LonghandId::LightingColor => {
                let computed = computed_values
                    .get_svg()
                    .clone_lighting_color();
                AnimationValue::LightingColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::MaskType => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_type();
                AnimationValue::MaskType(
                    computed
                )
            }
            LonghandId::ClipPath => {
                let computed = computed_values
                    .get_svg()
                    .clone_clip_path();
                AnimationValue::ClipPath(
                    computed
                )
            }
            LonghandId::MaskMode => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_mode();
                AnimationValue::MaskMode(
                    computed
                )
            }
            LonghandId::MaskRepeat => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_repeat();
                AnimationValue::MaskRepeat(
                    computed
                )
            }
            LonghandId::MaskPositionX => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_position_x();
                AnimationValue::MaskPositionX(
                    computed
                )
            }
            LonghandId::MaskPositionY => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_position_y();
                AnimationValue::MaskPositionY(
                    computed
                )
            }
            LonghandId::MaskClip => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_clip();
                AnimationValue::MaskClip(
                    computed
                )
            }
            LonghandId::MaskOrigin => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_origin();
                AnimationValue::MaskOrigin(
                    computed
                )
            }
            LonghandId::MaskSize => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_size();
                AnimationValue::MaskSize(
                    computed
                )
            }
            LonghandId::MaskComposite => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_composite();
                AnimationValue::MaskComposite(
                    computed
                )
            }
            LonghandId::MaskImage => {
                let computed = computed_values
                    .get_svg()
                    .clone_mask_image();
                AnimationValue::MaskImage(
                    computed
                )
            }
            LonghandId::MozBoxAlign => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_align();
                AnimationValue::MozBoxAlign(
                    computed
                )
            }
            LonghandId::MozBoxDirection => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_direction();
                AnimationValue::MozBoxDirection(
                    computed
                )
            }
            LonghandId::MozBoxFlex => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_flex();
                AnimationValue::MozBoxFlex(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozBoxOrient => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_orient();
                AnimationValue::MozBoxOrient(
                    computed
                )
            }
            LonghandId::MozBoxPack => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_pack();
                AnimationValue::MozBoxPack(
                    computed
                )
            }
            LonghandId::MozStackSizing => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_stack_sizing();
                AnimationValue::MozStackSizing(
                    computed
                )
            }
            LonghandId::MozBoxOrdinalGroup => {
                let computed = computed_values
                    .get_xul()
                    .clone__moz_box_ordinal_group();
                AnimationValue::MozBoxOrdinalGroup(
                    computed
                )
            }
            _ => return None,
        })
    }
}

fn animate_discrete<T: Clone>(this: &T, other: &T, procedure: Procedure) -> Result<T, ()> {
    if let Procedure::Interpolate { progress } = procedure {
        Ok(if progress < 0.5 { this.clone() } else { other.clone() })
    } else {
        Err(())
    }
}

impl Animate for AnimationValue {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let value = match (self, other) {
            (
                &AnimationValue::BackgroundColor(ref this),
                &AnimationValue::BackgroundColor(ref other),
            ) => {
                AnimationValue::BackgroundColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BackgroundImage(ref this),
                &AnimationValue::BackgroundImage(ref other),
            ) => {
                AnimationValue::BackgroundImage(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BackgroundPositionX(ref this),
                &AnimationValue::BackgroundPositionX(ref other),
            ) => {
                AnimationValue::BackgroundPositionX(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BackgroundPositionY(ref this),
                &AnimationValue::BackgroundPositionY(ref other),
            ) => {
                AnimationValue::BackgroundPositionY(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BackgroundRepeat(ref this),
                &AnimationValue::BackgroundRepeat(ref other),
            ) => {
                AnimationValue::BackgroundRepeat(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BackgroundAttachment(ref this),
                &AnimationValue::BackgroundAttachment(ref other),
            ) => {
                AnimationValue::BackgroundAttachment(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BackgroundClip(ref this),
                &AnimationValue::BackgroundClip(ref other),
            ) => {
                AnimationValue::BackgroundClip(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BackgroundOrigin(ref this),
                &AnimationValue::BackgroundOrigin(ref other),
            ) => {
                AnimationValue::BackgroundOrigin(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BackgroundSize(ref this),
                &AnimationValue::BackgroundSize(ref other),
            ) => {
                AnimationValue::BackgroundSize(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BackgroundBlendMode(ref this),
                &AnimationValue::BackgroundBlendMode(ref other),
            ) => {
                AnimationValue::BackgroundBlendMode(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderTopColor(ref this),
                &AnimationValue::BorderTopColor(ref other),
            ) => {
                AnimationValue::BorderTopColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderTopStyle(ref this),
                &AnimationValue::BorderTopStyle(ref other),
            ) => {
                AnimationValue::BorderTopStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderTopWidth(ref this),
                &AnimationValue::BorderTopWidth(ref other),
            ) => {
                AnimationValue::BorderTopWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderLeftColor(ref this),
                &AnimationValue::BorderLeftColor(ref other),
            ) => {
                AnimationValue::BorderLeftColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderLeftStyle(ref this),
                &AnimationValue::BorderLeftStyle(ref other),
            ) => {
                AnimationValue::BorderLeftStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderLeftWidth(ref this),
                &AnimationValue::BorderLeftWidth(ref other),
            ) => {
                AnimationValue::BorderLeftWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderBottomColor(ref this),
                &AnimationValue::BorderBottomColor(ref other),
            ) => {
                AnimationValue::BorderBottomColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderBottomStyle(ref this),
                &AnimationValue::BorderBottomStyle(ref other),
            ) => {
                AnimationValue::BorderBottomStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderBottomWidth(ref this),
                &AnimationValue::BorderBottomWidth(ref other),
            ) => {
                AnimationValue::BorderBottomWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderRightColor(ref this),
                &AnimationValue::BorderRightColor(ref other),
            ) => {
                AnimationValue::BorderRightColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderRightStyle(ref this),
                &AnimationValue::BorderRightStyle(ref other),
            ) => {
                AnimationValue::BorderRightStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderRightWidth(ref this),
                &AnimationValue::BorderRightWidth(ref other),
            ) => {
                AnimationValue::BorderRightWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderTopLeftRadius(ref this),
                &AnimationValue::BorderTopLeftRadius(ref other),
            ) => {
                AnimationValue::BorderTopLeftRadius(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderTopRightRadius(ref this),
                &AnimationValue::BorderTopRightRadius(ref other),
            ) => {
                AnimationValue::BorderTopRightRadius(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderBottomRightRadius(ref this),
                &AnimationValue::BorderBottomRightRadius(ref other),
            ) => {
                AnimationValue::BorderBottomRightRadius(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BorderBottomLeftRadius(ref this),
                &AnimationValue::BorderBottomLeftRadius(ref other),
            ) => {
                AnimationValue::BorderBottomLeftRadius(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozBorderTopColors(ref this),
                &AnimationValue::MozBorderTopColors(ref other),
            ) => {
                AnimationValue::MozBorderTopColors(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBorderLeftColors(ref this),
                &AnimationValue::MozBorderLeftColors(ref other),
            ) => {
                AnimationValue::MozBorderLeftColors(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBorderBottomColors(ref this),
                &AnimationValue::MozBorderBottomColors(ref other),
            ) => {
                AnimationValue::MozBorderBottomColors(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBorderRightColors(ref this),
                &AnimationValue::MozBorderRightColors(ref other),
            ) => {
                AnimationValue::MozBorderRightColors(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BoxDecorationBreak(ref this),
                &AnimationValue::BoxDecorationBreak(ref other),
            ) => {
                AnimationValue::BoxDecorationBreak(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozFloatEdge(ref this),
                &AnimationValue::MozFloatEdge(ref other),
            ) => {
                AnimationValue::MozFloatEdge(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderImageSource(ref this),
                &AnimationValue::BorderImageSource(ref other),
            ) => {
                AnimationValue::BorderImageSource(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderImageOutset(ref this),
                &AnimationValue::BorderImageOutset(ref other),
            ) => {
                AnimationValue::BorderImageOutset(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderImageRepeat(ref this),
                &AnimationValue::BorderImageRepeat(ref other),
            ) => {
                AnimationValue::BorderImageRepeat(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderImageWidth(ref this),
                &AnimationValue::BorderImageWidth(ref other),
            ) => {
                AnimationValue::BorderImageWidth(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderImageSlice(ref this),
                &AnimationValue::BorderImageSlice(ref other),
            ) => {
                AnimationValue::BorderImageSlice(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Display(ref this),
                &AnimationValue::Display(ref other),
            ) => {
                AnimationValue::Display(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Position(ref this),
                &AnimationValue::Position(ref other),
            ) => {
                AnimationValue::Position(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Float(ref this),
                &AnimationValue::Float(ref other),
            ) => {
                AnimationValue::Float(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Clear(ref this),
                &AnimationValue::Clear(ref other),
            ) => {
                AnimationValue::Clear(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::VerticalAlign(ref this),
                &AnimationValue::VerticalAlign(ref other),
            ) => {
                AnimationValue::VerticalAlign(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::OverflowClipBoxInline(ref this),
                &AnimationValue::OverflowClipBoxInline(ref other),
            ) => {
                AnimationValue::OverflowClipBoxInline(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OverflowClipBoxBlock(ref this),
                &AnimationValue::OverflowClipBoxBlock(ref other),
            ) => {
                AnimationValue::OverflowClipBoxBlock(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OverflowX(ref this),
                &AnimationValue::OverflowX(ref other),
            ) => {
                AnimationValue::OverflowX(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OverflowY(ref this),
                &AnimationValue::OverflowY(ref other),
            ) => {
                AnimationValue::OverflowY(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapPointsX(ref this),
                &AnimationValue::ScrollSnapPointsX(ref other),
            ) => {
                AnimationValue::ScrollSnapPointsX(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapPointsY(ref this),
                &AnimationValue::ScrollSnapPointsY(ref other),
            ) => {
                AnimationValue::ScrollSnapPointsY(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapDestination(ref this),
                &AnimationValue::ScrollSnapDestination(ref other),
            ) => {
                AnimationValue::ScrollSnapDestination(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapCoordinate(ref this),
                &AnimationValue::ScrollSnapCoordinate(ref other),
            ) => {
                AnimationValue::ScrollSnapCoordinate(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Transform(ref this),
                &AnimationValue::Transform(ref other),
            ) => {
                AnimationValue::Transform(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ScrollBehavior(ref this),
                &AnimationValue::ScrollBehavior(ref other),
            ) => {
                AnimationValue::ScrollBehavior(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapTypeX(ref this),
                &AnimationValue::ScrollSnapTypeX(ref other),
            ) => {
                AnimationValue::ScrollSnapTypeX(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ScrollSnapTypeY(ref this),
                &AnimationValue::ScrollSnapTypeY(ref other),
            ) => {
                AnimationValue::ScrollSnapTypeY(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OverscrollBehaviorX(ref this),
                &AnimationValue::OverscrollBehaviorX(ref other),
            ) => {
                AnimationValue::OverscrollBehaviorX(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OverscrollBehaviorY(ref this),
                &AnimationValue::OverscrollBehaviorY(ref other),
            ) => {
                AnimationValue::OverscrollBehaviorY(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Isolation(ref this),
                &AnimationValue::Isolation(ref other),
            ) => {
                AnimationValue::Isolation(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::PageBreakAfter(ref this),
                &AnimationValue::PageBreakAfter(ref other),
            ) => {
                AnimationValue::PageBreakAfter(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::PageBreakBefore(ref this),
                &AnimationValue::PageBreakBefore(ref other),
            ) => {
                AnimationValue::PageBreakBefore(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::PageBreakInside(ref this),
                &AnimationValue::PageBreakInside(ref other),
            ) => {
                AnimationValue::PageBreakInside(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Resize(ref this),
                &AnimationValue::Resize(ref other),
            ) => {
                AnimationValue::Resize(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Perspective(ref this),
                &AnimationValue::Perspective(ref other),
            ) => {
                AnimationValue::Perspective(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::PerspectiveOrigin(ref this),
                &AnimationValue::PerspectiveOrigin(ref other),
            ) => {
                AnimationValue::PerspectiveOrigin(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BackfaceVisibility(ref this),
                &AnimationValue::BackfaceVisibility(ref other),
            ) => {
                AnimationValue::BackfaceVisibility(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TransformBox(ref this),
                &AnimationValue::TransformBox(ref other),
            ) => {
                AnimationValue::TransformBox(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TransformStyle(ref this),
                &AnimationValue::TransformStyle(ref other),
            ) => {
                AnimationValue::TransformStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TransformOrigin(ref this),
                &AnimationValue::TransformOrigin(ref other),
            ) => {
                AnimationValue::TransformOrigin(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Contain(ref this),
                &AnimationValue::Contain(ref other),
            ) => {
                AnimationValue::Contain(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozAppearance(ref this),
                &AnimationValue::MozAppearance(ref other),
            ) => {
                AnimationValue::MozAppearance(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozOrient(ref this),
                &AnimationValue::MozOrient(ref other),
            ) => {
                AnimationValue::MozOrient(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::WillChange(ref this),
                &AnimationValue::WillChange(ref other),
            ) => {
                AnimationValue::WillChange(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ShapeImageThreshold(ref this),
                &AnimationValue::ShapeImageThreshold(ref other),
            ) => {
                AnimationValue::ShapeImageThreshold(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ShapeOutside(ref this),
                &AnimationValue::ShapeOutside(ref other),
            ) => {
                AnimationValue::ShapeOutside(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::TouchAction(ref this),
                &AnimationValue::TouchAction(ref other),
            ) => {
                AnimationValue::TouchAction(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Color(ref this),
                &AnimationValue::Color(ref other),
            ) => {
                AnimationValue::Color(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnWidth(ref this),
                &AnimationValue::ColumnWidth(ref other),
            ) => {
                AnimationValue::ColumnWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnCount(ref this),
                &AnimationValue::ColumnCount(ref other),
            ) => {
                AnimationValue::ColumnCount(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnGap(ref this),
                &AnimationValue::ColumnGap(ref other),
            ) => {
                AnimationValue::ColumnGap(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnFill(ref this),
                &AnimationValue::ColumnFill(ref other),
            ) => {
                AnimationValue::ColumnFill(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ColumnRuleWidth(ref this),
                &AnimationValue::ColumnRuleWidth(ref other),
            ) => {
                AnimationValue::ColumnRuleWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnRuleColor(ref this),
                &AnimationValue::ColumnRuleColor(ref other),
            ) => {
                AnimationValue::ColumnRuleColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ColumnSpan(ref this),
                &AnimationValue::ColumnSpan(ref other),
            ) => {
                AnimationValue::ColumnSpan(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ColumnRuleStyle(ref this),
                &AnimationValue::ColumnRuleStyle(ref other),
            ) => {
                AnimationValue::ColumnRuleStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Content(ref this),
                &AnimationValue::Content(ref other),
            ) => {
                AnimationValue::Content(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::CounterIncrement(ref this),
                &AnimationValue::CounterIncrement(ref other),
            ) => {
                AnimationValue::CounterIncrement(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::CounterReset(ref this),
                &AnimationValue::CounterReset(ref other),
            ) => {
                AnimationValue::CounterReset(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Opacity(ref this),
                &AnimationValue::Opacity(ref other),
            ) => {
                AnimationValue::Opacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BoxShadow(ref this),
                &AnimationValue::BoxShadow(ref other),
            ) => {
                AnimationValue::BoxShadow(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Clip(ref this),
                &AnimationValue::Clip(ref other),
            ) => {
                AnimationValue::Clip(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Filter(ref this),
                &AnimationValue::Filter(ref other),
            ) => {
                AnimationValue::Filter(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MixBlendMode(ref this),
                &AnimationValue::MixBlendMode(ref other),
            ) => {
                AnimationValue::MixBlendMode(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontFamily(ref this),
                &AnimationValue::FontFamily(ref other),
            ) => {
                AnimationValue::FontFamily(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontStyle(ref this),
                &AnimationValue::FontStyle(ref other),
            ) => {
                AnimationValue::FontStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantCaps(ref this),
                &AnimationValue::FontVariantCaps(ref other),
            ) => {
                AnimationValue::FontVariantCaps(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontWeight(ref this),
                &AnimationValue::FontWeight(ref other),
            ) => {
                AnimationValue::FontWeight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FontSize(ref this),
                &AnimationValue::FontSize(ref other),
            ) => {
                AnimationValue::FontSize(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FontSizeAdjust(ref this),
                &AnimationValue::FontSizeAdjust(ref other),
            ) => {
                AnimationValue::FontSizeAdjust(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FontSynthesis(ref this),
                &AnimationValue::FontSynthesis(ref other),
            ) => {
                AnimationValue::FontSynthesis(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontStretch(ref this),
                &AnimationValue::FontStretch(ref other),
            ) => {
                AnimationValue::FontStretch(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FontKerning(ref this),
                &AnimationValue::FontKerning(ref other),
            ) => {
                AnimationValue::FontKerning(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantAlternates(ref this),
                &AnimationValue::FontVariantAlternates(ref other),
            ) => {
                AnimationValue::FontVariantAlternates(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantEastAsian(ref this),
                &AnimationValue::FontVariantEastAsian(ref other),
            ) => {
                AnimationValue::FontVariantEastAsian(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantLigatures(ref this),
                &AnimationValue::FontVariantLigatures(ref other),
            ) => {
                AnimationValue::FontVariantLigatures(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantNumeric(ref this),
                &AnimationValue::FontVariantNumeric(ref other),
            ) => {
                AnimationValue::FontVariantNumeric(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariantPosition(ref this),
                &AnimationValue::FontVariantPosition(ref other),
            ) => {
                AnimationValue::FontVariantPosition(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontFeatureSettings(ref this),
                &AnimationValue::FontFeatureSettings(ref other),
            ) => {
                AnimationValue::FontFeatureSettings(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FontVariationSettings(ref this),
                &AnimationValue::FontVariationSettings(ref other),
            ) => {
                AnimationValue::FontVariationSettings(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FontLanguageOverride(ref this),
                &AnimationValue::FontLanguageOverride(ref other),
            ) => {
                AnimationValue::FontLanguageOverride(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozOsxFontSmoothing(ref this),
                &AnimationValue::MozOsxFontSmoothing(ref other),
            ) => {
                AnimationValue::MozOsxFontSmoothing(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozFontSmoothingBackgroundColor(ref this),
                &AnimationValue::MozFontSmoothingBackgroundColor(ref other),
            ) => {
                AnimationValue::MozFontSmoothingBackgroundColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Visibility(ref this),
                &AnimationValue::Visibility(ref other),
            ) => {
                AnimationValue::Visibility(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WritingMode(ref this),
                &AnimationValue::WritingMode(ref other),
            ) => {
                AnimationValue::WritingMode(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Direction(ref this),
                &AnimationValue::Direction(ref other),
            ) => {
                AnimationValue::Direction(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextOrientation(ref this),
                &AnimationValue::TextOrientation(ref other),
            ) => {
                AnimationValue::TextOrientation(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ColorAdjust(ref this),
                &AnimationValue::ColorAdjust(ref other),
            ) => {
                AnimationValue::ColorAdjust(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ImageRendering(ref this),
                &AnimationValue::ImageRendering(ref other),
            ) => {
                AnimationValue::ImageRendering(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ImageOrientation(ref this),
                &AnimationValue::ImageOrientation(ref other),
            ) => {
                AnimationValue::ImageOrientation(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderCollapse(ref this),
                &AnimationValue::BorderCollapse(ref other),
            ) => {
                AnimationValue::BorderCollapse(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::EmptyCells(ref this),
                &AnimationValue::EmptyCells(ref other),
            ) => {
                AnimationValue::EmptyCells(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::CaptionSide(ref this),
                &AnimationValue::CaptionSide(ref other),
            ) => {
                AnimationValue::CaptionSide(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::BorderSpacing(ref this),
                &AnimationValue::BorderSpacing(ref other),
            ) => {
                AnimationValue::BorderSpacing(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::LineHeight(ref this),
                &AnimationValue::LineHeight(ref other),
            ) => {
                AnimationValue::LineHeight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::TextTransform(ref this),
                &AnimationValue::TextTransform(ref other),
            ) => {
                AnimationValue::TextTransform(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Hyphens(ref this),
                &AnimationValue::Hyphens(ref other),
            ) => {
                AnimationValue::Hyphens(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozTextSizeAdjust(ref this),
                &AnimationValue::MozTextSizeAdjust(ref other),
            ) => {
                AnimationValue::MozTextSizeAdjust(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextIndent(ref this),
                &AnimationValue::TextIndent(ref other),
            ) => {
                AnimationValue::TextIndent(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::OverflowWrap(ref this),
                &AnimationValue::OverflowWrap(ref other),
            ) => {
                AnimationValue::OverflowWrap(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::WordBreak(ref this),
                &AnimationValue::WordBreak(ref other),
            ) => {
                AnimationValue::WordBreak(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextJustify(ref this),
                &AnimationValue::TextJustify(ref other),
            ) => {
                AnimationValue::TextJustify(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextAlignLast(ref this),
                &AnimationValue::TextAlignLast(ref other),
            ) => {
                AnimationValue::TextAlignLast(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextAlign(ref this),
                &AnimationValue::TextAlign(ref other),
            ) => {
                AnimationValue::TextAlign(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::LetterSpacing(ref this),
                &AnimationValue::LetterSpacing(ref other),
            ) => {
                AnimationValue::LetterSpacing(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WordSpacing(ref this),
                &AnimationValue::WordSpacing(ref other),
            ) => {
                AnimationValue::WordSpacing(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WhiteSpace(ref this),
                &AnimationValue::WhiteSpace(ref other),
            ) => {
                AnimationValue::WhiteSpace(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextShadow(ref this),
                &AnimationValue::TextShadow(ref other),
            ) => {
                AnimationValue::TextShadow(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::TextEmphasisStyle(ref this),
                &AnimationValue::TextEmphasisStyle(ref other),
            ) => {
                AnimationValue::TextEmphasisStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextEmphasisPosition(ref this),
                &AnimationValue::TextEmphasisPosition(ref other),
            ) => {
                AnimationValue::TextEmphasisPosition(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextEmphasisColor(ref this),
                &AnimationValue::TextEmphasisColor(ref other),
            ) => {
                AnimationValue::TextEmphasisColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozTabSize(ref this),
                &AnimationValue::MozTabSize(ref other),
            ) => {
                AnimationValue::MozTabSize(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WebkitTextFillColor(ref this),
                &AnimationValue::WebkitTextFillColor(ref other),
            ) => {
                AnimationValue::WebkitTextFillColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WebkitTextStrokeColor(ref this),
                &AnimationValue::WebkitTextStrokeColor(ref other),
            ) => {
                AnimationValue::WebkitTextStrokeColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::WebkitTextStrokeWidth(ref this),
                &AnimationValue::WebkitTextStrokeWidth(ref other),
            ) => {
                AnimationValue::WebkitTextStrokeWidth(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::RubyAlign(ref this),
                &AnimationValue::RubyAlign(ref other),
            ) => {
                AnimationValue::RubyAlign(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::RubyPosition(ref this),
                &AnimationValue::RubyPosition(ref other),
            ) => {
                AnimationValue::RubyPosition(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextCombineUpright(ref this),
                &AnimationValue::TextCombineUpright(ref other),
            ) => {
                AnimationValue::TextCombineUpright(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextRendering(ref this),
                &AnimationValue::TextRendering(ref other),
            ) => {
                AnimationValue::TextRendering(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ListStylePosition(ref this),
                &AnimationValue::ListStylePosition(ref other),
            ) => {
                AnimationValue::ListStylePosition(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ListStyleType(ref this),
                &AnimationValue::ListStyleType(ref other),
            ) => {
                AnimationValue::ListStyleType(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ListStyleImage(ref this),
                &AnimationValue::ListStyleImage(ref other),
            ) => {
                AnimationValue::ListStyleImage(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Quotes(ref this),
                &AnimationValue::Quotes(ref other),
            ) => {
                AnimationValue::Quotes(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozImageRegion(ref this),
                &AnimationValue::MozImageRegion(ref other),
            ) => {
                AnimationValue::MozImageRegion(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MarginTop(ref this),
                &AnimationValue::MarginTop(ref other),
            ) => {
                AnimationValue::MarginTop(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MarginLeft(ref this),
                &AnimationValue::MarginLeft(ref other),
            ) => {
                AnimationValue::MarginLeft(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MarginBottom(ref this),
                &AnimationValue::MarginBottom(ref other),
            ) => {
                AnimationValue::MarginBottom(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MarginRight(ref this),
                &AnimationValue::MarginRight(ref other),
            ) => {
                AnimationValue::MarginRight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::OutlineColor(ref this),
                &AnimationValue::OutlineColor(ref other),
            ) => {
                AnimationValue::OutlineColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::OutlineStyle(ref this),
                &AnimationValue::OutlineStyle(ref other),
            ) => {
                AnimationValue::OutlineStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::OutlineWidth(ref this),
                &AnimationValue::OutlineWidth(ref other),
            ) => {
                AnimationValue::OutlineWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozOutlineRadiusTopleft(ref this),
                &AnimationValue::MozOutlineRadiusTopleft(ref other),
            ) => {
                AnimationValue::MozOutlineRadiusTopleft(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozOutlineRadiusTopright(ref this),
                &AnimationValue::MozOutlineRadiusTopright(ref other),
            ) => {
                AnimationValue::MozOutlineRadiusTopright(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozOutlineRadiusBottomright(ref this),
                &AnimationValue::MozOutlineRadiusBottomright(ref other),
            ) => {
                AnimationValue::MozOutlineRadiusBottomright(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozOutlineRadiusBottomleft(ref this),
                &AnimationValue::MozOutlineRadiusBottomleft(ref other),
            ) => {
                AnimationValue::MozOutlineRadiusBottomleft(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::OutlineOffset(ref this),
                &AnimationValue::OutlineOffset(ref other),
            ) => {
                AnimationValue::OutlineOffset(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::PaddingTop(ref this),
                &AnimationValue::PaddingTop(ref other),
            ) => {
                AnimationValue::PaddingTop(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::PaddingLeft(ref this),
                &AnimationValue::PaddingLeft(ref other),
            ) => {
                AnimationValue::PaddingLeft(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::PaddingBottom(ref this),
                &AnimationValue::PaddingBottom(ref other),
            ) => {
                AnimationValue::PaddingBottom(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::PaddingRight(ref this),
                &AnimationValue::PaddingRight(ref other),
            ) => {
                AnimationValue::PaddingRight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Cursor(ref this),
                &AnimationValue::Cursor(ref other),
            ) => {
                AnimationValue::Cursor(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::PointerEvents(ref this),
                &AnimationValue::PointerEvents(ref other),
            ) => {
                AnimationValue::PointerEvents(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozUserInput(ref this),
                &AnimationValue::MozUserInput(ref other),
            ) => {
                AnimationValue::MozUserInput(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozUserModify(ref this),
                &AnimationValue::MozUserModify(ref other),
            ) => {
                AnimationValue::MozUserModify(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozUserFocus(ref this),
                &AnimationValue::MozUserFocus(ref other),
            ) => {
                AnimationValue::MozUserFocus(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::CaretColor(ref this),
                &AnimationValue::CaretColor(ref other),
            ) => {
                AnimationValue::CaretColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Top(ref this),
                &AnimationValue::Top(ref other),
            ) => {
                AnimationValue::Top(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Left(ref this),
                &AnimationValue::Left(ref other),
            ) => {
                AnimationValue::Left(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Bottom(ref this),
                &AnimationValue::Bottom(ref other),
            ) => {
                AnimationValue::Bottom(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Right(ref this),
                &AnimationValue::Right(ref other),
            ) => {
                AnimationValue::Right(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ZIndex(ref this),
                &AnimationValue::ZIndex(ref other),
            ) => {
                AnimationValue::ZIndex(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FlexDirection(ref this),
                &AnimationValue::FlexDirection(ref other),
            ) => {
                AnimationValue::FlexDirection(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FlexWrap(ref this),
                &AnimationValue::FlexWrap(ref other),
            ) => {
                AnimationValue::FlexWrap(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::JustifyContent(ref this),
                &AnimationValue::JustifyContent(ref other),
            ) => {
                AnimationValue::JustifyContent(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::AlignContent(ref this),
                &AnimationValue::AlignContent(ref other),
            ) => {
                AnimationValue::AlignContent(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::AlignItems(ref this),
                &AnimationValue::AlignItems(ref other),
            ) => {
                AnimationValue::AlignItems(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::JustifyItems(ref this),
                &AnimationValue::JustifyItems(ref other),
            ) => {
                AnimationValue::JustifyItems(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::FlexGrow(ref this),
                &AnimationValue::FlexGrow(ref other),
            ) => {
                AnimationValue::FlexGrow(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FlexShrink(ref this),
                &AnimationValue::FlexShrink(ref other),
            ) => {
                AnimationValue::FlexShrink(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::AlignSelf(ref this),
                &AnimationValue::AlignSelf(ref other),
            ) => {
                AnimationValue::AlignSelf(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::JustifySelf(ref this),
                &AnimationValue::JustifySelf(ref other),
            ) => {
                AnimationValue::JustifySelf(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Order(ref this),
                &AnimationValue::Order(ref other),
            ) => {
                AnimationValue::Order(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FlexBasis(ref this),
                &AnimationValue::FlexBasis(ref other),
            ) => {
                AnimationValue::FlexBasis(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Width(ref this),
                &AnimationValue::Width(ref other),
            ) => {
                AnimationValue::Width(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MinWidth(ref this),
                &AnimationValue::MinWidth(ref other),
            ) => {
                AnimationValue::MinWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaxWidth(ref this),
                &AnimationValue::MaxWidth(ref other),
            ) => {
                AnimationValue::MaxWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::Height(ref this),
                &AnimationValue::Height(ref other),
            ) => {
                AnimationValue::Height(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MinHeight(ref this),
                &AnimationValue::MinHeight(ref other),
            ) => {
                AnimationValue::MinHeight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaxHeight(ref this),
                &AnimationValue::MaxHeight(ref other),
            ) => {
                AnimationValue::MaxHeight(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::BoxSizing(ref this),
                &AnimationValue::BoxSizing(ref other),
            ) => {
                AnimationValue::BoxSizing(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ObjectFit(ref this),
                &AnimationValue::ObjectFit(ref other),
            ) => {
                AnimationValue::ObjectFit(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ObjectPosition(ref this),
                &AnimationValue::ObjectPosition(ref other),
            ) => {
                AnimationValue::ObjectPosition(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::GridRowGap(ref this),
                &AnimationValue::GridRowGap(ref other),
            ) => {
                AnimationValue::GridRowGap(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::GridRowStart(ref this),
                &AnimationValue::GridRowStart(ref other),
            ) => {
                AnimationValue::GridRowStart(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridRowEnd(ref this),
                &AnimationValue::GridRowEnd(ref other),
            ) => {
                AnimationValue::GridRowEnd(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridAutoRows(ref this),
                &AnimationValue::GridAutoRows(ref other),
            ) => {
                AnimationValue::GridAutoRows(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridTemplateRows(ref this),
                &AnimationValue::GridTemplateRows(ref other),
            ) => {
                AnimationValue::GridTemplateRows(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridColumnGap(ref this),
                &AnimationValue::GridColumnGap(ref other),
            ) => {
                AnimationValue::GridColumnGap(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::GridColumnStart(ref this),
                &AnimationValue::GridColumnStart(ref other),
            ) => {
                AnimationValue::GridColumnStart(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridColumnEnd(ref this),
                &AnimationValue::GridColumnEnd(ref other),
            ) => {
                AnimationValue::GridColumnEnd(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridAutoColumns(ref this),
                &AnimationValue::GridAutoColumns(ref other),
            ) => {
                AnimationValue::GridAutoColumns(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridTemplateColumns(ref this),
                &AnimationValue::GridTemplateColumns(ref other),
            ) => {
                AnimationValue::GridTemplateColumns(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridAutoFlow(ref this),
                &AnimationValue::GridAutoFlow(ref other),
            ) => {
                AnimationValue::GridAutoFlow(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::GridTemplateAreas(ref this),
                &AnimationValue::GridTemplateAreas(ref other),
            ) => {
                AnimationValue::GridTemplateAreas(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TableLayout(ref this),
                &AnimationValue::TableLayout(ref other),
            ) => {
                AnimationValue::TableLayout(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextOverflow(ref this),
                &AnimationValue::TextOverflow(ref other),
            ) => {
                AnimationValue::TextOverflow(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::UnicodeBidi(ref this),
                &AnimationValue::UnicodeBidi(ref other),
            ) => {
                AnimationValue::UnicodeBidi(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextDecorationLine(ref this),
                &AnimationValue::TextDecorationLine(ref other),
            ) => {
                AnimationValue::TextDecorationLine(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextDecorationStyle(ref this),
                &AnimationValue::TextDecorationStyle(ref other),
            ) => {
                AnimationValue::TextDecorationStyle(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextDecorationColor(ref this),
                &AnimationValue::TextDecorationColor(ref other),
            ) => {
                AnimationValue::TextDecorationColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::InitialLetter(ref this),
                &AnimationValue::InitialLetter(ref other),
            ) => {
                AnimationValue::InitialLetter(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ImeMode(ref this),
                &AnimationValue::ImeMode(ref other),
            ) => {
                AnimationValue::ImeMode(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozUserSelect(ref this),
                &AnimationValue::MozUserSelect(ref other),
            ) => {
                AnimationValue::MozUserSelect(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozWindowDragging(ref this),
                &AnimationValue::MozWindowDragging(ref other),
            ) => {
                AnimationValue::MozWindowDragging(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozWindowShadow(ref this),
                &AnimationValue::MozWindowShadow(ref other),
            ) => {
                AnimationValue::MozWindowShadow(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozWindowOpacity(ref this),
                &AnimationValue::MozWindowOpacity(ref other),
            ) => {
                AnimationValue::MozWindowOpacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozWindowTransform(ref this),
                &AnimationValue::MozWindowTransform(ref other),
            ) => {
                AnimationValue::MozWindowTransform(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozWindowTransformOrigin(ref this),
                &AnimationValue::MozWindowTransformOrigin(ref other),
            ) => {
                AnimationValue::MozWindowTransformOrigin(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozForceBrokenImageIcon(ref this),
                &AnimationValue::MozForceBrokenImageIcon(ref other),
            ) => {
                AnimationValue::MozForceBrokenImageIcon(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::TextAnchor(ref this),
                &AnimationValue::TextAnchor(ref other),
            ) => {
                AnimationValue::TextAnchor(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ColorInterpolation(ref this),
                &AnimationValue::ColorInterpolation(ref other),
            ) => {
                AnimationValue::ColorInterpolation(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ColorInterpolationFilters(ref this),
                &AnimationValue::ColorInterpolationFilters(ref other),
            ) => {
                AnimationValue::ColorInterpolationFilters(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Fill(ref this),
                &AnimationValue::Fill(ref other),
            ) => {
                AnimationValue::Fill(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FillOpacity(ref this),
                &AnimationValue::FillOpacity(ref other),
            ) => {
                AnimationValue::FillOpacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FillRule(ref this),
                &AnimationValue::FillRule(ref other),
            ) => {
                AnimationValue::FillRule(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ShapeRendering(ref this),
                &AnimationValue::ShapeRendering(ref other),
            ) => {
                AnimationValue::ShapeRendering(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::Stroke(ref this),
                &AnimationValue::Stroke(ref other),
            ) => {
                AnimationValue::Stroke(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StrokeWidth(ref this),
                &AnimationValue::StrokeWidth(ref other),
            ) => {
                AnimationValue::StrokeWidth(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StrokeLinecap(ref this),
                &AnimationValue::StrokeLinecap(ref other),
            ) => {
                AnimationValue::StrokeLinecap(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::StrokeLinejoin(ref this),
                &AnimationValue::StrokeLinejoin(ref other),
            ) => {
                AnimationValue::StrokeLinejoin(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::StrokeMiterlimit(ref this),
                &AnimationValue::StrokeMiterlimit(ref other),
            ) => {
                AnimationValue::StrokeMiterlimit(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StrokeOpacity(ref this),
                &AnimationValue::StrokeOpacity(ref other),
            ) => {
                AnimationValue::StrokeOpacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StrokeDasharray(ref this),
                &AnimationValue::StrokeDasharray(ref other),
            ) => {
                AnimationValue::StrokeDasharray(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StrokeDashoffset(ref this),
                &AnimationValue::StrokeDashoffset(ref other),
            ) => {
                AnimationValue::StrokeDashoffset(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::ClipRule(ref this),
                &AnimationValue::ClipRule(ref other),
            ) => {
                AnimationValue::ClipRule(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MarkerStart(ref this),
                &AnimationValue::MarkerStart(ref other),
            ) => {
                AnimationValue::MarkerStart(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MarkerMid(ref this),
                &AnimationValue::MarkerMid(ref other),
            ) => {
                AnimationValue::MarkerMid(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MarkerEnd(ref this),
                &AnimationValue::MarkerEnd(ref other),
            ) => {
                AnimationValue::MarkerEnd(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::PaintOrder(ref this),
                &AnimationValue::PaintOrder(ref other),
            ) => {
                AnimationValue::PaintOrder(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::DominantBaseline(ref this),
                &AnimationValue::DominantBaseline(ref other),
            ) => {
                AnimationValue::DominantBaseline(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::VectorEffect(ref this),
                &AnimationValue::VectorEffect(ref other),
            ) => {
                AnimationValue::VectorEffect(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::StopColor(ref this),
                &AnimationValue::StopColor(ref other),
            ) => {
                AnimationValue::StopColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::StopOpacity(ref this),
                &AnimationValue::StopOpacity(ref other),
            ) => {
                AnimationValue::StopOpacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FloodColor(ref this),
                &AnimationValue::FloodColor(ref other),
            ) => {
                AnimationValue::FloodColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::FloodOpacity(ref this),
                &AnimationValue::FloodOpacity(ref other),
            ) => {
                AnimationValue::FloodOpacity(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::LightingColor(ref this),
                &AnimationValue::LightingColor(ref other),
            ) => {
                AnimationValue::LightingColor(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaskType(ref this),
                &AnimationValue::MaskType(ref other),
            ) => {
                AnimationValue::MaskType(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::ClipPath(ref this),
                &AnimationValue::ClipPath(ref other),
            ) => {
                AnimationValue::ClipPath(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaskMode(ref this),
                &AnimationValue::MaskMode(ref other),
            ) => {
                AnimationValue::MaskMode(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MaskRepeat(ref this),
                &AnimationValue::MaskRepeat(ref other),
            ) => {
                AnimationValue::MaskRepeat(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MaskPositionX(ref this),
                &AnimationValue::MaskPositionX(ref other),
            ) => {
                AnimationValue::MaskPositionX(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaskPositionY(ref this),
                &AnimationValue::MaskPositionY(ref other),
            ) => {
                AnimationValue::MaskPositionY(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaskClip(ref this),
                &AnimationValue::MaskClip(ref other),
            ) => {
                AnimationValue::MaskClip(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MaskOrigin(ref this),
                &AnimationValue::MaskOrigin(ref other),
            ) => {
                AnimationValue::MaskOrigin(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MaskSize(ref this),
                &AnimationValue::MaskSize(ref other),
            ) => {
                AnimationValue::MaskSize(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MaskComposite(ref this),
                &AnimationValue::MaskComposite(ref other),
            ) => {
                AnimationValue::MaskComposite(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MaskImage(ref this),
                &AnimationValue::MaskImage(ref other),
            ) => {
                AnimationValue::MaskImage(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBoxAlign(ref this),
                &AnimationValue::MozBoxAlign(ref other),
            ) => {
                AnimationValue::MozBoxAlign(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBoxDirection(ref this),
                &AnimationValue::MozBoxDirection(ref other),
            ) => {
                AnimationValue::MozBoxDirection(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBoxFlex(ref this),
                &AnimationValue::MozBoxFlex(ref other),
            ) => {
                AnimationValue::MozBoxFlex(
                    this.animate(other, procedure)?,
                )
            },
            (
                &AnimationValue::MozBoxOrient(ref this),
                &AnimationValue::MozBoxOrient(ref other),
            ) => {
                AnimationValue::MozBoxOrient(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBoxPack(ref this),
                &AnimationValue::MozBoxPack(ref other),
            ) => {
                AnimationValue::MozBoxPack(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozStackSizing(ref this),
                &AnimationValue::MozStackSizing(ref other),
            ) => {
                AnimationValue::MozStackSizing(
                    animate_discrete(this, other, procedure)?
                )
            },
            (
                &AnimationValue::MozBoxOrdinalGroup(ref this),
                &AnimationValue::MozBoxOrdinalGroup(ref other),
            ) => {
                AnimationValue::MozBoxOrdinalGroup(
                    animate_discrete(this, other, procedure)?
                )
            },
            _ => {
                panic!("Unexpected AnimationValue::animate call");
            }
        };
        Ok(value)
    }
}

impl ComputeSquaredDistance for AnimationValue {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        match *self {
            AnimationValue::BackgroundImage(..)
            |
            AnimationValue::BackgroundRepeat(..)
            |
            AnimationValue::BackgroundAttachment(..)
            |
            AnimationValue::BackgroundClip(..)
            |
            AnimationValue::BackgroundOrigin(..)
            |
            AnimationValue::BackgroundBlendMode(..)
            |
            AnimationValue::BorderTopStyle(..)
            |
            AnimationValue::BorderLeftStyle(..)
            |
            AnimationValue::BorderBottomStyle(..)
            |
            AnimationValue::BorderRightStyle(..)
            |
            AnimationValue::MozBorderTopColors(..)
            |
            AnimationValue::MozBorderLeftColors(..)
            |
            AnimationValue::MozBorderBottomColors(..)
            |
            AnimationValue::MozBorderRightColors(..)
            |
            AnimationValue::BoxDecorationBreak(..)
            |
            AnimationValue::MozFloatEdge(..)
            |
            AnimationValue::BorderImageSource(..)
            |
            AnimationValue::BorderImageOutset(..)
            |
            AnimationValue::BorderImageRepeat(..)
            |
            AnimationValue::BorderImageWidth(..)
            |
            AnimationValue::BorderImageSlice(..)
            |
            AnimationValue::Display(..)
            |
            AnimationValue::Position(..)
            |
            AnimationValue::Float(..)
            |
            AnimationValue::Clear(..)
            |
            AnimationValue::OverflowClipBoxInline(..)
            |
            AnimationValue::OverflowClipBoxBlock(..)
            |
            AnimationValue::OverflowX(..)
            |
            AnimationValue::OverflowY(..)
            |
            AnimationValue::ScrollSnapPointsX(..)
            |
            AnimationValue::ScrollSnapPointsY(..)
            |
            AnimationValue::ScrollSnapDestination(..)
            |
            AnimationValue::ScrollSnapCoordinate(..)
            |
            AnimationValue::ScrollBehavior(..)
            |
            AnimationValue::ScrollSnapTypeX(..)
            |
            AnimationValue::ScrollSnapTypeY(..)
            |
            AnimationValue::OverscrollBehaviorX(..)
            |
            AnimationValue::OverscrollBehaviorY(..)
            |
            AnimationValue::Isolation(..)
            |
            AnimationValue::PageBreakAfter(..)
            |
            AnimationValue::PageBreakBefore(..)
            |
            AnimationValue::PageBreakInside(..)
            |
            AnimationValue::Resize(..)
            |
            AnimationValue::BackfaceVisibility(..)
            |
            AnimationValue::TransformBox(..)
            |
            AnimationValue::TransformStyle(..)
            |
            AnimationValue::Contain(..)
            |
            AnimationValue::MozAppearance(..)
            |
            AnimationValue::MozOrient(..)
            |
            AnimationValue::WillChange(..)
            |
            AnimationValue::TouchAction(..)
            |
            AnimationValue::ColumnFill(..)
            |
            AnimationValue::ColumnSpan(..)
            |
            AnimationValue::ColumnRuleStyle(..)
            |
            AnimationValue::Content(..)
            |
            AnimationValue::CounterIncrement(..)
            |
            AnimationValue::CounterReset(..)
            |
            AnimationValue::MixBlendMode(..)
            |
            AnimationValue::FontFamily(..)
            |
            AnimationValue::FontStyle(..)
            |
            AnimationValue::FontVariantCaps(..)
            |
            AnimationValue::FontSynthesis(..)
            |
            AnimationValue::FontKerning(..)
            |
            AnimationValue::FontVariantAlternates(..)
            |
            AnimationValue::FontVariantEastAsian(..)
            |
            AnimationValue::FontVariantLigatures(..)
            |
            AnimationValue::FontVariantNumeric(..)
            |
            AnimationValue::FontVariantPosition(..)
            |
            AnimationValue::FontFeatureSettings(..)
            |
            AnimationValue::FontLanguageOverride(..)
            |
            AnimationValue::MozOsxFontSmoothing(..)
            |
            AnimationValue::WritingMode(..)
            |
            AnimationValue::Direction(..)
            |
            AnimationValue::TextOrientation(..)
            |
            AnimationValue::ColorAdjust(..)
            |
            AnimationValue::ImageRendering(..)
            |
            AnimationValue::ImageOrientation(..)
            |
            AnimationValue::BorderCollapse(..)
            |
            AnimationValue::EmptyCells(..)
            |
            AnimationValue::CaptionSide(..)
            |
            AnimationValue::TextTransform(..)
            |
            AnimationValue::Hyphens(..)
            |
            AnimationValue::MozTextSizeAdjust(..)
            |
            AnimationValue::OverflowWrap(..)
            |
            AnimationValue::WordBreak(..)
            |
            AnimationValue::TextJustify(..)
            |
            AnimationValue::TextAlignLast(..)
            |
            AnimationValue::TextAlign(..)
            |
            AnimationValue::WhiteSpace(..)
            |
            AnimationValue::TextEmphasisStyle(..)
            |
            AnimationValue::TextEmphasisPosition(..)
            |
            AnimationValue::WebkitTextStrokeWidth(..)
            |
            AnimationValue::RubyAlign(..)
            |
            AnimationValue::RubyPosition(..)
            |
            AnimationValue::TextCombineUpright(..)
            |
            AnimationValue::TextRendering(..)
            |
            AnimationValue::ListStylePosition(..)
            |
            AnimationValue::ListStyleType(..)
            |
            AnimationValue::ListStyleImage(..)
            |
            AnimationValue::Quotes(..)
            |
            AnimationValue::OutlineStyle(..)
            |
            AnimationValue::Cursor(..)
            |
            AnimationValue::PointerEvents(..)
            |
            AnimationValue::MozUserInput(..)
            |
            AnimationValue::MozUserModify(..)
            |
            AnimationValue::MozUserFocus(..)
            |
            AnimationValue::FlexDirection(..)
            |
            AnimationValue::FlexWrap(..)
            |
            AnimationValue::JustifyContent(..)
            |
            AnimationValue::AlignContent(..)
            |
            AnimationValue::AlignItems(..)
            |
            AnimationValue::JustifyItems(..)
            |
            AnimationValue::AlignSelf(..)
            |
            AnimationValue::JustifySelf(..)
            |
            AnimationValue::BoxSizing(..)
            |
            AnimationValue::ObjectFit(..)
            |
            AnimationValue::GridRowStart(..)
            |
            AnimationValue::GridRowEnd(..)
            |
            AnimationValue::GridAutoRows(..)
            |
            AnimationValue::GridTemplateRows(..)
            |
            AnimationValue::GridColumnStart(..)
            |
            AnimationValue::GridColumnEnd(..)
            |
            AnimationValue::GridAutoColumns(..)
            |
            AnimationValue::GridTemplateColumns(..)
            |
            AnimationValue::GridAutoFlow(..)
            |
            AnimationValue::GridTemplateAreas(..)
            |
            AnimationValue::TableLayout(..)
            |
            AnimationValue::TextOverflow(..)
            |
            AnimationValue::UnicodeBidi(..)
            |
            AnimationValue::TextDecorationLine(..)
            |
            AnimationValue::TextDecorationStyle(..)
            |
            AnimationValue::InitialLetter(..)
            |
            AnimationValue::ImeMode(..)
            |
            AnimationValue::MozUserSelect(..)
            |
            AnimationValue::MozWindowDragging(..)
            |
            AnimationValue::MozWindowShadow(..)
            |
            AnimationValue::MozForceBrokenImageIcon(..)
            |
            AnimationValue::TextAnchor(..)
            |
            AnimationValue::ColorInterpolation(..)
            |
            AnimationValue::ColorInterpolationFilters(..)
            |
            AnimationValue::FillRule(..)
            |
            AnimationValue::ShapeRendering(..)
            |
            AnimationValue::StrokeLinecap(..)
            |
            AnimationValue::StrokeLinejoin(..)
            |
            AnimationValue::ClipRule(..)
            |
            AnimationValue::MarkerStart(..)
            |
            AnimationValue::MarkerMid(..)
            |
            AnimationValue::MarkerEnd(..)
            |
            AnimationValue::PaintOrder(..)
            |
            AnimationValue::DominantBaseline(..)
            |
            AnimationValue::VectorEffect(..)
            |
            AnimationValue::MaskType(..)
            |
            AnimationValue::MaskMode(..)
            |
            AnimationValue::MaskRepeat(..)
            |
            AnimationValue::MaskClip(..)
            |
            AnimationValue::MaskOrigin(..)
            |
            AnimationValue::MaskComposite(..)
            |
            AnimationValue::MaskImage(..)
            |
            AnimationValue::MozBoxAlign(..)
            |
            AnimationValue::MozBoxDirection(..)
            |
            AnimationValue::MozBoxOrient(..)
            |
            AnimationValue::MozBoxPack(..)
            |
            AnimationValue::MozStackSizing(..)
            |
            AnimationValue::MozBoxOrdinalGroup(..)
            => return Err(()),
            _ => (),
        }
        match (self, other) {
            (&AnimationValue::BackgroundColor(ref this), &AnimationValue::BackgroundColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BackgroundPositionX(ref this), &AnimationValue::BackgroundPositionX(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BackgroundPositionY(ref this), &AnimationValue::BackgroundPositionY(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BackgroundSize(ref this), &AnimationValue::BackgroundSize(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderTopColor(ref this), &AnimationValue::BorderTopColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderTopWidth(ref this), &AnimationValue::BorderTopWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderLeftColor(ref this), &AnimationValue::BorderLeftColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderLeftWidth(ref this), &AnimationValue::BorderLeftWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderBottomColor(ref this), &AnimationValue::BorderBottomColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderBottomWidth(ref this), &AnimationValue::BorderBottomWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderRightColor(ref this), &AnimationValue::BorderRightColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderRightWidth(ref this), &AnimationValue::BorderRightWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderTopLeftRadius(ref this), &AnimationValue::BorderTopLeftRadius(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderTopRightRadius(ref this), &AnimationValue::BorderTopRightRadius(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderBottomRightRadius(ref this), &AnimationValue::BorderBottomRightRadius(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderBottomLeftRadius(ref this), &AnimationValue::BorderBottomLeftRadius(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::VerticalAlign(ref this), &AnimationValue::VerticalAlign(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Transform(ref this), &AnimationValue::Transform(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Perspective(ref this), &AnimationValue::Perspective(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::PerspectiveOrigin(ref this), &AnimationValue::PerspectiveOrigin(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::TransformOrigin(ref this), &AnimationValue::TransformOrigin(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ShapeImageThreshold(ref this), &AnimationValue::ShapeImageThreshold(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ShapeOutside(ref this), &AnimationValue::ShapeOutside(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Color(ref this), &AnimationValue::Color(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ColumnWidth(ref this), &AnimationValue::ColumnWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ColumnCount(ref this), &AnimationValue::ColumnCount(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ColumnGap(ref this), &AnimationValue::ColumnGap(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ColumnRuleWidth(ref this), &AnimationValue::ColumnRuleWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ColumnRuleColor(ref this), &AnimationValue::ColumnRuleColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Opacity(ref this), &AnimationValue::Opacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BoxShadow(ref this), &AnimationValue::BoxShadow(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Clip(ref this), &AnimationValue::Clip(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Filter(ref this), &AnimationValue::Filter(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FontWeight(ref this), &AnimationValue::FontWeight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FontSize(ref this), &AnimationValue::FontSize(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FontSizeAdjust(ref this), &AnimationValue::FontSizeAdjust(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FontStretch(ref this), &AnimationValue::FontStretch(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FontVariationSettings(ref this), &AnimationValue::FontVariationSettings(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozFontSmoothingBackgroundColor(ref this), &AnimationValue::MozFontSmoothingBackgroundColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Visibility(ref this), &AnimationValue::Visibility(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::BorderSpacing(ref this), &AnimationValue::BorderSpacing(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::LineHeight(ref this), &AnimationValue::LineHeight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::TextIndent(ref this), &AnimationValue::TextIndent(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::LetterSpacing(ref this), &AnimationValue::LetterSpacing(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::WordSpacing(ref this), &AnimationValue::WordSpacing(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::TextShadow(ref this), &AnimationValue::TextShadow(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::TextEmphasisColor(ref this), &AnimationValue::TextEmphasisColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozTabSize(ref this), &AnimationValue::MozTabSize(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::WebkitTextFillColor(ref this), &AnimationValue::WebkitTextFillColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::WebkitTextStrokeColor(ref this), &AnimationValue::WebkitTextStrokeColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozImageRegion(ref this), &AnimationValue::MozImageRegion(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MarginTop(ref this), &AnimationValue::MarginTop(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MarginLeft(ref this), &AnimationValue::MarginLeft(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MarginBottom(ref this), &AnimationValue::MarginBottom(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MarginRight(ref this), &AnimationValue::MarginRight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::OutlineColor(ref this), &AnimationValue::OutlineColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::OutlineWidth(ref this), &AnimationValue::OutlineWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozOutlineRadiusTopleft(ref this), &AnimationValue::MozOutlineRadiusTopleft(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozOutlineRadiusTopright(ref this), &AnimationValue::MozOutlineRadiusTopright(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozOutlineRadiusBottomright(ref this), &AnimationValue::MozOutlineRadiusBottomright(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozOutlineRadiusBottomleft(ref this), &AnimationValue::MozOutlineRadiusBottomleft(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::OutlineOffset(ref this), &AnimationValue::OutlineOffset(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::PaddingTop(ref this), &AnimationValue::PaddingTop(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::PaddingLeft(ref this), &AnimationValue::PaddingLeft(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::PaddingBottom(ref this), &AnimationValue::PaddingBottom(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::PaddingRight(ref this), &AnimationValue::PaddingRight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::CaretColor(ref this), &AnimationValue::CaretColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Top(ref this), &AnimationValue::Top(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Left(ref this), &AnimationValue::Left(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Bottom(ref this), &AnimationValue::Bottom(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Right(ref this), &AnimationValue::Right(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ZIndex(ref this), &AnimationValue::ZIndex(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FlexGrow(ref this), &AnimationValue::FlexGrow(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FlexShrink(ref this), &AnimationValue::FlexShrink(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Order(ref this), &AnimationValue::Order(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FlexBasis(ref this), &AnimationValue::FlexBasis(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Width(ref this), &AnimationValue::Width(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MinWidth(ref this), &AnimationValue::MinWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MaxWidth(ref this), &AnimationValue::MaxWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Height(ref this), &AnimationValue::Height(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MinHeight(ref this), &AnimationValue::MinHeight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MaxHeight(ref this), &AnimationValue::MaxHeight(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ObjectPosition(ref this), &AnimationValue::ObjectPosition(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::GridRowGap(ref this), &AnimationValue::GridRowGap(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::GridColumnGap(ref this), &AnimationValue::GridColumnGap(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::TextDecorationColor(ref this), &AnimationValue::TextDecorationColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozWindowOpacity(ref this), &AnimationValue::MozWindowOpacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozWindowTransform(ref this), &AnimationValue::MozWindowTransform(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozWindowTransformOrigin(ref this), &AnimationValue::MozWindowTransformOrigin(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Fill(ref this), &AnimationValue::Fill(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FillOpacity(ref this), &AnimationValue::FillOpacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::Stroke(ref this), &AnimationValue::Stroke(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StrokeWidth(ref this), &AnimationValue::StrokeWidth(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StrokeMiterlimit(ref this), &AnimationValue::StrokeMiterlimit(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StrokeOpacity(ref this), &AnimationValue::StrokeOpacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StrokeDasharray(ref this), &AnimationValue::StrokeDasharray(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StrokeDashoffset(ref this), &AnimationValue::StrokeDashoffset(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StopColor(ref this), &AnimationValue::StopColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::StopOpacity(ref this), &AnimationValue::StopOpacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FloodColor(ref this), &AnimationValue::FloodColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::FloodOpacity(ref this), &AnimationValue::FloodOpacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::LightingColor(ref this), &AnimationValue::LightingColor(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::ClipPath(ref this), &AnimationValue::ClipPath(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MaskPositionX(ref this), &AnimationValue::MaskPositionX(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MaskPositionY(ref this), &AnimationValue::MaskPositionY(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MaskSize(ref this), &AnimationValue::MaskSize(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&AnimationValue::MozBoxFlex(ref this), &AnimationValue::MozBoxFlex(ref other)) => {
                this.compute_squared_distance(other)
            },
            _ => {
                panic!("computed values should be of the same property");
            },
        }
    }
}

impl ToAnimatedZero for AnimationValue {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            AnimationValue::BackgroundColor(ref base) => {
                Ok(AnimationValue::BackgroundColor(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionX(ref base) => {
                Ok(AnimationValue::BackgroundPositionX(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionY(ref base) => {
                Ok(AnimationValue::BackgroundPositionY(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundSize(ref base) => {
                Ok(AnimationValue::BackgroundSize(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopColor(ref base) => {
                Ok(AnimationValue::BorderTopColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopWidth(ref base) => {
                Ok(AnimationValue::BorderTopWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftColor(ref base) => {
                Ok(AnimationValue::BorderLeftColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftWidth(ref base) => {
                Ok(AnimationValue::BorderLeftWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomColor(ref base) => {
                Ok(AnimationValue::BorderBottomColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomWidth(ref base) => {
                Ok(AnimationValue::BorderBottomWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightColor(ref base) => {
                Ok(AnimationValue::BorderRightColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightWidth(ref base) => {
                Ok(AnimationValue::BorderRightWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopLeftRadius(ref base) => {
                Ok(AnimationValue::BorderTopLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopRightRadius(ref base) => {
                Ok(AnimationValue::BorderTopRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomRightRadius(ref base) => {
                Ok(AnimationValue::BorderBottomRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomLeftRadius(ref base) => {
                Ok(AnimationValue::BorderBottomLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::VerticalAlign(ref base) => {
                Ok(AnimationValue::VerticalAlign(base.to_animated_zero()?))
            },
            AnimationValue::Transform(ref base) => {
                Ok(AnimationValue::Transform(base.to_animated_zero()?))
            },
            AnimationValue::Perspective(ref base) => {
                Ok(AnimationValue::Perspective(base.to_animated_zero()?))
            },
            AnimationValue::PerspectiveOrigin(ref base) => {
                Ok(AnimationValue::PerspectiveOrigin(base.to_animated_zero()?))
            },
            AnimationValue::TransformOrigin(ref base) => {
                Ok(AnimationValue::TransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::ShapeImageThreshold(ref base) => {
                Ok(AnimationValue::ShapeImageThreshold(base.to_animated_zero()?))
            },
            AnimationValue::ShapeOutside(ref base) => {
                Ok(AnimationValue::ShapeOutside(base.to_animated_zero()?))
            },
            AnimationValue::Color(ref base) => {
                Ok(AnimationValue::Color(base.to_animated_zero()?))
            },
            AnimationValue::ColumnWidth(ref base) => {
                Ok(AnimationValue::ColumnWidth(base.to_animated_zero()?))
            },
            AnimationValue::ColumnCount(ref base) => {
                Ok(AnimationValue::ColumnCount(base.to_animated_zero()?))
            },
            AnimationValue::ColumnGap(ref base) => {
                Ok(AnimationValue::ColumnGap(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleWidth(ref base) => {
                Ok(AnimationValue::ColumnRuleWidth(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleColor(ref base) => {
                Ok(AnimationValue::ColumnRuleColor(base.to_animated_zero()?))
            },
            AnimationValue::Opacity(ref base) => {
                Ok(AnimationValue::Opacity(base.to_animated_zero()?))
            },
            AnimationValue::BoxShadow(ref base) => {
                Ok(AnimationValue::BoxShadow(base.to_animated_zero()?))
            },
            AnimationValue::Clip(ref base) => {
                Ok(AnimationValue::Clip(base.to_animated_zero()?))
            },
            AnimationValue::Filter(ref base) => {
                Ok(AnimationValue::Filter(base.to_animated_zero()?))
            },
            AnimationValue::FontWeight(ref base) => {
                Ok(AnimationValue::FontWeight(base.to_animated_zero()?))
            },
            AnimationValue::FontSize(ref base) => {
                Ok(AnimationValue::FontSize(base.to_animated_zero()?))
            },
            AnimationValue::FontSizeAdjust(ref base) => {
                Ok(AnimationValue::FontSizeAdjust(base.to_animated_zero()?))
            },
            AnimationValue::FontStretch(ref base) => {
                Ok(AnimationValue::FontStretch(base.to_animated_zero()?))
            },
            AnimationValue::FontVariationSettings(ref base) => {
                Ok(AnimationValue::FontVariationSettings(base.to_animated_zero()?))
            },
            AnimationValue::MozFontSmoothingBackgroundColor(ref base) => {
                Ok(AnimationValue::MozFontSmoothingBackgroundColor(base.to_animated_zero()?))
            },
            AnimationValue::Visibility(ref base) => {
                Ok(AnimationValue::Visibility(base.to_animated_zero()?))
            },
            AnimationValue::BorderSpacing(ref base) => {
                Ok(AnimationValue::BorderSpacing(base.to_animated_zero()?))
            },
            AnimationValue::LineHeight(ref base) => {
                Ok(AnimationValue::LineHeight(base.to_animated_zero()?))
            },
            AnimationValue::TextIndent(ref base) => {
                Ok(AnimationValue::TextIndent(base.to_animated_zero()?))
            },
            AnimationValue::LetterSpacing(ref base) => {
                Ok(AnimationValue::LetterSpacing(base.to_animated_zero()?))
            },
            AnimationValue::WordSpacing(ref base) => {
                Ok(AnimationValue::WordSpacing(base.to_animated_zero()?))
            },
            AnimationValue::TextShadow(ref base) => {
                Ok(AnimationValue::TextShadow(base.to_animated_zero()?))
            },
            AnimationValue::TextEmphasisColor(ref base) => {
                Ok(AnimationValue::TextEmphasisColor(base.to_animated_zero()?))
            },
            AnimationValue::MozTabSize(ref base) => {
                Ok(AnimationValue::MozTabSize(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextFillColor(ref base) => {
                Ok(AnimationValue::WebkitTextFillColor(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextStrokeColor(ref base) => {
                Ok(AnimationValue::WebkitTextStrokeColor(base.to_animated_zero()?))
            },
            AnimationValue::MozImageRegion(ref base) => {
                Ok(AnimationValue::MozImageRegion(base.to_animated_zero()?))
            },
            AnimationValue::MarginTop(ref base) => {
                Ok(AnimationValue::MarginTop(base.to_animated_zero()?))
            },
            AnimationValue::MarginLeft(ref base) => {
                Ok(AnimationValue::MarginLeft(base.to_animated_zero()?))
            },
            AnimationValue::MarginBottom(ref base) => {
                Ok(AnimationValue::MarginBottom(base.to_animated_zero()?))
            },
            AnimationValue::MarginRight(ref base) => {
                Ok(AnimationValue::MarginRight(base.to_animated_zero()?))
            },
            AnimationValue::OutlineColor(ref base) => {
                Ok(AnimationValue::OutlineColor(base.to_animated_zero()?))
            },
            AnimationValue::OutlineWidth(ref base) => {
                Ok(AnimationValue::OutlineWidth(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusTopleft(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusTopleft(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusTopright(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusTopright(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusBottomright(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusBottomright(base.to_animated_zero()?))
            },
            AnimationValue::MozOutlineRadiusBottomleft(ref base) => {
                Ok(AnimationValue::MozOutlineRadiusBottomleft(base.to_animated_zero()?))
            },
            AnimationValue::OutlineOffset(ref base) => {
                Ok(AnimationValue::OutlineOffset(base.to_animated_zero()?))
            },
            AnimationValue::PaddingTop(ref base) => {
                Ok(AnimationValue::PaddingTop(base.to_animated_zero()?))
            },
            AnimationValue::PaddingLeft(ref base) => {
                Ok(AnimationValue::PaddingLeft(base.to_animated_zero()?))
            },
            AnimationValue::PaddingBottom(ref base) => {
                Ok(AnimationValue::PaddingBottom(base.to_animated_zero()?))
            },
            AnimationValue::PaddingRight(ref base) => {
                Ok(AnimationValue::PaddingRight(base.to_animated_zero()?))
            },
            AnimationValue::CaretColor(ref base) => {
                Ok(AnimationValue::CaretColor(base.to_animated_zero()?))
            },
            AnimationValue::Top(ref base) => {
                Ok(AnimationValue::Top(base.to_animated_zero()?))
            },
            AnimationValue::Left(ref base) => {
                Ok(AnimationValue::Left(base.to_animated_zero()?))
            },
            AnimationValue::Bottom(ref base) => {
                Ok(AnimationValue::Bottom(base.to_animated_zero()?))
            },
            AnimationValue::Right(ref base) => {
                Ok(AnimationValue::Right(base.to_animated_zero()?))
            },
            AnimationValue::ZIndex(ref base) => {
                Ok(AnimationValue::ZIndex(base.to_animated_zero()?))
            },
            AnimationValue::FlexGrow(ref base) => {
                Ok(AnimationValue::FlexGrow(base.to_animated_zero()?))
            },
            AnimationValue::FlexShrink(ref base) => {
                Ok(AnimationValue::FlexShrink(base.to_animated_zero()?))
            },
            AnimationValue::Order(ref base) => {
                Ok(AnimationValue::Order(base.to_animated_zero()?))
            },
            AnimationValue::FlexBasis(ref base) => {
                Ok(AnimationValue::FlexBasis(base.to_animated_zero()?))
            },
            AnimationValue::Width(ref base) => {
                Ok(AnimationValue::Width(base.to_animated_zero()?))
            },
            AnimationValue::MinWidth(ref base) => {
                Ok(AnimationValue::MinWidth(base.to_animated_zero()?))
            },
            AnimationValue::MaxWidth(ref base) => {
                Ok(AnimationValue::MaxWidth(base.to_animated_zero()?))
            },
            AnimationValue::Height(ref base) => {
                Ok(AnimationValue::Height(base.to_animated_zero()?))
            },
            AnimationValue::MinHeight(ref base) => {
                Ok(AnimationValue::MinHeight(base.to_animated_zero()?))
            },
            AnimationValue::MaxHeight(ref base) => {
                Ok(AnimationValue::MaxHeight(base.to_animated_zero()?))
            },
            AnimationValue::ObjectPosition(ref base) => {
                Ok(AnimationValue::ObjectPosition(base.to_animated_zero()?))
            },
            AnimationValue::GridRowGap(ref base) => {
                Ok(AnimationValue::GridRowGap(base.to_animated_zero()?))
            },
            AnimationValue::GridColumnGap(ref base) => {
                Ok(AnimationValue::GridColumnGap(base.to_animated_zero()?))
            },
            AnimationValue::TextDecorationColor(ref base) => {
                Ok(AnimationValue::TextDecorationColor(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowOpacity(ref base) => {
                Ok(AnimationValue::MozWindowOpacity(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransform(ref base) => {
                Ok(AnimationValue::MozWindowTransform(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransformOrigin(ref base) => {
                Ok(AnimationValue::MozWindowTransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::Fill(ref base) => {
                Ok(AnimationValue::Fill(base.to_animated_zero()?))
            },
            AnimationValue::FillOpacity(ref base) => {
                Ok(AnimationValue::FillOpacity(base.to_animated_zero()?))
            },
            AnimationValue::Stroke(ref base) => {
                Ok(AnimationValue::Stroke(base.to_animated_zero()?))
            },
            AnimationValue::StrokeWidth(ref base) => {
                Ok(AnimationValue::StrokeWidth(base.to_animated_zero()?))
            },
            AnimationValue::StrokeMiterlimit(ref base) => {
                Ok(AnimationValue::StrokeMiterlimit(base.to_animated_zero()?))
            },
            AnimationValue::StrokeOpacity(ref base) => {
                Ok(AnimationValue::StrokeOpacity(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDasharray(ref base) => {
                Ok(AnimationValue::StrokeDasharray(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDashoffset(ref base) => {
                Ok(AnimationValue::StrokeDashoffset(base.to_animated_zero()?))
            },
            AnimationValue::StopColor(ref base) => {
                Ok(AnimationValue::StopColor(base.to_animated_zero()?))
            },
            AnimationValue::StopOpacity(ref base) => {
                Ok(AnimationValue::StopOpacity(base.to_animated_zero()?))
            },
            AnimationValue::FloodColor(ref base) => {
                Ok(AnimationValue::FloodColor(base.to_animated_zero()?))
            },
            AnimationValue::FloodOpacity(ref base) => {
                Ok(AnimationValue::FloodOpacity(base.to_animated_zero()?))
            },
            AnimationValue::LightingColor(ref base) => {
                Ok(AnimationValue::LightingColor(base.to_animated_zero()?))
            },
            AnimationValue::ClipPath(ref base) => {
                Ok(AnimationValue::ClipPath(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionX(ref base) => {
                Ok(AnimationValue::MaskPositionX(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionY(ref base) => {
                Ok(AnimationValue::MaskPositionY(base.to_animated_zero()?))
            },
            AnimationValue::MaskSize(ref base) => {
                Ok(AnimationValue::MaskSize(base.to_animated_zero()?))
            },
            AnimationValue::MozBoxFlex(ref base) => {
                Ok(AnimationValue::MozBoxFlex(base.to_animated_zero()?))
            },
            _ => Err(()),
        }
    }
}

impl RepeatableListAnimatable for LengthOrPercentage {}
impl RepeatableListAnimatable for Either<f32, LengthOrPercentage> {}
impl RepeatableListAnimatable for Either<NonNegativeNumber, NonNegativeLengthOrPercentage> {}
impl RepeatableListAnimatable for SvgLengthOrPercentageOrNumber<NonNegativeLengthOrPercentage, NonNegativeNumber> {}

macro_rules! repeated_vec_impl {
    ($($ty:ty),*) => {
        $(impl<T> Animate for $ty
        where
            T: RepeatableListAnimatable,
        {
            fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
                // If the length of either list is zero, the least common multiple is undefined.
                if self.is_empty() || other.is_empty() {
                    return Err(());
                }
                use num_integer::lcm;
                let len = lcm(self.len(), other.len());
                self.iter().cycle().zip(other.iter().cycle()).take(len).map(|(this, other)| {
                    this.animate(other, procedure)
                }).collect()
            }
        }

        impl<T> ComputeSquaredDistance for $ty
        where
            T: ComputeSquaredDistance + RepeatableListAnimatable,
        {
            #[inline]
            fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
                if self.is_empty() || other.is_empty() {
                    return Err(());
                }
                use num_integer::lcm;
                let len = lcm(self.len(), other.len());
                self.iter().cycle().zip(other.iter().cycle()).take(len).map(|(this, other)| {
                    this.compute_squared_distance(other)
                }).sum()
            }
        })*
    };
}

repeated_vec_impl!(SmallVec<[T; 1]>, Vec<T>);

/// <https://drafts.csswg.org/css-transitions/#animtype-visibility>
impl Animate for Visibility {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let (this_weight, other_weight) = procedure.weights();
        match (*self, *other) {
            (Visibility::Visible, _) => {
                Ok(if this_weight > 0.0 { *self } else { *other })
            },
            (_, Visibility::Visible) => {
                Ok(if other_weight > 0.0 { *other } else { *self })
            },
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for Visibility {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(SquaredDistance::Value(if *self == *other { 0. } else { 1. }))
    }
}

impl ToAnimatedZero for Visibility {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

/// <https://drafts.csswg.org/css-transitions/#animtype-lpcalc>
impl Animate for CalcLengthOrPercentage {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let animate_percentage_half = |this: Option<Percentage>, other: Option<Percentage>| {
            if this.is_none() && other.is_none() {
                return Ok(None);
            }
            let this = this.unwrap_or_default();
            let other = other.unwrap_or_default();
            Ok(Some(this.animate(&other, procedure)?))
        };

        let length = self.unclamped_length().animate(&other.unclamped_length(), procedure)?;
        let percentage = animate_percentage_half(self.percentage, other.percentage)?;
        Ok(CalcLengthOrPercentage::with_clamping_mode(length, percentage, self.clamping_mode))
    }
}

impl ToAnimatedZero for LengthOrPercentageOrAuto {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            LengthOrPercentageOrAuto::Length(_) |
            LengthOrPercentageOrAuto::Percentage(_) |
            LengthOrPercentageOrAuto::Calc(_) => {
                Ok(LengthOrPercentageOrAuto::Length(Length::new(0.)))
            },
            LengthOrPercentageOrAuto::Auto => Err(()),
        }
    }
}

impl ToAnimatedZero for LengthOrPercentageOrNone {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            LengthOrPercentageOrNone::Length(_) |
            LengthOrPercentageOrNone::Percentage(_) |
            LengthOrPercentageOrNone::Calc(_) => {
                Ok(LengthOrPercentageOrNone::Length(Length::new(0.)))
            },
            LengthOrPercentageOrNone::None => Err(()),
        }
    }
}

impl ToAnimatedZero for MaxLength {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

/// <http://dev.w3.org/csswg/css-transitions/#animtype-font-weight>
impl Animate for FontWeight {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let a = self.0 as f64;
        let b = other.0 as f64;
        const NORMAL: f64 = 400.;
        let (this_weight, other_weight) = procedure.weights();
        let weight = (a - NORMAL) * this_weight + (b - NORMAL) * other_weight + NORMAL;
        let weight = (weight.max(100.).min(900.) / 100.).round() * 100.;
        Ok(FontWeight(weight as u16))
    }
}

impl ToAnimatedZero for FontWeight {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Ok(FontWeight::normal())
    }
}

/// <https://drafts.csswg.org/css-fonts/#font-stretch-prop>
impl Animate for FontStretch {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()>
    {
        let from = f64::from(*self);
        let to = f64::from(*other);
        let normal = f64::from(FontStretch::Normal);
        let (this_weight, other_weight) = procedure.weights();
        let result = (from - normal) * this_weight + (to - normal) * other_weight + normal;
        Ok(result.into())
    }
}

impl ComputeSquaredDistance for FontStretch {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        f64::from(*self).compute_squared_distance(&(*other).into())
    }
}

impl ToAnimatedZero for FontStretch {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

/// We should treat font stretch as real number in order to interpolate this property.
/// <https://drafts.csswg.org/css-fonts-3/#font-stretch-animation>
impl From<FontStretch> for f64 {
    fn from(stretch: FontStretch) -> f64 {
        use self::FontStretch::*;
        match stretch {
            UltraCondensed => 1.0,
            ExtraCondensed => 2.0,
            Condensed => 3.0,
            SemiCondensed => 4.0,
            Normal => 5.0,
            SemiExpanded => 6.0,
            Expanded => 7.0,
            ExtraExpanded => 8.0,
            UltraExpanded => 9.0,
        }
    }
}

impl Into<FontStretch> for f64 {
    fn into(self) -> FontStretch {
        use properties::longhands::font_stretch::computed_value::T::*;
        let index = (self + 0.5).floor().min(9.0).max(1.0);
        static FONT_STRETCH_ENUM_MAP: [FontStretch; 9] =
            [ UltraCondensed, ExtraCondensed, Condensed, SemiCondensed, Normal,
              SemiExpanded, Expanded, ExtraExpanded, UltraExpanded ];
        FONT_STRETCH_ENUM_MAP[(index - 1.0) as usize]
    }
}

/// <https://drafts.csswg.org/css-fonts-4/#font-variation-settings-def>
#[cfg(feature = "gecko")]
impl Animate for FontVariationSettings {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        FontSettingTagIter::new(self, other)?
            .map(|r| r.and_then(|(st, ot)| st.animate(&ot, procedure)))
            .collect::<Result<Vec<FontSettingTag>, ()>>()
            .map(GenericFontSettings::Tag)
    }
}

#[cfg(feature = "gecko")]
impl ComputeSquaredDistance for FontVariationSettings {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        FontSettingTagIter::new(self, other)?
            .map(|r| r.and_then(|(st, ot)| st.compute_squared_distance(&ot)))
            .sum()
    }
}

#[cfg(feature = "gecko")]
impl ToAnimatedZero for FontVariationSettings {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

#[cfg(feature = "gecko")]
impl Animate for FontSettingTag {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if self.tag != other.tag {
            return Err(());
        }
        let value = self.value.animate(&other.value, procedure)?;
        Ok(FontSettingTag {
            tag: self.tag,
            value,
        })
    }
}

#[cfg(feature = "gecko")]
impl ComputeSquaredDistance for FontSettingTag {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        if self.tag != other.tag {
            return Err(());
        }
        self.value.compute_squared_distance(&other.value)
    }
}

#[cfg(feature = "gecko")]
type FontSettingTag = GenericFontSettingTag<FontSettingTagFloat>;

#[cfg(feature = "gecko")]
struct FontSettingTagIterState<'a> {
    tags: Vec<(&'a FontSettingTag)>,
    index: usize,
    prev_tag: u32,
}

#[cfg(feature = "gecko")]
impl<'a> FontSettingTagIterState<'a> {
    fn new(tags: Vec<(&'a FontSettingTag)>) -> FontSettingTagIterState<'a> {
        FontSettingTagIterState {
            index: tags.len(),
            tags,
            prev_tag: 0,
        }
    }
}

/// Iterator for font-variation-settings tag lists
///
/// [CSS fonts level 4](https://drafts.csswg.org/css-fonts-4/#descdef-font-face-font-variation-settings)
/// defines the animation of font-variation-settings as follows:
///
///   Two declarations of font-feature-settings[sic] can be animated between if they are "like".
///   "Like" declarations are ones where the same set of properties appear (in any order).
///   Because succesive[sic] duplicate properties are applied instead of prior duplicate
///   properties, two declarations can be "like" even if they have differing number of
///   properties. If two declarations are "like" then animation occurs pairwise between
///   corresponding values in the declarations.
///
/// In other words if we have the following lists:
///
///   "wght" 1.4, "wdth" 5, "wght" 2
///   "wdth" 8, "wght" 4, "wdth" 10
///
/// We should animate between:
///
///   "wdth" 5, "wght" 2
///   "wght" 4, "wdth" 10
///
/// This iterator supports this by sorting the two lists, then iterating them in reverse,
/// and skipping entries with repeated tag names. It will return Some(Err()) if it reaches the
/// end of one list before the other, or if the tag names do not match.
///
/// For the above example, this iterator would return:
///
///   Some(Ok("wght" 2, "wght" 4))
///   Some(Ok("wdth" 5, "wdth" 10))
///   None
///
#[cfg(feature = "gecko")]
struct FontSettingTagIter<'a> {
    a_state: FontSettingTagIterState<'a>,
    b_state: FontSettingTagIterState<'a>,
}

#[cfg(feature = "gecko")]
impl<'a> FontSettingTagIter<'a> {
    fn new(
        a_settings: &'a FontVariationSettings,
        b_settings: &'a FontVariationSettings,
    ) -> Result<FontSettingTagIter<'a>, ()> {
        if let (&GenericFontSettings::Tag(ref a_tags), &GenericFontSettings::Tag(ref b_tags)) = (a_settings, b_settings)
        {
            fn as_new_sorted_tags(tags: &Vec<FontSettingTag>) -> Vec<(&FontSettingTag)> {
                use std::iter::FromIterator;
                let mut sorted_tags: Vec<(&FontSettingTag)> = Vec::from_iter(tags.iter());
                sorted_tags.sort_by_key(|k| k.tag);
                sorted_tags
            };

            Ok(FontSettingTagIter {
                a_state: FontSettingTagIterState::new(as_new_sorted_tags(a_tags)),
                b_state: FontSettingTagIterState::new(as_new_sorted_tags(b_tags)),
            })
        } else {
            Err(())
        }
    }

    fn next_tag(state: &mut FontSettingTagIterState<'a>) -> Option<(&'a FontSettingTag)> {
        if state.index == 0 {
            return None;
        }

        state.index -= 1;
        let tag = state.tags[state.index];
        if tag.tag == state.prev_tag {
            FontSettingTagIter::next_tag(state)
        } else {
            state.prev_tag = tag.tag;
            Some(tag)
        }
    }
}

#[cfg(feature = "gecko")]
impl<'a> Iterator for FontSettingTagIter<'a> {
    type Item = Result<(&'a FontSettingTag, &'a FontSettingTag), ()>;

    fn next(&mut self) -> Option<Result<(&'a FontSettingTag, &'a FontSettingTag), ()>> {
        match (
            FontSettingTagIter::next_tag(&mut self.a_state),
            FontSettingTagIter::next_tag(&mut self.b_state),
        ) {
            (Some(at), Some(bt)) if at.tag == bt.tag => Some(Ok((at, bt))),
            (None, None) => None,
            _ => Some(Err(())), // Mismatch number of unique tags or tag names.
        }
    }
}

impl<H, V> RepeatableListAnimatable for generic_position::Position<H, V>
    where H: RepeatableListAnimatable, V: RepeatableListAnimatable {}

/// <https://drafts.csswg.org/css-transitions/#animtype-rect>
impl Animate for ClipRect {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        use values::computed::Length;
        let animate_component = |this: &Option<Length>, other: &Option<Length>| {
            match (this.animate(other, procedure)?, procedure) {
                (None, Procedure::Interpolate { .. }) => Ok(None),
                (None, _) => Err(()),
                (result, _) => Ok(result),
            }
        };

        Ok(ClipRect {
            top:    animate_component(&self.top, &other.top)?,
            right:  animate_component(&self.right, &other.right)?,
            bottom: animate_component(&self.bottom, &other.bottom)?,
            left:   animate_component(&self.left, &other.left)?,
        })
    }
}

impl ToAnimatedZero for ClipRect {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
}

fn animate_multiplicative_factor(
    this: CSSFloat,
    other: CSSFloat,
    procedure: Procedure,
) -> Result<CSSFloat, ()> {
    Ok((this - 1.).animate(&(other - 1.), procedure)? + 1.)
}

/// <http://dev.w3.org/csswg/css-transforms/#interpolation-of-transforms>
impl Animate for ComputedTransformOperation {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (
                &TransformOperation::Matrix3D(ref this),
                &TransformOperation::Matrix3D(ref other),
            ) => {
                Ok(TransformOperation::Matrix3D(
                    this.animate(other, procedure)?,
                ))
            },
            (
                &TransformOperation::Matrix(ref this),
                &TransformOperation::Matrix(ref other),
            ) => {
                Ok(TransformOperation::Matrix(
                    this.animate(other, procedure)?,
                ))
            },
            (
                &TransformOperation::Skew(ref fx, None),
                &TransformOperation::Skew(ref tx, None),
            ) => {
                Ok(TransformOperation::Skew(
                    fx.animate(tx, procedure)?,
                    None,
                ))
            },
            (
                &TransformOperation::Skew(ref fx, ref fy),
                &TransformOperation::Skew(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Skew(
                    fx.animate(tx, procedure)?,
                    Some(fy.unwrap_or(Angle::zero()).animate(&ty.unwrap_or(Angle::zero()), procedure)?)
                ))
            },
            (
                &TransformOperation::SkewX(ref f),
                &TransformOperation::SkewX(ref t),
            ) => {
                Ok(TransformOperation::SkewX(
                    f.animate(t, procedure)?,
                ))
            },
            (
                &TransformOperation::SkewY(ref f),
                &TransformOperation::SkewY(ref t),
            ) => {
                Ok(TransformOperation::SkewY(
                    f.animate(t, procedure)?,
                ))
            },
            (
                &TransformOperation::Translate3D(ref fx, ref fy, ref fz),
                &TransformOperation::Translate3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(TransformOperation::Translate3D(
                    fx.animate(tx, procedure)?,
                    fy.animate(ty, procedure)?,
                    fz.animate(tz, procedure)?,
                ))
            },
            (
                &TransformOperation::Translate(ref fx, None),
                &TransformOperation::Translate(ref tx, None),
            ) => {
                Ok(TransformOperation::Translate(
                    fx.animate(tx, procedure)?,
                    None
                ))
            },
            (
                &TransformOperation::Translate(ref fx, ref fy),
                &TransformOperation::Translate(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Translate(
                    fx.animate(tx, procedure)?,
                    Some(fy.unwrap_or(*fx).animate(&ty.unwrap_or(*tx), procedure)?)
                ))
            },
            (
                &TransformOperation::TranslateX(ref f),
                &TransformOperation::TranslateX(ref t),
            ) => {
                Ok(TransformOperation::TranslateX(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::TranslateY(ref f),
                &TransformOperation::TranslateY(ref t),
            ) => {
                Ok(TransformOperation::TranslateY(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::TranslateZ(ref f),
                &TransformOperation::TranslateZ(ref t),
            ) => {
                Ok(TransformOperation::TranslateZ(
                    f.animate(t, procedure)?
                ))
            },
            (
                &TransformOperation::Scale3D(ref fx, ref fy, ref fz),
                &TransformOperation::Scale3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(TransformOperation::Scale3D(
                    animate_multiplicative_factor(*fx, *tx, procedure)?,
                    animate_multiplicative_factor(*fy, *ty, procedure)?,
                    animate_multiplicative_factor(*fz, *tz, procedure)?,
                ))
            },
            (
                &TransformOperation::ScaleX(ref f),
                &TransformOperation::ScaleX(ref t),
            ) => {
                Ok(TransformOperation::ScaleX(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::ScaleY(ref f),
                &TransformOperation::ScaleY(ref t),
            ) => {
                Ok(TransformOperation::ScaleY(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::ScaleZ(ref f),
                &TransformOperation::ScaleZ(ref t),
            ) => {
                Ok(TransformOperation::ScaleZ(
                    animate_multiplicative_factor(*f, *t, procedure)?
                ))
            },
            (
                &TransformOperation::Scale(ref f, None),
                &TransformOperation::Scale(ref t, None),
            ) => {
                Ok(TransformOperation::Scale(
                    animate_multiplicative_factor(*f, *t, procedure)?,
                    None
                ))
            },
            (
                &TransformOperation::Scale(ref fx, ref fy),
                &TransformOperation::Scale(ref tx, ref ty),
            ) => {
                Ok(TransformOperation::Scale(
                    animate_multiplicative_factor(*fx, *tx, procedure)?,
                    Some(animate_multiplicative_factor(fy.unwrap_or(*fx), ty.unwrap_or(*tx), procedure)?),
                ))
            },
            (
                &TransformOperation::Rotate3D(fx, fy, fz, fa),
                &TransformOperation::Rotate3D(tx, ty, tz, ta),
            ) => {
                let (fx, fy, fz, fa) = transform::get_normalized_vector_and_angle(fx, fy, fz, fa);
                let (tx, ty, tz, ta) = transform::get_normalized_vector_and_angle(tx, ty, tz, ta);
                if (fx, fy, fz) == (tx, ty, tz) {
                    let ia = fa.animate(&ta, procedure)?;
                    Ok(TransformOperation::Rotate3D(fx, fy, fz, ia))
                } else {
                    let matrix_f = rotate_to_matrix(fx, fy, fz, fa);
                    let matrix_t = rotate_to_matrix(tx, ty, tz, ta);
                    Ok(TransformOperation::Matrix3D(
                        matrix_f.animate(&matrix_t, procedure)?,
                    ))
                }
            },
            (
                &TransformOperation::RotateX(fa),
                &TransformOperation::RotateX(ta),
            ) => {
                Ok(TransformOperation::RotateX(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateY(fa),
                &TransformOperation::RotateY(ta),
            ) => {
                Ok(TransformOperation::RotateY(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::RotateZ(ta),
            ) => {
                Ok(TransformOperation::RotateZ(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::RotateZ(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                Ok(TransformOperation::Rotate(
                    fa.animate(&ta, procedure)?
                ))
            },
            (
                &TransformOperation::Perspective(ref fd),
                &TransformOperation::Perspective(ref td),
            ) => {
                let mut fd_matrix = Matrix3D::identity();
                let mut td_matrix = Matrix3D::identity();
                if fd.px() > 0. {
                    fd_matrix.m34 = -1. / fd.px();
                }
                if td.px() > 0. {
                    td_matrix.m34 = -1. / td.px();
                }
                Ok(TransformOperation::Matrix3D(
                    fd_matrix.animate(&td_matrix, procedure)?,
                ))
            },
            _ if self.is_translate() && other.is_translate() => {
                self.to_translate_3d().animate(&other.to_translate_3d(), procedure)
            }
            _ if self.is_scale() && other.is_scale() => {
                self.to_scale_3d().animate(&other.to_scale_3d(), procedure)
            }
            _ => Err(()),
        }
    }
}

fn is_matched_operation(first: &ComputedTransformOperation, second: &ComputedTransformOperation) -> bool {
    match (first, second) {
        (&TransformOperation::Matrix(..),
         &TransformOperation::Matrix(..)) |
        (&TransformOperation::Matrix3D(..),
         &TransformOperation::Matrix3D(..)) |
        (&TransformOperation::Skew(..),
         &TransformOperation::Skew(..)) |
        (&TransformOperation::SkewX(..),
         &TransformOperation::SkewX(..)) |
        (&TransformOperation::SkewY(..),
         &TransformOperation::SkewY(..)) |
        (&TransformOperation::Rotate(..),
         &TransformOperation::Rotate(..)) |
        (&TransformOperation::Rotate3D(..),
         &TransformOperation::Rotate3D(..)) |
        (&TransformOperation::RotateX(..),
         &TransformOperation::RotateX(..)) |
        (&TransformOperation::RotateY(..),
         &TransformOperation::RotateY(..)) |
        (&TransformOperation::RotateZ(..),
         &TransformOperation::RotateZ(..)) |
        (&TransformOperation::Perspective(..),
         &TransformOperation::Perspective(..)) => true,
        // we animate scale and translate operations against each other
        (a, b) if a.is_translate() && b.is_translate() => true,
        (a, b) if a.is_scale() && b.is_scale() => true,
        // InterpolateMatrix and AccumulateMatrix are for mismatched transform.
        _ => false
    }
}

/// <https://www.w3.org/TR/css-transforms-1/#Rotate3dDefined>
fn rotate_to_matrix(x: f32, y: f32, z: f32, a: Angle) -> Matrix3D {
    let half_rad = a.radians() / 2.0;
    let sc = (half_rad).sin() * (half_rad).cos();
    let sq = (half_rad).sin().powi(2);

    Matrix3D {
        m11: 1.0 - 2.0 * (y * y + z * z) * sq,
        m12: 2.0 * (x * y * sq + z * sc),
        m13: 2.0 * (x * z * sq - y * sc),
        m14: 0.0,

        m21: 2.0 * (x * y * sq - z * sc),
        m22: 1.0 - 2.0 * (x * x + z * z) * sq,
        m23: 2.0 * (y * z * sq + x * sc),
        m24: 0.0,

        m31: 2.0 * (x * z * sq + y * sc),
        m32: 2.0 * (y * z * sq - x * sc),
        m33: 1.0 - 2.0 * (x * x + y * y) * sq,
        m34: 0.0,

        m41: 0.0,
        m42: 0.0,
        m43: 0.0,
        m44: 1.0
    }
}

/// A 2d matrix for interpolation.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[allow(missing_docs)]
// FIXME: We use custom derive for ComputeSquaredDistance. However, If possible, we should convert
// the InnerMatrix2D into types with physical meaning. This custom derive computes the squared
// distance from each matrix item, and this makes the result different from that in Gecko if we
// have skew factor in the Matrix3D.
pub struct InnerMatrix2D {
    pub m11: CSSFloat, pub m12: CSSFloat,
    pub m21: CSSFloat, pub m22: CSSFloat,
}

/// A 2d translation function.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, ComputeSquaredDistance, Copy, Debug)]
pub struct Translate2D(f32, f32);

/// A 2d scale function.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Scale2D(f32, f32);

/// A decomposed 2d matrix.
#[derive(Clone, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct MatrixDecomposed2D {
    /// The translation function.
    pub translate: Translate2D,
    /// The scale function.
    pub scale: Scale2D,
    /// The rotation angle.
    pub angle: f32,
    /// The inner matrix.
    pub matrix: InnerMatrix2D,
}

impl Animate for InnerMatrix2D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(InnerMatrix2D {
            m11: animate_multiplicative_factor(self.m11, other.m11, procedure)?,
            m12: self.m12.animate(&other.m12, procedure)?,
            m21: self.m21.animate(&other.m21, procedure)?,
            m22: animate_multiplicative_factor(self.m22, other.m22, procedure)?,
        })
    }
}

impl Animate for Scale2D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Scale2D(
            animate_multiplicative_factor(self.0, other.0, procedure)?,
            animate_multiplicative_factor(self.1, other.1, procedure)?,
        ))
    }
}

impl Animate for MatrixDecomposed2D {
    /// <https://drafts.csswg.org/css-transforms/#interpolation-of-decomposed-2d-matrix-values>
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        // If x-axis of one is flipped, and y-axis of the other,
        // convert to an unflipped rotation.
        let mut scale = self.scale;
        let mut angle = self.angle;
        let mut other_angle = other.angle;
        if (scale.0 < 0.0 && other.scale.1 < 0.0) || (scale.1 < 0.0 && other.scale.0 < 0.0) {
            scale.0 = -scale.0;
            scale.1 = -scale.1;
            angle += if angle < 0.0 {180.} else {-180.};
        }

        // Don't rotate the long way around.
        if angle == 0.0 {
            angle = 360.
        }
        if other_angle == 0.0 {
            other_angle = 360.
        }

        if (angle - other_angle).abs() > 180. {
            if angle > other_angle {
                angle -= 360.
            }
            else{
                other_angle -= 360.
            }
        }

        // Interpolate all values.
        let translate = self.translate.animate(&other.translate, procedure)?;
        let scale = scale.animate(&other.scale, procedure)?;
        let angle = angle.animate(&other_angle, procedure)?;
        let matrix = self.matrix.animate(&other.matrix, procedure)?;

        Ok(MatrixDecomposed2D {
            translate: translate,
            scale: scale,
            angle: angle,
            matrix: matrix,
        })
    }
}

impl ComputeSquaredDistance for MatrixDecomposed2D {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // Use Radian to compute the distance.
        const RAD_PER_DEG: f64 = ::std::f64::consts::PI / 180.0;
        let angle1 = self.angle as f64 * RAD_PER_DEG;
        let angle2 = other.angle as f64 * RAD_PER_DEG;
        Ok(self.translate.compute_squared_distance(&other.translate)? +
           self.scale.compute_squared_distance(&other.scale)? +
           angle1.compute_squared_distance(&angle2)? +
           self.matrix.compute_squared_distance(&other.matrix)?)
    }
}

impl Animate for Matrix3D {
    #[cfg(feature = "servo")]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if self.is_3d() || other.is_3d() {
            let decomposed_from = decompose_3d_matrix(*self);
            let decomposed_to = decompose_3d_matrix(*other);
            match (decomposed_from, decomposed_to) {
                (Ok(this), Ok(other)) => {
                    Ok(Matrix3D::from(this.animate(&other, procedure)?))
                },
                // Matrices can be undecomposable due to couple reasons, e.g.,
                // non-invertible matrices. In this case, we should report Err
                // here, and let the caller do the fallback procedure.
                _ => Err(())
            }
        } else {
            let this = MatrixDecomposed2D::from(*self);
            let other = MatrixDecomposed2D::from(*other);
            Ok(Matrix3D::from(this.animate(&other, procedure)?))
        }
    }

    #[cfg(feature = "gecko")]
    // Gecko doesn't exactly follow the spec here; we use a different procedure
    // to match it
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let (from, to) = if self.is_3d() || other.is_3d() {
            (decompose_3d_matrix(*self), decompose_3d_matrix(*other))
        } else {
            (decompose_2d_matrix(self), decompose_2d_matrix(other))
        };
        match (from, to) {
            (Ok(from), Ok(to)) => {
                Ok(Matrix3D::from(from.animate(&to, procedure)?))
            },
            // Matrices can be undecomposable due to couple reasons, e.g.,
            // non-invertible matrices. In this case, we should report Err here,
            // and let the caller do the fallback procedure.
            _ => Err(())
        }
    }
}

impl Animate for Matrix {
    #[cfg(feature = "servo")]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let this = Matrix3D::from(*self);
        let other = Matrix3D::from(*other);
        let this = MatrixDecomposed2D::from(this);
        let other = MatrixDecomposed2D::from(other);
        Ok(Matrix3D::from(this.animate(&other, procedure)?).into_2d()?)
    }

    #[cfg(feature = "gecko")]
    // Gecko doesn't exactly follow the spec here; we use a different procedure
    // to match it
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        let from = decompose_2d_matrix(&(*self).into());
        let to = decompose_2d_matrix(&(*other).into());
        match (from, to) {
            (Ok(from), Ok(to)) => {
                Matrix3D::from(from.animate(&to, procedure)?).into_2d()
            },
            // Matrices can be undecomposable due to couple reasons, e.g.,
            // non-invertible matrices. In this case, we should report Err here,
            // and let the caller do the fallback procedure.
            _ => Err(())
        }
    }
}

impl ComputeSquaredDistance for Matrix3D {
    #[inline]
    #[cfg(feature = "servo")]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        if self.is_3d() || other.is_3d() {
            let from = decompose_3d_matrix(*self)?;
            let to = decompose_3d_matrix(*other)?;
            from.compute_squared_distance(&to)
        } else {
            let from = MatrixDecomposed2D::from(*self);
            let to = MatrixDecomposed2D::from(*other);
            from.compute_squared_distance(&to)
        }
    }

    #[inline]
    #[cfg(feature = "gecko")]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        let (from, to) = if self.is_3d() || other.is_3d() {
            (decompose_3d_matrix(*self)?, decompose_3d_matrix(*other)?)
        } else {
            (decompose_2d_matrix(self)?, decompose_2d_matrix(other)?)
        };
        from.compute_squared_distance(&to)
    }
}

impl From<Matrix3D> for MatrixDecomposed2D {
    /// Decompose a 2D matrix.
    /// <https://drafts.csswg.org/css-transforms/#decomposing-a-2d-matrix>
    fn from(matrix: Matrix3D) -> MatrixDecomposed2D {
        let mut row0x = matrix.m11;
        let mut row0y = matrix.m12;
        let mut row1x = matrix.m21;
        let mut row1y = matrix.m22;

        let translate = Translate2D(matrix.m41, matrix.m42);
        let mut scale = Scale2D((row0x * row0x + row0y * row0y).sqrt(),
                                (row1x * row1x + row1y * row1y).sqrt());

        // If determinant is negative, one axis was flipped.
        let determinant = row0x * row1y - row0y * row1x;
        if determinant < 0. {
            if row0x < row1y {
                scale.0 = -scale.0;
            } else {
                scale.1 = -scale.1;
            }
        }

        // Renormalize matrix to remove scale.
        if scale.0 != 0.0 {
            row0x *= 1. / scale.0;
            row0y *= 1. / scale.0;
        }
        if scale.1 != 0.0 {
            row1x *= 1. / scale.1;
            row1y *= 1. / scale.1;
        }

        // Compute rotation and renormalize matrix.
        let mut angle = row0y.atan2(row0x);
        if angle != 0.0 {
            let sn = -row0y;
            let cs = row0x;
            let m11 = row0x;
            let m12 = row0y;
            let m21 = row1x;
            let m22 = row1y;
            row0x = cs * m11 + sn * m21;
            row0y = cs * m12 + sn * m22;
            row1x = -sn * m11 + cs * m21;
            row1y = -sn * m12 + cs * m22;
        }

        let m = InnerMatrix2D {
            m11: row0x, m12: row0y,
            m21: row1x, m22: row1y,
        };

        // Convert into degrees because our rotation functions expect it.
        angle = angle.to_degrees();
        MatrixDecomposed2D {
            translate: translate,
            scale: scale,
            angle: angle,
            matrix: m,
        }
    }
}

impl From<MatrixDecomposed2D> for Matrix3D {
    /// Recompose a 2D matrix.
    /// <https://drafts.csswg.org/css-transforms/#recomposing-to-a-2d-matrix>
    fn from(decomposed: MatrixDecomposed2D) -> Matrix3D {
        let mut computed_matrix = Matrix3D::identity();
        computed_matrix.m11 = decomposed.matrix.m11;
        computed_matrix.m12 = decomposed.matrix.m12;
        computed_matrix.m21 = decomposed.matrix.m21;
        computed_matrix.m22 = decomposed.matrix.m22;

        // Translate matrix.
        computed_matrix.m41 = decomposed.translate.0;
        computed_matrix.m42 = decomposed.translate.1;

        // Rotate matrix.
        let angle = decomposed.angle.to_radians();
        let cos_angle = angle.cos();
        let sin_angle = angle.sin();

        let mut rotate_matrix = Matrix3D::identity();
        rotate_matrix.m11 = cos_angle;
        rotate_matrix.m12 = sin_angle;
        rotate_matrix.m21 = -sin_angle;
        rotate_matrix.m22 = cos_angle;

        // Multiplication of computed_matrix and rotate_matrix
        computed_matrix = multiply(rotate_matrix, computed_matrix);

        // Scale matrix.
        computed_matrix.m11 *= decomposed.scale.0;
        computed_matrix.m12 *= decomposed.scale.0;
        computed_matrix.m21 *= decomposed.scale.1;
        computed_matrix.m22 *= decomposed.scale.1;
        computed_matrix
    }
}

#[cfg(feature = "gecko")]
impl<'a> From< &'a RawGeckoGfxMatrix4x4> for Matrix3D {
    fn from(m: &'a RawGeckoGfxMatrix4x4) -> Matrix3D {
        Matrix3D {
            m11: m[0],  m12: m[1],  m13: m[2],  m14: m[3],
            m21: m[4],  m22: m[5],  m23: m[6],  m24: m[7],
            m31: m[8],  m32: m[9],  m33: m[10], m34: m[11],
            m41: m[12], m42: m[13], m43: m[14], m44: m[15],
        }
    }
}

#[cfg(feature = "gecko")]
impl From<Matrix3D> for RawGeckoGfxMatrix4x4 {
    fn from(matrix: Matrix3D) -> RawGeckoGfxMatrix4x4 {
        [ matrix.m11, matrix.m12, matrix.m13, matrix.m14,
          matrix.m21, matrix.m22, matrix.m23, matrix.m24,
          matrix.m31, matrix.m32, matrix.m33, matrix.m34,
          matrix.m41, matrix.m42, matrix.m43, matrix.m44 ]
    }
}

/// A 3d translation.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, ComputeSquaredDistance, Copy, Debug)]
pub struct Translate3D(f32, f32, f32);

/// A 3d scale function.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Scale3D(f32, f32, f32);

/// A 3d skew function.
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
#[derive(Animate, Clone, Copy, Debug)]
pub struct Skew(f32, f32, f32);

/// A 3d perspective transformation.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Perspective(f32, f32, f32, f32);

/// A quaternion used to represent a rotation.
#[derive(Clone, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct Quaternion(f64, f64, f64, f64);

/// A decomposed 3d matrix.
#[derive(Clone, ComputeSquaredDistance, Copy, Debug)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub struct MatrixDecomposed3D {
    /// A translation function.
    pub translate: Translate3D,
    /// A scale function.
    pub scale: Scale3D,
    /// The skew component of the transformation.
    pub skew: Skew,
    /// The perspective component of the transformation.
    pub perspective: Perspective,
    /// The quaternion used to represent the rotation.
    pub quaternion: Quaternion,
}

impl Quaternion {
    /// Return a quaternion from a unit direction vector and angle (unit: radian).
    #[inline]
    fn from_direction_and_angle(vector: &DirectionVector, angle: f64) -> Self {
        debug_assert!((vector.length() - 1.).abs() < 0.0001,
                      "Only accept an unit direction vector to create a quaternion");
        // Reference:
        // https://en.wikipedia.org/wiki/Quaternions_and_spatial_rotation
        //
        // if the direction axis is (x, y, z) = xi + yj + zk,
        // and the angle is |theta|, this formula can be done using
        // an extension of Euler's formula:
        //   q = cos(theta/2) + (xi + yj + zk)(sin(theta/2))
        //     = cos(theta/2) +
        //       x*sin(theta/2)i + y*sin(theta/2)j + z*sin(theta/2)k
        Quaternion(vector.x as f64 * (angle / 2.).sin(),
                   vector.y as f64 * (angle / 2.).sin(),
                   vector.z as f64 * (angle / 2.).sin(),
                   (angle / 2.).cos())
    }

    /// Calculate the dot product.
    #[inline]
    fn dot(&self, other: &Self) -> f64 {
        self.0 * other.0 + self.1 * other.1 + self.2 * other.2 + self.3 * other.3
    }
}

impl ComputeSquaredDistance for Quaternion {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // Use quaternion vectors to get the angle difference. Both q1 and q2 are unit vectors,
        // so we can get their angle difference by:
        // cos(theta/2) = (q1 dot q2) / (|q1| * |q2|) = q1 dot q2.
        let distance = self.dot(other).max(-1.0).min(1.0).acos() * 2.0;
        Ok(SquaredDistance::Value(distance * distance))
    }
}

/// Decompose a 3D matrix.
/// <https://drafts.csswg.org/css-transforms/#decomposing-a-3d-matrix>
fn decompose_3d_matrix(mut matrix: Matrix3D) -> Result<MatrixDecomposed3D, ()> {
    // Normalize the matrix.
    if matrix.m44 == 0.0 {
        return Err(());
    }

    let scaling_factor = matrix.m44;
            matrix.m11 /= scaling_factor;
            matrix.m12 /= scaling_factor;
            matrix.m13 /= scaling_factor;
            matrix.m14 /= scaling_factor;
            matrix.m21 /= scaling_factor;
            matrix.m22 /= scaling_factor;
            matrix.m23 /= scaling_factor;
            matrix.m24 /= scaling_factor;
            matrix.m31 /= scaling_factor;
            matrix.m32 /= scaling_factor;
            matrix.m33 /= scaling_factor;
            matrix.m34 /= scaling_factor;
            matrix.m41 /= scaling_factor;
            matrix.m42 /= scaling_factor;
            matrix.m43 /= scaling_factor;
            matrix.m44 /= scaling_factor;

    // perspective_matrix is used to solve for perspective, but it also provides
    // an easy way to test for singularity of the upper 3x3 component.
    let mut perspective_matrix = matrix;

        perspective_matrix.m14 = 0.0;
        perspective_matrix.m24 = 0.0;
        perspective_matrix.m34 = 0.0;
    perspective_matrix.m44 = 1.0;

    if perspective_matrix.determinant() == 0.0 {
        return Err(());
    }

    // First, isolate perspective.
    let perspective = if matrix.m14 != 0.0 || matrix.m24 != 0.0 || matrix.m34 != 0.0 {
        let right_hand_side: [f32; 4] = [
            matrix.m14,
            matrix.m24,
            matrix.m34,
            matrix.m44
        ];

        perspective_matrix = perspective_matrix.inverse().unwrap();

        // Transpose perspective_matrix
        perspective_matrix = Matrix3D {
                    m11: perspective_matrix.m11,
                    m12: perspective_matrix.m21,
                    m13: perspective_matrix.m31,
                    m14: perspective_matrix.m41,
                    m21: perspective_matrix.m12,
                    m22: perspective_matrix.m22,
                    m23: perspective_matrix.m32,
                    m24: perspective_matrix.m42,
                    m31: perspective_matrix.m13,
                    m32: perspective_matrix.m23,
                    m33: perspective_matrix.m33,
                    m34: perspective_matrix.m43,
                    m41: perspective_matrix.m14,
                    m42: perspective_matrix.m24,
                    m43: perspective_matrix.m34,
                    m44: perspective_matrix.m44,
        };

        // Multiply right_hand_side with perspective_matrix
        let mut tmp: [f32; 4] = [0.0; 4];
            tmp[0] = (right_hand_side[0] * perspective_matrix.m11) +
                            (right_hand_side[1] * perspective_matrix.m21) +
                            (right_hand_side[2] * perspective_matrix.m31) +
                            (right_hand_side[3] * perspective_matrix.m41);
            tmp[1] = (right_hand_side[0] * perspective_matrix.m12) +
                            (right_hand_side[1] * perspective_matrix.m22) +
                            (right_hand_side[2] * perspective_matrix.m32) +
                            (right_hand_side[3] * perspective_matrix.m42);
            tmp[2] = (right_hand_side[0] * perspective_matrix.m13) +
                            (right_hand_side[1] * perspective_matrix.m23) +
                            (right_hand_side[2] * perspective_matrix.m33) +
                            (right_hand_side[3] * perspective_matrix.m43);
            tmp[3] = (right_hand_side[0] * perspective_matrix.m14) +
                            (right_hand_side[1] * perspective_matrix.m24) +
                            (right_hand_side[2] * perspective_matrix.m34) +
                            (right_hand_side[3] * perspective_matrix.m44);

        Perspective(tmp[0], tmp[1], tmp[2], tmp[3])
    } else {
        Perspective(0.0, 0.0, 0.0, 1.0)
    };

    // Next take care of translation
    let translate = Translate3D (
        matrix.m41,
        matrix.m42,
        matrix.m43
    );

    // Now get scale and shear. 'row' is a 3 element array of 3 component vectors
    let mut row: [[f32; 3]; 3] = [[0.0; 3]; 3];
        row[0][0] = matrix.m11;
        row[0][1] = matrix.m12;
        row[0][2] = matrix.m13;
        row[1][0] = matrix.m21;
        row[1][1] = matrix.m22;
        row[1][2] = matrix.m23;
        row[2][0] = matrix.m31;
        row[2][1] = matrix.m32;
        row[2][2] = matrix.m33;

    // Compute X scale factor and normalize first row.
    let row0len = (row[0][0] * row[0][0] + row[0][1] * row[0][1] + row[0][2] * row[0][2]).sqrt();
    let mut scale = Scale3D(row0len, 0.0, 0.0);
    row[0] = [row[0][0] / row0len, row[0][1] / row0len, row[0][2] / row0len];

    // Compute XY shear factor and make 2nd row orthogonal to 1st.
    let mut skew = Skew(dot(row[0], row[1]), 0.0, 0.0);
    row[1] = combine(row[1], row[0], 1.0, -skew.0);

    // Now, compute Y scale and normalize 2nd row.
    let row1len = (row[1][0] * row[1][0] + row[1][1] * row[1][1] + row[1][2] * row[1][2]).sqrt();
    scale.1 = row1len;
    row[1] = [row[1][0] / row1len, row[1][1] / row1len, row[1][2] / row1len];
    skew.0 /= scale.1;

    // Compute XZ and YZ shears, orthogonalize 3rd row
    skew.1 = dot(row[0], row[2]);
    row[2] = combine(row[2], row[0], 1.0, -skew.1);
    skew.2 = dot(row[1], row[2]);
    row[2] = combine(row[2], row[1], 1.0, -skew.2);

    // Next, get Z scale and normalize 3rd row.
    let row2len = (row[2][0] * row[2][0] + row[2][1] * row[2][1] + row[2][2] * row[2][2]).sqrt();
    scale.2 = row2len;
    row[2] = [row[2][0] / row2len, row[2][1] / row2len, row[2][2] / row2len];
    skew.1 /= scale.2;
    skew.2 /= scale.2;

    // At this point, the matrix (in rows) is orthonormal.
    // Check for a coordinate system flip.  If the determinant
    // is -1, then negate the matrix and the scaling factors.
    let pdum3 = cross(row[1], row[2]);
    if dot(row[0], pdum3) < 0.0 {
            scale.0 *= -1.0;
            row[0][0] *= -1.0;
            row[0][1] *= -1.0;
            row[0][2] *= -1.0;
            scale.1 *= -1.0;
            row[1][0] *= -1.0;
            row[1][1] *= -1.0;
            row[1][2] *= -1.0;
            scale.2 *= -1.0;
            row[2][0] *= -1.0;
            row[2][1] *= -1.0;
            row[2][2] *= -1.0;
    }

    // Now, get the rotations out
    let mut quaternion = Quaternion (
        0.5 * ((1.0 + row[0][0] - row[1][1] - row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 - row[0][0] + row[1][1] - row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 - row[0][0] - row[1][1] + row[2][2]).max(0.0) as f64).sqrt(),
        0.5 * ((1.0 + row[0][0] + row[1][1] + row[2][2]).max(0.0) as f64).sqrt()
    );

    if row[2][1] > row[1][2] {
        quaternion.0 = -quaternion.0
    }
    if row[0][2] > row[2][0] {
        quaternion.1 = -quaternion.1
    }
    if row[1][0] > row[0][1] {
        quaternion.2 = -quaternion.2
    }

    Ok(MatrixDecomposed3D {
        translate: translate,
        scale: scale,
        skew: skew,
        perspective: perspective,
        quaternion: quaternion
    })
}

/// Decompose a 2D matrix for Gecko.
// Use the algorithm from nsStyleTransformMatrix::Decompose2DMatrix() in Gecko.
#[cfg(feature = "gecko")]
fn decompose_2d_matrix(matrix: &Matrix3D) -> Result<MatrixDecomposed3D, ()> {
    // The index is column-major, so the equivalent transform matrix is:
    // | m11 m21  0 m41 |  =>  | m11 m21 | and translate(m41, m42)
    // | m12 m22  0 m42 |      | m12 m22 |
    // |   0   0  1   0 |
    // |   0   0  0   1 |
    let (mut m11, mut m12) = (matrix.m11, matrix.m12);
    let (mut m21, mut m22) = (matrix.m21, matrix.m22);
    // Check if this is a singular matrix.
    if m11 * m22 == m12 * m21 {
        return Err(());
    }

    let mut scale_x = (m11 * m11 + m12 * m12).sqrt();
    m11 /= scale_x;
    m12 /= scale_x;

    let mut shear_xy = m11 * m21 + m12 * m22;
    m21 -= m11 * shear_xy;
    m22 -= m12 * shear_xy;

    let scale_y = (m21 * m21 + m22 * m22).sqrt();
    m21 /= scale_y;
    m22 /= scale_y;
    shear_xy /= scale_y;

    let determinant = m11 * m22 - m12 * m21;
    // Determinant should now be 1 or -1.
    if 0.99 > determinant.abs() || determinant.abs() > 1.01 {
        return Err(());
    }

    if determinant < 0. {
        m11 = -m11;
        m12 = -m12;
        shear_xy = -shear_xy;
        scale_x = -scale_x;
    }

    Ok(MatrixDecomposed3D {
        translate: Translate3D(matrix.m41, matrix.m42, 0.),
        scale: Scale3D(scale_x, scale_y, 1.),
        skew: Skew(shear_xy, 0., 0.),
        perspective: Perspective(0., 0., 0., 1.),
        quaternion: Quaternion::from_direction_and_angle(&DirectionVector::new(0., 0., 1.),
                                                         m12.atan2(m11) as f64)
    })
}

// Combine 2 point.
fn combine(a: [f32; 3], b: [f32; 3], ascl: f32, bscl: f32) -> [f32; 3] {
    [
        (ascl * a[0]) + (bscl * b[0]),
        (ascl * a[1]) + (bscl * b[1]),
        (ascl * a[2]) + (bscl * b[2])
    ]
}

// Dot product.
fn dot(a: [f32; 3], b: [f32; 3]) -> f32 {
    a[0] * b[0] + a[1] * b[1] + a[2] * b[2]
}

// Cross product.
fn cross(row1: [f32; 3], row2: [f32; 3]) -> [f32; 3] {
    [
        row1[1] * row2[2] - row1[2] * row2[1],
        row1[2] * row2[0] - row1[0] * row2[2],
        row1[0] * row2[1] - row1[1] * row2[0]
    ]
}

impl Animate for Scale3D {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Scale3D(
            animate_multiplicative_factor(self.0, other.0, procedure)?,
            animate_multiplicative_factor(self.1, other.1, procedure)?,
            animate_multiplicative_factor(self.2, other.2, procedure)?,
        ))
    }
}

impl ComputeSquaredDistance for Skew {
    // We have to use atan() to convert the skew factors into skew angles, so implement
    // ComputeSquaredDistance manually.
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(self.0.atan().compute_squared_distance(&other.0.atan())? +
           self.1.atan().compute_squared_distance(&other.1.atan())? +
           self.2.atan().compute_squared_distance(&other.2.atan())?)
    }
}

impl Animate for Perspective {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(Perspective(
            self.0.animate(&other.0, procedure)?,
            self.1.animate(&other.1, procedure)?,
            self.2.animate(&other.2, procedure)?,
            animate_multiplicative_factor(self.3, other.3, procedure)?,
        ))
    }
}

impl Animate for MatrixDecomposed3D {
    /// <https://drafts.csswg.org/css-transforms/#interpolation-of-decomposed-3d-matrix-values>
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        use std::f64;

        let (this_weight, other_weight) = procedure.weights();

        debug_assert!((this_weight + other_weight - 1.0f64).abs() <= f64::EPSILON ||
                      other_weight == 1.0f64 || other_weight == 0.0f64,
                      "animate should only be used for interpolating or accumulating transforms");

        let mut sum = *self;

        // Add translate, scale, skew and perspective components.
        sum.translate = self.translate.animate(&other.translate, procedure)?;
        sum.scale = self.scale.animate(&other.scale, procedure)?;
        sum.skew = self.skew.animate(&other.skew, procedure)?;
        sum.perspective = self.perspective.animate(&other.perspective, procedure)?;

        // Add quaternions using spherical linear interpolation (Slerp).
        //
        // We take a specialized code path for accumulation (where other_weight is 1)
        if other_weight == 1.0 {
            if this_weight == 0.0 {
                return Ok(*other)
            }

            let clamped_w = self.quaternion.3.min(1.0).max(-1.0);

            // Determine the scale factor.
            let mut theta = clamped_w.acos();
            let mut scale = if theta == 0.0 { 0.0 } else { 1.0 / theta.sin() };
            theta *= this_weight;
            scale *= theta.sin();

            // Scale the self matrix by this_weight.
            let mut scaled_self = *self;
                scaled_self.quaternion.0 *= scale;
                scaled_self.quaternion.1 *= scale;
                scaled_self.quaternion.2 *= scale;
            scaled_self.quaternion.3 = theta.cos();

            // Multiply scaled-self by other.
            let a = &scaled_self.quaternion;
            let b = &other.quaternion;
            sum.quaternion = Quaternion(
                a.3 * b.0 + a.0 * b.3 + a.1 * b.2 - a.2 * b.1,
                a.3 * b.1 - a.0 * b.2 + a.1 * b.3 + a.2 * b.0,
                a.3 * b.2 + a.0 * b.1 - a.1 * b.0 + a.2 * b.3,
                a.3 * b.3 - a.0 * b.0 - a.1 * b.1 - a.2 * b.2,
            );
        } else {
            let mut product = self.quaternion.0 * other.quaternion.0 +
                              self.quaternion.1 * other.quaternion.1 +
                              self.quaternion.2 * other.quaternion.2 +
                              self.quaternion.3 * other.quaternion.3;

            // Clamp product to -1.0 <= product <= 1.0
            product = product.min(1.0);
            product = product.max(-1.0);

            if product == 1.0 {
                return Ok(sum);
            }

            let theta = product.acos();
            let w = (other_weight * theta).sin() * 1.0 / (1.0 - product * product).sqrt();

            let mut a = *self;
            let mut b = *other;
                a.quaternion.0 *= (other_weight * theta).cos() - product * w;
                b.quaternion.0 *= w;
                sum.quaternion.0 = a.quaternion.0 + b.quaternion.0;
                a.quaternion.1 *= (other_weight * theta).cos() - product * w;
                b.quaternion.1 *= w;
                sum.quaternion.1 = a.quaternion.1 + b.quaternion.1;
                a.quaternion.2 *= (other_weight * theta).cos() - product * w;
                b.quaternion.2 *= w;
                sum.quaternion.2 = a.quaternion.2 + b.quaternion.2;
                a.quaternion.3 *= (other_weight * theta).cos() - product * w;
                b.quaternion.3 *= w;
                sum.quaternion.3 = a.quaternion.3 + b.quaternion.3;
        }

        Ok(sum)
    }
}

impl From<MatrixDecomposed3D> for Matrix3D {
    /// Recompose a 3D matrix.
    /// <https://drafts.csswg.org/css-transforms/#recomposing-to-a-3d-matrix>
    fn from(decomposed: MatrixDecomposed3D) -> Matrix3D {
        let mut matrix = Matrix3D::identity();

        // Apply perspective
            matrix.m14 = decomposed.perspective.0;
            matrix.m24 = decomposed.perspective.1;
            matrix.m34 = decomposed.perspective.2;
            matrix.m44 = decomposed.perspective.3;

        // Apply translation
                matrix.m41 += decomposed.translate.0 * matrix.m11;
                matrix.m41 += decomposed.translate.1 * matrix.m21;
                matrix.m41 += decomposed.translate.2 * matrix.m31;
                matrix.m42 += decomposed.translate.0 * matrix.m12;
                matrix.m42 += decomposed.translate.1 * matrix.m22;
                matrix.m42 += decomposed.translate.2 * matrix.m32;
                matrix.m43 += decomposed.translate.0 * matrix.m13;
                matrix.m43 += decomposed.translate.1 * matrix.m23;
                matrix.m43 += decomposed.translate.2 * matrix.m33;

        // Apply rotation
        let x = decomposed.quaternion.0;
        let y = decomposed.quaternion.1;
        let z = decomposed.quaternion.2;
        let w = decomposed.quaternion.3;

        // Construct a composite rotation matrix from the quaternion values
        // rotationMatrix is a identity 4x4 matrix initially
        let mut rotation_matrix = Matrix3D::identity();
        rotation_matrix.m11 = 1.0 - 2.0 * (y * y + z * z) as f32;
        rotation_matrix.m12 = 2.0 * (x * y + z * w) as f32;
        rotation_matrix.m13 = 2.0 * (x * z - y * w) as f32;
        rotation_matrix.m21 = 2.0 * (x * y - z * w) as f32;
        rotation_matrix.m22 = 1.0 - 2.0 * (x * x + z * z) as f32;
        rotation_matrix.m23 = 2.0 * (y * z + x * w) as f32;
        rotation_matrix.m31 = 2.0 * (x * z + y * w) as f32;
        rotation_matrix.m32 = 2.0 * (y * z - x * w) as f32;
        rotation_matrix.m33 = 1.0 - 2.0 * (x * x + y * y) as f32;

        matrix = multiply(rotation_matrix, matrix);

        // Apply skew
        let mut temp = Matrix3D::identity();
        if decomposed.skew.2 != 0.0 {
            temp.m32 = decomposed.skew.2;
            matrix = multiply(temp, matrix);
        }

        if decomposed.skew.1 != 0.0 {
            temp.m32 = 0.0;
            temp.m31 = decomposed.skew.1;
            matrix = multiply(temp, matrix);
        }

        if decomposed.skew.0 != 0.0 {
            temp.m31 = 0.0;
            temp.m21 = decomposed.skew.0;
            matrix = multiply(temp, matrix);
        }

        // Apply scale
                matrix.m11 *= decomposed.scale.0;
                matrix.m12 *= decomposed.scale.0;
                matrix.m13 *= decomposed.scale.0;
                matrix.m21 *= decomposed.scale.1;
                matrix.m22 *= decomposed.scale.1;
                matrix.m23 *= decomposed.scale.1;
                matrix.m31 *= decomposed.scale.2;
                matrix.m32 *= decomposed.scale.2;
                matrix.m33 *= decomposed.scale.2;

        matrix
    }
}

// Multiplication of two 4x4 matrices.
fn multiply(a: Matrix3D, b: Matrix3D) -> Matrix3D {
    let mut a_clone = a;
            a_clone.m11 = (a.m11 * b.m11) +
                               (a.m12 * b.m21) +
                               (a.m13 * b.m31) +
                               (a.m14 * b.m41);
            a_clone.m12 = (a.m11 * b.m12) +
                               (a.m12 * b.m22) +
                               (a.m13 * b.m32) +
                               (a.m14 * b.m42);
            a_clone.m13 = (a.m11 * b.m13) +
                               (a.m12 * b.m23) +
                               (a.m13 * b.m33) +
                               (a.m14 * b.m43);
            a_clone.m14 = (a.m11 * b.m14) +
                               (a.m12 * b.m24) +
                               (a.m13 * b.m34) +
                               (a.m14 * b.m44);
            a_clone.m21 = (a.m21 * b.m11) +
                               (a.m22 * b.m21) +
                               (a.m23 * b.m31) +
                               (a.m24 * b.m41);
            a_clone.m22 = (a.m21 * b.m12) +
                               (a.m22 * b.m22) +
                               (a.m23 * b.m32) +
                               (a.m24 * b.m42);
            a_clone.m23 = (a.m21 * b.m13) +
                               (a.m22 * b.m23) +
                               (a.m23 * b.m33) +
                               (a.m24 * b.m43);
            a_clone.m24 = (a.m21 * b.m14) +
                               (a.m22 * b.m24) +
                               (a.m23 * b.m34) +
                               (a.m24 * b.m44);
            a_clone.m31 = (a.m31 * b.m11) +
                               (a.m32 * b.m21) +
                               (a.m33 * b.m31) +
                               (a.m34 * b.m41);
            a_clone.m32 = (a.m31 * b.m12) +
                               (a.m32 * b.m22) +
                               (a.m33 * b.m32) +
                               (a.m34 * b.m42);
            a_clone.m33 = (a.m31 * b.m13) +
                               (a.m32 * b.m23) +
                               (a.m33 * b.m33) +
                               (a.m34 * b.m43);
            a_clone.m34 = (a.m31 * b.m14) +
                               (a.m32 * b.m24) +
                               (a.m33 * b.m34) +
                               (a.m34 * b.m44);
            a_clone.m41 = (a.m41 * b.m11) +
                               (a.m42 * b.m21) +
                               (a.m43 * b.m31) +
                               (a.m44 * b.m41);
            a_clone.m42 = (a.m41 * b.m12) +
                               (a.m42 * b.m22) +
                               (a.m43 * b.m32) +
                               (a.m44 * b.m42);
            a_clone.m43 = (a.m41 * b.m13) +
                               (a.m42 * b.m23) +
                               (a.m43 * b.m33) +
                               (a.m44 * b.m43);
            a_clone.m44 = (a.m41 * b.m14) +
                               (a.m42 * b.m24) +
                               (a.m43 * b.m34) +
                               (a.m44 * b.m44);
    a_clone
}

impl Matrix3D {
    fn is_3d(&self) -> bool {
        self.m13 != 0.0 || self.m14 != 0.0 ||
        self.m23 != 0.0 || self.m24 != 0.0 ||
        self.m31 != 0.0 || self.m32 != 0.0 || self.m33 != 1.0 || self.m34 != 0.0 ||
        self.m43 != 0.0 || self.m44 != 1.0
    }

    fn determinant(&self) -> CSSFloat {
        self.m14 * self.m23 * self.m32 * self.m41 -
        self.m13 * self.m24 * self.m32 * self.m41 -
        self.m14 * self.m22 * self.m33 * self.m41 +
        self.m12 * self.m24 * self.m33 * self.m41 +
        self.m13 * self.m22 * self.m34 * self.m41 -
        self.m12 * self.m23 * self.m34 * self.m41 -
        self.m14 * self.m23 * self.m31 * self.m42 +
        self.m13 * self.m24 * self.m31 * self.m42 +
        self.m14 * self.m21 * self.m33 * self.m42 -
        self.m11 * self.m24 * self.m33 * self.m42 -
        self.m13 * self.m21 * self.m34 * self.m42 +
        self.m11 * self.m23 * self.m34 * self.m42 +
        self.m14 * self.m22 * self.m31 * self.m43 -
        self.m12 * self.m24 * self.m31 * self.m43 -
        self.m14 * self.m21 * self.m32 * self.m43 +
        self.m11 * self.m24 * self.m32 * self.m43 +
        self.m12 * self.m21 * self.m34 * self.m43 -
        self.m11 * self.m22 * self.m34 * self.m43 -
        self.m13 * self.m22 * self.m31 * self.m44 +
        self.m12 * self.m23 * self.m31 * self.m44 +
        self.m13 * self.m21 * self.m32 * self.m44 -
        self.m11 * self.m23 * self.m32 * self.m44 -
        self.m12 * self.m21 * self.m33 * self.m44 +
        self.m11 * self.m22 * self.m33 * self.m44
    }

    fn inverse(&self) -> Option<Matrix3D> {
        let mut det = self.determinant();

        if det == 0.0 {
            return None;
        }

        det = 1.0 / det;
        let x = Matrix3D {
            m11: det *
            (self.m23*self.m34*self.m42 - self.m24*self.m33*self.m42 +
             self.m24*self.m32*self.m43 - self.m22*self.m34*self.m43 -
             self.m23*self.m32*self.m44 + self.m22*self.m33*self.m44),
            m12: det *
            (self.m14*self.m33*self.m42 - self.m13*self.m34*self.m42 -
             self.m14*self.m32*self.m43 + self.m12*self.m34*self.m43 +
             self.m13*self.m32*self.m44 - self.m12*self.m33*self.m44),
            m13: det *
            (self.m13*self.m24*self.m42 - self.m14*self.m23*self.m42 +
             self.m14*self.m22*self.m43 - self.m12*self.m24*self.m43 -
             self.m13*self.m22*self.m44 + self.m12*self.m23*self.m44),
            m14: det *
            (self.m14*self.m23*self.m32 - self.m13*self.m24*self.m32 -
             self.m14*self.m22*self.m33 + self.m12*self.m24*self.m33 +
             self.m13*self.m22*self.m34 - self.m12*self.m23*self.m34),
            m21: det *
            (self.m24*self.m33*self.m41 - self.m23*self.m34*self.m41 -
             self.m24*self.m31*self.m43 + self.m21*self.m34*self.m43 +
             self.m23*self.m31*self.m44 - self.m21*self.m33*self.m44),
            m22: det *
            (self.m13*self.m34*self.m41 - self.m14*self.m33*self.m41 +
             self.m14*self.m31*self.m43 - self.m11*self.m34*self.m43 -
             self.m13*self.m31*self.m44 + self.m11*self.m33*self.m44),
            m23: det *
            (self.m14*self.m23*self.m41 - self.m13*self.m24*self.m41 -
             self.m14*self.m21*self.m43 + self.m11*self.m24*self.m43 +
             self.m13*self.m21*self.m44 - self.m11*self.m23*self.m44),
            m24: det *
            (self.m13*self.m24*self.m31 - self.m14*self.m23*self.m31 +
             self.m14*self.m21*self.m33 - self.m11*self.m24*self.m33 -
             self.m13*self.m21*self.m34 + self.m11*self.m23*self.m34),
            m31: det *
            (self.m22*self.m34*self.m41 - self.m24*self.m32*self.m41 +
             self.m24*self.m31*self.m42 - self.m21*self.m34*self.m42 -
             self.m22*self.m31*self.m44 + self.m21*self.m32*self.m44),
            m32: det *
            (self.m14*self.m32*self.m41 - self.m12*self.m34*self.m41 -
             self.m14*self.m31*self.m42 + self.m11*self.m34*self.m42 +
             self.m12*self.m31*self.m44 - self.m11*self.m32*self.m44),
            m33: det *
            (self.m12*self.m24*self.m41 - self.m14*self.m22*self.m41 +
             self.m14*self.m21*self.m42 - self.m11*self.m24*self.m42 -
             self.m12*self.m21*self.m44 + self.m11*self.m22*self.m44),
            m34: det *
            (self.m14*self.m22*self.m31 - self.m12*self.m24*self.m31 -
             self.m14*self.m21*self.m32 + self.m11*self.m24*self.m32 +
             self.m12*self.m21*self.m34 - self.m11*self.m22*self.m34),
            m41: det *
            (self.m23*self.m32*self.m41 - self.m22*self.m33*self.m41 -
             self.m23*self.m31*self.m42 + self.m21*self.m33*self.m42 +
             self.m22*self.m31*self.m43 - self.m21*self.m32*self.m43),
            m42: det *
            (self.m12*self.m33*self.m41 - self.m13*self.m32*self.m41 +
             self.m13*self.m31*self.m42 - self.m11*self.m33*self.m42 -
             self.m12*self.m31*self.m43 + self.m11*self.m32*self.m43),
            m43: det *
            (self.m13*self.m22*self.m41 - self.m12*self.m23*self.m41 -
             self.m13*self.m21*self.m42 + self.m11*self.m23*self.m42 +
             self.m12*self.m21*self.m43 - self.m11*self.m22*self.m43),
            m44: det *
            (self.m12*self.m23*self.m31 - self.m13*self.m22*self.m31 +
             self.m13*self.m21*self.m32 - self.m11*self.m23*self.m32 -
             self.m12*self.m21*self.m33 + self.m11*self.m22*self.m33),
        };

        Some(x)
    }
}

/// <https://drafts.csswg.org/css-transforms/#interpolation-of-transforms>
impl Animate for ComputedTransform {
    #[inline]
    fn animate(
        &self,
        other_: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {

        let animate_equal_lists = |this: &[ComputedTransformOperation],
                                   other: &[ComputedTransformOperation]|
                                   -> Result<ComputedTransform, ()> {
            Ok(Transform(this.iter().zip(other)
                             .map(|(this, other)| this.animate(other, procedure))
                             .collect::<Result<Vec<_>, _>>()?))
            // If we can't animate for a pair of matched transform lists
            // this means we have at least one undecomposable matrix,
            // so we should bubble out Err here, and let the caller do
            // the fallback procedure.
        };
        if self.0.is_empty() && other_.0.is_empty() {
            return Ok(Transform(vec![]));
        }


        let this = &self.0;
        let other = &other_.0;

        if procedure == Procedure::Add {
            let result = this.iter().chain(other).cloned().collect::<Vec<_>>();
            return Ok(Transform(result));
        }


        // For matched transform lists.
        {
            if this.len() == other.len() {
                let is_matched_transforms = this.iter().zip(other).all(|(this, other)| {
                    is_matched_operation(this, other)
                });

                if is_matched_transforms {
                    return animate_equal_lists(this, other);
                }
            }
        }

        // For mismatched transform lists.
        let mut owned_this = this.clone();
        let mut owned_other = other.clone();

        if this.is_empty() {
            let this = other_.to_animated_zero()?.0;
            if this.iter().zip(other).all(|(this, other)| is_matched_operation(this, other)) {
                return animate_equal_lists(&this, other)
            }
            owned_this = this;
        }
        if other.is_empty() {
            let other = self.to_animated_zero()?.0;
            if this.iter().zip(&other).all(|(this, other)| is_matched_operation(this, other)) {
                return animate_equal_lists(this, &other)
            }
            owned_other = other;
        }

        match procedure {
            Procedure::Add => Err(()),
            Procedure::Interpolate { progress } => {
                Ok(Transform(vec![TransformOperation::InterpolateMatrix {
                    from_list: Transform(owned_this),
                    to_list: Transform(owned_other),
                    progress: Percentage(progress as f32),
                }]))
            },
            Procedure::Accumulate { count } => {
                Ok(Transform(vec![TransformOperation::AccumulateMatrix {
                    from_list: Transform(owned_this),
                    to_list: Transform(owned_other),
                    count: cmp::min(count, i32::max_value() as u64) as i32,
                }]))
            },
        }
    }
}

// This might not be the most useful definition of distance. It might be better, for example,
// to trace the distance travelled by a point as its transform is interpolated between the two
// lists. That, however, proves to be quite complicated so we take a simple approach for now.
// See https://bugzilla.mozilla.org/show_bug.cgi?id=1318591#c0.
impl ComputeSquaredDistance for ComputedTransformOperation {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        // For translate, We don't want to require doing layout in order to calculate the result, so
        // drop the percentage part. However, dropping percentage makes us impossible to
        // compute the distance for the percentage-percentage case, but Gecko uses the
        // same formula, so it's fine for now.
        // Note: We use pixel value to compute the distance for translate, so we have to
        // convert Au into px.
        let extract_pixel_length = |lop: &LengthOrPercentage| {
            match *lop {
                LengthOrPercentage::Length(px) => px.px(),
                LengthOrPercentage::Percentage(_) => 0.,
                LengthOrPercentage::Calc(calc) => calc.length().px(),
            }
        };
        match (self, other) {
            (
                &TransformOperation::Matrix3D(ref this),
                &TransformOperation::Matrix3D(ref other),
            ) => {
                this.compute_squared_distance(other)
            },
            (
                &TransformOperation::Matrix(ref this),
                &TransformOperation::Matrix(ref other),
            ) => {
                let this: Matrix3D = (*this).into();
                let other: Matrix3D = (*other).into();
                this.compute_squared_distance(&other)
            },


            (
                &TransformOperation::Skew(ref fx, ref fy),
                &TransformOperation::Skew(ref tx, ref ty),
            ) => {
                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)?,
                )
            },
            (
                &TransformOperation::SkewX(ref f),
                &TransformOperation::SkewX(ref t),
            ) | (
                &TransformOperation::SkewY(ref f),
                &TransformOperation::SkewY(ref t),
            ) => {
                f.compute_squared_distance(&t)
            },
            (
                &TransformOperation::Translate3D(ref fx, ref fy, ref fz),
                &TransformOperation::Translate3D(ref tx, ref ty, ref tz),
            ) => {
                let fx = extract_pixel_length(&fx);
                let fy = extract_pixel_length(&fy);
                let tx = extract_pixel_length(&tx);
                let ty = extract_pixel_length(&ty);

                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)? +
                    fz.compute_squared_distance(&tz)?,
                )
            },
            (
                &TransformOperation::Scale3D(ref fx, ref fy, ref fz),
                &TransformOperation::Scale3D(ref tx, ref ty, ref tz),
            ) => {
                Ok(
                    fx.compute_squared_distance(&tx)? +
                    fy.compute_squared_distance(&ty)? +
                    fz.compute_squared_distance(&tz)?,
                )
            },
            (
                &TransformOperation::Rotate3D(fx, fy, fz, fa),
                &TransformOperation::Rotate3D(tx, ty, tz, ta),
            ) => {
                let (fx, fy, fz, angle1) =
                    transform::get_normalized_vector_and_angle(fx, fy, fz, fa);
                let (tx, ty, tz, angle2) =
                    transform::get_normalized_vector_and_angle(tx, ty, tz, ta);
                if (fx, fy, fz) == (tx, ty, tz) {
                    angle1.compute_squared_distance(&angle2)
                } else {
                    let v1 = DirectionVector::new(fx, fy, fz);
                    let v2 = DirectionVector::new(tx, ty, tz);
                    let q1 = Quaternion::from_direction_and_angle(&v1, angle1.radians64());
                    let q2 = Quaternion::from_direction_and_angle(&v2, angle2.radians64());
                    q1.compute_squared_distance(&q2)
                }
            }
            (
                &TransformOperation::RotateX(fa),
                &TransformOperation::RotateX(ta),
            ) |
            (
                &TransformOperation::RotateY(fa),
                &TransformOperation::RotateY(ta),
            ) |
            (
                &TransformOperation::RotateZ(fa),
                &TransformOperation::RotateZ(ta),
            ) |
            (
                &TransformOperation::Rotate(fa),
                &TransformOperation::Rotate(ta),
            ) => {
                fa.compute_squared_distance(&ta)
            }
            (
                &TransformOperation::Perspective(ref fd),
                &TransformOperation::Perspective(ref td),
            ) => {
                let mut fd_matrix = Matrix3D::identity();
                let mut td_matrix = Matrix3D::identity();
                if fd.px() > 0. {
                    fd_matrix.m34 = -1. / fd.px();
                }

                if td.px() > 0. {
                    td_matrix.m34 = -1. / td.px();
                }
                fd_matrix.compute_squared_distance(&td_matrix)
            }
            (
                &TransformOperation::Perspective(ref p),
                &TransformOperation::Matrix3D(ref m),
            ) | (
                &TransformOperation::Matrix3D(ref m),
                &TransformOperation::Perspective(ref p),
            ) => {
                let mut p_matrix = Matrix3D::identity();
                if p.px() > 0. {
                    p_matrix.m34 = -1. / p.px();
                }
                p_matrix.compute_squared_distance(&m)
            }
            // Gecko cross-interpolates amongst all translate and all scale
            // functions (See ToPrimitive in layout/style/StyleAnimationValue.cpp)
            // without falling back to InterpolateMatrix
            _ if self.is_translate() && other.is_translate() => {
                self.to_translate_3d().compute_squared_distance(&other.to_translate_3d())
            }
            _ if self.is_scale() && other.is_scale() => {
                self.to_scale_3d().compute_squared_distance(&other.to_scale_3d())
            }
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for ComputedTransform {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        let list1 = &self.0;
        let list2 = &other.0;

        let squared_dist: Result<SquaredDistance, _> = list1.iter().zip_longest(list2).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.compute_squared_distance(other)
                },
                EitherOrBoth::Left(list) | EitherOrBoth::Right(list) => {
                    list.to_animated_zero()?.compute_squared_distance(list)
                },
            }
        }).sum();

        // Roll back to matrix interpolation if there is any Err(()) in the transform lists, such
        // as mismatched transform functions.
        if let Err(_) = squared_dist {
            let matrix1: Matrix3D = self.to_transform_3d_matrix(None)?.0.into();
            let matrix2: Matrix3D = other.to_transform_3d_matrix(None)?.0.into();
            return matrix1.compute_squared_distance(&matrix2);
        }
        squared_dist
    }
}

/// Animated SVGPaint
pub type IntermediateSVGPaint = SVGPaint<AnimatedRGBA, ComputedUrl>;

/// Animated SVGPaintKind
pub type IntermediateSVGPaintKind = SVGPaintKind<AnimatedRGBA, ComputedUrl>;

impl ToAnimatedZero for IntermediateSVGPaint {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Ok(IntermediateSVGPaint {
            kind: self.kind.to_animated_zero()?,
            fallback: self.fallback.and_then(|v| v.to_animated_zero().ok()),
        })
    }
}

impl From<NonNegativeLengthOrPercentage> for NumberOrPercentage {
    fn from(lop: NonNegativeLengthOrPercentage) -> NumberOrPercentage {
        lop.0.into()
    }
}

impl From<NonNegativeNumber> for NumberOrPercentage {
    fn from(num: NonNegativeNumber) -> NumberOrPercentage {
        num.0.into()
    }
}

impl From<LengthOrPercentage> for NumberOrPercentage {
    fn from(lop: LengthOrPercentage) -> NumberOrPercentage {
        match lop {
            LengthOrPercentage::Length(len) => NumberOrPercentage::Number(len.px()),
            LengthOrPercentage::Percentage(p) => NumberOrPercentage::Percentage(p),
            LengthOrPercentage::Calc(_) => {
                panic!("We dont't expected calc interpolation for SvgLengthOrPercentageOrNumber");
            },
        }
    }
}

impl From<Number> for NumberOrPercentage {
    fn from(num: Number) -> NumberOrPercentage {
        NumberOrPercentage::Number(num)
    }
}

fn convert_to_number_or_percentage<LengthOrPercentageType, NumberType>(
    from: SvgLengthOrPercentageOrNumber<LengthOrPercentageType, NumberType>)
    -> NumberOrPercentage
    where LengthOrPercentageType: Into<NumberOrPercentage>,
          NumberType: Into<NumberOrPercentage>
{
    match from {
        SvgLengthOrPercentageOrNumber::LengthOrPercentage(lop) => {
            lop.into()
        }
        SvgLengthOrPercentageOrNumber::Number(num) => {
            num.into()
        }
    }
}

fn convert_from_number_or_percentage<LengthOrPercentageType, NumberType>(
    from: NumberOrPercentage)
    -> SvgLengthOrPercentageOrNumber<LengthOrPercentageType, NumberType>
    where LengthOrPercentageType: From<LengthOrPercentage>,
          NumberType: From<Number>
{
    match from {
        NumberOrPercentage::Number(num) =>
            SvgLengthOrPercentageOrNumber::Number(num.into()),
        NumberOrPercentage::Percentage(p) =>
            SvgLengthOrPercentageOrNumber::LengthOrPercentage(
                (LengthOrPercentage::Percentage(p)).into())
    }
}

impl <L, N> Animate for SvgLengthOrPercentageOrNumber<L, N>
where
    L: Animate + From<LengthOrPercentage> + Into<NumberOrPercentage> + Copy,
    N: Animate + From<Number> + Into<NumberOrPercentage>,
    LengthOrPercentage: From<L>,
    Self: Copy,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if self.has_calc() || other.has_calc() {
            // TODO: We need to treat calc value.
            // https://bugzilla.mozilla.org/show_bug.cgi?id=1386967
            return Err(());
        }

        let this = convert_to_number_or_percentage(*self);
        let other = convert_to_number_or_percentage(*other);

        match (this, other) {
            (
                NumberOrPercentage::Number(ref this),
                NumberOrPercentage::Number(ref other),
            ) => {
                Ok(convert_from_number_or_percentage(
                    NumberOrPercentage::Number(this.animate(other, procedure)?)
                ))
            },
            (
                NumberOrPercentage::Percentage(ref this),
                NumberOrPercentage::Percentage(ref other),
            ) => {
                Ok(convert_from_number_or_percentage(
                    NumberOrPercentage::Percentage(this.animate(other, procedure)?)
                ))
            },
            _ => Err(()),
        }
    }
}

impl<L> Animate for SVGLength<L>
where
    L: Animate + Clone,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (&SVGLength::Length(ref this), &SVGLength::Length(ref other)) => {
                Ok(SVGLength::Length(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

/// <https://www.w3.org/TR/SVG11/painting.html#StrokeDasharrayProperty>
impl<L> Animate for SVGStrokeDashArray<L>
where
    L: Clone + RepeatableListAnimatable,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        if matches!(procedure, Procedure::Add | Procedure::Accumulate { .. }) {
            // Non-additive.
            return Err(());
        }
        match (self, other) {
            (&SVGStrokeDashArray::Values(ref this), &SVGStrokeDashArray::Values(ref other)) => {
                Ok(SVGStrokeDashArray::Values(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

impl<L> ToAnimatedZero for SVGStrokeDashArray<L>
where
    L: ToAnimatedZero,
{
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            SVGStrokeDashArray::Values(ref values) => {
                Ok(SVGStrokeDashArray::Values(
                    values.iter().map(ToAnimatedZero::to_animated_zero).collect::<Result<Vec<_>, _>>()?,
                ))
            }
            SVGStrokeDashArray::ContextValue => Ok(SVGStrokeDashArray::ContextValue),
        }
    }
}

impl<O> Animate for SVGOpacity<O>
where
    O: Animate + Clone,
{
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match (self, other) {
            (&SVGOpacity::Opacity(ref this), &SVGOpacity::Opacity(ref other)) => {
                Ok(SVGOpacity::Opacity(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}



/// <https://drafts.fxtf.org/filters/#animation-of-filters>
impl Animate for AnimatedFilter {
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        match (self, other) {
            (&Filter::Blur(ref this), &Filter::Blur(ref other)) => {
                Ok(Filter::Blur(this.animate(other, procedure)?))
            },
            (&Filter::Grayscale(ref this), &Filter::Grayscale(ref other)) => {
                Ok(Filter::Grayscale(this.animate(other, procedure)?))
            },
            (&Filter::HueRotate(ref this), &Filter::HueRotate(ref other)) => {
                Ok(Filter::HueRotate(this.animate(other, procedure)?))
            },
            (&Filter::Invert(ref this), &Filter::Invert(ref other)) => {
                Ok(Filter::Invert(this.animate(other, procedure)?))
            },
            (&Filter::Sepia(ref this), &Filter::Sepia(ref other)) => {
                Ok(Filter::Sepia(this.animate(other, procedure)?))
            },
            (&Filter::Brightness(ref this), &Filter::Brightness(ref other)) => {
                Ok(Filter::Brightness(NonNegative(animate_multiplicative_factor(
                    this.0,
                    other.0,
                    procedure,
                )?)))
            },
            (&Filter::Contrast(ref this), &Filter::Contrast(ref other)) => {
                Ok(Filter::Contrast(NonNegative(animate_multiplicative_factor(
                    this.0,
                    other.0,
                    procedure,
                )?)))
            },
            (&Filter::Opacity(ref this), &Filter::Opacity(ref other)) => {
                Ok(Filter::Opacity(NonNegative(animate_multiplicative_factor(
                    this.0,
                    other.0,
                    procedure,
                )?)))
            },
            (&Filter::Saturate(ref this), &Filter::Saturate(ref other)) => {
                Ok(Filter::Saturate(NonNegative(animate_multiplicative_factor(
                    this.0,
                    other.0,
                    procedure,
                )?)))
            },
            (&Filter::DropShadow(ref this), &Filter::DropShadow(ref other)) => {
                Ok(Filter::DropShadow(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

/// <http://dev.w3.org/csswg/css-transforms/#none-transform-animation>
impl ToAnimatedZero for AnimatedFilter {
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            Filter::Blur(ref this) => Ok(Filter::Blur(this.to_animated_zero()?)),
            Filter::Grayscale(ref this) => Ok(Filter::Grayscale(this.to_animated_zero()?)),
            Filter::HueRotate(ref this) => Ok(Filter::HueRotate(this.to_animated_zero()?)),
            Filter::Invert(ref this) => Ok(Filter::Invert(this.to_animated_zero()?)),
            Filter::Sepia(ref this) => Ok(Filter::Sepia(this.to_animated_zero()?)),
            Filter::Brightness(_) => Ok(Filter::Brightness(NonNegative(1.))),
            Filter::Contrast(_) => Ok(Filter::Contrast(NonNegative(1.))),
            Filter::Opacity(_) => Ok(Filter::Opacity(NonNegative(1.))),
            Filter::Saturate(_) => Ok(Filter::Saturate(NonNegative(1.))),
            Filter::DropShadow(ref this) => Ok(Filter::DropShadow(this.to_animated_zero()?)),
            _ => Err(()),
        }
    }
}

// FIXME(nox): This should be derived.
impl ComputeSquaredDistance for AnimatedFilter {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        match (self, other) {
            (&Filter::Blur(ref this), &Filter::Blur(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Brightness(ref this), &Filter::Brightness(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Contrast(ref this), &Filter::Contrast(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Grayscale(ref this), &Filter::Grayscale(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::HueRotate(ref this), &Filter::HueRotate(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Invert(ref this), &Filter::Invert(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Opacity(ref this), &Filter::Opacity(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Saturate(ref this), &Filter::Saturate(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::Sepia(ref this), &Filter::Sepia(ref other)) => {
                this.compute_squared_distance(other)
            },
            (&Filter::DropShadow(ref this), &Filter::DropShadow(ref other)) => {
                this.compute_squared_distance(other)
            },
            _ => Err(()),
        }
    }
}

impl Animate for AnimatedFilterList {
    #[inline]
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        if procedure == Procedure::Add {
            return Ok(AnimatedFilterList(
                self.0.iter().chain(other.0.iter()).cloned().collect(),
            ));
        }
        Ok(AnimatedFilterList(self.0.iter().zip_longest(other.0.iter()).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.animate(other, procedure)
                },
                EitherOrBoth::Left(this) => {
                    this.animate(&this.to_animated_zero()?, procedure)
                },
                EitherOrBoth::Right(other) => {
                    other.to_animated_zero()?.animate(other, procedure)
                },
            }
        }).collect::<Result<Vec<_>, _>>()?))
    }
}

impl ComputeSquaredDistance for AnimatedFilterList {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        self.0.iter().zip_longest(other.0.iter()).map(|it| {
            match it {
                EitherOrBoth::Both(this, other) => {
                    this.compute_squared_distance(other)
                },
                EitherOrBoth::Left(list) | EitherOrBoth::Right(list) => {
                    list.to_animated_zero()?.compute_squared_distance(list)
                },
            }
        }).sum()
    }
}

/// A comparator to sort PropertyIds such that longhands are sorted before shorthands,
/// shorthands with fewer components are sorted before shorthands with more components,
/// and otherwise shorthands are sorted by IDL name as defined by [Web Animations][property-order].
///
/// Using this allows us to prioritize values specified by longhands (or smaller
/// shorthand subsets) when longhands and shorthands are both specified on the one keyframe.
///
/// Example orderings that result from this:
///
///   margin-left, margin
///
/// and:
///
///   border-top-color, border-color, border-top, border
///
/// [property-order] https://drafts.csswg.org/web-animations/#calculating-computed-keyframes
#[cfg(feature = "gecko")]
pub fn compare_property_priority(a: &PropertyId, b: &PropertyId) -> cmp::Ordering {
    match (a.as_shorthand(), b.as_shorthand()) {
        // Within shorthands, sort by the number of subproperties, then by IDL name.
        (Ok(a), Ok(b)) => {
            let subprop_count_a = a.longhands().len();
            let subprop_count_b = b.longhands().len();
            subprop_count_a.cmp(&subprop_count_b).then_with(
                || get_idl_name_sort_order(&a).cmp(&get_idl_name_sort_order(&b)))
        },

        // Longhands go before shorthands.
        (Ok(_), Err(_)) => cmp::Ordering::Greater,
        (Err(_), Ok(_)) => cmp::Ordering::Less,

        // Both are longhands or custom properties in which case they don't overlap and should
        // sort equally.
        _ => cmp::Ordering::Equal,
    }
}

#[cfg(feature = "gecko")]
fn get_idl_name_sort_order(shorthand: &ShorthandId) -> u32 {

    match *shorthand {
            ShorthandId::MozOutlineRadius => 0,
            ShorthandId::MozTransform => 1,
            ShorthandId::WebkitTextStroke => 2,
            ShorthandId::All => 3,
            ShorthandId::Animation => 4,
            ShorthandId::Background => 5,
            ShorthandId::BackgroundPosition => 6,
            ShorthandId::Border => 7,
            ShorthandId::BorderBlockEnd => 8,
            ShorthandId::BorderBlockStart => 9,
            ShorthandId::BorderBottom => 10,
            ShorthandId::BorderColor => 11,
            ShorthandId::BorderImage => 12,
            ShorthandId::BorderInlineEnd => 13,
            ShorthandId::BorderInlineStart => 14,
            ShorthandId::BorderLeft => 15,
            ShorthandId::BorderRadius => 16,
            ShorthandId::BorderRight => 17,
            ShorthandId::BorderStyle => 18,
            ShorthandId::BorderTop => 19,
            ShorthandId::BorderWidth => 20,
            ShorthandId::ColumnRule => 21,
            ShorthandId::Columns => 22,
            ShorthandId::Flex => 23,
            ShorthandId::FlexFlow => 24,
            ShorthandId::Font => 25,
            ShorthandId::FontVariant => 26,
            ShorthandId::Grid => 27,
            ShorthandId::GridArea => 28,
            ShorthandId::GridColumn => 29,
            ShorthandId::GridGap => 30,
            ShorthandId::GridRow => 31,
            ShorthandId::GridTemplate => 32,
            ShorthandId::ListStyle => 33,
            ShorthandId::Margin => 34,
            ShorthandId::Marker => 35,
            ShorthandId::Mask => 36,
            ShorthandId::MaskPosition => 37,
            ShorthandId::Outline => 38,
            ShorthandId::Overflow => 39,
            ShorthandId::OverflowClipBox => 40,
            ShorthandId::OverscrollBehavior => 41,
            ShorthandId::Padding => 42,
            ShorthandId::PlaceContent => 43,
            ShorthandId::PlaceItems => 44,
            ShorthandId::PlaceSelf => 45,
            ShorthandId::ScrollSnapType => 46,
            ShorthandId::TextDecoration => 47,
            ShorthandId::TextEmphasis => 48,
            ShorthandId::Transition => 49,
    }
}

}

/// A longhand or shorthand porperty
#[derive(Clone, Copy, Debug)]
pub struct NonCustomPropertyId(usize);

impl From<LonghandId> for NonCustomPropertyId {
    fn from(id: LonghandId) -> Self {
        NonCustomPropertyId(id as usize)
    }
}

impl From<ShorthandId> for NonCustomPropertyId {
    fn from(id: ShorthandId) -> Self {
        NonCustomPropertyId((id as usize) + 326)
    }
}

impl From<AliasId> for NonCustomPropertyId {
    fn from(id: AliasId) -> Self {
        NonCustomPropertyId(id as usize + 376)
    }
}

/// A set of all properties
#[derive(Clone, PartialEq)]
pub struct NonCustomPropertyIdSet {
    storage: [u32; (485 - 1 + 32) / 32]
}

impl NonCustomPropertyIdSet {
    /// Return whether the given property is in the set
    #[inline]
    pub fn contains(&self, id: NonCustomPropertyId) -> bool {
        let bit = id.0;
        (self.storage[bit / 32] & (1 << (bit % 32))) != 0
    }
}





/// A set of longhand properties
#[derive(Clone, Debug, MallocSizeOf, PartialEq)]
pub struct LonghandIdSet {
    storage: [u32; (326 - 1 + 32) / 32]
}

/// An iterator over a set of longhand ids.
pub struct LonghandIdSetIterator<'a> {
    longhands: &'a LonghandIdSet,
    cur: usize,
}

impl<'a> Iterator for LonghandIdSetIterator<'a> {
    type Item = LonghandId;

    fn next(&mut self) -> Option<Self::Item> {
        use std::mem;

        loop {
            if self.cur >= 326 {
                return None;
            }

            let id: LonghandId = unsafe { mem::transmute(self.cur as u16) };
            self.cur += 1;

            if self.longhands.contains(id) {
                return Some(id);
            }
        }
    }
}

impl LonghandIdSet {
    /// Iterate over the current longhand id set.
    pub fn iter(&self) -> LonghandIdSetIterator {
        LonghandIdSetIterator { longhands: self, cur: 0, }
    }

    /// Returns whether this set contains at least every longhand that `other`
    /// also contains.
    pub fn contains_all(&self, other: &Self) -> bool {
        for (self_cell, other_cell) in self.storage.iter().zip(other.storage.iter()) {
            if (*self_cell & *other_cell) != *other_cell {
                return false;
            }
        }
        true
    }

    /// Returns whether this set contains any longhand that `other` also contains.
    pub fn contains_any(&self, other: &Self) -> bool {
        for (self_cell, other_cell) in self.storage.iter().zip(other.storage.iter()) {
            if (*self_cell & *other_cell) != 0 {
                return true;
            }
        }
        false
    }

    /// Create an empty set
    #[inline]
    pub fn new() -> LonghandIdSet {
        LonghandIdSet { storage: [0; (326 - 1 + 32) / 32] }
    }

    /// Return whether the given property is in the set
    #[inline]
    pub fn contains(&self, id: LonghandId) -> bool {
        let bit = id as usize;
        (self.storage[bit / 32] & (1 << (bit % 32))) != 0
    }

    /// Return whether this set contains any reset longhand.
    #[inline]
    pub fn contains_any_reset(&self) -> bool {
        
static RESET: LonghandIdSet = LonghandIdSet {
    
    storage: [0xffffffff, 0xffffffff, 0xffffffff, 0x1fffef, 0x0, 0xfc000000, 0xff03ffff, 0xffffffff, 0xffffff, 0xffffe000, 0x3f]
};

        self.contains_any(&RESET)
    }

    /// Add the given property to the set
    #[inline]
    pub fn insert(&mut self, id: LonghandId) {
        let bit = id as usize;
        self.storage[bit / 32] |= 1 << (bit % 32);
    }

    /// Remove the given property from the set
    #[inline]
    pub fn remove(&mut self, id: LonghandId) {
        let bit = id as usize;
        self.storage[bit / 32] &= !(1 << (bit % 32));
    }

    /// Clear all bits
    #[inline]
    pub fn clear(&mut self) {
        for cell in &mut self.storage {
            *cell = 0
        }
    }

    /// Returns whether the set is empty.
    #[inline]
    pub fn is_empty(&self) -> bool {
        self.storage.iter().all(|c| *c == 0)
    }
}

/// A specialized set of PropertyDeclarationId
pub struct PropertyDeclarationIdSet {
    longhands: LonghandIdSet,

    // FIXME: Use a HashSet instead? This Vec is usually small, so linear scan might be ok.
    custom: Vec<::custom_properties::Name>,
}

impl PropertyDeclarationIdSet {
    /// Empty set
    pub fn new() -> Self {
        PropertyDeclarationIdSet {
            longhands: LonghandIdSet::new(),
            custom: Vec::new(),
        }
    }

    /// Returns all the longhands that this set contains.
    pub fn longhands(&self) -> &LonghandIdSet {
        &self.longhands
    }

    /// Returns whether the set is empty.
    #[inline]
    pub fn is_empty(&self) -> bool {
        self.longhands.is_empty() && self.custom.is_empty()
    }

    /// Clears the set.
    #[inline]
    pub fn clear(&mut self) {
        self.longhands.clear();
        self.custom.clear();
    }

    /// Returns whether the given ID is in the set
    pub fn contains(&mut self, id: PropertyDeclarationId) -> bool {
        match id {
            PropertyDeclarationId::Longhand(id) => self.longhands.contains(id),
            PropertyDeclarationId::Custom(name) => self.custom.contains(name),
        }
    }

    /// Insert the given ID in the set
    pub fn insert(&mut self, id: PropertyDeclarationId) {
        match id {
            PropertyDeclarationId::Longhand(id) => self.longhands.insert(id),
            PropertyDeclarationId::Custom(name) => {
                if !self.custom.contains(name) {
                    self.custom.push(name.clone())
                }
            }
        }
    }
}

/// An enum to represent a CSS Wide keyword.
#[derive(Clone, Copy, Debug, Eq, MallocSizeOf, PartialEq, ToCss)]
pub enum CSSWideKeyword {
    /// The `initial` keyword.
    Initial,
    /// The `inherit` keyword.
    Inherit,
    /// The `unset` keyword.
    Unset,
}

impl CSSWideKeyword {
    fn to_str(&self) -> &'static str {
        match *self {
            CSSWideKeyword::Initial => "initial",
            CSSWideKeyword::Inherit => "inherit",
            CSSWideKeyword::Unset => "unset",
        }
    }

    /// Takes the result of cssparser::Parser::expect_ident() and converts it
    /// to a CSSWideKeyword.
    pub fn from_ident<'i>(ident: &str) -> Option<Self> {
        match_ignore_ascii_case! { ident,
            // If modifying this set of keyword, also update values::CustomIdent::from_ident
            "initial" => Some(CSSWideKeyword::Initial),
            "inherit" => Some(CSSWideKeyword::Inherit),
            "unset" => Some(CSSWideKeyword::Unset),
            _ => None
        }
    }
}

impl CSSWideKeyword {
    fn parse(input: &mut Parser) -> Result<Self, ()> {
        let ident = input.expect_ident().map_err(|_| ())?.clone();
        input.expect_exhausted().map_err(|_| ())?;
        CSSWideKeyword::from_ident(&ident).ok_or(())
    }
}

bitflags! {
    /// A set of flags for properties.
    pub struct PropertyFlags: u8 {
        /// This property requires a stacking context.
        const CREATES_STACKING_CONTEXT = 1 << 0;
        /// This property has values that can establish a containing block for
        /// fixed positioned and absolutely positioned elements.
        const FIXPOS_CB = 1 << 1;
        /// This property has values that can establish a containing block for
        /// absolutely positioned elements.
        const ABSPOS_CB = 1 << 2;
        /// This shorthand property is an alias of another property.
        const SHORTHAND_ALIAS_PROPERTY = 1 << 3;
        /// This longhand property applies to ::first-letter.
        const APPLIES_TO_FIRST_LETTER = 1 << 4;
        /// This longhand property applies to ::first-line.
        const APPLIES_TO_FIRST_LINE = 1 << 5;
        /// This longhand property applies to ::placeholder.
        const APPLIES_TO_PLACEHOLDER = 1 << 6;
    }
}

/// An identifier for a given longhand property.
#[derive(Clone, Copy, Eq, Hash, MallocSizeOf, PartialEq)]
pub enum LonghandId {
        /// background-color
        BackgroundColor = 0,
        /// background-image
        BackgroundImage = 1,
        /// background-position-x
        BackgroundPositionX = 2,
        /// background-position-y
        BackgroundPositionY = 3,
        /// background-repeat
        BackgroundRepeat = 4,
        /// background-attachment
        BackgroundAttachment = 5,
        /// background-clip
        BackgroundClip = 6,
        /// background-origin
        BackgroundOrigin = 7,
        /// background-size
        BackgroundSize = 8,
        /// background-blend-mode
        BackgroundBlendMode = 9,
        /// border-top-color
        BorderTopColor = 10,
        /// border-top-style
        BorderTopStyle = 11,
        /// border-top-width
        BorderTopWidth = 12,
        /// border-left-color
        BorderLeftColor = 13,
        /// border-left-style
        BorderLeftStyle = 14,
        /// border-left-width
        BorderLeftWidth = 15,
        /// border-bottom-color
        BorderBottomColor = 16,
        /// border-bottom-style
        BorderBottomStyle = 17,
        /// border-bottom-width
        BorderBottomWidth = 18,
        /// border-right-color
        BorderRightColor = 19,
        /// border-right-style
        BorderRightStyle = 20,
        /// border-right-width
        BorderRightWidth = 21,
        /// border-block-start-color
        BorderBlockStartColor = 22,
        /// border-block-start-style
        BorderBlockStartStyle = 23,
        /// border-block-start-width
        BorderBlockStartWidth = 24,
        /// border-block-end-color
        BorderBlockEndColor = 25,
        /// border-block-end-style
        BorderBlockEndStyle = 26,
        /// border-block-end-width
        BorderBlockEndWidth = 27,
        /// border-inline-start-color
        BorderInlineStartColor = 28,
        /// border-inline-start-style
        BorderInlineStartStyle = 29,
        /// border-inline-start-width
        BorderInlineStartWidth = 30,
        /// border-inline-end-color
        BorderInlineEndColor = 31,
        /// border-inline-end-style
        BorderInlineEndStyle = 32,
        /// border-inline-end-width
        BorderInlineEndWidth = 33,
        /// border-top-left-radius
        BorderTopLeftRadius = 34,
        /// border-top-right-radius
        BorderTopRightRadius = 35,
        /// border-bottom-right-radius
        BorderBottomRightRadius = 36,
        /// border-bottom-left-radius
        BorderBottomLeftRadius = 37,
        /// -moz-border-top-colors
        MozBorderTopColors = 38,
        /// -moz-border-left-colors
        MozBorderLeftColors = 39,
        /// -moz-border-bottom-colors
        MozBorderBottomColors = 40,
        /// -moz-border-right-colors
        MozBorderRightColors = 41,
        /// box-decoration-break
        BoxDecorationBreak = 42,
        /// -moz-float-edge
        MozFloatEdge = 43,
        /// border-image-source
        BorderImageSource = 44,
        /// border-image-outset
        BorderImageOutset = 45,
        /// border-image-repeat
        BorderImageRepeat = 46,
        /// border-image-width
        BorderImageWidth = 47,
        /// border-image-slice
        BorderImageSlice = 48,
        /// display
        Display = 49,
        /// -moz-top-layer
        MozTopLayer = 50,
        /// position
        Position = 51,
        /// float
        Float = 52,
        /// clear
        Clear = 53,
        /// vertical-align
        VerticalAlign = 54,
        /// overflow-clip-box-inline
        OverflowClipBoxInline = 55,
        /// overflow-clip-box-block
        OverflowClipBoxBlock = 56,
        /// overflow-x
        OverflowX = 57,
        /// overflow-y
        OverflowY = 58,
        /// transition-duration
        TransitionDuration = 59,
        /// transition-timing-function
        TransitionTimingFunction = 60,
        /// transition-property
        TransitionProperty = 61,
        /// transition-delay
        TransitionDelay = 62,
        /// animation-name
        AnimationName = 63,
        /// animation-duration
        AnimationDuration = 64,
        /// animation-timing-function
        AnimationTimingFunction = 65,
        /// animation-iteration-count
        AnimationIterationCount = 66,
        /// animation-direction
        AnimationDirection = 67,
        /// animation-play-state
        AnimationPlayState = 68,
        /// animation-fill-mode
        AnimationFillMode = 69,
        /// animation-delay
        AnimationDelay = 70,
        /// scroll-snap-points-x
        ScrollSnapPointsX = 71,
        /// scroll-snap-points-y
        ScrollSnapPointsY = 72,
        /// scroll-snap-destination
        ScrollSnapDestination = 73,
        /// scroll-snap-coordinate
        ScrollSnapCoordinate = 74,
        /// transform
        Transform = 75,
        /// scroll-behavior
        ScrollBehavior = 76,
        /// scroll-snap-type-x
        ScrollSnapTypeX = 77,
        /// scroll-snap-type-y
        ScrollSnapTypeY = 78,
        /// overscroll-behavior-x
        OverscrollBehaviorX = 79,
        /// overscroll-behavior-y
        OverscrollBehaviorY = 80,
        /// isolation
        Isolation = 81,
        /// page-break-after
        PageBreakAfter = 82,
        /// page-break-before
        PageBreakBefore = 83,
        /// page-break-inside
        PageBreakInside = 84,
        /// resize
        Resize = 85,
        /// perspective
        Perspective = 86,
        /// perspective-origin
        PerspectiveOrigin = 87,
        /// backface-visibility
        BackfaceVisibility = 88,
        /// transform-box
        TransformBox = 89,
        /// transform-style
        TransformStyle = 90,
        /// transform-origin
        TransformOrigin = 91,
        /// contain
        Contain = 92,
        /// -moz-appearance
        MozAppearance = 93,
        /// -moz-binding
        MozBinding = 94,
        /// -moz-orient
        MozOrient = 95,
        /// will-change
        WillChange = 96,
        /// shape-image-threshold
        ShapeImageThreshold = 97,
        /// shape-outside
        ShapeOutside = 98,
        /// touch-action
        TouchAction = 99,
        /// color
        Color = 100,
        /// column-width
        ColumnWidth = 101,
        /// column-count
        ColumnCount = 102,
        /// column-gap
        ColumnGap = 103,
        /// column-fill
        ColumnFill = 104,
        /// column-rule-width
        ColumnRuleWidth = 105,
        /// column-rule-color
        ColumnRuleColor = 106,
        /// column-span
        ColumnSpan = 107,
        /// column-rule-style
        ColumnRuleStyle = 108,
        /// content
        Content = 109,
        /// counter-increment
        CounterIncrement = 110,
        /// counter-reset
        CounterReset = 111,
        /// opacity
        Opacity = 112,
        /// box-shadow
        BoxShadow = 113,
        /// clip
        Clip = 114,
        /// filter
        Filter = 115,
        /// mix-blend-mode
        MixBlendMode = 116,
        /// font-family
        FontFamily = 117,
        /// font-style
        FontStyle = 118,
        /// font-variant-caps
        FontVariantCaps = 119,
        /// font-weight
        FontWeight = 120,
        /// font-size
        FontSize = 121,
        /// font-size-adjust
        FontSizeAdjust = 122,
        /// font-synthesis
        FontSynthesis = 123,
        /// font-stretch
        FontStretch = 124,
        /// font-kerning
        FontKerning = 125,
        /// font-variant-alternates
        FontVariantAlternates = 126,
        /// font-variant-east-asian
        FontVariantEastAsian = 127,
        /// font-variant-ligatures
        FontVariantLigatures = 128,
        /// font-variant-numeric
        FontVariantNumeric = 129,
        /// font-variant-position
        FontVariantPosition = 130,
        /// font-feature-settings
        FontFeatureSettings = 131,
        /// font-variation-settings
        FontVariationSettings = 132,
        /// font-language-override
        FontLanguageOverride = 133,
        /// -x-lang
        XLang = 134,
        /// -moz-script-size-multiplier
        MozScriptSizeMultiplier = 135,
        /// -moz-script-level
        MozScriptLevel = 136,
        /// -moz-math-display
        MozMathDisplay = 137,
        /// -moz-math-variant
        MozMathVariant = 138,
        /// -moz-script-min-size
        MozScriptMinSize = 139,
        /// -x-text-zoom
        XTextZoom = 140,
        /// -moz-osx-font-smoothing
        MozOsxFontSmoothing = 141,
        /// -moz-font-smoothing-background-color
        MozFontSmoothingBackgroundColor = 142,
        /// -moz-min-font-size-ratio
        MozMinFontSizeRatio = 143,
        /// visibility
        Visibility = 144,
        /// writing-mode
        WritingMode = 145,
        /// direction
        Direction = 146,
        /// text-orientation
        TextOrientation = 147,
        /// color-adjust
        ColorAdjust = 148,
        /// image-rendering
        ImageRendering = 149,
        /// image-orientation
        ImageOrientation = 150,
        /// border-collapse
        BorderCollapse = 151,
        /// empty-cells
        EmptyCells = 152,
        /// caption-side
        CaptionSide = 153,
        /// border-spacing
        BorderSpacing = 154,
        /// line-height
        LineHeight = 155,
        /// text-transform
        TextTransform = 156,
        /// hyphens
        Hyphens = 157,
        /// -moz-text-size-adjust
        MozTextSizeAdjust = 158,
        /// text-indent
        TextIndent = 159,
        /// overflow-wrap
        OverflowWrap = 160,
        /// word-break
        WordBreak = 161,
        /// text-justify
        TextJustify = 162,
        /// text-align-last
        TextAlignLast = 163,
        /// text-align
        TextAlign = 164,
        /// letter-spacing
        LetterSpacing = 165,
        /// word-spacing
        WordSpacing = 166,
        /// white-space
        WhiteSpace = 167,
        /// text-shadow
        TextShadow = 168,
        /// text-emphasis-style
        TextEmphasisStyle = 169,
        /// text-emphasis-position
        TextEmphasisPosition = 170,
        /// text-emphasis-color
        TextEmphasisColor = 171,
        /// -moz-tab-size
        MozTabSize = 172,
        /// -webkit-text-fill-color
        WebkitTextFillColor = 173,
        /// -webkit-text-stroke-color
        WebkitTextStrokeColor = 174,
        /// -webkit-text-stroke-width
        WebkitTextStrokeWidth = 175,
        /// ruby-align
        RubyAlign = 176,
        /// ruby-position
        RubyPosition = 177,
        /// text-combine-upright
        TextCombineUpright = 178,
        /// text-rendering
        TextRendering = 179,
        /// -moz-control-character-visibility
        MozControlCharacterVisibility = 180,
        /// list-style-position
        ListStylePosition = 181,
        /// list-style-type
        ListStyleType = 182,
        /// list-style-image
        ListStyleImage = 183,
        /// quotes
        Quotes = 184,
        /// -moz-image-region
        MozImageRegion = 185,
        /// margin-top
        MarginTop = 186,
        /// margin-left
        MarginLeft = 187,
        /// margin-bottom
        MarginBottom = 188,
        /// margin-right
        MarginRight = 189,
        /// margin-block-start
        MarginBlockStart = 190,
        /// margin-block-end
        MarginBlockEnd = 191,
        /// margin-inline-start
        MarginInlineStart = 192,
        /// margin-inline-end
        MarginInlineEnd = 193,
        /// outline-color
        OutlineColor = 194,
        /// outline-style
        OutlineStyle = 195,
        /// outline-width
        OutlineWidth = 196,
        /// -moz-outline-radius-topleft
        MozOutlineRadiusTopleft = 197,
        /// -moz-outline-radius-topright
        MozOutlineRadiusTopright = 198,
        /// -moz-outline-radius-bottomright
        MozOutlineRadiusBottomright = 199,
        /// -moz-outline-radius-bottomleft
        MozOutlineRadiusBottomleft = 200,
        /// outline-offset
        OutlineOffset = 201,
        /// padding-top
        PaddingTop = 202,
        /// padding-left
        PaddingLeft = 203,
        /// padding-bottom
        PaddingBottom = 204,
        /// padding-right
        PaddingRight = 205,
        /// padding-block-start
        PaddingBlockStart = 206,
        /// padding-block-end
        PaddingBlockEnd = 207,
        /// padding-inline-start
        PaddingInlineStart = 208,
        /// padding-inline-end
        PaddingInlineEnd = 209,
        /// cursor
        Cursor = 210,
        /// pointer-events
        PointerEvents = 211,
        /// -moz-user-input
        MozUserInput = 212,
        /// -moz-user-modify
        MozUserModify = 213,
        /// -moz-user-focus
        MozUserFocus = 214,
        /// caret-color
        CaretColor = 215,
        /// top
        Top = 216,
        /// left
        Left = 217,
        /// bottom
        Bottom = 218,
        /// right
        Right = 219,
        /// offset-block-start
        OffsetBlockStart = 220,
        /// offset-block-end
        OffsetBlockEnd = 221,
        /// offset-inline-start
        OffsetInlineStart = 222,
        /// offset-inline-end
        OffsetInlineEnd = 223,
        /// z-index
        ZIndex = 224,
        /// flex-direction
        FlexDirection = 225,
        /// flex-wrap
        FlexWrap = 226,
        /// justify-content
        JustifyContent = 227,
        /// align-content
        AlignContent = 228,
        /// align-items
        AlignItems = 229,
        /// justify-items
        JustifyItems = 230,
        /// flex-grow
        FlexGrow = 231,
        /// flex-shrink
        FlexShrink = 232,
        /// align-self
        AlignSelf = 233,
        /// justify-self
        JustifySelf = 234,
        /// order
        Order = 235,
        /// flex-basis
        FlexBasis = 236,
        /// width
        Width = 237,
        /// min-width
        MinWidth = 238,
        /// max-width
        MaxWidth = 239,
        /// height
        Height = 240,
        /// min-height
        MinHeight = 241,
        /// max-height
        MaxHeight = 242,
        /// block-size
        BlockSize = 243,
        /// min-block-size
        MinBlockSize = 244,
        /// max-block-size
        MaxBlockSize = 245,
        /// inline-size
        InlineSize = 246,
        /// min-inline-size
        MinInlineSize = 247,
        /// max-inline-size
        MaxInlineSize = 248,
        /// box-sizing
        BoxSizing = 249,
        /// object-fit
        ObjectFit = 250,
        /// object-position
        ObjectPosition = 251,
        /// grid-row-gap
        GridRowGap = 252,
        /// grid-row-start
        GridRowStart = 253,
        /// grid-row-end
        GridRowEnd = 254,
        /// grid-auto-rows
        GridAutoRows = 255,
        /// grid-template-rows
        GridTemplateRows = 256,
        /// grid-column-gap
        GridColumnGap = 257,
        /// grid-column-start
        GridColumnStart = 258,
        /// grid-column-end
        GridColumnEnd = 259,
        /// grid-auto-columns
        GridAutoColumns = 260,
        /// grid-template-columns
        GridTemplateColumns = 261,
        /// grid-auto-flow
        GridAutoFlow = 262,
        /// grid-template-areas
        GridTemplateAreas = 263,
        /// table-layout
        TableLayout = 264,
        /// -x-span
        XSpan = 265,
        /// text-overflow
        TextOverflow = 266,
        /// unicode-bidi
        UnicodeBidi = 267,
        /// text-decoration-line
        TextDecorationLine = 268,
        /// text-decoration-style
        TextDecorationStyle = 269,
        /// text-decoration-color
        TextDecorationColor = 270,
        /// initial-letter
        InitialLetter = 271,
        /// ime-mode
        ImeMode = 272,
        /// -moz-user-select
        MozUserSelect = 273,
        /// -moz-window-dragging
        MozWindowDragging = 274,
        /// -moz-window-shadow
        MozWindowShadow = 275,
        /// -moz-window-opacity
        MozWindowOpacity = 276,
        /// -moz-window-transform
        MozWindowTransform = 277,
        /// -moz-window-transform-origin
        MozWindowTransformOrigin = 278,
        /// -moz-force-broken-image-icon
        MozForceBrokenImageIcon = 279,
        /// text-anchor
        TextAnchor = 280,
        /// color-interpolation
        ColorInterpolation = 281,
        /// color-interpolation-filters
        ColorInterpolationFilters = 282,
        /// fill
        Fill = 283,
        /// fill-opacity
        FillOpacity = 284,
        /// fill-rule
        FillRule = 285,
        /// shape-rendering
        ShapeRendering = 286,
        /// stroke
        Stroke = 287,
        /// stroke-width
        StrokeWidth = 288,
        /// stroke-linecap
        StrokeLinecap = 289,
        /// stroke-linejoin
        StrokeLinejoin = 290,
        /// stroke-miterlimit
        StrokeMiterlimit = 291,
        /// stroke-opacity
        StrokeOpacity = 292,
        /// stroke-dasharray
        StrokeDasharray = 293,
        /// stroke-dashoffset
        StrokeDashoffset = 294,
        /// clip-rule
        ClipRule = 295,
        /// marker-start
        MarkerStart = 296,
        /// marker-mid
        MarkerMid = 297,
        /// marker-end
        MarkerEnd = 298,
        /// paint-order
        PaintOrder = 299,
        /// -moz-context-properties
        MozContextProperties = 300,
        /// dominant-baseline
        DominantBaseline = 301,
        /// vector-effect
        VectorEffect = 302,
        /// stop-color
        StopColor = 303,
        /// stop-opacity
        StopOpacity = 304,
        /// flood-color
        FloodColor = 305,
        /// flood-opacity
        FloodOpacity = 306,
        /// lighting-color
        LightingColor = 307,
        /// mask-type
        MaskType = 308,
        /// clip-path
        ClipPath = 309,
        /// mask-mode
        MaskMode = 310,
        /// mask-repeat
        MaskRepeat = 311,
        /// mask-position-x
        MaskPositionX = 312,
        /// mask-position-y
        MaskPositionY = 313,
        /// mask-clip
        MaskClip = 314,
        /// mask-origin
        MaskOrigin = 315,
        /// mask-size
        MaskSize = 316,
        /// mask-composite
        MaskComposite = 317,
        /// mask-image
        MaskImage = 318,
        /// -moz-box-align
        MozBoxAlign = 319,
        /// -moz-box-direction
        MozBoxDirection = 320,
        /// -moz-box-flex
        MozBoxFlex = 321,
        /// -moz-box-orient
        MozBoxOrient = 322,
        /// -moz-box-pack
        MozBoxPack = 323,
        /// -moz-stack-sizing
        MozStackSizing = 324,
        /// -moz-box-ordinal-group
        MozBoxOrdinalGroup = 325,
}

impl fmt::Debug for LonghandId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        formatter.write_str(self.name())
    }
}

impl LonghandId {
    /// Get the name of this longhand property.
    pub fn name(&self) -> &'static str {
        match *self {
                LonghandId::BackgroundColor => "background-color",
                LonghandId::BackgroundImage => "background-image",
                LonghandId::BackgroundPositionX => "background-position-x",
                LonghandId::BackgroundPositionY => "background-position-y",
                LonghandId::BackgroundRepeat => "background-repeat",
                LonghandId::BackgroundAttachment => "background-attachment",
                LonghandId::BackgroundClip => "background-clip",
                LonghandId::BackgroundOrigin => "background-origin",
                LonghandId::BackgroundSize => "background-size",
                LonghandId::BackgroundBlendMode => "background-blend-mode",
                LonghandId::BorderTopColor => "border-top-color",
                LonghandId::BorderTopStyle => "border-top-style",
                LonghandId::BorderTopWidth => "border-top-width",
                LonghandId::BorderLeftColor => "border-left-color",
                LonghandId::BorderLeftStyle => "border-left-style",
                LonghandId::BorderLeftWidth => "border-left-width",
                LonghandId::BorderBottomColor => "border-bottom-color",
                LonghandId::BorderBottomStyle => "border-bottom-style",
                LonghandId::BorderBottomWidth => "border-bottom-width",
                LonghandId::BorderRightColor => "border-right-color",
                LonghandId::BorderRightStyle => "border-right-style",
                LonghandId::BorderRightWidth => "border-right-width",
                LonghandId::BorderBlockStartColor => "border-block-start-color",
                LonghandId::BorderBlockStartStyle => "border-block-start-style",
                LonghandId::BorderBlockStartWidth => "border-block-start-width",
                LonghandId::BorderBlockEndColor => "border-block-end-color",
                LonghandId::BorderBlockEndStyle => "border-block-end-style",
                LonghandId::BorderBlockEndWidth => "border-block-end-width",
                LonghandId::BorderInlineStartColor => "border-inline-start-color",
                LonghandId::BorderInlineStartStyle => "border-inline-start-style",
                LonghandId::BorderInlineStartWidth => "border-inline-start-width",
                LonghandId::BorderInlineEndColor => "border-inline-end-color",
                LonghandId::BorderInlineEndStyle => "border-inline-end-style",
                LonghandId::BorderInlineEndWidth => "border-inline-end-width",
                LonghandId::BorderTopLeftRadius => "border-top-left-radius",
                LonghandId::BorderTopRightRadius => "border-top-right-radius",
                LonghandId::BorderBottomRightRadius => "border-bottom-right-radius",
                LonghandId::BorderBottomLeftRadius => "border-bottom-left-radius",
                LonghandId::MozBorderTopColors => "-moz-border-top-colors",
                LonghandId::MozBorderLeftColors => "-moz-border-left-colors",
                LonghandId::MozBorderBottomColors => "-moz-border-bottom-colors",
                LonghandId::MozBorderRightColors => "-moz-border-right-colors",
                LonghandId::BoxDecorationBreak => "box-decoration-break",
                LonghandId::MozFloatEdge => "-moz-float-edge",
                LonghandId::BorderImageSource => "border-image-source",
                LonghandId::BorderImageOutset => "border-image-outset",
                LonghandId::BorderImageRepeat => "border-image-repeat",
                LonghandId::BorderImageWidth => "border-image-width",
                LonghandId::BorderImageSlice => "border-image-slice",
                LonghandId::Display => "display",
                LonghandId::MozTopLayer => "-moz-top-layer",
                LonghandId::Position => "position",
                LonghandId::Float => "float",
                LonghandId::Clear => "clear",
                LonghandId::VerticalAlign => "vertical-align",
                LonghandId::OverflowClipBoxInline => "overflow-clip-box-inline",
                LonghandId::OverflowClipBoxBlock => "overflow-clip-box-block",
                LonghandId::OverflowX => "overflow-x",
                LonghandId::OverflowY => "overflow-y",
                LonghandId::TransitionDuration => "transition-duration",
                LonghandId::TransitionTimingFunction => "transition-timing-function",
                LonghandId::TransitionProperty => "transition-property",
                LonghandId::TransitionDelay => "transition-delay",
                LonghandId::AnimationName => "animation-name",
                LonghandId::AnimationDuration => "animation-duration",
                LonghandId::AnimationTimingFunction => "animation-timing-function",
                LonghandId::AnimationIterationCount => "animation-iteration-count",
                LonghandId::AnimationDirection => "animation-direction",
                LonghandId::AnimationPlayState => "animation-play-state",
                LonghandId::AnimationFillMode => "animation-fill-mode",
                LonghandId::AnimationDelay => "animation-delay",
                LonghandId::ScrollSnapPointsX => "scroll-snap-points-x",
                LonghandId::ScrollSnapPointsY => "scroll-snap-points-y",
                LonghandId::ScrollSnapDestination => "scroll-snap-destination",
                LonghandId::ScrollSnapCoordinate => "scroll-snap-coordinate",
                LonghandId::Transform => "transform",
                LonghandId::ScrollBehavior => "scroll-behavior",
                LonghandId::ScrollSnapTypeX => "scroll-snap-type-x",
                LonghandId::ScrollSnapTypeY => "scroll-snap-type-y",
                LonghandId::OverscrollBehaviorX => "overscroll-behavior-x",
                LonghandId::OverscrollBehaviorY => "overscroll-behavior-y",
                LonghandId::Isolation => "isolation",
                LonghandId::PageBreakAfter => "page-break-after",
                LonghandId::PageBreakBefore => "page-break-before",
                LonghandId::PageBreakInside => "page-break-inside",
                LonghandId::Resize => "resize",
                LonghandId::Perspective => "perspective",
                LonghandId::PerspectiveOrigin => "perspective-origin",
                LonghandId::BackfaceVisibility => "backface-visibility",
                LonghandId::TransformBox => "transform-box",
                LonghandId::TransformStyle => "transform-style",
                LonghandId::TransformOrigin => "transform-origin",
                LonghandId::Contain => "contain",
                LonghandId::MozAppearance => "-moz-appearance",
                LonghandId::MozBinding => "-moz-binding",
                LonghandId::MozOrient => "-moz-orient",
                LonghandId::WillChange => "will-change",
                LonghandId::ShapeImageThreshold => "shape-image-threshold",
                LonghandId::ShapeOutside => "shape-outside",
                LonghandId::TouchAction => "touch-action",
                LonghandId::Color => "color",
                LonghandId::ColumnWidth => "column-width",
                LonghandId::ColumnCount => "column-count",
                LonghandId::ColumnGap => "column-gap",
                LonghandId::ColumnFill => "column-fill",
                LonghandId::ColumnRuleWidth => "column-rule-width",
                LonghandId::ColumnRuleColor => "column-rule-color",
                LonghandId::ColumnSpan => "column-span",
                LonghandId::ColumnRuleStyle => "column-rule-style",
                LonghandId::Content => "content",
                LonghandId::CounterIncrement => "counter-increment",
                LonghandId::CounterReset => "counter-reset",
                LonghandId::Opacity => "opacity",
                LonghandId::BoxShadow => "box-shadow",
                LonghandId::Clip => "clip",
                LonghandId::Filter => "filter",
                LonghandId::MixBlendMode => "mix-blend-mode",
                LonghandId::FontFamily => "font-family",
                LonghandId::FontStyle => "font-style",
                LonghandId::FontVariantCaps => "font-variant-caps",
                LonghandId::FontWeight => "font-weight",
                LonghandId::FontSize => "font-size",
                LonghandId::FontSizeAdjust => "font-size-adjust",
                LonghandId::FontSynthesis => "font-synthesis",
                LonghandId::FontStretch => "font-stretch",
                LonghandId::FontKerning => "font-kerning",
                LonghandId::FontVariantAlternates => "font-variant-alternates",
                LonghandId::FontVariantEastAsian => "font-variant-east-asian",
                LonghandId::FontVariantLigatures => "font-variant-ligatures",
                LonghandId::FontVariantNumeric => "font-variant-numeric",
                LonghandId::FontVariantPosition => "font-variant-position",
                LonghandId::FontFeatureSettings => "font-feature-settings",
                LonghandId::FontVariationSettings => "font-variation-settings",
                LonghandId::FontLanguageOverride => "font-language-override",
                LonghandId::XLang => "-x-lang",
                LonghandId::MozScriptSizeMultiplier => "-moz-script-size-multiplier",
                LonghandId::MozScriptLevel => "-moz-script-level",
                LonghandId::MozMathDisplay => "-moz-math-display",
                LonghandId::MozMathVariant => "-moz-math-variant",
                LonghandId::MozScriptMinSize => "-moz-script-min-size",
                LonghandId::XTextZoom => "-x-text-zoom",
                LonghandId::MozOsxFontSmoothing => "-moz-osx-font-smoothing",
                LonghandId::MozFontSmoothingBackgroundColor => "-moz-font-smoothing-background-color",
                LonghandId::MozMinFontSizeRatio => "-moz-min-font-size-ratio",
                LonghandId::Visibility => "visibility",
                LonghandId::WritingMode => "writing-mode",
                LonghandId::Direction => "direction",
                LonghandId::TextOrientation => "text-orientation",
                LonghandId::ColorAdjust => "color-adjust",
                LonghandId::ImageRendering => "image-rendering",
                LonghandId::ImageOrientation => "image-orientation",
                LonghandId::BorderCollapse => "border-collapse",
                LonghandId::EmptyCells => "empty-cells",
                LonghandId::CaptionSide => "caption-side",
                LonghandId::BorderSpacing => "border-spacing",
                LonghandId::LineHeight => "line-height",
                LonghandId::TextTransform => "text-transform",
                LonghandId::Hyphens => "hyphens",
                LonghandId::MozTextSizeAdjust => "-moz-text-size-adjust",
                LonghandId::TextIndent => "text-indent",
                LonghandId::OverflowWrap => "overflow-wrap",
                LonghandId::WordBreak => "word-break",
                LonghandId::TextJustify => "text-justify",
                LonghandId::TextAlignLast => "text-align-last",
                LonghandId::TextAlign => "text-align",
                LonghandId::LetterSpacing => "letter-spacing",
                LonghandId::WordSpacing => "word-spacing",
                LonghandId::WhiteSpace => "white-space",
                LonghandId::TextShadow => "text-shadow",
                LonghandId::TextEmphasisStyle => "text-emphasis-style",
                LonghandId::TextEmphasisPosition => "text-emphasis-position",
                LonghandId::TextEmphasisColor => "text-emphasis-color",
                LonghandId::MozTabSize => "-moz-tab-size",
                LonghandId::WebkitTextFillColor => "-webkit-text-fill-color",
                LonghandId::WebkitTextStrokeColor => "-webkit-text-stroke-color",
                LonghandId::WebkitTextStrokeWidth => "-webkit-text-stroke-width",
                LonghandId::RubyAlign => "ruby-align",
                LonghandId::RubyPosition => "ruby-position",
                LonghandId::TextCombineUpright => "text-combine-upright",
                LonghandId::TextRendering => "text-rendering",
                LonghandId::MozControlCharacterVisibility => "-moz-control-character-visibility",
                LonghandId::ListStylePosition => "list-style-position",
                LonghandId::ListStyleType => "list-style-type",
                LonghandId::ListStyleImage => "list-style-image",
                LonghandId::Quotes => "quotes",
                LonghandId::MozImageRegion => "-moz-image-region",
                LonghandId::MarginTop => "margin-top",
                LonghandId::MarginLeft => "margin-left",
                LonghandId::MarginBottom => "margin-bottom",
                LonghandId::MarginRight => "margin-right",
                LonghandId::MarginBlockStart => "margin-block-start",
                LonghandId::MarginBlockEnd => "margin-block-end",
                LonghandId::MarginInlineStart => "margin-inline-start",
                LonghandId::MarginInlineEnd => "margin-inline-end",
                LonghandId::OutlineColor => "outline-color",
                LonghandId::OutlineStyle => "outline-style",
                LonghandId::OutlineWidth => "outline-width",
                LonghandId::MozOutlineRadiusTopleft => "-moz-outline-radius-topleft",
                LonghandId::MozOutlineRadiusTopright => "-moz-outline-radius-topright",
                LonghandId::MozOutlineRadiusBottomright => "-moz-outline-radius-bottomright",
                LonghandId::MozOutlineRadiusBottomleft => "-moz-outline-radius-bottomleft",
                LonghandId::OutlineOffset => "outline-offset",
                LonghandId::PaddingTop => "padding-top",
                LonghandId::PaddingLeft => "padding-left",
                LonghandId::PaddingBottom => "padding-bottom",
                LonghandId::PaddingRight => "padding-right",
                LonghandId::PaddingBlockStart => "padding-block-start",
                LonghandId::PaddingBlockEnd => "padding-block-end",
                LonghandId::PaddingInlineStart => "padding-inline-start",
                LonghandId::PaddingInlineEnd => "padding-inline-end",
                LonghandId::Cursor => "cursor",
                LonghandId::PointerEvents => "pointer-events",
                LonghandId::MozUserInput => "-moz-user-input",
                LonghandId::MozUserModify => "-moz-user-modify",
                LonghandId::MozUserFocus => "-moz-user-focus",
                LonghandId::CaretColor => "caret-color",
                LonghandId::Top => "top",
                LonghandId::Left => "left",
                LonghandId::Bottom => "bottom",
                LonghandId::Right => "right",
                LonghandId::OffsetBlockStart => "offset-block-start",
                LonghandId::OffsetBlockEnd => "offset-block-end",
                LonghandId::OffsetInlineStart => "offset-inline-start",
                LonghandId::OffsetInlineEnd => "offset-inline-end",
                LonghandId::ZIndex => "z-index",
                LonghandId::FlexDirection => "flex-direction",
                LonghandId::FlexWrap => "flex-wrap",
                LonghandId::JustifyContent => "justify-content",
                LonghandId::AlignContent => "align-content",
                LonghandId::AlignItems => "align-items",
                LonghandId::JustifyItems => "justify-items",
                LonghandId::FlexGrow => "flex-grow",
                LonghandId::FlexShrink => "flex-shrink",
                LonghandId::AlignSelf => "align-self",
                LonghandId::JustifySelf => "justify-self",
                LonghandId::Order => "order",
                LonghandId::FlexBasis => "flex-basis",
                LonghandId::Width => "width",
                LonghandId::MinWidth => "min-width",
                LonghandId::MaxWidth => "max-width",
                LonghandId::Height => "height",
                LonghandId::MinHeight => "min-height",
                LonghandId::MaxHeight => "max-height",
                LonghandId::BlockSize => "block-size",
                LonghandId::MinBlockSize => "min-block-size",
                LonghandId::MaxBlockSize => "max-block-size",
                LonghandId::InlineSize => "inline-size",
                LonghandId::MinInlineSize => "min-inline-size",
                LonghandId::MaxInlineSize => "max-inline-size",
                LonghandId::BoxSizing => "box-sizing",
                LonghandId::ObjectFit => "object-fit",
                LonghandId::ObjectPosition => "object-position",
                LonghandId::GridRowGap => "grid-row-gap",
                LonghandId::GridRowStart => "grid-row-start",
                LonghandId::GridRowEnd => "grid-row-end",
                LonghandId::GridAutoRows => "grid-auto-rows",
                LonghandId::GridTemplateRows => "grid-template-rows",
                LonghandId::GridColumnGap => "grid-column-gap",
                LonghandId::GridColumnStart => "grid-column-start",
                LonghandId::GridColumnEnd => "grid-column-end",
                LonghandId::GridAutoColumns => "grid-auto-columns",
                LonghandId::GridTemplateColumns => "grid-template-columns",
                LonghandId::GridAutoFlow => "grid-auto-flow",
                LonghandId::GridTemplateAreas => "grid-template-areas",
                LonghandId::TableLayout => "table-layout",
                LonghandId::XSpan => "-x-span",
                LonghandId::TextOverflow => "text-overflow",
                LonghandId::UnicodeBidi => "unicode-bidi",
                LonghandId::TextDecorationLine => "text-decoration-line",
                LonghandId::TextDecorationStyle => "text-decoration-style",
                LonghandId::TextDecorationColor => "text-decoration-color",
                LonghandId::InitialLetter => "initial-letter",
                LonghandId::ImeMode => "ime-mode",
                LonghandId::MozUserSelect => "-moz-user-select",
                LonghandId::MozWindowDragging => "-moz-window-dragging",
                LonghandId::MozWindowShadow => "-moz-window-shadow",
                LonghandId::MozWindowOpacity => "-moz-window-opacity",
                LonghandId::MozWindowTransform => "-moz-window-transform",
                LonghandId::MozWindowTransformOrigin => "-moz-window-transform-origin",
                LonghandId::MozForceBrokenImageIcon => "-moz-force-broken-image-icon",
                LonghandId::TextAnchor => "text-anchor",
                LonghandId::ColorInterpolation => "color-interpolation",
                LonghandId::ColorInterpolationFilters => "color-interpolation-filters",
                LonghandId::Fill => "fill",
                LonghandId::FillOpacity => "fill-opacity",
                LonghandId::FillRule => "fill-rule",
                LonghandId::ShapeRendering => "shape-rendering",
                LonghandId::Stroke => "stroke",
                LonghandId::StrokeWidth => "stroke-width",
                LonghandId::StrokeLinecap => "stroke-linecap",
                LonghandId::StrokeLinejoin => "stroke-linejoin",
                LonghandId::StrokeMiterlimit => "stroke-miterlimit",
                LonghandId::StrokeOpacity => "stroke-opacity",
                LonghandId::StrokeDasharray => "stroke-dasharray",
                LonghandId::StrokeDashoffset => "stroke-dashoffset",
                LonghandId::ClipRule => "clip-rule",
                LonghandId::MarkerStart => "marker-start",
                LonghandId::MarkerMid => "marker-mid",
                LonghandId::MarkerEnd => "marker-end",
                LonghandId::PaintOrder => "paint-order",
                LonghandId::MozContextProperties => "-moz-context-properties",
                LonghandId::DominantBaseline => "dominant-baseline",
                LonghandId::VectorEffect => "vector-effect",
                LonghandId::StopColor => "stop-color",
                LonghandId::StopOpacity => "stop-opacity",
                LonghandId::FloodColor => "flood-color",
                LonghandId::FloodOpacity => "flood-opacity",
                LonghandId::LightingColor => "lighting-color",
                LonghandId::MaskType => "mask-type",
                LonghandId::ClipPath => "clip-path",
                LonghandId::MaskMode => "mask-mode",
                LonghandId::MaskRepeat => "mask-repeat",
                LonghandId::MaskPositionX => "mask-position-x",
                LonghandId::MaskPositionY => "mask-position-y",
                LonghandId::MaskClip => "mask-clip",
                LonghandId::MaskOrigin => "mask-origin",
                LonghandId::MaskSize => "mask-size",
                LonghandId::MaskComposite => "mask-composite",
                LonghandId::MaskImage => "mask-image",
                LonghandId::MozBoxAlign => "-moz-box-align",
                LonghandId::MozBoxDirection => "-moz-box-direction",
                LonghandId::MozBoxFlex => "-moz-box-flex",
                LonghandId::MozBoxOrient => "-moz-box-orient",
                LonghandId::MozBoxPack => "-moz-box-pack",
                LonghandId::MozStackSizing => "-moz-stack-sizing",
                LonghandId::MozBoxOrdinalGroup => "-moz-box-ordinal-group",
        }
    }

    fn inherited(&self) -> bool {
        
static INHERITED: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0xffe00010, 0xffffffff, 0x3ffffff, 0xfc0000, 0x0, 0xff000000, 0x1fff, 0x0]
};

        INHERITED.contains(*self)
    }

    fn shorthands(&self) -> &'static [ShorthandId] {
        // first generate longhand to shorthands lookup map
        //
        // NOTE(emilio): This currently doesn't exclude the "all" shorthand. It
        // could potentially do so, which would speed up serialization
        // algorithms and what not, I guess.
        

        // based on lookup results for each longhand, create result arrays
            static BACKGROUND_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_POSITION_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ];
            static BACKGROUND_POSITION_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ];
            static BACKGROUND_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_ATTACHMENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ];
            static BACKGROUND_BLEND_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_TOP_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderTop,
            ];
            static BORDER_TOP_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderTop,
            ];
            static BORDER_TOP_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderTop,
            ];
            static BORDER_LEFT_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_LEFT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_LEFT_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderLeft,
            ];
            static BORDER_BOTTOM_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_BOTTOM_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_BOTTOM_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderBottom,
            ];
            static BORDER_RIGHT_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderRight,
            ];
            static BORDER_RIGHT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderRight,
            ];
            static BORDER_RIGHT_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderRight,
            ];
            static BORDER_BLOCK_START_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BLOCK_START_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BLOCK_START_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockStart,
            ];
            static BORDER_BLOCK_END_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_BLOCK_END_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_BLOCK_END_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderBlockEnd,
            ];
            static BORDER_INLINE_START_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_INLINE_START_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_INLINE_START_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineStart,
            ];
            static BORDER_INLINE_END_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_INLINE_END_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_INLINE_END_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderInlineEnd,
            ];
            static BORDER_TOP_LEFT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_TOP_RIGHT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_BOTTOM_RIGHT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static BORDER_BOTTOM_LEFT_RADIUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ];
            static _MOZ_BORDER_TOP_COLORS: &'static [ShorthandId] = &[
            ];
            static _MOZ_BORDER_LEFT_COLORS: &'static [ShorthandId] = &[
            ];
            static _MOZ_BORDER_BOTTOM_COLORS: &'static [ShorthandId] = &[
            ];
            static _MOZ_BORDER_RIGHT_COLORS: &'static [ShorthandId] = &[
            ];
            static BOX_DECORATION_BREAK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_FLOAT_EDGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_IMAGE_SOURCE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_OUTSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static BORDER_IMAGE_SLICE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ];
            static DISPLAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_TOP_LAYER: &'static [ShorthandId] = &[
            ];
            static POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLOAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLEAR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static VERTICAL_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OVERFLOW_CLIP_BOX_INLINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ];
            static OVERFLOW_CLIP_BOX_BLOCK: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ];
            static OVERFLOW_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ];
            static OVERFLOW_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ];
            static TRANSITION_DURATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_TIMING_FUNCTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_PROPERTY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static TRANSITION_DELAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ];
            static ANIMATION_NAME: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_DURATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_TIMING_FUNCTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_ITERATION_COUNT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_PLAY_STATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_FILL_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static ANIMATION_DELAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ];
            static SCROLL_SNAP_POINTS_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_POINTS_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_DESTINATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_COORDINATE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozTransform,
            ];
            static SCROLL_BEHAVIOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SCROLL_SNAP_TYPE_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ScrollSnapType,
            ];
            static SCROLL_SNAP_TYPE_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ScrollSnapType,
            ];
            static OVERSCROLL_BEHAVIOR_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ];
            static OVERSCROLL_BEHAVIOR_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ];
            static ISOLATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAGE_BREAK_AFTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAGE_BREAK_BEFORE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PAGE_BREAK_INSIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RESIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PERSPECTIVE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PERSPECTIVE_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BACKFACE_VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM_BOX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TRANSFORM_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CONTAIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_APPEARANCE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BINDING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_ORIENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WILL_CHANGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_IMAGE_THRESHOLD: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_OUTSIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TOUCH_ACTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ];
            static COLUMN_COUNT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ];
            static COLUMN_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_FILL: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_RULE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static COLUMN_RULE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static COLUMN_SPAN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLUMN_RULE_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ];
            static CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COUNTER_INCREMENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COUNTER_RESET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BOX_SHADOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIX_BLEND_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_FAMILY: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_VARIANT_CAPS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_WEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SIZE_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_SYNTHESIS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_STRETCH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_KERNING: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_VARIANT_ALTERNATES: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_EAST_ASIAN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_LIGATURES: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_NUMERIC: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_VARIANT_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ];
            static FONT_FEATURE_SETTINGS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static FONT_VARIATION_SETTINGS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FONT_LANGUAGE_OVERRIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static _X_LANG: &'static [ShorthandId] = &[
            ];
            static _MOZ_SCRIPT_SIZE_MULTIPLIER: &'static [ShorthandId] = &[
            ];
            static _MOZ_SCRIPT_LEVEL: &'static [ShorthandId] = &[
            ];
            static _MOZ_MATH_DISPLAY: &'static [ShorthandId] = &[
            ];
            static _MOZ_MATH_VARIANT: &'static [ShorthandId] = &[
            ];
            static _MOZ_SCRIPT_MIN_SIZE: &'static [ShorthandId] = &[
            ];
            static _X_TEXT_ZOOM: &'static [ShorthandId] = &[
            ];
            static _MOZ_OSX_FONT_SMOOTHING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_FONT_SMOOTHING_BACKGROUND_COLOR: &'static [ShorthandId] = &[
            ];
            static _MOZ_MIN_FONT_SIZE_RATIO: &'static [ShorthandId] = &[
            ];
            static VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WRITING_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static DIRECTION: &'static [ShorthandId] = &[
            ];
            static TEXT_ORIENTATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IMAGE_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IMAGE_ORIENTATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_COLLAPSE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static EMPTY_CELLS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CAPTION_SIDE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BORDER_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LINE_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ];
            static TEXT_TRANSFORM: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static HYPHENS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_TEXT_SIZE_ADJUST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_INDENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OVERFLOW_WRAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WORD_BREAK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_JUSTIFY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ALIGN_LAST: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LETTER_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WORD_SPACING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static WHITE_SPACE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_SHADOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_EMPHASIS_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ];
            static TEXT_EMPHASIS_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_EMPHASIS_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ];
            static _MOZ_TAB_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _WEBKIT_TEXT_FILL_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _WEBKIT_TEXT_STROKE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ];
            static _WEBKIT_TEXT_STROKE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ];
            static RUBY_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RUBY_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_COMBINE_UPRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_CONTROL_CHARACTER_VISIBILITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LIST_STYLE_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static LIST_STYLE_TYPE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static LIST_STYLE_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ];
            static QUOTES: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_IMAGE_REGION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ];
            static MARGIN_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARGIN_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OUTLINE_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static OUTLINE_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static OUTLINE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ];
            static _MOZ_OUTLINE_RADIUS_TOPLEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_TOPRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_BOTTOMRIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static _MOZ_OUTLINE_RADIUS_BOTTOMLEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::MozOutlineRadius,
            ];
            static OUTLINE_OFFSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ];
            static PADDING_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static PADDING_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CURSOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static POINTER_EVENTS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_INPUT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_MODIFY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_FOCUS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CARET_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TOP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LEFT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BOTTOM: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static RIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_BLOCK_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_BLOCK_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_INLINE_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OFFSET_INLINE_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static Z_INDEX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLEX_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ];
            static FLEX_WRAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ];
            static JUSTIFY_CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ];
            static ALIGN_CONTENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ];
            static ALIGN_ITEMS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ];
            static JUSTIFY_ITEMS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ];
            static FLEX_GROW: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static FLEX_SHRINK: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static ALIGN_SELF: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ];
            static JUSTIFY_SELF: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ];
            static ORDER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLEX_BASIS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ];
            static WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_HEIGHT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_BLOCK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MIN_INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MAX_INLINE_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static BOX_SIZING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OBJECT_FIT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static OBJECT_POSITION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static GRID_ROW_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridGap,
            ];
            static GRID_ROW_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ];
            static GRID_ROW_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ];
            static GRID_AUTO_ROWS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static GRID_TEMPLATE_ROWS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static GRID_COLUMN_GAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridGap,
            ];
            static GRID_COLUMN_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ];
            static GRID_COLUMN_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ];
            static GRID_AUTO_COLUMNS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static GRID_TEMPLATE_COLUMNS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static GRID_AUTO_FLOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ];
            static GRID_TEMPLATE_AREAS: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ];
            static TABLE_LAYOUT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _X_SPAN: &'static [ShorthandId] = &[
            ];
            static TEXT_OVERFLOW: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static UNICODE_BIDI: &'static [ShorthandId] = &[
            ];
            static TEXT_DECORATION_LINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static TEXT_DECORATION_STYLE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static TEXT_DECORATION_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ];
            static INITIAL_LETTER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static IME_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_USER_SELECT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_DRAGGING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_WINDOW_SHADOW: &'static [ShorthandId] = &[
            ];
            static _MOZ_WINDOW_OPACITY: &'static [ShorthandId] = &[
            ];
            static _MOZ_WINDOW_TRANSFORM: &'static [ShorthandId] = &[
            ];
            static _MOZ_WINDOW_TRANSFORM_ORIGIN: &'static [ShorthandId] = &[
            ];
            static _MOZ_FORCE_BROKEN_IMAGE_ICON: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static TEXT_ANCHOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_INTERPOLATION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static COLOR_INTERPOLATION_FILTERS: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILL: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILL_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FILL_RULE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static SHAPE_RENDERING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_WIDTH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_LINECAP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_LINEJOIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_MITERLIMIT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_DASHARRAY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STROKE_DASHOFFSET: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP_RULE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MARKER_START: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static MARKER_MID: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static MARKER_END: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ];
            static PAINT_ORDER: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_CONTEXT_PROPERTIES: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static DOMINANT_BASELINE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static VECTOR_EFFECT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STOP_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static STOP_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLOOD_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static FLOOD_OPACITY: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static LIGHTING_COLOR: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MASK_TYPE: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static CLIP_PATH: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static MASK_MODE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_REPEAT: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_POSITION_X: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ];
            static MASK_POSITION_Y: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ];
            static MASK_CLIP: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_ORIGIN: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_SIZE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_COMPOSITE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static MASK_IMAGE: &'static [ShorthandId] = &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ];
            static _MOZ_BOX_ALIGN: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_DIRECTION: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_FLEX: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_ORIENT: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_PACK: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_STACK_SIZING: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];
            static _MOZ_BOX_ORDINAL_GROUP: &'static [ShorthandId] = &[
                    ShorthandId::All,
            ];

        match *self {
                LonghandId::BackgroundColor => BACKGROUND_COLOR,
                LonghandId::BackgroundImage => BACKGROUND_IMAGE,
                LonghandId::BackgroundPositionX => BACKGROUND_POSITION_X,
                LonghandId::BackgroundPositionY => BACKGROUND_POSITION_Y,
                LonghandId::BackgroundRepeat => BACKGROUND_REPEAT,
                LonghandId::BackgroundAttachment => BACKGROUND_ATTACHMENT,
                LonghandId::BackgroundClip => BACKGROUND_CLIP,
                LonghandId::BackgroundOrigin => BACKGROUND_ORIGIN,
                LonghandId::BackgroundSize => BACKGROUND_SIZE,
                LonghandId::BackgroundBlendMode => BACKGROUND_BLEND_MODE,
                LonghandId::BorderTopColor => BORDER_TOP_COLOR,
                LonghandId::BorderTopStyle => BORDER_TOP_STYLE,
                LonghandId::BorderTopWidth => BORDER_TOP_WIDTH,
                LonghandId::BorderLeftColor => BORDER_LEFT_COLOR,
                LonghandId::BorderLeftStyle => BORDER_LEFT_STYLE,
                LonghandId::BorderLeftWidth => BORDER_LEFT_WIDTH,
                LonghandId::BorderBottomColor => BORDER_BOTTOM_COLOR,
                LonghandId::BorderBottomStyle => BORDER_BOTTOM_STYLE,
                LonghandId::BorderBottomWidth => BORDER_BOTTOM_WIDTH,
                LonghandId::BorderRightColor => BORDER_RIGHT_COLOR,
                LonghandId::BorderRightStyle => BORDER_RIGHT_STYLE,
                LonghandId::BorderRightWidth => BORDER_RIGHT_WIDTH,
                LonghandId::BorderBlockStartColor => BORDER_BLOCK_START_COLOR,
                LonghandId::BorderBlockStartStyle => BORDER_BLOCK_START_STYLE,
                LonghandId::BorderBlockStartWidth => BORDER_BLOCK_START_WIDTH,
                LonghandId::BorderBlockEndColor => BORDER_BLOCK_END_COLOR,
                LonghandId::BorderBlockEndStyle => BORDER_BLOCK_END_STYLE,
                LonghandId::BorderBlockEndWidth => BORDER_BLOCK_END_WIDTH,
                LonghandId::BorderInlineStartColor => BORDER_INLINE_START_COLOR,
                LonghandId::BorderInlineStartStyle => BORDER_INLINE_START_STYLE,
                LonghandId::BorderInlineStartWidth => BORDER_INLINE_START_WIDTH,
                LonghandId::BorderInlineEndColor => BORDER_INLINE_END_COLOR,
                LonghandId::BorderInlineEndStyle => BORDER_INLINE_END_STYLE,
                LonghandId::BorderInlineEndWidth => BORDER_INLINE_END_WIDTH,
                LonghandId::BorderTopLeftRadius => BORDER_TOP_LEFT_RADIUS,
                LonghandId::BorderTopRightRadius => BORDER_TOP_RIGHT_RADIUS,
                LonghandId::BorderBottomRightRadius => BORDER_BOTTOM_RIGHT_RADIUS,
                LonghandId::BorderBottomLeftRadius => BORDER_BOTTOM_LEFT_RADIUS,
                LonghandId::MozBorderTopColors => _MOZ_BORDER_TOP_COLORS,
                LonghandId::MozBorderLeftColors => _MOZ_BORDER_LEFT_COLORS,
                LonghandId::MozBorderBottomColors => _MOZ_BORDER_BOTTOM_COLORS,
                LonghandId::MozBorderRightColors => _MOZ_BORDER_RIGHT_COLORS,
                LonghandId::BoxDecorationBreak => BOX_DECORATION_BREAK,
                LonghandId::MozFloatEdge => _MOZ_FLOAT_EDGE,
                LonghandId::BorderImageSource => BORDER_IMAGE_SOURCE,
                LonghandId::BorderImageOutset => BORDER_IMAGE_OUTSET,
                LonghandId::BorderImageRepeat => BORDER_IMAGE_REPEAT,
                LonghandId::BorderImageWidth => BORDER_IMAGE_WIDTH,
                LonghandId::BorderImageSlice => BORDER_IMAGE_SLICE,
                LonghandId::Display => DISPLAY,
                LonghandId::MozTopLayer => _MOZ_TOP_LAYER,
                LonghandId::Position => POSITION,
                LonghandId::Float => FLOAT,
                LonghandId::Clear => CLEAR,
                LonghandId::VerticalAlign => VERTICAL_ALIGN,
                LonghandId::OverflowClipBoxInline => OVERFLOW_CLIP_BOX_INLINE,
                LonghandId::OverflowClipBoxBlock => OVERFLOW_CLIP_BOX_BLOCK,
                LonghandId::OverflowX => OVERFLOW_X,
                LonghandId::OverflowY => OVERFLOW_Y,
                LonghandId::TransitionDuration => TRANSITION_DURATION,
                LonghandId::TransitionTimingFunction => TRANSITION_TIMING_FUNCTION,
                LonghandId::TransitionProperty => TRANSITION_PROPERTY,
                LonghandId::TransitionDelay => TRANSITION_DELAY,
                LonghandId::AnimationName => ANIMATION_NAME,
                LonghandId::AnimationDuration => ANIMATION_DURATION,
                LonghandId::AnimationTimingFunction => ANIMATION_TIMING_FUNCTION,
                LonghandId::AnimationIterationCount => ANIMATION_ITERATION_COUNT,
                LonghandId::AnimationDirection => ANIMATION_DIRECTION,
                LonghandId::AnimationPlayState => ANIMATION_PLAY_STATE,
                LonghandId::AnimationFillMode => ANIMATION_FILL_MODE,
                LonghandId::AnimationDelay => ANIMATION_DELAY,
                LonghandId::ScrollSnapPointsX => SCROLL_SNAP_POINTS_X,
                LonghandId::ScrollSnapPointsY => SCROLL_SNAP_POINTS_Y,
                LonghandId::ScrollSnapDestination => SCROLL_SNAP_DESTINATION,
                LonghandId::ScrollSnapCoordinate => SCROLL_SNAP_COORDINATE,
                LonghandId::Transform => TRANSFORM,
                LonghandId::ScrollBehavior => SCROLL_BEHAVIOR,
                LonghandId::ScrollSnapTypeX => SCROLL_SNAP_TYPE_X,
                LonghandId::ScrollSnapTypeY => SCROLL_SNAP_TYPE_Y,
                LonghandId::OverscrollBehaviorX => OVERSCROLL_BEHAVIOR_X,
                LonghandId::OverscrollBehaviorY => OVERSCROLL_BEHAVIOR_Y,
                LonghandId::Isolation => ISOLATION,
                LonghandId::PageBreakAfter => PAGE_BREAK_AFTER,
                LonghandId::PageBreakBefore => PAGE_BREAK_BEFORE,
                LonghandId::PageBreakInside => PAGE_BREAK_INSIDE,
                LonghandId::Resize => RESIZE,
                LonghandId::Perspective => PERSPECTIVE,
                LonghandId::PerspectiveOrigin => PERSPECTIVE_ORIGIN,
                LonghandId::BackfaceVisibility => BACKFACE_VISIBILITY,
                LonghandId::TransformBox => TRANSFORM_BOX,
                LonghandId::TransformStyle => TRANSFORM_STYLE,
                LonghandId::TransformOrigin => TRANSFORM_ORIGIN,
                LonghandId::Contain => CONTAIN,
                LonghandId::MozAppearance => _MOZ_APPEARANCE,
                LonghandId::MozBinding => _MOZ_BINDING,
                LonghandId::MozOrient => _MOZ_ORIENT,
                LonghandId::WillChange => WILL_CHANGE,
                LonghandId::ShapeImageThreshold => SHAPE_IMAGE_THRESHOLD,
                LonghandId::ShapeOutside => SHAPE_OUTSIDE,
                LonghandId::TouchAction => TOUCH_ACTION,
                LonghandId::Color => COLOR,
                LonghandId::ColumnWidth => COLUMN_WIDTH,
                LonghandId::ColumnCount => COLUMN_COUNT,
                LonghandId::ColumnGap => COLUMN_GAP,
                LonghandId::ColumnFill => COLUMN_FILL,
                LonghandId::ColumnRuleWidth => COLUMN_RULE_WIDTH,
                LonghandId::ColumnRuleColor => COLUMN_RULE_COLOR,
                LonghandId::ColumnSpan => COLUMN_SPAN,
                LonghandId::ColumnRuleStyle => COLUMN_RULE_STYLE,
                LonghandId::Content => CONTENT,
                LonghandId::CounterIncrement => COUNTER_INCREMENT,
                LonghandId::CounterReset => COUNTER_RESET,
                LonghandId::Opacity => OPACITY,
                LonghandId::BoxShadow => BOX_SHADOW,
                LonghandId::Clip => CLIP,
                LonghandId::Filter => FILTER,
                LonghandId::MixBlendMode => MIX_BLEND_MODE,
                LonghandId::FontFamily => FONT_FAMILY,
                LonghandId::FontStyle => FONT_STYLE,
                LonghandId::FontVariantCaps => FONT_VARIANT_CAPS,
                LonghandId::FontWeight => FONT_WEIGHT,
                LonghandId::FontSize => FONT_SIZE,
                LonghandId::FontSizeAdjust => FONT_SIZE_ADJUST,
                LonghandId::FontSynthesis => FONT_SYNTHESIS,
                LonghandId::FontStretch => FONT_STRETCH,
                LonghandId::FontKerning => FONT_KERNING,
                LonghandId::FontVariantAlternates => FONT_VARIANT_ALTERNATES,
                LonghandId::FontVariantEastAsian => FONT_VARIANT_EAST_ASIAN,
                LonghandId::FontVariantLigatures => FONT_VARIANT_LIGATURES,
                LonghandId::FontVariantNumeric => FONT_VARIANT_NUMERIC,
                LonghandId::FontVariantPosition => FONT_VARIANT_POSITION,
                LonghandId::FontFeatureSettings => FONT_FEATURE_SETTINGS,
                LonghandId::FontVariationSettings => FONT_VARIATION_SETTINGS,
                LonghandId::FontLanguageOverride => FONT_LANGUAGE_OVERRIDE,
                LonghandId::XLang => _X_LANG,
                LonghandId::MozScriptSizeMultiplier => _MOZ_SCRIPT_SIZE_MULTIPLIER,
                LonghandId::MozScriptLevel => _MOZ_SCRIPT_LEVEL,
                LonghandId::MozMathDisplay => _MOZ_MATH_DISPLAY,
                LonghandId::MozMathVariant => _MOZ_MATH_VARIANT,
                LonghandId::MozScriptMinSize => _MOZ_SCRIPT_MIN_SIZE,
                LonghandId::XTextZoom => _X_TEXT_ZOOM,
                LonghandId::MozOsxFontSmoothing => _MOZ_OSX_FONT_SMOOTHING,
                LonghandId::MozFontSmoothingBackgroundColor => _MOZ_FONT_SMOOTHING_BACKGROUND_COLOR,
                LonghandId::MozMinFontSizeRatio => _MOZ_MIN_FONT_SIZE_RATIO,
                LonghandId::Visibility => VISIBILITY,
                LonghandId::WritingMode => WRITING_MODE,
                LonghandId::Direction => DIRECTION,
                LonghandId::TextOrientation => TEXT_ORIENTATION,
                LonghandId::ColorAdjust => COLOR_ADJUST,
                LonghandId::ImageRendering => IMAGE_RENDERING,
                LonghandId::ImageOrientation => IMAGE_ORIENTATION,
                LonghandId::BorderCollapse => BORDER_COLLAPSE,
                LonghandId::EmptyCells => EMPTY_CELLS,
                LonghandId::CaptionSide => CAPTION_SIDE,
                LonghandId::BorderSpacing => BORDER_SPACING,
                LonghandId::LineHeight => LINE_HEIGHT,
                LonghandId::TextTransform => TEXT_TRANSFORM,
                LonghandId::Hyphens => HYPHENS,
                LonghandId::MozTextSizeAdjust => _MOZ_TEXT_SIZE_ADJUST,
                LonghandId::TextIndent => TEXT_INDENT,
                LonghandId::OverflowWrap => OVERFLOW_WRAP,
                LonghandId::WordBreak => WORD_BREAK,
                LonghandId::TextJustify => TEXT_JUSTIFY,
                LonghandId::TextAlignLast => TEXT_ALIGN_LAST,
                LonghandId::TextAlign => TEXT_ALIGN,
                LonghandId::LetterSpacing => LETTER_SPACING,
                LonghandId::WordSpacing => WORD_SPACING,
                LonghandId::WhiteSpace => WHITE_SPACE,
                LonghandId::TextShadow => TEXT_SHADOW,
                LonghandId::TextEmphasisStyle => TEXT_EMPHASIS_STYLE,
                LonghandId::TextEmphasisPosition => TEXT_EMPHASIS_POSITION,
                LonghandId::TextEmphasisColor => TEXT_EMPHASIS_COLOR,
                LonghandId::MozTabSize => _MOZ_TAB_SIZE,
                LonghandId::WebkitTextFillColor => _WEBKIT_TEXT_FILL_COLOR,
                LonghandId::WebkitTextStrokeColor => _WEBKIT_TEXT_STROKE_COLOR,
                LonghandId::WebkitTextStrokeWidth => _WEBKIT_TEXT_STROKE_WIDTH,
                LonghandId::RubyAlign => RUBY_ALIGN,
                LonghandId::RubyPosition => RUBY_POSITION,
                LonghandId::TextCombineUpright => TEXT_COMBINE_UPRIGHT,
                LonghandId::TextRendering => TEXT_RENDERING,
                LonghandId::MozControlCharacterVisibility => _MOZ_CONTROL_CHARACTER_VISIBILITY,
                LonghandId::ListStylePosition => LIST_STYLE_POSITION,
                LonghandId::ListStyleType => LIST_STYLE_TYPE,
                LonghandId::ListStyleImage => LIST_STYLE_IMAGE,
                LonghandId::Quotes => QUOTES,
                LonghandId::MozImageRegion => _MOZ_IMAGE_REGION,
                LonghandId::MarginTop => MARGIN_TOP,
                LonghandId::MarginLeft => MARGIN_LEFT,
                LonghandId::MarginBottom => MARGIN_BOTTOM,
                LonghandId::MarginRight => MARGIN_RIGHT,
                LonghandId::MarginBlockStart => MARGIN_BLOCK_START,
                LonghandId::MarginBlockEnd => MARGIN_BLOCK_END,
                LonghandId::MarginInlineStart => MARGIN_INLINE_START,
                LonghandId::MarginInlineEnd => MARGIN_INLINE_END,
                LonghandId::OutlineColor => OUTLINE_COLOR,
                LonghandId::OutlineStyle => OUTLINE_STYLE,
                LonghandId::OutlineWidth => OUTLINE_WIDTH,
                LonghandId::MozOutlineRadiusTopleft => _MOZ_OUTLINE_RADIUS_TOPLEFT,
                LonghandId::MozOutlineRadiusTopright => _MOZ_OUTLINE_RADIUS_TOPRIGHT,
                LonghandId::MozOutlineRadiusBottomright => _MOZ_OUTLINE_RADIUS_BOTTOMRIGHT,
                LonghandId::MozOutlineRadiusBottomleft => _MOZ_OUTLINE_RADIUS_BOTTOMLEFT,
                LonghandId::OutlineOffset => OUTLINE_OFFSET,
                LonghandId::PaddingTop => PADDING_TOP,
                LonghandId::PaddingLeft => PADDING_LEFT,
                LonghandId::PaddingBottom => PADDING_BOTTOM,
                LonghandId::PaddingRight => PADDING_RIGHT,
                LonghandId::PaddingBlockStart => PADDING_BLOCK_START,
                LonghandId::PaddingBlockEnd => PADDING_BLOCK_END,
                LonghandId::PaddingInlineStart => PADDING_INLINE_START,
                LonghandId::PaddingInlineEnd => PADDING_INLINE_END,
                LonghandId::Cursor => CURSOR,
                LonghandId::PointerEvents => POINTER_EVENTS,
                LonghandId::MozUserInput => _MOZ_USER_INPUT,
                LonghandId::MozUserModify => _MOZ_USER_MODIFY,
                LonghandId::MozUserFocus => _MOZ_USER_FOCUS,
                LonghandId::CaretColor => CARET_COLOR,
                LonghandId::Top => TOP,
                LonghandId::Left => LEFT,
                LonghandId::Bottom => BOTTOM,
                LonghandId::Right => RIGHT,
                LonghandId::OffsetBlockStart => OFFSET_BLOCK_START,
                LonghandId::OffsetBlockEnd => OFFSET_BLOCK_END,
                LonghandId::OffsetInlineStart => OFFSET_INLINE_START,
                LonghandId::OffsetInlineEnd => OFFSET_INLINE_END,
                LonghandId::ZIndex => Z_INDEX,
                LonghandId::FlexDirection => FLEX_DIRECTION,
                LonghandId::FlexWrap => FLEX_WRAP,
                LonghandId::JustifyContent => JUSTIFY_CONTENT,
                LonghandId::AlignContent => ALIGN_CONTENT,
                LonghandId::AlignItems => ALIGN_ITEMS,
                LonghandId::JustifyItems => JUSTIFY_ITEMS,
                LonghandId::FlexGrow => FLEX_GROW,
                LonghandId::FlexShrink => FLEX_SHRINK,
                LonghandId::AlignSelf => ALIGN_SELF,
                LonghandId::JustifySelf => JUSTIFY_SELF,
                LonghandId::Order => ORDER,
                LonghandId::FlexBasis => FLEX_BASIS,
                LonghandId::Width => WIDTH,
                LonghandId::MinWidth => MIN_WIDTH,
                LonghandId::MaxWidth => MAX_WIDTH,
                LonghandId::Height => HEIGHT,
                LonghandId::MinHeight => MIN_HEIGHT,
                LonghandId::MaxHeight => MAX_HEIGHT,
                LonghandId::BlockSize => BLOCK_SIZE,
                LonghandId::MinBlockSize => MIN_BLOCK_SIZE,
                LonghandId::MaxBlockSize => MAX_BLOCK_SIZE,
                LonghandId::InlineSize => INLINE_SIZE,
                LonghandId::MinInlineSize => MIN_INLINE_SIZE,
                LonghandId::MaxInlineSize => MAX_INLINE_SIZE,
                LonghandId::BoxSizing => BOX_SIZING,
                LonghandId::ObjectFit => OBJECT_FIT,
                LonghandId::ObjectPosition => OBJECT_POSITION,
                LonghandId::GridRowGap => GRID_ROW_GAP,
                LonghandId::GridRowStart => GRID_ROW_START,
                LonghandId::GridRowEnd => GRID_ROW_END,
                LonghandId::GridAutoRows => GRID_AUTO_ROWS,
                LonghandId::GridTemplateRows => GRID_TEMPLATE_ROWS,
                LonghandId::GridColumnGap => GRID_COLUMN_GAP,
                LonghandId::GridColumnStart => GRID_COLUMN_START,
                LonghandId::GridColumnEnd => GRID_COLUMN_END,
                LonghandId::GridAutoColumns => GRID_AUTO_COLUMNS,
                LonghandId::GridTemplateColumns => GRID_TEMPLATE_COLUMNS,
                LonghandId::GridAutoFlow => GRID_AUTO_FLOW,
                LonghandId::GridTemplateAreas => GRID_TEMPLATE_AREAS,
                LonghandId::TableLayout => TABLE_LAYOUT,
                LonghandId::XSpan => _X_SPAN,
                LonghandId::TextOverflow => TEXT_OVERFLOW,
                LonghandId::UnicodeBidi => UNICODE_BIDI,
                LonghandId::TextDecorationLine => TEXT_DECORATION_LINE,
                LonghandId::TextDecorationStyle => TEXT_DECORATION_STYLE,
                LonghandId::TextDecorationColor => TEXT_DECORATION_COLOR,
                LonghandId::InitialLetter => INITIAL_LETTER,
                LonghandId::ImeMode => IME_MODE,
                LonghandId::MozUserSelect => _MOZ_USER_SELECT,
                LonghandId::MozWindowDragging => _MOZ_WINDOW_DRAGGING,
                LonghandId::MozWindowShadow => _MOZ_WINDOW_SHADOW,
                LonghandId::MozWindowOpacity => _MOZ_WINDOW_OPACITY,
                LonghandId::MozWindowTransform => _MOZ_WINDOW_TRANSFORM,
                LonghandId::MozWindowTransformOrigin => _MOZ_WINDOW_TRANSFORM_ORIGIN,
                LonghandId::MozForceBrokenImageIcon => _MOZ_FORCE_BROKEN_IMAGE_ICON,
                LonghandId::TextAnchor => TEXT_ANCHOR,
                LonghandId::ColorInterpolation => COLOR_INTERPOLATION,
                LonghandId::ColorInterpolationFilters => COLOR_INTERPOLATION_FILTERS,
                LonghandId::Fill => FILL,
                LonghandId::FillOpacity => FILL_OPACITY,
                LonghandId::FillRule => FILL_RULE,
                LonghandId::ShapeRendering => SHAPE_RENDERING,
                LonghandId::Stroke => STROKE,
                LonghandId::StrokeWidth => STROKE_WIDTH,
                LonghandId::StrokeLinecap => STROKE_LINECAP,
                LonghandId::StrokeLinejoin => STROKE_LINEJOIN,
                LonghandId::StrokeMiterlimit => STROKE_MITERLIMIT,
                LonghandId::StrokeOpacity => STROKE_OPACITY,
                LonghandId::StrokeDasharray => STROKE_DASHARRAY,
                LonghandId::StrokeDashoffset => STROKE_DASHOFFSET,
                LonghandId::ClipRule => CLIP_RULE,
                LonghandId::MarkerStart => MARKER_START,
                LonghandId::MarkerMid => MARKER_MID,
                LonghandId::MarkerEnd => MARKER_END,
                LonghandId::PaintOrder => PAINT_ORDER,
                LonghandId::MozContextProperties => _MOZ_CONTEXT_PROPERTIES,
                LonghandId::DominantBaseline => DOMINANT_BASELINE,
                LonghandId::VectorEffect => VECTOR_EFFECT,
                LonghandId::StopColor => STOP_COLOR,
                LonghandId::StopOpacity => STOP_OPACITY,
                LonghandId::FloodColor => FLOOD_COLOR,
                LonghandId::FloodOpacity => FLOOD_OPACITY,
                LonghandId::LightingColor => LIGHTING_COLOR,
                LonghandId::MaskType => MASK_TYPE,
                LonghandId::ClipPath => CLIP_PATH,
                LonghandId::MaskMode => MASK_MODE,
                LonghandId::MaskRepeat => MASK_REPEAT,
                LonghandId::MaskPositionX => MASK_POSITION_X,
                LonghandId::MaskPositionY => MASK_POSITION_Y,
                LonghandId::MaskClip => MASK_CLIP,
                LonghandId::MaskOrigin => MASK_ORIGIN,
                LonghandId::MaskSize => MASK_SIZE,
                LonghandId::MaskComposite => MASK_COMPOSITE,
                LonghandId::MaskImage => MASK_IMAGE,
                LonghandId::MozBoxAlign => _MOZ_BOX_ALIGN,
                LonghandId::MozBoxDirection => _MOZ_BOX_DIRECTION,
                LonghandId::MozBoxFlex => _MOZ_BOX_FLEX,
                LonghandId::MozBoxOrient => _MOZ_BOX_ORIENT,
                LonghandId::MozBoxPack => _MOZ_BOX_PACK,
                LonghandId::MozStackSizing => _MOZ_STACK_SIZING,
                LonghandId::MozBoxOrdinalGroup => _MOZ_BOX_ORDINAL_GROUP,
        }
    }

    fn parse_value<'i, 't>(&self, context: &ParserContext, input: &mut Parser<'i, 't>)
                           -> Result<PropertyDeclaration, ParseError<'i>> {
        match *self {
                LonghandId::BackgroundColor => {
                    longhands::background_color::parse_declared(context, input)
                }
                LonghandId::BackgroundImage => {
                    longhands::background_image::parse_declared(context, input)
                }
                LonghandId::BackgroundPositionX => {
                    longhands::background_position_x::parse_declared(context, input)
                }
                LonghandId::BackgroundPositionY => {
                    longhands::background_position_y::parse_declared(context, input)
                }
                LonghandId::BackgroundRepeat => {
                    longhands::background_repeat::parse_declared(context, input)
                }
                LonghandId::BackgroundAttachment => {
                    longhands::background_attachment::parse_declared(context, input)
                }
                LonghandId::BackgroundClip => {
                    longhands::background_clip::parse_declared(context, input)
                }
                LonghandId::BackgroundOrigin => {
                    longhands::background_origin::parse_declared(context, input)
                }
                LonghandId::BackgroundSize => {
                    longhands::background_size::parse_declared(context, input)
                }
                LonghandId::BackgroundBlendMode => {
                    longhands::background_blend_mode::parse_declared(context, input)
                }
                LonghandId::BorderTopColor => {
                    longhands::border_top_color::parse_declared(context, input)
                }
                LonghandId::BorderTopStyle => {
                    longhands::border_top_style::parse_declared(context, input)
                }
                LonghandId::BorderTopWidth => {
                    longhands::border_top_width::parse_declared(context, input)
                }
                LonghandId::BorderLeftColor => {
                    longhands::border_left_color::parse_declared(context, input)
                }
                LonghandId::BorderLeftStyle => {
                    longhands::border_left_style::parse_declared(context, input)
                }
                LonghandId::BorderLeftWidth => {
                    longhands::border_left_width::parse_declared(context, input)
                }
                LonghandId::BorderBottomColor => {
                    longhands::border_bottom_color::parse_declared(context, input)
                }
                LonghandId::BorderBottomStyle => {
                    longhands::border_bottom_style::parse_declared(context, input)
                }
                LonghandId::BorderBottomWidth => {
                    longhands::border_bottom_width::parse_declared(context, input)
                }
                LonghandId::BorderRightColor => {
                    longhands::border_right_color::parse_declared(context, input)
                }
                LonghandId::BorderRightStyle => {
                    longhands::border_right_style::parse_declared(context, input)
                }
                LonghandId::BorderRightWidth => {
                    longhands::border_right_width::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartColor => {
                    longhands::border_block_start_color::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartStyle => {
                    longhands::border_block_start_style::parse_declared(context, input)
                }
                LonghandId::BorderBlockStartWidth => {
                    longhands::border_block_start_width::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndColor => {
                    longhands::border_block_end_color::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndStyle => {
                    longhands::border_block_end_style::parse_declared(context, input)
                }
                LonghandId::BorderBlockEndWidth => {
                    longhands::border_block_end_width::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartColor => {
                    longhands::border_inline_start_color::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartStyle => {
                    longhands::border_inline_start_style::parse_declared(context, input)
                }
                LonghandId::BorderInlineStartWidth => {
                    longhands::border_inline_start_width::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndColor => {
                    longhands::border_inline_end_color::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndStyle => {
                    longhands::border_inline_end_style::parse_declared(context, input)
                }
                LonghandId::BorderInlineEndWidth => {
                    longhands::border_inline_end_width::parse_declared(context, input)
                }
                LonghandId::BorderTopLeftRadius => {
                    longhands::border_top_left_radius::parse_declared(context, input)
                }
                LonghandId::BorderTopRightRadius => {
                    longhands::border_top_right_radius::parse_declared(context, input)
                }
                LonghandId::BorderBottomRightRadius => {
                    longhands::border_bottom_right_radius::parse_declared(context, input)
                }
                LonghandId::BorderBottomLeftRadius => {
                    longhands::border_bottom_left_radius::parse_declared(context, input)
                }
                LonghandId::MozBorderTopColors => {
                    longhands::_moz_border_top_colors::parse_declared(context, input)
                }
                LonghandId::MozBorderLeftColors => {
                    longhands::_moz_border_left_colors::parse_declared(context, input)
                }
                LonghandId::MozBorderBottomColors => {
                    longhands::_moz_border_bottom_colors::parse_declared(context, input)
                }
                LonghandId::MozBorderRightColors => {
                    longhands::_moz_border_right_colors::parse_declared(context, input)
                }
                LonghandId::BoxDecorationBreak => {
                    longhands::box_decoration_break::parse_declared(context, input)
                }
                LonghandId::MozFloatEdge => {
                    longhands::_moz_float_edge::parse_declared(context, input)
                }
                LonghandId::BorderImageSource => {
                    longhands::border_image_source::parse_declared(context, input)
                }
                LonghandId::BorderImageOutset => {
                    longhands::border_image_outset::parse_declared(context, input)
                }
                LonghandId::BorderImageRepeat => {
                    longhands::border_image_repeat::parse_declared(context, input)
                }
                LonghandId::BorderImageWidth => {
                    longhands::border_image_width::parse_declared(context, input)
                }
                LonghandId::BorderImageSlice => {
                    longhands::border_image_slice::parse_declared(context, input)
                }
                LonghandId::Display => {
                    longhands::display::parse_declared(context, input)
                }
                LonghandId::MozTopLayer => {
                    longhands::_moz_top_layer::parse_declared(context, input)
                }
                LonghandId::Position => {
                    longhands::position::parse_declared(context, input)
                }
                LonghandId::Float => {
                    longhands::float::parse_declared(context, input)
                }
                LonghandId::Clear => {
                    longhands::clear::parse_declared(context, input)
                }
                LonghandId::VerticalAlign => {
                    longhands::vertical_align::parse_declared(context, input)
                }
                LonghandId::OverflowClipBoxInline => {
                    longhands::overflow_clip_box_inline::parse_declared(context, input)
                }
                LonghandId::OverflowClipBoxBlock => {
                    longhands::overflow_clip_box_block::parse_declared(context, input)
                }
                LonghandId::OverflowX => {
                    longhands::overflow_x::parse_declared(context, input)
                }
                LonghandId::OverflowY => {
                    longhands::overflow_y::parse_declared(context, input)
                }
                LonghandId::TransitionDuration => {
                    longhands::transition_duration::parse_declared(context, input)
                }
                LonghandId::TransitionTimingFunction => {
                    longhands::transition_timing_function::parse_declared(context, input)
                }
                LonghandId::TransitionProperty => {
                    longhands::transition_property::parse_declared(context, input)
                }
                LonghandId::TransitionDelay => {
                    longhands::transition_delay::parse_declared(context, input)
                }
                LonghandId::AnimationName => {
                    longhands::animation_name::parse_declared(context, input)
                }
                LonghandId::AnimationDuration => {
                    longhands::animation_duration::parse_declared(context, input)
                }
                LonghandId::AnimationTimingFunction => {
                    longhands::animation_timing_function::parse_declared(context, input)
                }
                LonghandId::AnimationIterationCount => {
                    longhands::animation_iteration_count::parse_declared(context, input)
                }
                LonghandId::AnimationDirection => {
                    longhands::animation_direction::parse_declared(context, input)
                }
                LonghandId::AnimationPlayState => {
                    longhands::animation_play_state::parse_declared(context, input)
                }
                LonghandId::AnimationFillMode => {
                    longhands::animation_fill_mode::parse_declared(context, input)
                }
                LonghandId::AnimationDelay => {
                    longhands::animation_delay::parse_declared(context, input)
                }
                LonghandId::ScrollSnapPointsX => {
                    longhands::scroll_snap_points_x::parse_declared(context, input)
                }
                LonghandId::ScrollSnapPointsY => {
                    longhands::scroll_snap_points_y::parse_declared(context, input)
                }
                LonghandId::ScrollSnapDestination => {
                    longhands::scroll_snap_destination::parse_declared(context, input)
                }
                LonghandId::ScrollSnapCoordinate => {
                    longhands::scroll_snap_coordinate::parse_declared(context, input)
                }
                LonghandId::Transform => {
                    longhands::transform::parse_declared(context, input)
                }
                LonghandId::ScrollBehavior => {
                    longhands::scroll_behavior::parse_declared(context, input)
                }
                LonghandId::ScrollSnapTypeX => {
                    longhands::scroll_snap_type_x::parse_declared(context, input)
                }
                LonghandId::ScrollSnapTypeY => {
                    longhands::scroll_snap_type_y::parse_declared(context, input)
                }
                LonghandId::OverscrollBehaviorX => {
                    longhands::overscroll_behavior_x::parse_declared(context, input)
                }
                LonghandId::OverscrollBehaviorY => {
                    longhands::overscroll_behavior_y::parse_declared(context, input)
                }
                LonghandId::Isolation => {
                    longhands::isolation::parse_declared(context, input)
                }
                LonghandId::PageBreakAfter => {
                    longhands::page_break_after::parse_declared(context, input)
                }
                LonghandId::PageBreakBefore => {
                    longhands::page_break_before::parse_declared(context, input)
                }
                LonghandId::PageBreakInside => {
                    longhands::page_break_inside::parse_declared(context, input)
                }
                LonghandId::Resize => {
                    longhands::resize::parse_declared(context, input)
                }
                LonghandId::Perspective => {
                    longhands::perspective::parse_declared(context, input)
                }
                LonghandId::PerspectiveOrigin => {
                    longhands::perspective_origin::parse_declared(context, input)
                }
                LonghandId::BackfaceVisibility => {
                    longhands::backface_visibility::parse_declared(context, input)
                }
                LonghandId::TransformBox => {
                    longhands::transform_box::parse_declared(context, input)
                }
                LonghandId::TransformStyle => {
                    longhands::transform_style::parse_declared(context, input)
                }
                LonghandId::TransformOrigin => {
                    longhands::transform_origin::parse_declared(context, input)
                }
                LonghandId::Contain => {
                    longhands::contain::parse_declared(context, input)
                }
                LonghandId::MozAppearance => {
                    longhands::_moz_appearance::parse_declared(context, input)
                }
                LonghandId::MozBinding => {
                    longhands::_moz_binding::parse_declared(context, input)
                }
                LonghandId::MozOrient => {
                    longhands::_moz_orient::parse_declared(context, input)
                }
                LonghandId::WillChange => {
                    longhands::will_change::parse_declared(context, input)
                }
                LonghandId::ShapeImageThreshold => {
                    longhands::shape_image_threshold::parse_declared(context, input)
                }
                LonghandId::ShapeOutside => {
                    longhands::shape_outside::parse_declared(context, input)
                }
                LonghandId::TouchAction => {
                    longhands::touch_action::parse_declared(context, input)
                }
                LonghandId::Color => {
                    longhands::color::parse_declared(context, input)
                }
                LonghandId::ColumnWidth => {
                    longhands::column_width::parse_declared(context, input)
                }
                LonghandId::ColumnCount => {
                    longhands::column_count::parse_declared(context, input)
                }
                LonghandId::ColumnGap => {
                    longhands::column_gap::parse_declared(context, input)
                }
                LonghandId::ColumnFill => {
                    longhands::column_fill::parse_declared(context, input)
                }
                LonghandId::ColumnRuleWidth => {
                    longhands::column_rule_width::parse_declared(context, input)
                }
                LonghandId::ColumnRuleColor => {
                    longhands::column_rule_color::parse_declared(context, input)
                }
                LonghandId::ColumnSpan => {
                    longhands::column_span::parse_declared(context, input)
                }
                LonghandId::ColumnRuleStyle => {
                    longhands::column_rule_style::parse_declared(context, input)
                }
                LonghandId::Content => {
                    longhands::content::parse_declared(context, input)
                }
                LonghandId::CounterIncrement => {
                    longhands::counter_increment::parse_declared(context, input)
                }
                LonghandId::CounterReset => {
                    longhands::counter_reset::parse_declared(context, input)
                }
                LonghandId::Opacity => {
                    longhands::opacity::parse_declared(context, input)
                }
                LonghandId::BoxShadow => {
                    longhands::box_shadow::parse_declared(context, input)
                }
                LonghandId::Clip => {
                    longhands::clip::parse_declared(context, input)
                }
                LonghandId::Filter => {
                    longhands::filter::parse_declared(context, input)
                }
                LonghandId::MixBlendMode => {
                    longhands::mix_blend_mode::parse_declared(context, input)
                }
                LonghandId::FontFamily => {
                    longhands::font_family::parse_declared(context, input)
                }
                LonghandId::FontStyle => {
                    longhands::font_style::parse_declared(context, input)
                }
                LonghandId::FontVariantCaps => {
                    longhands::font_variant_caps::parse_declared(context, input)
                }
                LonghandId::FontWeight => {
                    longhands::font_weight::parse_declared(context, input)
                }
                LonghandId::FontSize => {
                    longhands::font_size::parse_declared(context, input)
                }
                LonghandId::FontSizeAdjust => {
                    longhands::font_size_adjust::parse_declared(context, input)
                }
                LonghandId::FontSynthesis => {
                    longhands::font_synthesis::parse_declared(context, input)
                }
                LonghandId::FontStretch => {
                    longhands::font_stretch::parse_declared(context, input)
                }
                LonghandId::FontKerning => {
                    longhands::font_kerning::parse_declared(context, input)
                }
                LonghandId::FontVariantAlternates => {
                    longhands::font_variant_alternates::parse_declared(context, input)
                }
                LonghandId::FontVariantEastAsian => {
                    longhands::font_variant_east_asian::parse_declared(context, input)
                }
                LonghandId::FontVariantLigatures => {
                    longhands::font_variant_ligatures::parse_declared(context, input)
                }
                LonghandId::FontVariantNumeric => {
                    longhands::font_variant_numeric::parse_declared(context, input)
                }
                LonghandId::FontVariantPosition => {
                    longhands::font_variant_position::parse_declared(context, input)
                }
                LonghandId::FontFeatureSettings => {
                    longhands::font_feature_settings::parse_declared(context, input)
                }
                LonghandId::FontVariationSettings => {
                    longhands::font_variation_settings::parse_declared(context, input)
                }
                LonghandId::FontLanguageOverride => {
                    longhands::font_language_override::parse_declared(context, input)
                }
                LonghandId::XLang => {
                    longhands::_x_lang::parse_declared(context, input)
                }
                LonghandId::MozScriptSizeMultiplier => {
                    longhands::_moz_script_size_multiplier::parse_declared(context, input)
                }
                LonghandId::MozScriptLevel => {
                    longhands::_moz_script_level::parse_declared(context, input)
                }
                LonghandId::MozMathDisplay => {
                    longhands::_moz_math_display::parse_declared(context, input)
                }
                LonghandId::MozMathVariant => {
                    longhands::_moz_math_variant::parse_declared(context, input)
                }
                LonghandId::MozScriptMinSize => {
                    longhands::_moz_script_min_size::parse_declared(context, input)
                }
                LonghandId::XTextZoom => {
                    longhands::_x_text_zoom::parse_declared(context, input)
                }
                LonghandId::MozOsxFontSmoothing => {
                    longhands::_moz_osx_font_smoothing::parse_declared(context, input)
                }
                LonghandId::MozFontSmoothingBackgroundColor => {
                    longhands::_moz_font_smoothing_background_color::parse_declared(context, input)
                }
                LonghandId::MozMinFontSizeRatio => {
                    longhands::_moz_min_font_size_ratio::parse_declared(context, input)
                }
                LonghandId::Visibility => {
                    longhands::visibility::parse_declared(context, input)
                }
                LonghandId::WritingMode => {
                    longhands::writing_mode::parse_declared(context, input)
                }
                LonghandId::Direction => {
                    longhands::direction::parse_declared(context, input)
                }
                LonghandId::TextOrientation => {
                    longhands::text_orientation::parse_declared(context, input)
                }
                LonghandId::ColorAdjust => {
                    longhands::color_adjust::parse_declared(context, input)
                }
                LonghandId::ImageRendering => {
                    longhands::image_rendering::parse_declared(context, input)
                }
                LonghandId::ImageOrientation => {
                    longhands::image_orientation::parse_declared(context, input)
                }
                LonghandId::BorderCollapse => {
                    longhands::border_collapse::parse_declared(context, input)
                }
                LonghandId::EmptyCells => {
                    longhands::empty_cells::parse_declared(context, input)
                }
                LonghandId::CaptionSide => {
                    longhands::caption_side::parse_declared(context, input)
                }
                LonghandId::BorderSpacing => {
                    longhands::border_spacing::parse_declared(context, input)
                }
                LonghandId::LineHeight => {
                    longhands::line_height::parse_declared(context, input)
                }
                LonghandId::TextTransform => {
                    longhands::text_transform::parse_declared(context, input)
                }
                LonghandId::Hyphens => {
                    longhands::hyphens::parse_declared(context, input)
                }
                LonghandId::MozTextSizeAdjust => {
                    longhands::_moz_text_size_adjust::parse_declared(context, input)
                }
                LonghandId::TextIndent => {
                    longhands::text_indent::parse_declared(context, input)
                }
                LonghandId::OverflowWrap => {
                    longhands::overflow_wrap::parse_declared(context, input)
                }
                LonghandId::WordBreak => {
                    longhands::word_break::parse_declared(context, input)
                }
                LonghandId::TextJustify => {
                    longhands::text_justify::parse_declared(context, input)
                }
                LonghandId::TextAlignLast => {
                    longhands::text_align_last::parse_declared(context, input)
                }
                LonghandId::TextAlign => {
                    longhands::text_align::parse_declared(context, input)
                }
                LonghandId::LetterSpacing => {
                    longhands::letter_spacing::parse_declared(context, input)
                }
                LonghandId::WordSpacing => {
                    longhands::word_spacing::parse_declared(context, input)
                }
                LonghandId::WhiteSpace => {
                    longhands::white_space::parse_declared(context, input)
                }
                LonghandId::TextShadow => {
                    longhands::text_shadow::parse_declared(context, input)
                }
                LonghandId::TextEmphasisStyle => {
                    longhands::text_emphasis_style::parse_declared(context, input)
                }
                LonghandId::TextEmphasisPosition => {
                    longhands::text_emphasis_position::parse_declared(context, input)
                }
                LonghandId::TextEmphasisColor => {
                    longhands::text_emphasis_color::parse_declared(context, input)
                }
                LonghandId::MozTabSize => {
                    longhands::_moz_tab_size::parse_declared(context, input)
                }
                LonghandId::WebkitTextFillColor => {
                    longhands::_webkit_text_fill_color::parse_declared(context, input)
                }
                LonghandId::WebkitTextStrokeColor => {
                    longhands::_webkit_text_stroke_color::parse_declared(context, input)
                }
                LonghandId::WebkitTextStrokeWidth => {
                    longhands::_webkit_text_stroke_width::parse_declared(context, input)
                }
                LonghandId::RubyAlign => {
                    longhands::ruby_align::parse_declared(context, input)
                }
                LonghandId::RubyPosition => {
                    longhands::ruby_position::parse_declared(context, input)
                }
                LonghandId::TextCombineUpright => {
                    longhands::text_combine_upright::parse_declared(context, input)
                }
                LonghandId::TextRendering => {
                    longhands::text_rendering::parse_declared(context, input)
                }
                LonghandId::MozControlCharacterVisibility => {
                    longhands::_moz_control_character_visibility::parse_declared(context, input)
                }
                LonghandId::ListStylePosition => {
                    longhands::list_style_position::parse_declared(context, input)
                }
                LonghandId::ListStyleType => {
                    longhands::list_style_type::parse_declared(context, input)
                }
                LonghandId::ListStyleImage => {
                    longhands::list_style_image::parse_declared(context, input)
                }
                LonghandId::Quotes => {
                    longhands::quotes::parse_declared(context, input)
                }
                LonghandId::MozImageRegion => {
                    longhands::_moz_image_region::parse_declared(context, input)
                }
                LonghandId::MarginTop => {
                    longhands::margin_top::parse_declared(context, input)
                }
                LonghandId::MarginLeft => {
                    longhands::margin_left::parse_declared(context, input)
                }
                LonghandId::MarginBottom => {
                    longhands::margin_bottom::parse_declared(context, input)
                }
                LonghandId::MarginRight => {
                    longhands::margin_right::parse_declared(context, input)
                }
                LonghandId::MarginBlockStart => {
                    longhands::margin_block_start::parse_declared(context, input)
                }
                LonghandId::MarginBlockEnd => {
                    longhands::margin_block_end::parse_declared(context, input)
                }
                LonghandId::MarginInlineStart => {
                    longhands::margin_inline_start::parse_declared(context, input)
                }
                LonghandId::MarginInlineEnd => {
                    longhands::margin_inline_end::parse_declared(context, input)
                }
                LonghandId::OutlineColor => {
                    longhands::outline_color::parse_declared(context, input)
                }
                LonghandId::OutlineStyle => {
                    longhands::outline_style::parse_declared(context, input)
                }
                LonghandId::OutlineWidth => {
                    longhands::outline_width::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusTopleft => {
                    longhands::_moz_outline_radius_topleft::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusTopright => {
                    longhands::_moz_outline_radius_topright::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusBottomright => {
                    longhands::_moz_outline_radius_bottomright::parse_declared(context, input)
                }
                LonghandId::MozOutlineRadiusBottomleft => {
                    longhands::_moz_outline_radius_bottomleft::parse_declared(context, input)
                }
                LonghandId::OutlineOffset => {
                    longhands::outline_offset::parse_declared(context, input)
                }
                LonghandId::PaddingTop => {
                    longhands::padding_top::parse_declared(context, input)
                }
                LonghandId::PaddingLeft => {
                    longhands::padding_left::parse_declared(context, input)
                }
                LonghandId::PaddingBottom => {
                    longhands::padding_bottom::parse_declared(context, input)
                }
                LonghandId::PaddingRight => {
                    longhands::padding_right::parse_declared(context, input)
                }
                LonghandId::PaddingBlockStart => {
                    longhands::padding_block_start::parse_declared(context, input)
                }
                LonghandId::PaddingBlockEnd => {
                    longhands::padding_block_end::parse_declared(context, input)
                }
                LonghandId::PaddingInlineStart => {
                    longhands::padding_inline_start::parse_declared(context, input)
                }
                LonghandId::PaddingInlineEnd => {
                    longhands::padding_inline_end::parse_declared(context, input)
                }
                LonghandId::Cursor => {
                    longhands::cursor::parse_declared(context, input)
                }
                LonghandId::PointerEvents => {
                    longhands::pointer_events::parse_declared(context, input)
                }
                LonghandId::MozUserInput => {
                    longhands::_moz_user_input::parse_declared(context, input)
                }
                LonghandId::MozUserModify => {
                    longhands::_moz_user_modify::parse_declared(context, input)
                }
                LonghandId::MozUserFocus => {
                    longhands::_moz_user_focus::parse_declared(context, input)
                }
                LonghandId::CaretColor => {
                    longhands::caret_color::parse_declared(context, input)
                }
                LonghandId::Top => {
                    longhands::top::parse_declared(context, input)
                }
                LonghandId::Left => {
                    longhands::left::parse_declared(context, input)
                }
                LonghandId::Bottom => {
                    longhands::bottom::parse_declared(context, input)
                }
                LonghandId::Right => {
                    longhands::right::parse_declared(context, input)
                }
                LonghandId::OffsetBlockStart => {
                    longhands::offset_block_start::parse_declared(context, input)
                }
                LonghandId::OffsetBlockEnd => {
                    longhands::offset_block_end::parse_declared(context, input)
                }
                LonghandId::OffsetInlineStart => {
                    longhands::offset_inline_start::parse_declared(context, input)
                }
                LonghandId::OffsetInlineEnd => {
                    longhands::offset_inline_end::parse_declared(context, input)
                }
                LonghandId::ZIndex => {
                    longhands::z_index::parse_declared(context, input)
                }
                LonghandId::FlexDirection => {
                    longhands::flex_direction::parse_declared(context, input)
                }
                LonghandId::FlexWrap => {
                    longhands::flex_wrap::parse_declared(context, input)
                }
                LonghandId::JustifyContent => {
                    longhands::justify_content::parse_declared(context, input)
                }
                LonghandId::AlignContent => {
                    longhands::align_content::parse_declared(context, input)
                }
                LonghandId::AlignItems => {
                    longhands::align_items::parse_declared(context, input)
                }
                LonghandId::JustifyItems => {
                    longhands::justify_items::parse_declared(context, input)
                }
                LonghandId::FlexGrow => {
                    longhands::flex_grow::parse_declared(context, input)
                }
                LonghandId::FlexShrink => {
                    longhands::flex_shrink::parse_declared(context, input)
                }
                LonghandId::AlignSelf => {
                    longhands::align_self::parse_declared(context, input)
                }
                LonghandId::JustifySelf => {
                    longhands::justify_self::parse_declared(context, input)
                }
                LonghandId::Order => {
                    longhands::order::parse_declared(context, input)
                }
                LonghandId::FlexBasis => {
                    longhands::flex_basis::parse_declared(context, input)
                }
                LonghandId::Width => {
                    longhands::width::parse_declared(context, input)
                }
                LonghandId::MinWidth => {
                    longhands::min_width::parse_declared(context, input)
                }
                LonghandId::MaxWidth => {
                    longhands::max_width::parse_declared(context, input)
                }
                LonghandId::Height => {
                    longhands::height::parse_declared(context, input)
                }
                LonghandId::MinHeight => {
                    longhands::min_height::parse_declared(context, input)
                }
                LonghandId::MaxHeight => {
                    longhands::max_height::parse_declared(context, input)
                }
                LonghandId::BlockSize => {
                    longhands::block_size::parse_declared(context, input)
                }
                LonghandId::MinBlockSize => {
                    longhands::min_block_size::parse_declared(context, input)
                }
                LonghandId::MaxBlockSize => {
                    longhands::max_block_size::parse_declared(context, input)
                }
                LonghandId::InlineSize => {
                    longhands::inline_size::parse_declared(context, input)
                }
                LonghandId::MinInlineSize => {
                    longhands::min_inline_size::parse_declared(context, input)
                }
                LonghandId::MaxInlineSize => {
                    longhands::max_inline_size::parse_declared(context, input)
                }
                LonghandId::BoxSizing => {
                    longhands::box_sizing::parse_declared(context, input)
                }
                LonghandId::ObjectFit => {
                    longhands::object_fit::parse_declared(context, input)
                }
                LonghandId::ObjectPosition => {
                    longhands::object_position::parse_declared(context, input)
                }
                LonghandId::GridRowGap => {
                    longhands::grid_row_gap::parse_declared(context, input)
                }
                LonghandId::GridRowStart => {
                    longhands::grid_row_start::parse_declared(context, input)
                }
                LonghandId::GridRowEnd => {
                    longhands::grid_row_end::parse_declared(context, input)
                }
                LonghandId::GridAutoRows => {
                    longhands::grid_auto_rows::parse_declared(context, input)
                }
                LonghandId::GridTemplateRows => {
                    longhands::grid_template_rows::parse_declared(context, input)
                }
                LonghandId::GridColumnGap => {
                    longhands::grid_column_gap::parse_declared(context, input)
                }
                LonghandId::GridColumnStart => {
                    longhands::grid_column_start::parse_declared(context, input)
                }
                LonghandId::GridColumnEnd => {
                    longhands::grid_column_end::parse_declared(context, input)
                }
                LonghandId::GridAutoColumns => {
                    longhands::grid_auto_columns::parse_declared(context, input)
                }
                LonghandId::GridTemplateColumns => {
                    longhands::grid_template_columns::parse_declared(context, input)
                }
                LonghandId::GridAutoFlow => {
                    longhands::grid_auto_flow::parse_declared(context, input)
                }
                LonghandId::GridTemplateAreas => {
                    longhands::grid_template_areas::parse_declared(context, input)
                }
                LonghandId::TableLayout => {
                    longhands::table_layout::parse_declared(context, input)
                }
                LonghandId::XSpan => {
                    longhands::_x_span::parse_declared(context, input)
                }
                LonghandId::TextOverflow => {
                    longhands::text_overflow::parse_declared(context, input)
                }
                LonghandId::UnicodeBidi => {
                    longhands::unicode_bidi::parse_declared(context, input)
                }
                LonghandId::TextDecorationLine => {
                    longhands::text_decoration_line::parse_declared(context, input)
                }
                LonghandId::TextDecorationStyle => {
                    longhands::text_decoration_style::parse_declared(context, input)
                }
                LonghandId::TextDecorationColor => {
                    longhands::text_decoration_color::parse_declared(context, input)
                }
                LonghandId::InitialLetter => {
                    longhands::initial_letter::parse_declared(context, input)
                }
                LonghandId::ImeMode => {
                    longhands::ime_mode::parse_declared(context, input)
                }
                LonghandId::MozUserSelect => {
                    longhands::_moz_user_select::parse_declared(context, input)
                }
                LonghandId::MozWindowDragging => {
                    longhands::_moz_window_dragging::parse_declared(context, input)
                }
                LonghandId::MozWindowShadow => {
                    longhands::_moz_window_shadow::parse_declared(context, input)
                }
                LonghandId::MozWindowOpacity => {
                    longhands::_moz_window_opacity::parse_declared(context, input)
                }
                LonghandId::MozWindowTransform => {
                    longhands::_moz_window_transform::parse_declared(context, input)
                }
                LonghandId::MozWindowTransformOrigin => {
                    longhands::_moz_window_transform_origin::parse_declared(context, input)
                }
                LonghandId::MozForceBrokenImageIcon => {
                    longhands::_moz_force_broken_image_icon::parse_declared(context, input)
                }
                LonghandId::TextAnchor => {
                    longhands::text_anchor::parse_declared(context, input)
                }
                LonghandId::ColorInterpolation => {
                    longhands::color_interpolation::parse_declared(context, input)
                }
                LonghandId::ColorInterpolationFilters => {
                    longhands::color_interpolation_filters::parse_declared(context, input)
                }
                LonghandId::Fill => {
                    longhands::fill::parse_declared(context, input)
                }
                LonghandId::FillOpacity => {
                    longhands::fill_opacity::parse_declared(context, input)
                }
                LonghandId::FillRule => {
                    longhands::fill_rule::parse_declared(context, input)
                }
                LonghandId::ShapeRendering => {
                    longhands::shape_rendering::parse_declared(context, input)
                }
                LonghandId::Stroke => {
                    longhands::stroke::parse_declared(context, input)
                }
                LonghandId::StrokeWidth => {
                    longhands::stroke_width::parse_declared(context, input)
                }
                LonghandId::StrokeLinecap => {
                    longhands::stroke_linecap::parse_declared(context, input)
                }
                LonghandId::StrokeLinejoin => {
                    longhands::stroke_linejoin::parse_declared(context, input)
                }
                LonghandId::StrokeMiterlimit => {
                    longhands::stroke_miterlimit::parse_declared(context, input)
                }
                LonghandId::StrokeOpacity => {
                    longhands::stroke_opacity::parse_declared(context, input)
                }
                LonghandId::StrokeDasharray => {
                    longhands::stroke_dasharray::parse_declared(context, input)
                }
                LonghandId::StrokeDashoffset => {
                    longhands::stroke_dashoffset::parse_declared(context, input)
                }
                LonghandId::ClipRule => {
                    longhands::clip_rule::parse_declared(context, input)
                }
                LonghandId::MarkerStart => {
                    longhands::marker_start::parse_declared(context, input)
                }
                LonghandId::MarkerMid => {
                    longhands::marker_mid::parse_declared(context, input)
                }
                LonghandId::MarkerEnd => {
                    longhands::marker_end::parse_declared(context, input)
                }
                LonghandId::PaintOrder => {
                    longhands::paint_order::parse_declared(context, input)
                }
                LonghandId::MozContextProperties => {
                    longhands::_moz_context_properties::parse_declared(context, input)
                }
                LonghandId::DominantBaseline => {
                    longhands::dominant_baseline::parse_declared(context, input)
                }
                LonghandId::VectorEffect => {
                    longhands::vector_effect::parse_declared(context, input)
                }
                LonghandId::StopColor => {
                    longhands::stop_color::parse_declared(context, input)
                }
                LonghandId::StopOpacity => {
                    longhands::stop_opacity::parse_declared(context, input)
                }
                LonghandId::FloodColor => {
                    longhands::flood_color::parse_declared(context, input)
                }
                LonghandId::FloodOpacity => {
                    longhands::flood_opacity::parse_declared(context, input)
                }
                LonghandId::LightingColor => {
                    longhands::lighting_color::parse_declared(context, input)
                }
                LonghandId::MaskType => {
                    longhands::mask_type::parse_declared(context, input)
                }
                LonghandId::ClipPath => {
                    longhands::clip_path::parse_declared(context, input)
                }
                LonghandId::MaskMode => {
                    longhands::mask_mode::parse_declared(context, input)
                }
                LonghandId::MaskRepeat => {
                    longhands::mask_repeat::parse_declared(context, input)
                }
                LonghandId::MaskPositionX => {
                    longhands::mask_position_x::parse_declared(context, input)
                }
                LonghandId::MaskPositionY => {
                    longhands::mask_position_y::parse_declared(context, input)
                }
                LonghandId::MaskClip => {
                    longhands::mask_clip::parse_declared(context, input)
                }
                LonghandId::MaskOrigin => {
                    longhands::mask_origin::parse_declared(context, input)
                }
                LonghandId::MaskSize => {
                    longhands::mask_size::parse_declared(context, input)
                }
                LonghandId::MaskComposite => {
                    longhands::mask_composite::parse_declared(context, input)
                }
                LonghandId::MaskImage => {
                    longhands::mask_image::parse_declared(context, input)
                }
                LonghandId::MozBoxAlign => {
                    longhands::_moz_box_align::parse_declared(context, input)
                }
                LonghandId::MozBoxDirection => {
                    longhands::_moz_box_direction::parse_declared(context, input)
                }
                LonghandId::MozBoxFlex => {
                    longhands::_moz_box_flex::parse_declared(context, input)
                }
                LonghandId::MozBoxOrient => {
                    longhands::_moz_box_orient::parse_declared(context, input)
                }
                LonghandId::MozBoxPack => {
                    longhands::_moz_box_pack::parse_declared(context, input)
                }
                LonghandId::MozStackSizing => {
                    longhands::_moz_stack_sizing::parse_declared(context, input)
                }
                LonghandId::MozBoxOrdinalGroup => {
                    longhands::_moz_box_ordinal_group::parse_declared(context, input)
                }
        }
    }

    /// Returns whether this property is animatable.
    pub fn is_animatable(self) -> bool {
        match self {
            LonghandId::BackgroundColor => {
                true
            }
            LonghandId::BackgroundImage => {
                true
            }
            LonghandId::BackgroundPositionX => {
                true
            }
            LonghandId::BackgroundPositionY => {
                true
            }
            LonghandId::BackgroundRepeat => {
                true
            }
            LonghandId::BackgroundAttachment => {
                true
            }
            LonghandId::BackgroundClip => {
                true
            }
            LonghandId::BackgroundOrigin => {
                true
            }
            LonghandId::BackgroundSize => {
                true
            }
            LonghandId::BackgroundBlendMode => {
                true
            }
            LonghandId::BorderTopColor => {
                true
            }
            LonghandId::BorderTopStyle => {
                true
            }
            LonghandId::BorderTopWidth => {
                true
            }
            LonghandId::BorderLeftColor => {
                true
            }
            LonghandId::BorderLeftStyle => {
                true
            }
            LonghandId::BorderLeftWidth => {
                true
            }
            LonghandId::BorderBottomColor => {
                true
            }
            LonghandId::BorderBottomStyle => {
                true
            }
            LonghandId::BorderBottomWidth => {
                true
            }
            LonghandId::BorderRightColor => {
                true
            }
            LonghandId::BorderRightStyle => {
                true
            }
            LonghandId::BorderRightWidth => {
                true
            }
            LonghandId::BorderBlockStartColor => {
                false
            }
            LonghandId::BorderBlockStartStyle => {
                false
            }
            LonghandId::BorderBlockStartWidth => {
                false
            }
            LonghandId::BorderBlockEndColor => {
                false
            }
            LonghandId::BorderBlockEndStyle => {
                false
            }
            LonghandId::BorderBlockEndWidth => {
                false
            }
            LonghandId::BorderInlineStartColor => {
                false
            }
            LonghandId::BorderInlineStartStyle => {
                false
            }
            LonghandId::BorderInlineStartWidth => {
                false
            }
            LonghandId::BorderInlineEndColor => {
                false
            }
            LonghandId::BorderInlineEndStyle => {
                false
            }
            LonghandId::BorderInlineEndWidth => {
                false
            }
            LonghandId::BorderTopLeftRadius => {
                true
            }
            LonghandId::BorderTopRightRadius => {
                true
            }
            LonghandId::BorderBottomRightRadius => {
                true
            }
            LonghandId::BorderBottomLeftRadius => {
                true
            }
            LonghandId::MozBorderTopColors => {
                true
            }
            LonghandId::MozBorderLeftColors => {
                true
            }
            LonghandId::MozBorderBottomColors => {
                true
            }
            LonghandId::MozBorderRightColors => {
                true
            }
            LonghandId::BoxDecorationBreak => {
                true
            }
            LonghandId::MozFloatEdge => {
                true
            }
            LonghandId::BorderImageSource => {
                true
            }
            LonghandId::BorderImageOutset => {
                true
            }
            LonghandId::BorderImageRepeat => {
                true
            }
            LonghandId::BorderImageWidth => {
                true
            }
            LonghandId::BorderImageSlice => {
                true
            }
            LonghandId::Display => {
                true
            }
            LonghandId::MozTopLayer => {
                false
            }
            LonghandId::Position => {
                true
            }
            LonghandId::Float => {
                true
            }
            LonghandId::Clear => {
                true
            }
            LonghandId::VerticalAlign => {
                true
            }
            LonghandId::OverflowClipBoxInline => {
                true
            }
            LonghandId::OverflowClipBoxBlock => {
                true
            }
            LonghandId::OverflowX => {
                true
            }
            LonghandId::OverflowY => {
                true
            }
            LonghandId::TransitionDuration => {
                false
            }
            LonghandId::TransitionTimingFunction => {
                false
            }
            LonghandId::TransitionProperty => {
                false
            }
            LonghandId::TransitionDelay => {
                false
            }
            LonghandId::AnimationName => {
                false
            }
            LonghandId::AnimationDuration => {
                false
            }
            LonghandId::AnimationTimingFunction => {
                false
            }
            LonghandId::AnimationIterationCount => {
                false
            }
            LonghandId::AnimationDirection => {
                false
            }
            LonghandId::AnimationPlayState => {
                false
            }
            LonghandId::AnimationFillMode => {
                false
            }
            LonghandId::AnimationDelay => {
                false
            }
            LonghandId::ScrollSnapPointsX => {
                true
            }
            LonghandId::ScrollSnapPointsY => {
                true
            }
            LonghandId::ScrollSnapDestination => {
                true
            }
            LonghandId::ScrollSnapCoordinate => {
                true
            }
            LonghandId::Transform => {
                true
            }
            LonghandId::ScrollBehavior => {
                true
            }
            LonghandId::ScrollSnapTypeX => {
                true
            }
            LonghandId::ScrollSnapTypeY => {
                true
            }
            LonghandId::OverscrollBehaviorX => {
                true
            }
            LonghandId::OverscrollBehaviorY => {
                true
            }
            LonghandId::Isolation => {
                true
            }
            LonghandId::PageBreakAfter => {
                true
            }
            LonghandId::PageBreakBefore => {
                true
            }
            LonghandId::PageBreakInside => {
                true
            }
            LonghandId::Resize => {
                true
            }
            LonghandId::Perspective => {
                true
            }
            LonghandId::PerspectiveOrigin => {
                true
            }
            LonghandId::BackfaceVisibility => {
                true
            }
            LonghandId::TransformBox => {
                true
            }
            LonghandId::TransformStyle => {
                true
            }
            LonghandId::TransformOrigin => {
                true
            }
            LonghandId::Contain => {
                true
            }
            LonghandId::MozAppearance => {
                true
            }
            LonghandId::MozBinding => {
                false
            }
            LonghandId::MozOrient => {
                true
            }
            LonghandId::WillChange => {
                true
            }
            LonghandId::ShapeImageThreshold => {
                true
            }
            LonghandId::ShapeOutside => {
                true
            }
            LonghandId::TouchAction => {
                true
            }
            LonghandId::Color => {
                true
            }
            LonghandId::ColumnWidth => {
                true
            }
            LonghandId::ColumnCount => {
                true
            }
            LonghandId::ColumnGap => {
                true
            }
            LonghandId::ColumnFill => {
                true
            }
            LonghandId::ColumnRuleWidth => {
                true
            }
            LonghandId::ColumnRuleColor => {
                true
            }
            LonghandId::ColumnSpan => {
                true
            }
            LonghandId::ColumnRuleStyle => {
                true
            }
            LonghandId::Content => {
                true
            }
            LonghandId::CounterIncrement => {
                true
            }
            LonghandId::CounterReset => {
                true
            }
            LonghandId::Opacity => {
                true
            }
            LonghandId::BoxShadow => {
                true
            }
            LonghandId::Clip => {
                true
            }
            LonghandId::Filter => {
                true
            }
            LonghandId::MixBlendMode => {
                true
            }
            LonghandId::FontFamily => {
                true
            }
            LonghandId::FontStyle => {
                true
            }
            LonghandId::FontVariantCaps => {
                true
            }
            LonghandId::FontWeight => {
                true
            }
            LonghandId::FontSize => {
                true
            }
            LonghandId::FontSizeAdjust => {
                true
            }
            LonghandId::FontSynthesis => {
                true
            }
            LonghandId::FontStretch => {
                true
            }
            LonghandId::FontKerning => {
                true
            }
            LonghandId::FontVariantAlternates => {
                true
            }
            LonghandId::FontVariantEastAsian => {
                true
            }
            LonghandId::FontVariantLigatures => {
                true
            }
            LonghandId::FontVariantNumeric => {
                true
            }
            LonghandId::FontVariantPosition => {
                true
            }
            LonghandId::FontFeatureSettings => {
                true
            }
            LonghandId::FontVariationSettings => {
                true
            }
            LonghandId::FontLanguageOverride => {
                true
            }
            LonghandId::XLang => {
                false
            }
            LonghandId::MozScriptSizeMultiplier => {
                false
            }
            LonghandId::MozScriptLevel => {
                false
            }
            LonghandId::MozMathDisplay => {
                false
            }
            LonghandId::MozMathVariant => {
                false
            }
            LonghandId::MozScriptMinSize => {
                false
            }
            LonghandId::XTextZoom => {
                false
            }
            LonghandId::MozOsxFontSmoothing => {
                true
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                true
            }
            LonghandId::MozMinFontSizeRatio => {
                false
            }
            LonghandId::Visibility => {
                true
            }
            LonghandId::WritingMode => {
                true
            }
            LonghandId::Direction => {
                true
            }
            LonghandId::TextOrientation => {
                true
            }
            LonghandId::ColorAdjust => {
                true
            }
            LonghandId::ImageRendering => {
                true
            }
            LonghandId::ImageOrientation => {
                true
            }
            LonghandId::BorderCollapse => {
                true
            }
            LonghandId::EmptyCells => {
                true
            }
            LonghandId::CaptionSide => {
                true
            }
            LonghandId::BorderSpacing => {
                true
            }
            LonghandId::LineHeight => {
                true
            }
            LonghandId::TextTransform => {
                true
            }
            LonghandId::Hyphens => {
                true
            }
            LonghandId::MozTextSizeAdjust => {
                true
            }
            LonghandId::TextIndent => {
                true
            }
            LonghandId::OverflowWrap => {
                true
            }
            LonghandId::WordBreak => {
                true
            }
            LonghandId::TextJustify => {
                true
            }
            LonghandId::TextAlignLast => {
                true
            }
            LonghandId::TextAlign => {
                true
            }
            LonghandId::LetterSpacing => {
                true
            }
            LonghandId::WordSpacing => {
                true
            }
            LonghandId::WhiteSpace => {
                true
            }
            LonghandId::TextShadow => {
                true
            }
            LonghandId::TextEmphasisStyle => {
                true
            }
            LonghandId::TextEmphasisPosition => {
                true
            }
            LonghandId::TextEmphasisColor => {
                true
            }
            LonghandId::MozTabSize => {
                true
            }
            LonghandId::WebkitTextFillColor => {
                true
            }
            LonghandId::WebkitTextStrokeColor => {
                true
            }
            LonghandId::WebkitTextStrokeWidth => {
                true
            }
            LonghandId::RubyAlign => {
                true
            }
            LonghandId::RubyPosition => {
                true
            }
            LonghandId::TextCombineUpright => {
                true
            }
            LonghandId::TextRendering => {
                true
            }
            LonghandId::MozControlCharacterVisibility => {
                false
            }
            LonghandId::ListStylePosition => {
                true
            }
            LonghandId::ListStyleType => {
                true
            }
            LonghandId::ListStyleImage => {
                true
            }
            LonghandId::Quotes => {
                true
            }
            LonghandId::MozImageRegion => {
                true
            }
            LonghandId::MarginTop => {
                true
            }
            LonghandId::MarginLeft => {
                true
            }
            LonghandId::MarginBottom => {
                true
            }
            LonghandId::MarginRight => {
                true
            }
            LonghandId::MarginBlockStart => {
                false
            }
            LonghandId::MarginBlockEnd => {
                false
            }
            LonghandId::MarginInlineStart => {
                false
            }
            LonghandId::MarginInlineEnd => {
                false
            }
            LonghandId::OutlineColor => {
                true
            }
            LonghandId::OutlineStyle => {
                true
            }
            LonghandId::OutlineWidth => {
                true
            }
            LonghandId::MozOutlineRadiusTopleft => {
                true
            }
            LonghandId::MozOutlineRadiusTopright => {
                true
            }
            LonghandId::MozOutlineRadiusBottomright => {
                true
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                true
            }
            LonghandId::OutlineOffset => {
                true
            }
            LonghandId::PaddingTop => {
                true
            }
            LonghandId::PaddingLeft => {
                true
            }
            LonghandId::PaddingBottom => {
                true
            }
            LonghandId::PaddingRight => {
                true
            }
            LonghandId::PaddingBlockStart => {
                false
            }
            LonghandId::PaddingBlockEnd => {
                false
            }
            LonghandId::PaddingInlineStart => {
                false
            }
            LonghandId::PaddingInlineEnd => {
                false
            }
            LonghandId::Cursor => {
                true
            }
            LonghandId::PointerEvents => {
                true
            }
            LonghandId::MozUserInput => {
                true
            }
            LonghandId::MozUserModify => {
                true
            }
            LonghandId::MozUserFocus => {
                true
            }
            LonghandId::CaretColor => {
                true
            }
            LonghandId::Top => {
                true
            }
            LonghandId::Left => {
                true
            }
            LonghandId::Bottom => {
                true
            }
            LonghandId::Right => {
                true
            }
            LonghandId::OffsetBlockStart => {
                false
            }
            LonghandId::OffsetBlockEnd => {
                false
            }
            LonghandId::OffsetInlineStart => {
                false
            }
            LonghandId::OffsetInlineEnd => {
                false
            }
            LonghandId::ZIndex => {
                true
            }
            LonghandId::FlexDirection => {
                true
            }
            LonghandId::FlexWrap => {
                true
            }
            LonghandId::JustifyContent => {
                true
            }
            LonghandId::AlignContent => {
                true
            }
            LonghandId::AlignItems => {
                true
            }
            LonghandId::JustifyItems => {
                true
            }
            LonghandId::FlexGrow => {
                true
            }
            LonghandId::FlexShrink => {
                true
            }
            LonghandId::AlignSelf => {
                true
            }
            LonghandId::JustifySelf => {
                true
            }
            LonghandId::Order => {
                true
            }
            LonghandId::FlexBasis => {
                true
            }
            LonghandId::Width => {
                true
            }
            LonghandId::MinWidth => {
                true
            }
            LonghandId::MaxWidth => {
                true
            }
            LonghandId::Height => {
                true
            }
            LonghandId::MinHeight => {
                true
            }
            LonghandId::MaxHeight => {
                true
            }
            LonghandId::BlockSize => {
                false
            }
            LonghandId::MinBlockSize => {
                false
            }
            LonghandId::MaxBlockSize => {
                false
            }
            LonghandId::InlineSize => {
                false
            }
            LonghandId::MinInlineSize => {
                false
            }
            LonghandId::MaxInlineSize => {
                false
            }
            LonghandId::BoxSizing => {
                true
            }
            LonghandId::ObjectFit => {
                true
            }
            LonghandId::ObjectPosition => {
                true
            }
            LonghandId::GridRowGap => {
                true
            }
            LonghandId::GridRowStart => {
                true
            }
            LonghandId::GridRowEnd => {
                true
            }
            LonghandId::GridAutoRows => {
                true
            }
            LonghandId::GridTemplateRows => {
                true
            }
            LonghandId::GridColumnGap => {
                true
            }
            LonghandId::GridColumnStart => {
                true
            }
            LonghandId::GridColumnEnd => {
                true
            }
            LonghandId::GridAutoColumns => {
                true
            }
            LonghandId::GridTemplateColumns => {
                true
            }
            LonghandId::GridAutoFlow => {
                true
            }
            LonghandId::GridTemplateAreas => {
                true
            }
            LonghandId::TableLayout => {
                true
            }
            LonghandId::XSpan => {
                false
            }
            LonghandId::TextOverflow => {
                true
            }
            LonghandId::UnicodeBidi => {
                true
            }
            LonghandId::TextDecorationLine => {
                true
            }
            LonghandId::TextDecorationStyle => {
                true
            }
            LonghandId::TextDecorationColor => {
                true
            }
            LonghandId::InitialLetter => {
                true
            }
            LonghandId::ImeMode => {
                true
            }
            LonghandId::MozUserSelect => {
                true
            }
            LonghandId::MozWindowDragging => {
                true
            }
            LonghandId::MozWindowShadow => {
                true
            }
            LonghandId::MozWindowOpacity => {
                true
            }
            LonghandId::MozWindowTransform => {
                true
            }
            LonghandId::MozWindowTransformOrigin => {
                true
            }
            LonghandId::MozForceBrokenImageIcon => {
                true
            }
            LonghandId::TextAnchor => {
                true
            }
            LonghandId::ColorInterpolation => {
                true
            }
            LonghandId::ColorInterpolationFilters => {
                true
            }
            LonghandId::Fill => {
                true
            }
            LonghandId::FillOpacity => {
                true
            }
            LonghandId::FillRule => {
                true
            }
            LonghandId::ShapeRendering => {
                true
            }
            LonghandId::Stroke => {
                true
            }
            LonghandId::StrokeWidth => {
                true
            }
            LonghandId::StrokeLinecap => {
                true
            }
            LonghandId::StrokeLinejoin => {
                true
            }
            LonghandId::StrokeMiterlimit => {
                true
            }
            LonghandId::StrokeOpacity => {
                true
            }
            LonghandId::StrokeDasharray => {
                true
            }
            LonghandId::StrokeDashoffset => {
                true
            }
            LonghandId::ClipRule => {
                true
            }
            LonghandId::MarkerStart => {
                true
            }
            LonghandId::MarkerMid => {
                true
            }
            LonghandId::MarkerEnd => {
                true
            }
            LonghandId::PaintOrder => {
                true
            }
            LonghandId::MozContextProperties => {
                false
            }
            LonghandId::DominantBaseline => {
                true
            }
            LonghandId::VectorEffect => {
                true
            }
            LonghandId::StopColor => {
                true
            }
            LonghandId::StopOpacity => {
                true
            }
            LonghandId::FloodColor => {
                true
            }
            LonghandId::FloodOpacity => {
                true
            }
            LonghandId::LightingColor => {
                true
            }
            LonghandId::MaskType => {
                true
            }
            LonghandId::ClipPath => {
                true
            }
            LonghandId::MaskMode => {
                true
            }
            LonghandId::MaskRepeat => {
                true
            }
            LonghandId::MaskPositionX => {
                true
            }
            LonghandId::MaskPositionY => {
                true
            }
            LonghandId::MaskClip => {
                true
            }
            LonghandId::MaskOrigin => {
                true
            }
            LonghandId::MaskSize => {
                true
            }
            LonghandId::MaskComposite => {
                true
            }
            LonghandId::MaskImage => {
                true
            }
            LonghandId::MozBoxAlign => {
                true
            }
            LonghandId::MozBoxDirection => {
                true
            }
            LonghandId::MozBoxFlex => {
                true
            }
            LonghandId::MozBoxOrient => {
                true
            }
            LonghandId::MozBoxPack => {
                true
            }
            LonghandId::MozStackSizing => {
                true
            }
            LonghandId::MozBoxOrdinalGroup => {
                true
            }
        }
    }

    /// Returns whether this property is animatable in a discrete way.
    pub fn is_discrete_animatable(self) -> bool {
        match self {
            LonghandId::BackgroundColor => {
                false
            }
            LonghandId::BackgroundImage => {
                true
            }
            LonghandId::BackgroundPositionX => {
                false
            }
            LonghandId::BackgroundPositionY => {
                false
            }
            LonghandId::BackgroundRepeat => {
                true
            }
            LonghandId::BackgroundAttachment => {
                true
            }
            LonghandId::BackgroundClip => {
                true
            }
            LonghandId::BackgroundOrigin => {
                true
            }
            LonghandId::BackgroundSize => {
                false
            }
            LonghandId::BackgroundBlendMode => {
                true
            }
            LonghandId::BorderTopColor => {
                false
            }
            LonghandId::BorderTopStyle => {
                true
            }
            LonghandId::BorderTopWidth => {
                false
            }
            LonghandId::BorderLeftColor => {
                false
            }
            LonghandId::BorderLeftStyle => {
                true
            }
            LonghandId::BorderLeftWidth => {
                false
            }
            LonghandId::BorderBottomColor => {
                false
            }
            LonghandId::BorderBottomStyle => {
                true
            }
            LonghandId::BorderBottomWidth => {
                false
            }
            LonghandId::BorderRightColor => {
                false
            }
            LonghandId::BorderRightStyle => {
                true
            }
            LonghandId::BorderRightWidth => {
                false
            }
            LonghandId::BorderBlockStartColor => {
                false
            }
            LonghandId::BorderBlockStartStyle => {
                false
            }
            LonghandId::BorderBlockStartWidth => {
                false
            }
            LonghandId::BorderBlockEndColor => {
                false
            }
            LonghandId::BorderBlockEndStyle => {
                false
            }
            LonghandId::BorderBlockEndWidth => {
                false
            }
            LonghandId::BorderInlineStartColor => {
                false
            }
            LonghandId::BorderInlineStartStyle => {
                false
            }
            LonghandId::BorderInlineStartWidth => {
                false
            }
            LonghandId::BorderInlineEndColor => {
                false
            }
            LonghandId::BorderInlineEndStyle => {
                false
            }
            LonghandId::BorderInlineEndWidth => {
                false
            }
            LonghandId::BorderTopLeftRadius => {
                false
            }
            LonghandId::BorderTopRightRadius => {
                false
            }
            LonghandId::BorderBottomRightRadius => {
                false
            }
            LonghandId::BorderBottomLeftRadius => {
                false
            }
            LonghandId::MozBorderTopColors => {
                true
            }
            LonghandId::MozBorderLeftColors => {
                true
            }
            LonghandId::MozBorderBottomColors => {
                true
            }
            LonghandId::MozBorderRightColors => {
                true
            }
            LonghandId::BoxDecorationBreak => {
                true
            }
            LonghandId::MozFloatEdge => {
                true
            }
            LonghandId::BorderImageSource => {
                true
            }
            LonghandId::BorderImageOutset => {
                true
            }
            LonghandId::BorderImageRepeat => {
                true
            }
            LonghandId::BorderImageWidth => {
                true
            }
            LonghandId::BorderImageSlice => {
                true
            }
            LonghandId::Display => {
                true
            }
            LonghandId::MozTopLayer => {
                false
            }
            LonghandId::Position => {
                true
            }
            LonghandId::Float => {
                true
            }
            LonghandId::Clear => {
                true
            }
            LonghandId::VerticalAlign => {
                false
            }
            LonghandId::OverflowClipBoxInline => {
                true
            }
            LonghandId::OverflowClipBoxBlock => {
                true
            }
            LonghandId::OverflowX => {
                true
            }
            LonghandId::OverflowY => {
                true
            }
            LonghandId::TransitionDuration => {
                false
            }
            LonghandId::TransitionTimingFunction => {
                false
            }
            LonghandId::TransitionProperty => {
                false
            }
            LonghandId::TransitionDelay => {
                false
            }
            LonghandId::AnimationName => {
                false
            }
            LonghandId::AnimationDuration => {
                false
            }
            LonghandId::AnimationTimingFunction => {
                false
            }
            LonghandId::AnimationIterationCount => {
                false
            }
            LonghandId::AnimationDirection => {
                false
            }
            LonghandId::AnimationPlayState => {
                false
            }
            LonghandId::AnimationFillMode => {
                false
            }
            LonghandId::AnimationDelay => {
                false
            }
            LonghandId::ScrollSnapPointsX => {
                true
            }
            LonghandId::ScrollSnapPointsY => {
                true
            }
            LonghandId::ScrollSnapDestination => {
                true
            }
            LonghandId::ScrollSnapCoordinate => {
                true
            }
            LonghandId::Transform => {
                false
            }
            LonghandId::ScrollBehavior => {
                true
            }
            LonghandId::ScrollSnapTypeX => {
                true
            }
            LonghandId::ScrollSnapTypeY => {
                true
            }
            LonghandId::OverscrollBehaviorX => {
                true
            }
            LonghandId::OverscrollBehaviorY => {
                true
            }
            LonghandId::Isolation => {
                true
            }
            LonghandId::PageBreakAfter => {
                true
            }
            LonghandId::PageBreakBefore => {
                true
            }
            LonghandId::PageBreakInside => {
                true
            }
            LonghandId::Resize => {
                true
            }
            LonghandId::Perspective => {
                false
            }
            LonghandId::PerspectiveOrigin => {
                false
            }
            LonghandId::BackfaceVisibility => {
                true
            }
            LonghandId::TransformBox => {
                true
            }
            LonghandId::TransformStyle => {
                true
            }
            LonghandId::TransformOrigin => {
                false
            }
            LonghandId::Contain => {
                true
            }
            LonghandId::MozAppearance => {
                true
            }
            LonghandId::MozBinding => {
                false
            }
            LonghandId::MozOrient => {
                true
            }
            LonghandId::WillChange => {
                true
            }
            LonghandId::ShapeImageThreshold => {
                false
            }
            LonghandId::ShapeOutside => {
                false
            }
            LonghandId::TouchAction => {
                true
            }
            LonghandId::Color => {
                false
            }
            LonghandId::ColumnWidth => {
                false
            }
            LonghandId::ColumnCount => {
                false
            }
            LonghandId::ColumnGap => {
                false
            }
            LonghandId::ColumnFill => {
                true
            }
            LonghandId::ColumnRuleWidth => {
                false
            }
            LonghandId::ColumnRuleColor => {
                false
            }
            LonghandId::ColumnSpan => {
                true
            }
            LonghandId::ColumnRuleStyle => {
                true
            }
            LonghandId::Content => {
                true
            }
            LonghandId::CounterIncrement => {
                true
            }
            LonghandId::CounterReset => {
                true
            }
            LonghandId::Opacity => {
                false
            }
            LonghandId::BoxShadow => {
                false
            }
            LonghandId::Clip => {
                false
            }
            LonghandId::Filter => {
                false
            }
            LonghandId::MixBlendMode => {
                true
            }
            LonghandId::FontFamily => {
                true
            }
            LonghandId::FontStyle => {
                true
            }
            LonghandId::FontVariantCaps => {
                true
            }
            LonghandId::FontWeight => {
                false
            }
            LonghandId::FontSize => {
                false
            }
            LonghandId::FontSizeAdjust => {
                false
            }
            LonghandId::FontSynthesis => {
                true
            }
            LonghandId::FontStretch => {
                false
            }
            LonghandId::FontKerning => {
                true
            }
            LonghandId::FontVariantAlternates => {
                true
            }
            LonghandId::FontVariantEastAsian => {
                true
            }
            LonghandId::FontVariantLigatures => {
                true
            }
            LonghandId::FontVariantNumeric => {
                true
            }
            LonghandId::FontVariantPosition => {
                true
            }
            LonghandId::FontFeatureSettings => {
                true
            }
            LonghandId::FontVariationSettings => {
                false
            }
            LonghandId::FontLanguageOverride => {
                true
            }
            LonghandId::XLang => {
                false
            }
            LonghandId::MozScriptSizeMultiplier => {
                false
            }
            LonghandId::MozScriptLevel => {
                false
            }
            LonghandId::MozMathDisplay => {
                false
            }
            LonghandId::MozMathVariant => {
                false
            }
            LonghandId::MozScriptMinSize => {
                false
            }
            LonghandId::XTextZoom => {
                false
            }
            LonghandId::MozOsxFontSmoothing => {
                true
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                false
            }
            LonghandId::MozMinFontSizeRatio => {
                false
            }
            LonghandId::Visibility => {
                false
            }
            LonghandId::WritingMode => {
                true
            }
            LonghandId::Direction => {
                true
            }
            LonghandId::TextOrientation => {
                true
            }
            LonghandId::ColorAdjust => {
                true
            }
            LonghandId::ImageRendering => {
                true
            }
            LonghandId::ImageOrientation => {
                true
            }
            LonghandId::BorderCollapse => {
                true
            }
            LonghandId::EmptyCells => {
                true
            }
            LonghandId::CaptionSide => {
                true
            }
            LonghandId::BorderSpacing => {
                false
            }
            LonghandId::LineHeight => {
                false
            }
            LonghandId::TextTransform => {
                true
            }
            LonghandId::Hyphens => {
                true
            }
            LonghandId::MozTextSizeAdjust => {
                true
            }
            LonghandId::TextIndent => {
                false
            }
            LonghandId::OverflowWrap => {
                true
            }
            LonghandId::WordBreak => {
                true
            }
            LonghandId::TextJustify => {
                true
            }
            LonghandId::TextAlignLast => {
                true
            }
            LonghandId::TextAlign => {
                true
            }
            LonghandId::LetterSpacing => {
                false
            }
            LonghandId::WordSpacing => {
                false
            }
            LonghandId::WhiteSpace => {
                true
            }
            LonghandId::TextShadow => {
                false
            }
            LonghandId::TextEmphasisStyle => {
                true
            }
            LonghandId::TextEmphasisPosition => {
                true
            }
            LonghandId::TextEmphasisColor => {
                false
            }
            LonghandId::MozTabSize => {
                false
            }
            LonghandId::WebkitTextFillColor => {
                false
            }
            LonghandId::WebkitTextStrokeColor => {
                false
            }
            LonghandId::WebkitTextStrokeWidth => {
                true
            }
            LonghandId::RubyAlign => {
                true
            }
            LonghandId::RubyPosition => {
                true
            }
            LonghandId::TextCombineUpright => {
                true
            }
            LonghandId::TextRendering => {
                true
            }
            LonghandId::MozControlCharacterVisibility => {
                false
            }
            LonghandId::ListStylePosition => {
                true
            }
            LonghandId::ListStyleType => {
                true
            }
            LonghandId::ListStyleImage => {
                true
            }
            LonghandId::Quotes => {
                true
            }
            LonghandId::MozImageRegion => {
                false
            }
            LonghandId::MarginTop => {
                false
            }
            LonghandId::MarginLeft => {
                false
            }
            LonghandId::MarginBottom => {
                false
            }
            LonghandId::MarginRight => {
                false
            }
            LonghandId::MarginBlockStart => {
                false
            }
            LonghandId::MarginBlockEnd => {
                false
            }
            LonghandId::MarginInlineStart => {
                false
            }
            LonghandId::MarginInlineEnd => {
                false
            }
            LonghandId::OutlineColor => {
                false
            }
            LonghandId::OutlineStyle => {
                true
            }
            LonghandId::OutlineWidth => {
                false
            }
            LonghandId::MozOutlineRadiusTopleft => {
                false
            }
            LonghandId::MozOutlineRadiusTopright => {
                false
            }
            LonghandId::MozOutlineRadiusBottomright => {
                false
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                false
            }
            LonghandId::OutlineOffset => {
                false
            }
            LonghandId::PaddingTop => {
                false
            }
            LonghandId::PaddingLeft => {
                false
            }
            LonghandId::PaddingBottom => {
                false
            }
            LonghandId::PaddingRight => {
                false
            }
            LonghandId::PaddingBlockStart => {
                false
            }
            LonghandId::PaddingBlockEnd => {
                false
            }
            LonghandId::PaddingInlineStart => {
                false
            }
            LonghandId::PaddingInlineEnd => {
                false
            }
            LonghandId::Cursor => {
                true
            }
            LonghandId::PointerEvents => {
                true
            }
            LonghandId::MozUserInput => {
                true
            }
            LonghandId::MozUserModify => {
                true
            }
            LonghandId::MozUserFocus => {
                true
            }
            LonghandId::CaretColor => {
                false
            }
            LonghandId::Top => {
                false
            }
            LonghandId::Left => {
                false
            }
            LonghandId::Bottom => {
                false
            }
            LonghandId::Right => {
                false
            }
            LonghandId::OffsetBlockStart => {
                false
            }
            LonghandId::OffsetBlockEnd => {
                false
            }
            LonghandId::OffsetInlineStart => {
                false
            }
            LonghandId::OffsetInlineEnd => {
                false
            }
            LonghandId::ZIndex => {
                false
            }
            LonghandId::FlexDirection => {
                true
            }
            LonghandId::FlexWrap => {
                true
            }
            LonghandId::JustifyContent => {
                true
            }
            LonghandId::AlignContent => {
                true
            }
            LonghandId::AlignItems => {
                true
            }
            LonghandId::JustifyItems => {
                true
            }
            LonghandId::FlexGrow => {
                false
            }
            LonghandId::FlexShrink => {
                false
            }
            LonghandId::AlignSelf => {
                true
            }
            LonghandId::JustifySelf => {
                true
            }
            LonghandId::Order => {
                false
            }
            LonghandId::FlexBasis => {
                false
            }
            LonghandId::Width => {
                false
            }
            LonghandId::MinWidth => {
                false
            }
            LonghandId::MaxWidth => {
                false
            }
            LonghandId::Height => {
                false
            }
            LonghandId::MinHeight => {
                false
            }
            LonghandId::MaxHeight => {
                false
            }
            LonghandId::BlockSize => {
                false
            }
            LonghandId::MinBlockSize => {
                false
            }
            LonghandId::MaxBlockSize => {
                false
            }
            LonghandId::InlineSize => {
                false
            }
            LonghandId::MinInlineSize => {
                false
            }
            LonghandId::MaxInlineSize => {
                false
            }
            LonghandId::BoxSizing => {
                true
            }
            LonghandId::ObjectFit => {
                true
            }
            LonghandId::ObjectPosition => {
                false
            }
            LonghandId::GridRowGap => {
                false
            }
            LonghandId::GridRowStart => {
                true
            }
            LonghandId::GridRowEnd => {
                true
            }
            LonghandId::GridAutoRows => {
                true
            }
            LonghandId::GridTemplateRows => {
                true
            }
            LonghandId::GridColumnGap => {
                false
            }
            LonghandId::GridColumnStart => {
                true
            }
            LonghandId::GridColumnEnd => {
                true
            }
            LonghandId::GridAutoColumns => {
                true
            }
            LonghandId::GridTemplateColumns => {
                true
            }
            LonghandId::GridAutoFlow => {
                true
            }
            LonghandId::GridTemplateAreas => {
                true
            }
            LonghandId::TableLayout => {
                true
            }
            LonghandId::XSpan => {
                false
            }
            LonghandId::TextOverflow => {
                true
            }
            LonghandId::UnicodeBidi => {
                true
            }
            LonghandId::TextDecorationLine => {
                true
            }
            LonghandId::TextDecorationStyle => {
                true
            }
            LonghandId::TextDecorationColor => {
                false
            }
            LonghandId::InitialLetter => {
                true
            }
            LonghandId::ImeMode => {
                true
            }
            LonghandId::MozUserSelect => {
                true
            }
            LonghandId::MozWindowDragging => {
                true
            }
            LonghandId::MozWindowShadow => {
                true
            }
            LonghandId::MozWindowOpacity => {
                false
            }
            LonghandId::MozWindowTransform => {
                false
            }
            LonghandId::MozWindowTransformOrigin => {
                false
            }
            LonghandId::MozForceBrokenImageIcon => {
                true
            }
            LonghandId::TextAnchor => {
                true
            }
            LonghandId::ColorInterpolation => {
                true
            }
            LonghandId::ColorInterpolationFilters => {
                true
            }
            LonghandId::Fill => {
                false
            }
            LonghandId::FillOpacity => {
                false
            }
            LonghandId::FillRule => {
                true
            }
            LonghandId::ShapeRendering => {
                true
            }
            LonghandId::Stroke => {
                false
            }
            LonghandId::StrokeWidth => {
                false
            }
            LonghandId::StrokeLinecap => {
                true
            }
            LonghandId::StrokeLinejoin => {
                true
            }
            LonghandId::StrokeMiterlimit => {
                false
            }
            LonghandId::StrokeOpacity => {
                false
            }
            LonghandId::StrokeDasharray => {
                false
            }
            LonghandId::StrokeDashoffset => {
                false
            }
            LonghandId::ClipRule => {
                true
            }
            LonghandId::MarkerStart => {
                true
            }
            LonghandId::MarkerMid => {
                true
            }
            LonghandId::MarkerEnd => {
                true
            }
            LonghandId::PaintOrder => {
                true
            }
            LonghandId::MozContextProperties => {
                false
            }
            LonghandId::DominantBaseline => {
                true
            }
            LonghandId::VectorEffect => {
                true
            }
            LonghandId::StopColor => {
                false
            }
            LonghandId::StopOpacity => {
                false
            }
            LonghandId::FloodColor => {
                false
            }
            LonghandId::FloodOpacity => {
                false
            }
            LonghandId::LightingColor => {
                false
            }
            LonghandId::MaskType => {
                true
            }
            LonghandId::ClipPath => {
                false
            }
            LonghandId::MaskMode => {
                true
            }
            LonghandId::MaskRepeat => {
                true
            }
            LonghandId::MaskPositionX => {
                false
            }
            LonghandId::MaskPositionY => {
                false
            }
            LonghandId::MaskClip => {
                true
            }
            LonghandId::MaskOrigin => {
                true
            }
            LonghandId::MaskSize => {
                false
            }
            LonghandId::MaskComposite => {
                true
            }
            LonghandId::MaskImage => {
                true
            }
            LonghandId::MozBoxAlign => {
                true
            }
            LonghandId::MozBoxDirection => {
                true
            }
            LonghandId::MozBoxFlex => {
                false
            }
            LonghandId::MozBoxOrient => {
                true
            }
            LonghandId::MozBoxPack => {
                true
            }
            LonghandId::MozStackSizing => {
                true
            }
            LonghandId::MozBoxOrdinalGroup => {
                true
            }
        }
    }

    /// Converts from a LonghandId to an adequate nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    pub fn to_nscsspropertyid(self) -> nsCSSPropertyID {
        match self {
            LonghandId::BackgroundColor => {
                
    nsCSSPropertyID::eCSSProperty_background_color
            }
            LonghandId::BackgroundImage => {
                
    nsCSSPropertyID::eCSSProperty_background_image
            }
            LonghandId::BackgroundPositionX => {
                
    nsCSSPropertyID::eCSSProperty_background_position_x
            }
            LonghandId::BackgroundPositionY => {
                
    nsCSSPropertyID::eCSSProperty_background_position_y
            }
            LonghandId::BackgroundRepeat => {
                
    nsCSSPropertyID::eCSSProperty_background_repeat
            }
            LonghandId::BackgroundAttachment => {
                
    nsCSSPropertyID::eCSSProperty_background_attachment
            }
            LonghandId::BackgroundClip => {
                
    nsCSSPropertyID::eCSSProperty_background_clip
            }
            LonghandId::BackgroundOrigin => {
                
    nsCSSPropertyID::eCSSProperty_background_origin
            }
            LonghandId::BackgroundSize => {
                
    nsCSSPropertyID::eCSSProperty_background_size
            }
            LonghandId::BackgroundBlendMode => {
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode
            }
            LonghandId::BorderTopColor => {
                
    nsCSSPropertyID::eCSSProperty_border_top_color
            }
            LonghandId::BorderTopStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_top_style
            }
            LonghandId::BorderTopWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_top_width
            }
            LonghandId::BorderLeftColor => {
                
    nsCSSPropertyID::eCSSProperty_border_left_color
            }
            LonghandId::BorderLeftStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_left_style
            }
            LonghandId::BorderLeftWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_left_width
            }
            LonghandId::BorderBottomColor => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color
            }
            LonghandId::BorderBottomStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style
            }
            LonghandId::BorderBottomWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width
            }
            LonghandId::BorderRightColor => {
                
    nsCSSPropertyID::eCSSProperty_border_right_color
            }
            LonghandId::BorderRightStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_right_style
            }
            LonghandId::BorderRightWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_right_width
            }
            LonghandId::BorderBlockStartColor => {
                
    nsCSSPropertyID::eCSSProperty_border_block_start_color
            }
            LonghandId::BorderBlockStartStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_block_start_style
            }
            LonghandId::BorderBlockStartWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_block_start_width
            }
            LonghandId::BorderBlockEndColor => {
                
    nsCSSPropertyID::eCSSProperty_border_block_end_color
            }
            LonghandId::BorderBlockEndStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_block_end_style
            }
            LonghandId::BorderBlockEndWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_block_end_width
            }
            LonghandId::BorderInlineStartColor => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_color
            }
            LonghandId::BorderInlineStartStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_style
            }
            LonghandId::BorderInlineStartWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_width
            }
            LonghandId::BorderInlineEndColor => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_color
            }
            LonghandId::BorderInlineEndStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_style
            }
            LonghandId::BorderInlineEndWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_width
            }
            LonghandId::BorderTopLeftRadius => {
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius
            }
            LonghandId::BorderTopRightRadius => {
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius
            }
            LonghandId::BorderBottomRightRadius => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius
            }
            LonghandId::BorderBottomLeftRadius => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius
            }
            LonghandId::MozBorderTopColors => {
                
    nsCSSPropertyID::eCSSProperty__moz_border_top_colors
            }
            LonghandId::MozBorderLeftColors => {
                
    nsCSSPropertyID::eCSSProperty__moz_border_left_colors
            }
            LonghandId::MozBorderBottomColors => {
                
    nsCSSPropertyID::eCSSProperty__moz_border_bottom_colors
            }
            LonghandId::MozBorderRightColors => {
                
    nsCSSPropertyID::eCSSProperty__moz_border_right_colors
            }
            LonghandId::BoxDecorationBreak => {
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break
            }
            LonghandId::MozFloatEdge => {
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge
            }
            LonghandId::BorderImageSource => {
                
    nsCSSPropertyID::eCSSProperty_border_image_source
            }
            LonghandId::BorderImageOutset => {
                
    nsCSSPropertyID::eCSSProperty_border_image_outset
            }
            LonghandId::BorderImageRepeat => {
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat
            }
            LonghandId::BorderImageWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_image_width
            }
            LonghandId::BorderImageSlice => {
                
    nsCSSPropertyID::eCSSProperty_border_image_slice
            }
            LonghandId::Display => {
                
    nsCSSPropertyID::eCSSProperty_display
            }
            LonghandId::MozTopLayer => {
                
    nsCSSPropertyID::eCSSProperty__moz_top_layer
            }
            LonghandId::Position => {
                
    nsCSSPropertyID::eCSSProperty_position
            }
            LonghandId::Float => {
                
    nsCSSPropertyID::eCSSProperty_float_
            }
            LonghandId::Clear => {
                
    nsCSSPropertyID::eCSSProperty_clear
            }
            LonghandId::VerticalAlign => {
                
    nsCSSPropertyID::eCSSProperty_vertical_align
            }
            LonghandId::OverflowClipBoxInline => {
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline
            }
            LonghandId::OverflowClipBoxBlock => {
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block
            }
            LonghandId::OverflowX => {
                
    nsCSSPropertyID::eCSSProperty_overflow_x
            }
            LonghandId::OverflowY => {
                
    nsCSSPropertyID::eCSSProperty_overflow_y
            }
            LonghandId::TransitionDuration => {
                
    nsCSSPropertyID::eCSSProperty_transition_duration
            }
            LonghandId::TransitionTimingFunction => {
                
    nsCSSPropertyID::eCSSProperty_transition_timing_function
            }
            LonghandId::TransitionProperty => {
                
    nsCSSPropertyID::eCSSProperty_transition_property
            }
            LonghandId::TransitionDelay => {
                
    nsCSSPropertyID::eCSSProperty_transition_delay
            }
            LonghandId::AnimationName => {
                
    nsCSSPropertyID::eCSSProperty_animation_name
            }
            LonghandId::AnimationDuration => {
                
    nsCSSPropertyID::eCSSProperty_animation_duration
            }
            LonghandId::AnimationTimingFunction => {
                
    nsCSSPropertyID::eCSSProperty_animation_timing_function
            }
            LonghandId::AnimationIterationCount => {
                
    nsCSSPropertyID::eCSSProperty_animation_iteration_count
            }
            LonghandId::AnimationDirection => {
                
    nsCSSPropertyID::eCSSProperty_animation_direction
            }
            LonghandId::AnimationPlayState => {
                
    nsCSSPropertyID::eCSSProperty_animation_play_state
            }
            LonghandId::AnimationFillMode => {
                
    nsCSSPropertyID::eCSSProperty_animation_fill_mode
            }
            LonghandId::AnimationDelay => {
                
    nsCSSPropertyID::eCSSProperty_animation_delay
            }
            LonghandId::ScrollSnapPointsX => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x
            }
            LonghandId::ScrollSnapPointsY => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y
            }
            LonghandId::ScrollSnapDestination => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination
            }
            LonghandId::ScrollSnapCoordinate => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate
            }
            LonghandId::Transform => {
                
    nsCSSPropertyID::eCSSProperty_transform
            }
            LonghandId::ScrollBehavior => {
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior
            }
            LonghandId::ScrollSnapTypeX => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x
            }
            LonghandId::ScrollSnapTypeY => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y
            }
            LonghandId::OverscrollBehaviorX => {
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x
            }
            LonghandId::OverscrollBehaviorY => {
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y
            }
            LonghandId::Isolation => {
                
    nsCSSPropertyID::eCSSProperty_isolation
            }
            LonghandId::PageBreakAfter => {
                
    nsCSSPropertyID::eCSSProperty_page_break_after
            }
            LonghandId::PageBreakBefore => {
                
    nsCSSPropertyID::eCSSProperty_page_break_before
            }
            LonghandId::PageBreakInside => {
                
    nsCSSPropertyID::eCSSProperty_page_break_inside
            }
            LonghandId::Resize => {
                
    nsCSSPropertyID::eCSSProperty_resize
            }
            LonghandId::Perspective => {
                
    nsCSSPropertyID::eCSSProperty_perspective
            }
            LonghandId::PerspectiveOrigin => {
                
    nsCSSPropertyID::eCSSProperty_perspective_origin
            }
            LonghandId::BackfaceVisibility => {
                
    nsCSSPropertyID::eCSSProperty_backface_visibility
            }
            LonghandId::TransformBox => {
                
    nsCSSPropertyID::eCSSProperty_transform_box
            }
            LonghandId::TransformStyle => {
                
    nsCSSPropertyID::eCSSProperty_transform_style
            }
            LonghandId::TransformOrigin => {
                
    nsCSSPropertyID::eCSSProperty_transform_origin
            }
            LonghandId::Contain => {
                
    nsCSSPropertyID::eCSSProperty_contain
            }
            LonghandId::MozAppearance => {
                
    nsCSSPropertyID::eCSSProperty__moz_appearance
            }
            LonghandId::MozBinding => {
                
    nsCSSPropertyID::eCSSProperty__moz_binding
            }
            LonghandId::MozOrient => {
                
    nsCSSPropertyID::eCSSProperty__moz_orient
            }
            LonghandId::WillChange => {
                
    nsCSSPropertyID::eCSSProperty_will_change
            }
            LonghandId::ShapeImageThreshold => {
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold
            }
            LonghandId::ShapeOutside => {
                
    nsCSSPropertyID::eCSSProperty_shape_outside
            }
            LonghandId::TouchAction => {
                
    nsCSSPropertyID::eCSSProperty_touch_action
            }
            LonghandId::Color => {
                
    nsCSSPropertyID::eCSSProperty_color
            }
            LonghandId::ColumnWidth => {
                
    nsCSSPropertyID::eCSSProperty_column_width
            }
            LonghandId::ColumnCount => {
                
    nsCSSPropertyID::eCSSProperty_column_count
            }
            LonghandId::ColumnGap => {
                
    nsCSSPropertyID::eCSSProperty_column_gap
            }
            LonghandId::ColumnFill => {
                
    nsCSSPropertyID::eCSSProperty_column_fill
            }
            LonghandId::ColumnRuleWidth => {
                
    nsCSSPropertyID::eCSSProperty_column_rule_width
            }
            LonghandId::ColumnRuleColor => {
                
    nsCSSPropertyID::eCSSProperty_column_rule_color
            }
            LonghandId::ColumnSpan => {
                
    nsCSSPropertyID::eCSSProperty_column_span
            }
            LonghandId::ColumnRuleStyle => {
                
    nsCSSPropertyID::eCSSProperty_column_rule_style
            }
            LonghandId::Content => {
                
    nsCSSPropertyID::eCSSProperty_content
            }
            LonghandId::CounterIncrement => {
                
    nsCSSPropertyID::eCSSProperty_counter_increment
            }
            LonghandId::CounterReset => {
                
    nsCSSPropertyID::eCSSProperty_counter_reset
            }
            LonghandId::Opacity => {
                
    nsCSSPropertyID::eCSSProperty_opacity
            }
            LonghandId::BoxShadow => {
                
    nsCSSPropertyID::eCSSProperty_box_shadow
            }
            LonghandId::Clip => {
                
    nsCSSPropertyID::eCSSProperty_clip
            }
            LonghandId::Filter => {
                
    nsCSSPropertyID::eCSSProperty_filter
            }
            LonghandId::MixBlendMode => {
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode
            }
            LonghandId::FontFamily => {
                
    nsCSSPropertyID::eCSSProperty_font_family
            }
            LonghandId::FontStyle => {
                
    nsCSSPropertyID::eCSSProperty_font_style
            }
            LonghandId::FontVariantCaps => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps
            }
            LonghandId::FontWeight => {
                
    nsCSSPropertyID::eCSSProperty_font_weight
            }
            LonghandId::FontSize => {
                
    nsCSSPropertyID::eCSSProperty_font_size
            }
            LonghandId::FontSizeAdjust => {
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust
            }
            LonghandId::FontSynthesis => {
                
    nsCSSPropertyID::eCSSProperty_font_synthesis
            }
            LonghandId::FontStretch => {
                
    nsCSSPropertyID::eCSSProperty_font_stretch
            }
            LonghandId::FontKerning => {
                
    nsCSSPropertyID::eCSSProperty_font_kerning
            }
            LonghandId::FontVariantAlternates => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates
            }
            LonghandId::FontVariantEastAsian => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian
            }
            LonghandId::FontVariantLigatures => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures
            }
            LonghandId::FontVariantNumeric => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric
            }
            LonghandId::FontVariantPosition => {
                
    nsCSSPropertyID::eCSSProperty_font_variant_position
            }
            LonghandId::FontFeatureSettings => {
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings
            }
            LonghandId::FontVariationSettings => {
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings
            }
            LonghandId::FontLanguageOverride => {
                
    nsCSSPropertyID::eCSSProperty_font_language_override
            }
            LonghandId::XLang => {
                
    nsCSSPropertyID::eCSSProperty__x_lang
            }
            LonghandId::MozScriptSizeMultiplier => {
                
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier
            }
            LonghandId::MozScriptLevel => {
                
    nsCSSPropertyID::eCSSProperty__moz_script_level
            }
            LonghandId::MozMathDisplay => {
                
    nsCSSPropertyID::eCSSProperty__moz_math_display
            }
            LonghandId::MozMathVariant => {
                
    nsCSSPropertyID::eCSSProperty__moz_math_variant
            }
            LonghandId::MozScriptMinSize => {
                
    nsCSSPropertyID::eCSSProperty__moz_script_min_size
            }
            LonghandId::XTextZoom => {
                
    nsCSSPropertyID::eCSSProperty__x_text_zoom
            }
            LonghandId::MozOsxFontSmoothing => {
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing
            }
            LonghandId::MozFontSmoothingBackgroundColor => {
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color
            }
            LonghandId::MozMinFontSizeRatio => {
                
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio
            }
            LonghandId::Visibility => {
                
    nsCSSPropertyID::eCSSProperty_visibility
            }
            LonghandId::WritingMode => {
                
    nsCSSPropertyID::eCSSProperty_writing_mode
            }
            LonghandId::Direction => {
                
    nsCSSPropertyID::eCSSProperty_direction
            }
            LonghandId::TextOrientation => {
                
    nsCSSPropertyID::eCSSProperty_text_orientation
            }
            LonghandId::ColorAdjust => {
                
    nsCSSPropertyID::eCSSProperty_color_adjust
            }
            LonghandId::ImageRendering => {
                
    nsCSSPropertyID::eCSSProperty_image_rendering
            }
            LonghandId::ImageOrientation => {
                
    nsCSSPropertyID::eCSSProperty_image_orientation
            }
            LonghandId::BorderCollapse => {
                
    nsCSSPropertyID::eCSSProperty_border_collapse
            }
            LonghandId::EmptyCells => {
                
    nsCSSPropertyID::eCSSProperty_empty_cells
            }
            LonghandId::CaptionSide => {
                
    nsCSSPropertyID::eCSSProperty_caption_side
            }
            LonghandId::BorderSpacing => {
                
    nsCSSPropertyID::eCSSProperty_border_spacing
            }
            LonghandId::LineHeight => {
                
    nsCSSPropertyID::eCSSProperty_line_height
            }
            LonghandId::TextTransform => {
                
    nsCSSPropertyID::eCSSProperty_text_transform
            }
            LonghandId::Hyphens => {
                
    nsCSSPropertyID::eCSSProperty_hyphens
            }
            LonghandId::MozTextSizeAdjust => {
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust
            }
            LonghandId::TextIndent => {
                
    nsCSSPropertyID::eCSSProperty_text_indent
            }
            LonghandId::OverflowWrap => {
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap
            }
            LonghandId::WordBreak => {
                
    nsCSSPropertyID::eCSSProperty_word_break
            }
            LonghandId::TextJustify => {
                
    nsCSSPropertyID::eCSSProperty_text_justify
            }
            LonghandId::TextAlignLast => {
                
    nsCSSPropertyID::eCSSProperty_text_align_last
            }
            LonghandId::TextAlign => {
                
    nsCSSPropertyID::eCSSProperty_text_align
            }
            LonghandId::LetterSpacing => {
                
    nsCSSPropertyID::eCSSProperty_letter_spacing
            }
            LonghandId::WordSpacing => {
                
    nsCSSPropertyID::eCSSProperty_word_spacing
            }
            LonghandId::WhiteSpace => {
                
    nsCSSPropertyID::eCSSProperty_white_space
            }
            LonghandId::TextShadow => {
                
    nsCSSPropertyID::eCSSProperty_text_shadow
            }
            LonghandId::TextEmphasisStyle => {
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style
            }
            LonghandId::TextEmphasisPosition => {
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position
            }
            LonghandId::TextEmphasisColor => {
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color
            }
            LonghandId::MozTabSize => {
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size
            }
            LonghandId::WebkitTextFillColor => {
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color
            }
            LonghandId::WebkitTextStrokeColor => {
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color
            }
            LonghandId::WebkitTextStrokeWidth => {
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width
            }
            LonghandId::RubyAlign => {
                
    nsCSSPropertyID::eCSSProperty_ruby_align
            }
            LonghandId::RubyPosition => {
                
    nsCSSPropertyID::eCSSProperty_ruby_position
            }
            LonghandId::TextCombineUpright => {
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright
            }
            LonghandId::TextRendering => {
                
    nsCSSPropertyID::eCSSProperty_text_rendering
            }
            LonghandId::MozControlCharacterVisibility => {
                
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility
            }
            LonghandId::ListStylePosition => {
                
    nsCSSPropertyID::eCSSProperty_list_style_position
            }
            LonghandId::ListStyleType => {
                
    nsCSSPropertyID::eCSSProperty_list_style_type
            }
            LonghandId::ListStyleImage => {
                
    nsCSSPropertyID::eCSSProperty_list_style_image
            }
            LonghandId::Quotes => {
                
    nsCSSPropertyID::eCSSProperty_quotes
            }
            LonghandId::MozImageRegion => {
                
    nsCSSPropertyID::eCSSProperty__moz_image_region
            }
            LonghandId::MarginTop => {
                
    nsCSSPropertyID::eCSSProperty_margin_top
            }
            LonghandId::MarginLeft => {
                
    nsCSSPropertyID::eCSSProperty_margin_left
            }
            LonghandId::MarginBottom => {
                
    nsCSSPropertyID::eCSSProperty_margin_bottom
            }
            LonghandId::MarginRight => {
                
    nsCSSPropertyID::eCSSProperty_margin_right
            }
            LonghandId::MarginBlockStart => {
                
    nsCSSPropertyID::eCSSProperty_margin_block_start
            }
            LonghandId::MarginBlockEnd => {
                
    nsCSSPropertyID::eCSSProperty_margin_block_end
            }
            LonghandId::MarginInlineStart => {
                
    nsCSSPropertyID::eCSSProperty_margin_inline_start
            }
            LonghandId::MarginInlineEnd => {
                
    nsCSSPropertyID::eCSSProperty_margin_inline_end
            }
            LonghandId::OutlineColor => {
                
    nsCSSPropertyID::eCSSProperty_outline_color
            }
            LonghandId::OutlineStyle => {
                
    nsCSSPropertyID::eCSSProperty_outline_style
            }
            LonghandId::OutlineWidth => {
                
    nsCSSPropertyID::eCSSProperty_outline_width
            }
            LonghandId::MozOutlineRadiusTopleft => {
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft
            }
            LonghandId::MozOutlineRadiusTopright => {
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright
            }
            LonghandId::MozOutlineRadiusBottomright => {
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright
            }
            LonghandId::MozOutlineRadiusBottomleft => {
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft
            }
            LonghandId::OutlineOffset => {
                
    nsCSSPropertyID::eCSSProperty_outline_offset
            }
            LonghandId::PaddingTop => {
                
    nsCSSPropertyID::eCSSProperty_padding_top
            }
            LonghandId::PaddingLeft => {
                
    nsCSSPropertyID::eCSSProperty_padding_left
            }
            LonghandId::PaddingBottom => {
                
    nsCSSPropertyID::eCSSProperty_padding_bottom
            }
            LonghandId::PaddingRight => {
                
    nsCSSPropertyID::eCSSProperty_padding_right
            }
            LonghandId::PaddingBlockStart => {
                
    nsCSSPropertyID::eCSSProperty_padding_block_start
            }
            LonghandId::PaddingBlockEnd => {
                
    nsCSSPropertyID::eCSSProperty_padding_block_end
            }
            LonghandId::PaddingInlineStart => {
                
    nsCSSPropertyID::eCSSProperty_padding_inline_start
            }
            LonghandId::PaddingInlineEnd => {
                
    nsCSSPropertyID::eCSSProperty_padding_inline_end
            }
            LonghandId::Cursor => {
                
    nsCSSPropertyID::eCSSProperty_cursor
            }
            LonghandId::PointerEvents => {
                
    nsCSSPropertyID::eCSSProperty_pointer_events
            }
            LonghandId::MozUserInput => {
                
    nsCSSPropertyID::eCSSProperty__moz_user_input
            }
            LonghandId::MozUserModify => {
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify
            }
            LonghandId::MozUserFocus => {
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus
            }
            LonghandId::CaretColor => {
                
    nsCSSPropertyID::eCSSProperty_caret_color
            }
            LonghandId::Top => {
                
    nsCSSPropertyID::eCSSProperty_top
            }
            LonghandId::Left => {
                
    nsCSSPropertyID::eCSSProperty_left
            }
            LonghandId::Bottom => {
                
    nsCSSPropertyID::eCSSProperty_bottom
            }
            LonghandId::Right => {
                
    nsCSSPropertyID::eCSSProperty_right
            }
            LonghandId::OffsetBlockStart => {
                
    nsCSSPropertyID::eCSSProperty_offset_block_start
            }
            LonghandId::OffsetBlockEnd => {
                
    nsCSSPropertyID::eCSSProperty_offset_block_end
            }
            LonghandId::OffsetInlineStart => {
                
    nsCSSPropertyID::eCSSProperty_offset_inline_start
            }
            LonghandId::OffsetInlineEnd => {
                
    nsCSSPropertyID::eCSSProperty_offset_inline_end
            }
            LonghandId::ZIndex => {
                
    nsCSSPropertyID::eCSSProperty_z_index
            }
            LonghandId::FlexDirection => {
                
    nsCSSPropertyID::eCSSProperty_flex_direction
            }
            LonghandId::FlexWrap => {
                
    nsCSSPropertyID::eCSSProperty_flex_wrap
            }
            LonghandId::JustifyContent => {
                
    nsCSSPropertyID::eCSSProperty_justify_content
            }
            LonghandId::AlignContent => {
                
    nsCSSPropertyID::eCSSProperty_align_content
            }
            LonghandId::AlignItems => {
                
    nsCSSPropertyID::eCSSProperty_align_items
            }
            LonghandId::JustifyItems => {
                
    nsCSSPropertyID::eCSSProperty_justify_items
            }
            LonghandId::FlexGrow => {
                
    nsCSSPropertyID::eCSSProperty_flex_grow
            }
            LonghandId::FlexShrink => {
                
    nsCSSPropertyID::eCSSProperty_flex_shrink
            }
            LonghandId::AlignSelf => {
                
    nsCSSPropertyID::eCSSProperty_align_self
            }
            LonghandId::JustifySelf => {
                
    nsCSSPropertyID::eCSSProperty_justify_self
            }
            LonghandId::Order => {
                
    nsCSSPropertyID::eCSSProperty_order
            }
            LonghandId::FlexBasis => {
                
    nsCSSPropertyID::eCSSProperty_flex_basis
            }
            LonghandId::Width => {
                
    nsCSSPropertyID::eCSSProperty_width
            }
            LonghandId::MinWidth => {
                
    nsCSSPropertyID::eCSSProperty_min_width
            }
            LonghandId::MaxWidth => {
                
    nsCSSPropertyID::eCSSProperty_max_width
            }
            LonghandId::Height => {
                
    nsCSSPropertyID::eCSSProperty_height
            }
            LonghandId::MinHeight => {
                
    nsCSSPropertyID::eCSSProperty_min_height
            }
            LonghandId::MaxHeight => {
                
    nsCSSPropertyID::eCSSProperty_max_height
            }
            LonghandId::BlockSize => {
                
    nsCSSPropertyID::eCSSProperty_block_size
            }
            LonghandId::MinBlockSize => {
                
    nsCSSPropertyID::eCSSProperty_min_block_size
            }
            LonghandId::MaxBlockSize => {
                
    nsCSSPropertyID::eCSSProperty_max_block_size
            }
            LonghandId::InlineSize => {
                
    nsCSSPropertyID::eCSSProperty_inline_size
            }
            LonghandId::MinInlineSize => {
                
    nsCSSPropertyID::eCSSProperty_min_inline_size
            }
            LonghandId::MaxInlineSize => {
                
    nsCSSPropertyID::eCSSProperty_max_inline_size
            }
            LonghandId::BoxSizing => {
                
    nsCSSPropertyID::eCSSProperty_box_sizing
            }
            LonghandId::ObjectFit => {
                
    nsCSSPropertyID::eCSSProperty_object_fit
            }
            LonghandId::ObjectPosition => {
                
    nsCSSPropertyID::eCSSProperty_object_position
            }
            LonghandId::GridRowGap => {
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap
            }
            LonghandId::GridRowStart => {
                
    nsCSSPropertyID::eCSSProperty_grid_row_start
            }
            LonghandId::GridRowEnd => {
                
    nsCSSPropertyID::eCSSProperty_grid_row_end
            }
            LonghandId::GridAutoRows => {
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows
            }
            LonghandId::GridTemplateRows => {
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows
            }
            LonghandId::GridColumnGap => {
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap
            }
            LonghandId::GridColumnStart => {
                
    nsCSSPropertyID::eCSSProperty_grid_column_start
            }
            LonghandId::GridColumnEnd => {
                
    nsCSSPropertyID::eCSSProperty_grid_column_end
            }
            LonghandId::GridAutoColumns => {
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns
            }
            LonghandId::GridTemplateColumns => {
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns
            }
            LonghandId::GridAutoFlow => {
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow
            }
            LonghandId::GridTemplateAreas => {
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas
            }
            LonghandId::TableLayout => {
                
    nsCSSPropertyID::eCSSProperty_table_layout
            }
            LonghandId::XSpan => {
                
    nsCSSPropertyID::eCSSProperty__x_span
            }
            LonghandId::TextOverflow => {
                
    nsCSSPropertyID::eCSSProperty_text_overflow
            }
            LonghandId::UnicodeBidi => {
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi
            }
            LonghandId::TextDecorationLine => {
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line
            }
            LonghandId::TextDecorationStyle => {
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style
            }
            LonghandId::TextDecorationColor => {
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color
            }
            LonghandId::InitialLetter => {
                
    nsCSSPropertyID::eCSSProperty_initial_letter
            }
            LonghandId::ImeMode => {
                
    nsCSSPropertyID::eCSSProperty_ime_mode
            }
            LonghandId::MozUserSelect => {
                
    nsCSSPropertyID::eCSSProperty__moz_user_select
            }
            LonghandId::MozWindowDragging => {
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging
            }
            LonghandId::MozWindowShadow => {
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow
            }
            LonghandId::MozWindowOpacity => {
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity
            }
            LonghandId::MozWindowTransform => {
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform
            }
            LonghandId::MozWindowTransformOrigin => {
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin
            }
            LonghandId::MozForceBrokenImageIcon => {
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon
            }
            LonghandId::TextAnchor => {
                
    nsCSSPropertyID::eCSSProperty_text_anchor
            }
            LonghandId::ColorInterpolation => {
                
    nsCSSPropertyID::eCSSProperty_color_interpolation
            }
            LonghandId::ColorInterpolationFilters => {
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters
            }
            LonghandId::Fill => {
                
    nsCSSPropertyID::eCSSProperty_fill
            }
            LonghandId::FillOpacity => {
                
    nsCSSPropertyID::eCSSProperty_fill_opacity
            }
            LonghandId::FillRule => {
                
    nsCSSPropertyID::eCSSProperty_fill_rule
            }
            LonghandId::ShapeRendering => {
                
    nsCSSPropertyID::eCSSProperty_shape_rendering
            }
            LonghandId::Stroke => {
                
    nsCSSPropertyID::eCSSProperty_stroke
            }
            LonghandId::StrokeWidth => {
                
    nsCSSPropertyID::eCSSProperty_stroke_width
            }
            LonghandId::StrokeLinecap => {
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap
            }
            LonghandId::StrokeLinejoin => {
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin
            }
            LonghandId::StrokeMiterlimit => {
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit
            }
            LonghandId::StrokeOpacity => {
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity
            }
            LonghandId::StrokeDasharray => {
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray
            }
            LonghandId::StrokeDashoffset => {
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset
            }
            LonghandId::ClipRule => {
                
    nsCSSPropertyID::eCSSProperty_clip_rule
            }
            LonghandId::MarkerStart => {
                
    nsCSSPropertyID::eCSSProperty_marker_start
            }
            LonghandId::MarkerMid => {
                
    nsCSSPropertyID::eCSSProperty_marker_mid
            }
            LonghandId::MarkerEnd => {
                
    nsCSSPropertyID::eCSSProperty_marker_end
            }
            LonghandId::PaintOrder => {
                
    nsCSSPropertyID::eCSSProperty_paint_order
            }
            LonghandId::MozContextProperties => {
                
    nsCSSPropertyID::eCSSProperty__moz_context_properties
            }
            LonghandId::DominantBaseline => {
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline
            }
            LonghandId::VectorEffect => {
                
    nsCSSPropertyID::eCSSProperty_vector_effect
            }
            LonghandId::StopColor => {
                
    nsCSSPropertyID::eCSSProperty_stop_color
            }
            LonghandId::StopOpacity => {
                
    nsCSSPropertyID::eCSSProperty_stop_opacity
            }
            LonghandId::FloodColor => {
                
    nsCSSPropertyID::eCSSProperty_flood_color
            }
            LonghandId::FloodOpacity => {
                
    nsCSSPropertyID::eCSSProperty_flood_opacity
            }
            LonghandId::LightingColor => {
                
    nsCSSPropertyID::eCSSProperty_lighting_color
            }
            LonghandId::MaskType => {
                
    nsCSSPropertyID::eCSSProperty_mask_type
            }
            LonghandId::ClipPath => {
                
    nsCSSPropertyID::eCSSProperty_clip_path
            }
            LonghandId::MaskMode => {
                
    nsCSSPropertyID::eCSSProperty_mask_mode
            }
            LonghandId::MaskRepeat => {
                
    nsCSSPropertyID::eCSSProperty_mask_repeat
            }
            LonghandId::MaskPositionX => {
                
    nsCSSPropertyID::eCSSProperty_mask_position_x
            }
            LonghandId::MaskPositionY => {
                
    nsCSSPropertyID::eCSSProperty_mask_position_y
            }
            LonghandId::MaskClip => {
                
    nsCSSPropertyID::eCSSProperty_mask_clip
            }
            LonghandId::MaskOrigin => {
                
    nsCSSPropertyID::eCSSProperty_mask_origin
            }
            LonghandId::MaskSize => {
                
    nsCSSPropertyID::eCSSProperty_mask_size
            }
            LonghandId::MaskComposite => {
                
    nsCSSPropertyID::eCSSProperty_mask_composite
            }
            LonghandId::MaskImage => {
                
    nsCSSPropertyID::eCSSProperty_mask_image
            }
            LonghandId::MozBoxAlign => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_align
            }
            LonghandId::MozBoxDirection => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction
            }
            LonghandId::MozBoxFlex => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex
            }
            LonghandId::MozBoxOrient => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient
            }
            LonghandId::MozBoxPack => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack
            }
            LonghandId::MozStackSizing => {
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing
            }
            LonghandId::MozBoxOrdinalGroup => {
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group
            }
        }
    }

    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    /// Returns a longhand id from Gecko's nsCSSPropertyID.
    pub fn from_nscsspropertyid(id: nsCSSPropertyID) -> Result<Self, ()> {
        match PropertyId::from_nscsspropertyid(id) {
            Ok(PropertyId::Longhand(id)) |
            Ok(PropertyId::LonghandAlias(id, _)) => Ok(id),
            _ => Err(()),
        }
    }

    /// If this is a logical property, return the corresponding physical one in the given writing mode.
    /// Otherwise, return unchanged.
    pub fn to_physical(&self, wm: WritingMode) -> Self {
        match *self {
                    LonghandId::BorderBlockStartColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderBlockStartStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderBlockStartWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderBlockEndColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderBlockEndStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderBlockEndWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderInlineStartWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndColor => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopColor
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftColor
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomColor
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightColor
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndStyle => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopStyle
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftStyle
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomStyle
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightStyle
                            
                }
        }

                    }
                    LonghandId::BorderInlineEndWidth => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::BorderTopWidth
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::BorderLeftWidth
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::BorderBottomWidth
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::BorderRightWidth
                            
                }
        }

                    }
                    LonghandId::MarginBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::MarginInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::MarginTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::MarginLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::MarginBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::MarginRight
                            
                }
        }

                    }
                    LonghandId::PaddingBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::PaddingInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::PaddingTop
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::PaddingLeft
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::PaddingBottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::PaddingRight
                            
                }
        }

                    }
                    LonghandId::OffsetBlockStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetBlockEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetInlineStart => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::OffsetInlineEnd => {
                        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                                LonghandId::Top
                            
                }
                PhysicalSide::Left => {
                    
                                LonghandId::Left
                            
                }
                PhysicalSide::Bottom => {
                    
                                LonghandId::Bottom
                            
                }
                PhysicalSide::Right => {
                    
                                LonghandId::Right
                            
                }
        }

                    }
                    LonghandId::BlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::Width
                            
        } else {
            
                                LonghandId::Height
                            
        }

                    }
                    LonghandId::MinBlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MinWidth
                            
        } else {
            
                                LonghandId::MinHeight
                            
        }

                    }
                    LonghandId::MaxBlockSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MaxWidth
                            
        } else {
            
                                LonghandId::MaxHeight
                            
        }

                    }
                    LonghandId::InlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::Height
                            
        } else {
            
                                LonghandId::Width
                            
        }

                    }
                    LonghandId::MinInlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MinHeight
                            
        } else {
            
                                LonghandId::MinWidth
                            
        }

                    }
                    LonghandId::MaxInlineSize => {
                        
    
        
        if wm.is_vertical() {
            
                                LonghandId::MaxHeight
                            
        } else {
            
                                LonghandId::MaxWidth
                            
        }

                    }
            _ => *self
        }
    }

    /// Returns PropertyFlags for given longhand property.
    pub fn flags(&self) -> PropertyFlags {
        match *self {
                LonghandId::BackgroundColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundImage =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundPositionX =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundPositionY =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundRepeat =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundAttachment =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundClip =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundOrigin =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundSize =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BackgroundBlendMode =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderLeftWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderRightWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockStartWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBlockEndWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineStartWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderInlineEndWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopLeftRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderTopRightRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomRightRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderBottomLeftRadius =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MozBorderTopColors =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MozBorderLeftColors =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MozBorderBottomColors =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MozBorderRightColors =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BoxDecorationBreak =>
                    PropertyFlags::empty(),
                LonghandId::MozFloatEdge =>
                    PropertyFlags::empty(),
                LonghandId::BorderImageSource =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageOutset =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageRepeat =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::BorderImageSlice =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::Display =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::MozTopLayer =>
                    PropertyFlags::empty(),
                LonghandId::Position =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::ABSPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::Float =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::Clear =>
                    PropertyFlags::empty(),
                LonghandId::VerticalAlign =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::OverflowClipBoxInline =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::OverflowClipBoxBlock =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::OverflowX =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::OverflowY =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TransitionDuration =>
                    PropertyFlags::empty(),
                LonghandId::TransitionTimingFunction =>
                    PropertyFlags::empty(),
                LonghandId::TransitionProperty =>
                    PropertyFlags::empty(),
                LonghandId::TransitionDelay =>
                    PropertyFlags::empty(),
                LonghandId::AnimationName =>
                    PropertyFlags::empty(),
                LonghandId::AnimationDuration =>
                    PropertyFlags::empty(),
                LonghandId::AnimationTimingFunction =>
                    PropertyFlags::empty(),
                LonghandId::AnimationIterationCount =>
                    PropertyFlags::empty(),
                LonghandId::AnimationDirection =>
                    PropertyFlags::empty(),
                LonghandId::AnimationPlayState =>
                    PropertyFlags::empty(),
                LonghandId::AnimationFillMode =>
                    PropertyFlags::empty(),
                LonghandId::AnimationDelay =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapPointsX =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapPointsY =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapDestination =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapCoordinate =>
                    PropertyFlags::empty(),
                LonghandId::Transform =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::ScrollBehavior =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapTypeX =>
                    PropertyFlags::empty(),
                LonghandId::ScrollSnapTypeY =>
                    PropertyFlags::empty(),
                LonghandId::OverscrollBehaviorX =>
                    PropertyFlags::empty(),
                LonghandId::OverscrollBehaviorY =>
                    PropertyFlags::empty(),
                LonghandId::Isolation =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::PageBreakAfter =>
                    PropertyFlags::empty(),
                LonghandId::PageBreakBefore =>
                    PropertyFlags::empty(),
                LonghandId::PageBreakInside =>
                    PropertyFlags::empty(),
                LonghandId::Resize =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Perspective =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::PerspectiveOrigin =>
                    PropertyFlags::empty(),
                LonghandId::BackfaceVisibility =>
                    PropertyFlags::empty(),
                LonghandId::TransformBox =>
                    PropertyFlags::empty(),
                LonghandId::TransformStyle =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::TransformOrigin =>
                    PropertyFlags::empty(),
                LonghandId::Contain =>
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::MozAppearance =>
                    PropertyFlags::empty(),
                LonghandId::MozBinding =>
                    PropertyFlags::empty(),
                LonghandId::MozOrient =>
                    PropertyFlags::empty(),
                LonghandId::WillChange =>
                    PropertyFlags::empty(),
                LonghandId::ShapeImageThreshold =>
                    PropertyFlags::empty(),
                LonghandId::ShapeOutside =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::TouchAction =>
                    PropertyFlags::empty(),
                LonghandId::Color =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::ColumnWidth =>
                    PropertyFlags::empty(),
                LonghandId::ColumnCount =>
                    PropertyFlags::empty(),
                LonghandId::ColumnGap =>
                    PropertyFlags::empty(),
                LonghandId::ColumnFill =>
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleWidth =>
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleColor =>
                    PropertyFlags::empty(),
                LonghandId::ColumnSpan =>
                    PropertyFlags::empty(),
                LonghandId::ColumnRuleStyle =>
                    PropertyFlags::empty(),
                LonghandId::Content =>
                    PropertyFlags::empty(),
                LonghandId::CounterIncrement =>
                    PropertyFlags::empty(),
                LonghandId::CounterReset =>
                    PropertyFlags::empty(),
                LonghandId::Opacity =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::BoxShadow =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::Clip =>
                    PropertyFlags::empty(),
                LonghandId::Filter =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                        PropertyFlags::FIXPOS_CB |
                    PropertyFlags::empty(),
                LonghandId::MixBlendMode =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::FontFamily =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantCaps =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontWeight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSize =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSizeAdjust =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontSynthesis =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontStretch =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontKerning =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantAlternates =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantEastAsian =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantLigatures =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantNumeric =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariantPosition =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontFeatureSettings =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontVariationSettings =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::FontLanguageOverride =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::XLang =>
                    PropertyFlags::empty(),
                LonghandId::MozScriptSizeMultiplier =>
                    PropertyFlags::empty(),
                LonghandId::MozScriptLevel =>
                    PropertyFlags::empty(),
                LonghandId::MozMathDisplay =>
                    PropertyFlags::empty(),
                LonghandId::MozMathVariant =>
                    PropertyFlags::empty(),
                LonghandId::MozScriptMinSize =>
                    PropertyFlags::empty(),
                LonghandId::XTextZoom =>
                    PropertyFlags::empty(),
                LonghandId::MozOsxFontSmoothing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::MozFontSmoothingBackgroundColor =>
                    PropertyFlags::empty(),
                LonghandId::MozMinFontSizeRatio =>
                    PropertyFlags::empty(),
                LonghandId::Visibility =>
                    PropertyFlags::empty(),
                LonghandId::WritingMode =>
                    PropertyFlags::empty(),
                LonghandId::Direction =>
                    PropertyFlags::empty(),
                LonghandId::TextOrientation =>
                    PropertyFlags::empty(),
                LonghandId::ColorAdjust =>
                    PropertyFlags::empty(),
                LonghandId::ImageRendering =>
                    PropertyFlags::empty(),
                LonghandId::ImageOrientation =>
                    PropertyFlags::empty(),
                LonghandId::BorderCollapse =>
                    PropertyFlags::empty(),
                LonghandId::EmptyCells =>
                    PropertyFlags::empty(),
                LonghandId::CaptionSide =>
                    PropertyFlags::empty(),
                LonghandId::BorderSpacing =>
                    PropertyFlags::empty(),
                LonghandId::LineHeight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextTransform =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Hyphens =>
                    PropertyFlags::empty(),
                LonghandId::MozTextSizeAdjust =>
                    PropertyFlags::empty(),
                LonghandId::TextIndent =>
                    PropertyFlags::empty(),
                LonghandId::OverflowWrap =>
                    PropertyFlags::empty(),
                LonghandId::WordBreak =>
                    PropertyFlags::empty(),
                LonghandId::TextJustify =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextAlignLast =>
                    PropertyFlags::empty(),
                LonghandId::TextAlign =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::LetterSpacing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WordSpacing =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WhiteSpace =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextShadow =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisStyle =>
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisPosition =>
                    PropertyFlags::empty(),
                LonghandId::TextEmphasisColor =>
                    PropertyFlags::empty(),
                LonghandId::MozTabSize =>
                    PropertyFlags::empty(),
                LonghandId::WebkitTextFillColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WebkitTextStrokeColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::WebkitTextStrokeWidth =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::RubyAlign =>
                    PropertyFlags::empty(),
                LonghandId::RubyPosition =>
                    PropertyFlags::empty(),
                LonghandId::TextCombineUpright =>
                    PropertyFlags::empty(),
                LonghandId::TextRendering =>
                    PropertyFlags::empty(),
                LonghandId::MozControlCharacterVisibility =>
                    PropertyFlags::empty(),
                LonghandId::ListStylePosition =>
                    PropertyFlags::empty(),
                LonghandId::ListStyleType =>
                    PropertyFlags::empty(),
                LonghandId::ListStyleImage =>
                    PropertyFlags::empty(),
                LonghandId::Quotes =>
                    PropertyFlags::empty(),
                LonghandId::MozImageRegion =>
                    PropertyFlags::empty(),
                LonghandId::MarginTop =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginLeft =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginBottom =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginRight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginBlockStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginBlockEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginInlineStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::MarginInlineEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::OutlineColor =>
                    PropertyFlags::empty(),
                LonghandId::OutlineStyle =>
                    PropertyFlags::empty(),
                LonghandId::OutlineWidth =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusTopleft =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusTopright =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusBottomright =>
                    PropertyFlags::empty(),
                LonghandId::MozOutlineRadiusBottomleft =>
                    PropertyFlags::empty(),
                LonghandId::OutlineOffset =>
                    PropertyFlags::empty(),
                LonghandId::PaddingTop =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingLeft =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingBottom =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingRight =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingBlockStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingBlockEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingInlineStart =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::PaddingInlineEnd =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::Cursor =>
                    PropertyFlags::empty(),
                LonghandId::PointerEvents =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::MozUserInput =>
                    PropertyFlags::empty(),
                LonghandId::MozUserModify =>
                    PropertyFlags::empty(),
                LonghandId::MozUserFocus =>
                    PropertyFlags::empty(),
                LonghandId::CaretColor =>
                    PropertyFlags::empty(),
                LonghandId::Top =>
                    PropertyFlags::empty(),
                LonghandId::Left =>
                    PropertyFlags::empty(),
                LonghandId::Bottom =>
                    PropertyFlags::empty(),
                LonghandId::Right =>
                    PropertyFlags::empty(),
                LonghandId::OffsetBlockStart =>
                    PropertyFlags::empty(),
                LonghandId::OffsetBlockEnd =>
                    PropertyFlags::empty(),
                LonghandId::OffsetInlineStart =>
                    PropertyFlags::empty(),
                LonghandId::OffsetInlineEnd =>
                    PropertyFlags::empty(),
                LonghandId::ZIndex =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::FlexDirection =>
                    PropertyFlags::empty(),
                LonghandId::FlexWrap =>
                    PropertyFlags::empty(),
                LonghandId::JustifyContent =>
                    PropertyFlags::empty(),
                LonghandId::AlignContent =>
                    PropertyFlags::empty(),
                LonghandId::AlignItems =>
                    PropertyFlags::empty(),
                LonghandId::JustifyItems =>
                    PropertyFlags::empty(),
                LonghandId::FlexGrow =>
                    PropertyFlags::empty(),
                LonghandId::FlexShrink =>
                    PropertyFlags::empty(),
                LonghandId::AlignSelf =>
                    PropertyFlags::empty(),
                LonghandId::JustifySelf =>
                    PropertyFlags::empty(),
                LonghandId::Order =>
                    PropertyFlags::empty(),
                LonghandId::FlexBasis =>
                    PropertyFlags::empty(),
                LonghandId::Width =>
                    PropertyFlags::empty(),
                LonghandId::MinWidth =>
                    PropertyFlags::empty(),
                LonghandId::MaxWidth =>
                    PropertyFlags::empty(),
                LonghandId::Height =>
                    PropertyFlags::empty(),
                LonghandId::MinHeight =>
                    PropertyFlags::empty(),
                LonghandId::MaxHeight =>
                    PropertyFlags::empty(),
                LonghandId::BlockSize =>
                    PropertyFlags::empty(),
                LonghandId::MinBlockSize =>
                    PropertyFlags::empty(),
                LonghandId::MaxBlockSize =>
                    PropertyFlags::empty(),
                LonghandId::InlineSize =>
                    PropertyFlags::empty(),
                LonghandId::MinInlineSize =>
                    PropertyFlags::empty(),
                LonghandId::MaxInlineSize =>
                    PropertyFlags::empty(),
                LonghandId::BoxSizing =>
                    PropertyFlags::empty(),
                LonghandId::ObjectFit =>
                    PropertyFlags::empty(),
                LonghandId::ObjectPosition =>
                    PropertyFlags::empty(),
                LonghandId::GridRowGap =>
                    PropertyFlags::empty(),
                LonghandId::GridRowStart =>
                    PropertyFlags::empty(),
                LonghandId::GridRowEnd =>
                    PropertyFlags::empty(),
                LonghandId::GridAutoRows =>
                    PropertyFlags::empty(),
                LonghandId::GridTemplateRows =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnGap =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnStart =>
                    PropertyFlags::empty(),
                LonghandId::GridColumnEnd =>
                    PropertyFlags::empty(),
                LonghandId::GridAutoColumns =>
                    PropertyFlags::empty(),
                LonghandId::GridTemplateColumns =>
                    PropertyFlags::empty(),
                LonghandId::GridAutoFlow =>
                    PropertyFlags::empty(),
                LonghandId::GridTemplateAreas =>
                    PropertyFlags::empty(),
                LonghandId::TableLayout =>
                    PropertyFlags::empty(),
                LonghandId::XSpan =>
                    PropertyFlags::empty(),
                LonghandId::TextOverflow =>
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::UnicodeBidi =>
                    PropertyFlags::empty(),
                LonghandId::TextDecorationLine =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextDecorationStyle =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::TextDecorationColor =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                        PropertyFlags::APPLIES_TO_FIRST_LINE |
                        PropertyFlags::APPLIES_TO_PLACEHOLDER |
                    PropertyFlags::empty(),
                LonghandId::InitialLetter =>
                        PropertyFlags::APPLIES_TO_FIRST_LETTER |
                    PropertyFlags::empty(),
                LonghandId::ImeMode =>
                    PropertyFlags::empty(),
                LonghandId::MozUserSelect =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowDragging =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowShadow =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowOpacity =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowTransform =>
                    PropertyFlags::empty(),
                LonghandId::MozWindowTransformOrigin =>
                    PropertyFlags::empty(),
                LonghandId::MozForceBrokenImageIcon =>
                    PropertyFlags::empty(),
                LonghandId::TextAnchor =>
                    PropertyFlags::empty(),
                LonghandId::ColorInterpolation =>
                    PropertyFlags::empty(),
                LonghandId::ColorInterpolationFilters =>
                    PropertyFlags::empty(),
                LonghandId::Fill =>
                    PropertyFlags::empty(),
                LonghandId::FillOpacity =>
                    PropertyFlags::empty(),
                LonghandId::FillRule =>
                    PropertyFlags::empty(),
                LonghandId::ShapeRendering =>
                    PropertyFlags::empty(),
                LonghandId::Stroke =>
                    PropertyFlags::empty(),
                LonghandId::StrokeWidth =>
                    PropertyFlags::empty(),
                LonghandId::StrokeLinecap =>
                    PropertyFlags::empty(),
                LonghandId::StrokeLinejoin =>
                    PropertyFlags::empty(),
                LonghandId::StrokeMiterlimit =>
                    PropertyFlags::empty(),
                LonghandId::StrokeOpacity =>
                    PropertyFlags::empty(),
                LonghandId::StrokeDasharray =>
                    PropertyFlags::empty(),
                LonghandId::StrokeDashoffset =>
                    PropertyFlags::empty(),
                LonghandId::ClipRule =>
                    PropertyFlags::empty(),
                LonghandId::MarkerStart =>
                    PropertyFlags::empty(),
                LonghandId::MarkerMid =>
                    PropertyFlags::empty(),
                LonghandId::MarkerEnd =>
                    PropertyFlags::empty(),
                LonghandId::PaintOrder =>
                    PropertyFlags::empty(),
                LonghandId::MozContextProperties =>
                    PropertyFlags::empty(),
                LonghandId::DominantBaseline =>
                    PropertyFlags::empty(),
                LonghandId::VectorEffect =>
                    PropertyFlags::empty(),
                LonghandId::StopColor =>
                    PropertyFlags::empty(),
                LonghandId::StopOpacity =>
                    PropertyFlags::empty(),
                LonghandId::FloodColor =>
                    PropertyFlags::empty(),
                LonghandId::FloodOpacity =>
                    PropertyFlags::empty(),
                LonghandId::LightingColor =>
                    PropertyFlags::empty(),
                LonghandId::MaskType =>
                    PropertyFlags::empty(),
                LonghandId::ClipPath =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::MaskMode =>
                    PropertyFlags::empty(),
                LonghandId::MaskRepeat =>
                    PropertyFlags::empty(),
                LonghandId::MaskPositionX =>
                    PropertyFlags::empty(),
                LonghandId::MaskPositionY =>
                    PropertyFlags::empty(),
                LonghandId::MaskClip =>
                    PropertyFlags::empty(),
                LonghandId::MaskOrigin =>
                    PropertyFlags::empty(),
                LonghandId::MaskSize =>
                    PropertyFlags::empty(),
                LonghandId::MaskComposite =>
                    PropertyFlags::empty(),
                LonghandId::MaskImage =>
                        PropertyFlags::CREATES_STACKING_CONTEXT |
                    PropertyFlags::empty(),
                LonghandId::MozBoxAlign =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxDirection =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxFlex =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxOrient =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxPack =>
                    PropertyFlags::empty(),
                LonghandId::MozStackSizing =>
                    PropertyFlags::empty(),
                LonghandId::MozBoxOrdinalGroup =>
                    PropertyFlags::empty(),
        }
    }

    /// Only a few properties are allowed to depend on the visited state of
    /// links. When cascading visited styles, we can save time by only
    /// processing these properties.
    fn is_visited_dependent(&self) -> bool {
        matches!(*self,
            LonghandId::ColumnRuleColor |
            LonghandId::TextEmphasisColor |
            LonghandId::WebkitTextFillColor |
            LonghandId::WebkitTextStrokeColor |
            LonghandId::TextDecorationColor |
            LonghandId::Fill |
            LonghandId::Stroke |
            LonghandId::CaretColor |
            LonghandId::Color |
            LonghandId::BackgroundColor |
            LonghandId::BorderTopColor |
            LonghandId::BorderRightColor |
            LonghandId::BorderBottomColor |
            LonghandId::BorderLeftColor |
            LonghandId::OutlineColor
        )
    }

    /// Returns true if the property is one that is ignored when document
    /// colors are disabled.
    fn is_ignored_when_document_colors_disabled(
        &self,
        cascade_level: CascadeLevel,
        pseudo: Option<&PseudoElement>,
    ) -> bool {
        let is_ua_or_user_rule = matches!(
            cascade_level,
            CascadeLevel::UANormal |
            CascadeLevel::UserNormal |
            CascadeLevel::UserImportant |
            CascadeLevel::UAImportant
        );

        if is_ua_or_user_rule {
            return false;
        }

        let is_style_attribute = matches!(
            cascade_level,
            CascadeLevel::StyleAttributeNormal |
            CascadeLevel::StyleAttributeImportant
        );
        // Don't override colors on pseudo-element's style attributes. The
        // background-color on ::-moz-color-swatch is an example. Those are set
        // as an author style (via the style attribute), but it's pretty
        // important for it to show up for obvious reasons :)
        if pseudo.is_some() && is_style_attribute {
            return false;
        }

        matches!(*self,
            LonghandId::BackgroundColor | LonghandId::BackgroundImage | LonghandId::BorderTopColor | LonghandId::BorderLeftColor | LonghandId::BorderBottomColor | LonghandId::BorderRightColor | LonghandId::BorderBlockStartColor | LonghandId::BorderBlockEndColor | LonghandId::BorderInlineStartColor | LonghandId::BorderInlineEndColor | LonghandId::MozBorderTopColors | LonghandId::MozBorderLeftColors | LonghandId::MozBorderBottomColors | LonghandId::MozBorderRightColors | LonghandId::Color | LonghandId::ColumnRuleColor | LonghandId::BoxShadow | LonghandId::TextShadow | LonghandId::TextEmphasisColor | LonghandId::WebkitTextFillColor | LonghandId::WebkitTextStrokeColor | LonghandId::OutlineColor | LonghandId::CaretColor | LonghandId::TextDecorationColor
        )
    }

    /// The computed value of some properties depends on the (sometimes
    /// computed) value of *other* properties.
    ///
    /// So we classify properties into "early" and "other", such that the only
    /// dependencies can be from "other" to "early".
    ///
    /// Unfortunately, it’s not easy to check that this classification is
    /// correct.
    fn is_early_property(&self) -> bool {
        matches!(*self,

            // Needed to properly compute the writing mode, to resolve logical
            // properties, and similar stuff. In this block instead of along
            // `WritingMode` and `Direction` just for convenience, since it's
            // Gecko-only (for now at least).
            //
            // see WritingMode::new.
            LonghandId::TextOrientation |

            // Needed to properly compute the zoomed font-size.
            //
            // FIXME(emilio): This could probably just be a cascade flag like
            // IN_SVG_SUBTREE or such, and we could nuke this property.
            LonghandId::XTextZoom |

            // Needed to do font-size computation in a language-dependent way.
            LonghandId::XLang |
            // Needed for ruby to respect language-dependent min-font-size
            // preferences properly, see bug 1165538.
            LonghandId::MozMinFontSizeRatio |

            // Needed to do font-size for MathML. :(
            LonghandId::MozScriptLevel |

            // Needed to compute font-relative lengths correctly.
            LonghandId::FontSize |
            LonghandId::FontFamily |

            // Needed to resolve currentcolor at computed value time properly.
            //
            // FIXME(emilio): All the properties should be moved to currentcolor
            // as a computed-value (and thus resolving it at used-value time).
            //
            // This would allow this property to go away from this list.
            LonghandId::Color |

            // FIXME(emilio): There's no reason for this afaict, nuke it.
            LonghandId::TextDecorationLine |

            // Needed to properly compute the writing mode, to resolve logical
            // properties, and similar stuff.
            LonghandId::WritingMode |
            LonghandId::Direction
        )
    }

    /// Whether computed values of this property lossily convert any complex
    /// colors into RGBA colors.
    ///
    /// In Gecko, there are some properties still that compute currentcolor
    /// down to an RGBA color at computed value time, instead of as
    /// `StyleComplexColor`s. For these properties, we must return `false`,
    /// so that we correctly avoid caching style data in the rule tree.
    pub fn stores_complex_colors_lossily(&self) -> bool {
        matches!(*self,
            LonghandId::MozFontSmoothingBackgroundColor |
            LonghandId::StopColor |
            LonghandId::FloodColor |
            LonghandId::LightingColor |
            LonghandId::BackgroundImage |
            LonghandId::BorderImageSource |
            LonghandId::BoxShadow |
            LonghandId::MaskImage |
            LonghandId::MozBorderBottomColors |
            LonghandId::MozBorderLeftColors |
            LonghandId::MozBorderRightColors |
            LonghandId::MozBorderTopColors |
            LonghandId::TextShadow
        )
    }
}

/// An identifier for a given shorthand property.
#[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, PartialEq, ToCss)]
pub enum ShorthandId {
        /// background
        Background,
        /// background-position
        BackgroundPosition,
        /// border-color
        BorderColor,
        /// border-style
        BorderStyle,
        /// border-width
        BorderWidth,
        /// border-top
        BorderTop,
        /// border-left
        BorderLeft,
        /// border-bottom
        BorderBottom,
        /// border-right
        BorderRight,
        /// border-block-start
        BorderBlockStart,
        /// border-block-end
        BorderBlockEnd,
        /// border-inline-start
        BorderInlineStart,
        /// border-inline-end
        BorderInlineEnd,
        /// border
        Border,
        /// border-radius
        BorderRadius,
        /// border-image
        BorderImage,
        /// overflow
        Overflow,
        /// overflow-clip-box
        OverflowClipBox,
        /// transition
        Transition,
        /// animation
        Animation,
        /// scroll-snap-type
        ScrollSnapType,
        /// overscroll-behavior
        OverscrollBehavior,
        /// -moz-transform
        MozTransform,
        /// columns
        Columns,
        /// column-rule
        ColumnRule,
        /// font
        Font,
        /// font-variant
        FontVariant,
        /// text-emphasis
        TextEmphasis,
        /// -webkit-text-stroke
        WebkitTextStroke,
        /// list-style
        ListStyle,
        /// margin
        Margin,
        /// mask
        Mask,
        /// mask-position
        MaskPosition,
        /// outline
        Outline,
        /// -moz-outline-radius
        MozOutlineRadius,
        /// padding
        Padding,
        /// flex-flow
        FlexFlow,
        /// flex
        Flex,
        /// grid-gap
        GridGap,
        /// grid-row
        GridRow,
        /// grid-column
        GridColumn,
        /// grid-area
        GridArea,
        /// grid-template
        GridTemplate,
        /// grid
        Grid,
        /// place-content
        PlaceContent,
        /// place-self
        PlaceSelf,
        /// place-items
        PlaceItems,
        /// marker
        Marker,
        /// text-decoration
        TextDecoration,
        /// all
        All,
}

impl ShorthandId {
    /// Get the name for this shorthand property.
    pub fn name(&self) -> &'static str {
        match *self {
                ShorthandId::Background => "background",
                ShorthandId::BackgroundPosition => "background-position",
                ShorthandId::BorderColor => "border-color",
                ShorthandId::BorderStyle => "border-style",
                ShorthandId::BorderWidth => "border-width",
                ShorthandId::BorderTop => "border-top",
                ShorthandId::BorderLeft => "border-left",
                ShorthandId::BorderBottom => "border-bottom",
                ShorthandId::BorderRight => "border-right",
                ShorthandId::BorderBlockStart => "border-block-start",
                ShorthandId::BorderBlockEnd => "border-block-end",
                ShorthandId::BorderInlineStart => "border-inline-start",
                ShorthandId::BorderInlineEnd => "border-inline-end",
                ShorthandId::Border => "border",
                ShorthandId::BorderRadius => "border-radius",
                ShorthandId::BorderImage => "border-image",
                ShorthandId::Overflow => "overflow",
                ShorthandId::OverflowClipBox => "overflow-clip-box",
                ShorthandId::Transition => "transition",
                ShorthandId::Animation => "animation",
                ShorthandId::ScrollSnapType => "scroll-snap-type",
                ShorthandId::OverscrollBehavior => "overscroll-behavior",
                ShorthandId::MozTransform => "-moz-transform",
                ShorthandId::Columns => "columns",
                ShorthandId::ColumnRule => "column-rule",
                ShorthandId::Font => "font",
                ShorthandId::FontVariant => "font-variant",
                ShorthandId::TextEmphasis => "text-emphasis",
                ShorthandId::WebkitTextStroke => "-webkit-text-stroke",
                ShorthandId::ListStyle => "list-style",
                ShorthandId::Margin => "margin",
                ShorthandId::Mask => "mask",
                ShorthandId::MaskPosition => "mask-position",
                ShorthandId::Outline => "outline",
                ShorthandId::MozOutlineRadius => "-moz-outline-radius",
                ShorthandId::Padding => "padding",
                ShorthandId::FlexFlow => "flex-flow",
                ShorthandId::Flex => "flex",
                ShorthandId::GridGap => "grid-gap",
                ShorthandId::GridRow => "grid-row",
                ShorthandId::GridColumn => "grid-column",
                ShorthandId::GridArea => "grid-area",
                ShorthandId::GridTemplate => "grid-template",
                ShorthandId::Grid => "grid",
                ShorthandId::PlaceContent => "place-content",
                ShorthandId::PlaceSelf => "place-self",
                ShorthandId::PlaceItems => "place-items",
                ShorthandId::Marker => "marker",
                ShorthandId::TextDecoration => "text-decoration",
                ShorthandId::All => "all",
        }
    }

    /// Converts from a ShorthandId to an adequate nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    pub fn to_nscsspropertyid(self) -> nsCSSPropertyID {
        match self {
            ShorthandId::Background => {
                
    nsCSSPropertyID::eCSSProperty_background
            }
            ShorthandId::BackgroundPosition => {
                
    nsCSSPropertyID::eCSSProperty_background_position
            }
            ShorthandId::BorderColor => {
                
    nsCSSPropertyID::eCSSProperty_border_color
            }
            ShorthandId::BorderStyle => {
                
    nsCSSPropertyID::eCSSProperty_border_style
            }
            ShorthandId::BorderWidth => {
                
    nsCSSPropertyID::eCSSProperty_border_width
            }
            ShorthandId::BorderTop => {
                
    nsCSSPropertyID::eCSSProperty_border_top
            }
            ShorthandId::BorderLeft => {
                
    nsCSSPropertyID::eCSSProperty_border_left
            }
            ShorthandId::BorderBottom => {
                
    nsCSSPropertyID::eCSSProperty_border_bottom
            }
            ShorthandId::BorderRight => {
                
    nsCSSPropertyID::eCSSProperty_border_right
            }
            ShorthandId::BorderBlockStart => {
                
    nsCSSPropertyID::eCSSProperty_border_block_start
            }
            ShorthandId::BorderBlockEnd => {
                
    nsCSSPropertyID::eCSSProperty_border_block_end
            }
            ShorthandId::BorderInlineStart => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_start
            }
            ShorthandId::BorderInlineEnd => {
                
    nsCSSPropertyID::eCSSProperty_border_inline_end
            }
            ShorthandId::Border => {
                
    nsCSSPropertyID::eCSSProperty_border
            }
            ShorthandId::BorderRadius => {
                
    nsCSSPropertyID::eCSSProperty_border_radius
            }
            ShorthandId::BorderImage => {
                
    nsCSSPropertyID::eCSSProperty_border_image
            }
            ShorthandId::Overflow => {
                
    nsCSSPropertyID::eCSSProperty_overflow
            }
            ShorthandId::OverflowClipBox => {
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box
            }
            ShorthandId::Transition => {
                
    nsCSSPropertyID::eCSSProperty_transition
            }
            ShorthandId::Animation => {
                
    nsCSSPropertyID::eCSSProperty_animation
            }
            ShorthandId::ScrollSnapType => {
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type
            }
            ShorthandId::OverscrollBehavior => {
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior
            }
            ShorthandId::MozTransform => {
                
    nsCSSPropertyID::eCSSProperty__moz_transform
            }
            ShorthandId::Columns => {
                
    nsCSSPropertyID::eCSSProperty_columns
            }
            ShorthandId::ColumnRule => {
                
    nsCSSPropertyID::eCSSProperty_column_rule
            }
            ShorthandId::Font => {
                
    nsCSSPropertyID::eCSSProperty_font
            }
            ShorthandId::FontVariant => {
                
    nsCSSPropertyID::eCSSProperty_font_variant
            }
            ShorthandId::TextEmphasis => {
                
    nsCSSPropertyID::eCSSProperty_text_emphasis
            }
            ShorthandId::WebkitTextStroke => {
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke
            }
            ShorthandId::ListStyle => {
                
    nsCSSPropertyID::eCSSProperty_list_style
            }
            ShorthandId::Margin => {
                
    nsCSSPropertyID::eCSSProperty_margin
            }
            ShorthandId::Mask => {
                
    nsCSSPropertyID::eCSSProperty_mask
            }
            ShorthandId::MaskPosition => {
                
    nsCSSPropertyID::eCSSProperty_mask_position
            }
            ShorthandId::Outline => {
                
    nsCSSPropertyID::eCSSProperty_outline
            }
            ShorthandId::MozOutlineRadius => {
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius
            }
            ShorthandId::Padding => {
                
    nsCSSPropertyID::eCSSProperty_padding
            }
            ShorthandId::FlexFlow => {
                
    nsCSSPropertyID::eCSSProperty_flex_flow
            }
            ShorthandId::Flex => {
                
    nsCSSPropertyID::eCSSProperty_flex
            }
            ShorthandId::GridGap => {
                
    nsCSSPropertyID::eCSSProperty_grid_gap
            }
            ShorthandId::GridRow => {
                
    nsCSSPropertyID::eCSSProperty_grid_row
            }
            ShorthandId::GridColumn => {
                
    nsCSSPropertyID::eCSSProperty_grid_column
            }
            ShorthandId::GridArea => {
                
    nsCSSPropertyID::eCSSProperty_grid_area
            }
            ShorthandId::GridTemplate => {
                
    nsCSSPropertyID::eCSSProperty_grid_template
            }
            ShorthandId::Grid => {
                
    nsCSSPropertyID::eCSSProperty_grid
            }
            ShorthandId::PlaceContent => {
                
    nsCSSPropertyID::eCSSProperty_place_content
            }
            ShorthandId::PlaceSelf => {
                
    nsCSSPropertyID::eCSSProperty_place_self
            }
            ShorthandId::PlaceItems => {
                
    nsCSSPropertyID::eCSSProperty_place_items
            }
            ShorthandId::Marker => {
                
    nsCSSPropertyID::eCSSProperty_marker
            }
            ShorthandId::TextDecoration => {
                
    nsCSSPropertyID::eCSSProperty_text_decoration
            }
            ShorthandId::All => {
                
    nsCSSPropertyID::eCSSProperty_all
            }
        }
    }

    /// Get the longhand ids that form this shorthand.
    pub fn longhands(&self) -> &'static [LonghandId] {
            static BACKGROUND: &'static [LonghandId] = &[
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundClip,
            ];
            static BACKGROUND_POSITION: &'static [LonghandId] = &[
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
            ];
            static BORDER_COLOR: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderLeftColor,
            ];
            static BORDER_STYLE: &'static [LonghandId] = &[
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderLeftStyle,
            ];
            static BORDER_WIDTH: &'static [LonghandId] = &[
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightWidth,
            ];
            static BORDER_TOP: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
            ];
            static BORDER_LEFT: &'static [LonghandId] = &[
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
            ];
            static BORDER_BOTTOM: &'static [LonghandId] = &[
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
            ];
            static BORDER_RIGHT: &'static [LonghandId] = &[
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
            ];
            static BORDER_BLOCK_START: &'static [LonghandId] = &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartWidth,
            ];
            static BORDER_BLOCK_END: &'static [LonghandId] = &[
                    LonghandId::BorderBlockEndColor,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndWidth,
            ];
            static BORDER_INLINE_START: &'static [LonghandId] = &[
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartWidth,
            ];
            static BORDER_INLINE_END: &'static [LonghandId] = &[
                    LonghandId::BorderInlineEndColor,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndWidth,
            ];
            static BORDER: &'static [LonghandId] = &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ];
            static BORDER_RADIUS: &'static [LonghandId] = &[
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
            ];
            static BORDER_IMAGE: &'static [LonghandId] = &[
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ];
            static OVERFLOW: &'static [LonghandId] = &[
                    LonghandId::OverflowX,
                    LonghandId::OverflowY,
            ];
            static OVERFLOW_CLIP_BOX: &'static [LonghandId] = &[
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowClipBoxInline,
            ];
            static TRANSITION: &'static [LonghandId] = &[
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionDelay,
            ];
            static ANIMATION: &'static [LonghandId] = &[
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationDelay,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationPlayState,
            ];
            static SCROLL_SNAP_TYPE: &'static [LonghandId] = &[
                    LonghandId::ScrollSnapTypeX,
                    LonghandId::ScrollSnapTypeY,
            ];
            static OVERSCROLL_BEHAVIOR: &'static [LonghandId] = &[
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::OverscrollBehaviorY,
            ];
            static _MOZ_TRANSFORM: &'static [LonghandId] = &[
                    LonghandId::Transform,
            ];
            static COLUMNS: &'static [LonghandId] = &[
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
            ];
            static COLUMN_RULE: &'static [LonghandId] = &[
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::ColumnRuleColor,
            ];
            static FONT: &'static [LonghandId] = &[
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontStretch,
                    LonghandId::FontSize,
                    LonghandId::LineHeight,
                    LonghandId::FontFamily,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontKerning,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontLanguageOverride,
                    LonghandId::FontFeatureSettings,
            ];
            static FONT_VARIANT: &'static [LonghandId] = &[
                    LonghandId::FontVariantCaps,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
            ];
            static TEXT_EMPHASIS: &'static [LonghandId] = &[
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisColor,
            ];
            static _WEBKIT_TEXT_STROKE: &'static [LonghandId] = &[
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::WebkitTextStrokeColor,
            ];
            static LIST_STYLE: &'static [LonghandId] = &[
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleImage,
                    LonghandId::ListStyleType,
            ];
            static MARGIN: &'static [LonghandId] = &[
                    LonghandId::MarginTop,
                    LonghandId::MarginRight,
                    LonghandId::MarginBottom,
                    LonghandId::MarginLeft,
            ];
            static MASK: &'static [LonghandId] = &[
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskComposite,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskSize,
                    LonghandId::MaskImage,
            ];
            static MASK_POSITION: &'static [LonghandId] = &[
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
            ];
            static OUTLINE: &'static [LonghandId] = &[
                    LonghandId::OutlineWidth,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineColor,
            ];
            static _MOZ_OUTLINE_RADIUS: &'static [LonghandId] = &[
                    LonghandId::MozOutlineRadiusTopleft,
                    LonghandId::MozOutlineRadiusTopright,
                    LonghandId::MozOutlineRadiusBottomright,
                    LonghandId::MozOutlineRadiusBottomleft,
            ];
            static PADDING: &'static [LonghandId] = &[
                    LonghandId::PaddingTop,
                    LonghandId::PaddingRight,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingLeft,
            ];
            static FLEX_FLOW: &'static [LonghandId] = &[
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
            ];
            static FLEX: &'static [LonghandId] = &[
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::FlexBasis,
            ];
            static GRID_GAP: &'static [LonghandId] = &[
                    LonghandId::GridRowGap,
                    LonghandId::GridColumnGap,
            ];
            static GRID_ROW: &'static [LonghandId] = &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
            ];
            static GRID_COLUMN: &'static [LonghandId] = &[
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ];
            static GRID_AREA: &'static [LonghandId] = &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ];
            static GRID_TEMPLATE: &'static [LonghandId] = &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
            ];
            static GRID: &'static [LonghandId] = &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
                    LonghandId::GridAutoRows,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridAutoFlow,
            ];
            static PLACE_CONTENT: &'static [LonghandId] = &[
                    LonghandId::AlignContent,
                    LonghandId::JustifyContent,
            ];
            static PLACE_SELF: &'static [LonghandId] = &[
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
            ];
            static PLACE_ITEMS: &'static [LonghandId] = &[
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
            ];
            static MARKER: &'static [LonghandId] = &[
                    LonghandId::MarkerStart,
                    LonghandId::MarkerEnd,
                    LonghandId::MarkerMid,
            ];
            static TEXT_DECORATION: &'static [LonghandId] = &[
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
            ];
            static ALL: &'static [LonghandId] = &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockEndColor,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndWidth,
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineEndColor,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndWidth,
                    LonghandId::MarginBlockStart,
                    LonghandId::MarginBlockEnd,
                    LonghandId::MarginInlineStart,
                    LonghandId::MarginInlineEnd,
                    LonghandId::PaddingBlockStart,
                    LonghandId::PaddingBlockEnd,
                    LonghandId::PaddingInlineStart,
                    LonghandId::PaddingInlineEnd,
                    LonghandId::OffsetBlockStart,
                    LonghandId::OffsetBlockEnd,
                    LonghandId::OffsetInlineStart,
                    LonghandId::OffsetInlineEnd,
                    LonghandId::BlockSize,
                    LonghandId::MinBlockSize,
                    LonghandId::MaxBlockSize,
                    LonghandId::InlineSize,
                    LonghandId::MinInlineSize,
                    LonghandId::MaxInlineSize,
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundClip,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundBlendMode,
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
                    LonghandId::BoxDecorationBreak,
                    LonghandId::MozFloatEdge,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageWidth,
                    LonghandId::BorderImageSlice,
                    LonghandId::Display,
                    LonghandId::Position,
                    LonghandId::Float,
                    LonghandId::Clear,
                    LonghandId::VerticalAlign,
                    LonghandId::OverflowClipBoxInline,
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowX,
                    LonghandId::OverflowY,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDelay,
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationPlayState,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationDelay,
                    LonghandId::ScrollSnapPointsX,
                    LonghandId::ScrollSnapPointsY,
                    LonghandId::ScrollSnapDestination,
                    LonghandId::ScrollSnapCoordinate,
                    LonghandId::Transform,
                    LonghandId::ScrollBehavior,
                    LonghandId::ScrollSnapTypeX,
                    LonghandId::ScrollSnapTypeY,
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::OverscrollBehaviorY,
                    LonghandId::Isolation,
                    LonghandId::PageBreakAfter,
                    LonghandId::PageBreakBefore,
                    LonghandId::PageBreakInside,
                    LonghandId::Resize,
                    LonghandId::Perspective,
                    LonghandId::PerspectiveOrigin,
                    LonghandId::BackfaceVisibility,
                    LonghandId::TransformBox,
                    LonghandId::TransformStyle,
                    LonghandId::TransformOrigin,
                    LonghandId::Contain,
                    LonghandId::MozAppearance,
                    LonghandId::MozBinding,
                    LonghandId::MozOrient,
                    LonghandId::WillChange,
                    LonghandId::ShapeImageThreshold,
                    LonghandId::ShapeOutside,
                    LonghandId::TouchAction,
                    LonghandId::Color,
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
                    LonghandId::ColumnGap,
                    LonghandId::ColumnFill,
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleColor,
                    LonghandId::ColumnSpan,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::Content,
                    LonghandId::CounterIncrement,
                    LonghandId::CounterReset,
                    LonghandId::Opacity,
                    LonghandId::BoxShadow,
                    LonghandId::Clip,
                    LonghandId::Filter,
                    LonghandId::MixBlendMode,
                    LonghandId::FontFamily,
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontSize,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontSynthesis,
                    LonghandId::FontStretch,
                    LonghandId::FontKerning,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontFeatureSettings,
                    LonghandId::FontVariationSettings,
                    LonghandId::FontLanguageOverride,
                    LonghandId::MozOsxFontSmoothing,
                    LonghandId::Visibility,
                    LonghandId::WritingMode,
                    LonghandId::TextOrientation,
                    LonghandId::ColorAdjust,
                    LonghandId::ImageRendering,
                    LonghandId::ImageOrientation,
                    LonghandId::BorderCollapse,
                    LonghandId::EmptyCells,
                    LonghandId::CaptionSide,
                    LonghandId::BorderSpacing,
                    LonghandId::LineHeight,
                    LonghandId::TextTransform,
                    LonghandId::Hyphens,
                    LonghandId::MozTextSizeAdjust,
                    LonghandId::TextIndent,
                    LonghandId::OverflowWrap,
                    LonghandId::WordBreak,
                    LonghandId::TextJustify,
                    LonghandId::TextAlignLast,
                    LonghandId::TextAlign,
                    LonghandId::LetterSpacing,
                    LonghandId::WordSpacing,
                    LonghandId::WhiteSpace,
                    LonghandId::TextShadow,
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisPosition,
                    LonghandId::TextEmphasisColor,
                    LonghandId::MozTabSize,
                    LonghandId::WebkitTextFillColor,
                    LonghandId::WebkitTextStrokeColor,
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::RubyAlign,
                    LonghandId::RubyPosition,
                    LonghandId::TextCombineUpright,
                    LonghandId::TextRendering,
                    LonghandId::MozControlCharacterVisibility,
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleType,
                    LonghandId::ListStyleImage,
                    LonghandId::Quotes,
                    LonghandId::MozImageRegion,
                    LonghandId::MarginTop,
                    LonghandId::MarginLeft,
                    LonghandId::MarginBottom,
                    LonghandId::MarginRight,
                    LonghandId::OutlineColor,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineWidth,
                    LonghandId::MozOutlineRadiusTopleft,
                    LonghandId::MozOutlineRadiusTopright,
                    LonghandId::MozOutlineRadiusBottomright,
                    LonghandId::MozOutlineRadiusBottomleft,
                    LonghandId::OutlineOffset,
                    LonghandId::PaddingTop,
                    LonghandId::PaddingLeft,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingRight,
                    LonghandId::Cursor,
                    LonghandId::PointerEvents,
                    LonghandId::MozUserInput,
                    LonghandId::MozUserModify,
                    LonghandId::MozUserFocus,
                    LonghandId::CaretColor,
                    LonghandId::Top,
                    LonghandId::Left,
                    LonghandId::Bottom,
                    LonghandId::Right,
                    LonghandId::ZIndex,
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
                    LonghandId::JustifyContent,
                    LonghandId::AlignContent,
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
                    LonghandId::Order,
                    LonghandId::FlexBasis,
                    LonghandId::Width,
                    LonghandId::MinWidth,
                    LonghandId::MaxWidth,
                    LonghandId::Height,
                    LonghandId::MinHeight,
                    LonghandId::MaxHeight,
                    LonghandId::BoxSizing,
                    LonghandId::ObjectFit,
                    LonghandId::ObjectPosition,
                    LonghandId::GridRowGap,
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridAutoRows,
                    LonghandId::GridTemplateRows,
                    LonghandId::GridColumnGap,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridAutoFlow,
                    LonghandId::GridTemplateAreas,
                    LonghandId::TableLayout,
                    LonghandId::TextOverflow,
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
                    LonghandId::InitialLetter,
                    LonghandId::ImeMode,
                    LonghandId::MozUserSelect,
                    LonghandId::MozWindowDragging,
                    LonghandId::MozForceBrokenImageIcon,
                    LonghandId::TextAnchor,
                    LonghandId::ColorInterpolation,
                    LonghandId::ColorInterpolationFilters,
                    LonghandId::Fill,
                    LonghandId::FillOpacity,
                    LonghandId::FillRule,
                    LonghandId::ShapeRendering,
                    LonghandId::Stroke,
                    LonghandId::StrokeWidth,
                    LonghandId::StrokeLinecap,
                    LonghandId::StrokeLinejoin,
                    LonghandId::StrokeMiterlimit,
                    LonghandId::StrokeOpacity,
                    LonghandId::StrokeDasharray,
                    LonghandId::StrokeDashoffset,
                    LonghandId::ClipRule,
                    LonghandId::MarkerStart,
                    LonghandId::MarkerMid,
                    LonghandId::MarkerEnd,
                    LonghandId::PaintOrder,
                    LonghandId::MozContextProperties,
                    LonghandId::DominantBaseline,
                    LonghandId::VectorEffect,
                    LonghandId::StopColor,
                    LonghandId::StopOpacity,
                    LonghandId::FloodColor,
                    LonghandId::FloodOpacity,
                    LonghandId::LightingColor,
                    LonghandId::MaskType,
                    LonghandId::ClipPath,
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskSize,
                    LonghandId::MaskComposite,
                    LonghandId::MaskImage,
                    LonghandId::MozBoxAlign,
                    LonghandId::MozBoxDirection,
                    LonghandId::MozBoxFlex,
                    LonghandId::MozBoxOrient,
                    LonghandId::MozBoxPack,
                    LonghandId::MozStackSizing,
                    LonghandId::MozBoxOrdinalGroup,
            ];
        match *self {
                ShorthandId::Background => BACKGROUND,
                ShorthandId::BackgroundPosition => BACKGROUND_POSITION,
                ShorthandId::BorderColor => BORDER_COLOR,
                ShorthandId::BorderStyle => BORDER_STYLE,
                ShorthandId::BorderWidth => BORDER_WIDTH,
                ShorthandId::BorderTop => BORDER_TOP,
                ShorthandId::BorderLeft => BORDER_LEFT,
                ShorthandId::BorderBottom => BORDER_BOTTOM,
                ShorthandId::BorderRight => BORDER_RIGHT,
                ShorthandId::BorderBlockStart => BORDER_BLOCK_START,
                ShorthandId::BorderBlockEnd => BORDER_BLOCK_END,
                ShorthandId::BorderInlineStart => BORDER_INLINE_START,
                ShorthandId::BorderInlineEnd => BORDER_INLINE_END,
                ShorthandId::Border => BORDER,
                ShorthandId::BorderRadius => BORDER_RADIUS,
                ShorthandId::BorderImage => BORDER_IMAGE,
                ShorthandId::Overflow => OVERFLOW,
                ShorthandId::OverflowClipBox => OVERFLOW_CLIP_BOX,
                ShorthandId::Transition => TRANSITION,
                ShorthandId::Animation => ANIMATION,
                ShorthandId::ScrollSnapType => SCROLL_SNAP_TYPE,
                ShorthandId::OverscrollBehavior => OVERSCROLL_BEHAVIOR,
                ShorthandId::MozTransform => _MOZ_TRANSFORM,
                ShorthandId::Columns => COLUMNS,
                ShorthandId::ColumnRule => COLUMN_RULE,
                ShorthandId::Font => FONT,
                ShorthandId::FontVariant => FONT_VARIANT,
                ShorthandId::TextEmphasis => TEXT_EMPHASIS,
                ShorthandId::WebkitTextStroke => _WEBKIT_TEXT_STROKE,
                ShorthandId::ListStyle => LIST_STYLE,
                ShorthandId::Margin => MARGIN,
                ShorthandId::Mask => MASK,
                ShorthandId::MaskPosition => MASK_POSITION,
                ShorthandId::Outline => OUTLINE,
                ShorthandId::MozOutlineRadius => _MOZ_OUTLINE_RADIUS,
                ShorthandId::Padding => PADDING,
                ShorthandId::FlexFlow => FLEX_FLOW,
                ShorthandId::Flex => FLEX,
                ShorthandId::GridGap => GRID_GAP,
                ShorthandId::GridRow => GRID_ROW,
                ShorthandId::GridColumn => GRID_COLUMN,
                ShorthandId::GridArea => GRID_AREA,
                ShorthandId::GridTemplate => GRID_TEMPLATE,
                ShorthandId::Grid => GRID,
                ShorthandId::PlaceContent => PLACE_CONTENT,
                ShorthandId::PlaceSelf => PLACE_SELF,
                ShorthandId::PlaceItems => PLACE_ITEMS,
                ShorthandId::Marker => MARKER,
                ShorthandId::TextDecoration => TEXT_DECORATION,
                ShorthandId::All => ALL,
        }
    }

    /// Try to serialize the given declarations as this shorthand.
    ///
    /// Returns an error if writing to the stream fails, or if the declarations
    /// do not map to a shorthand.
    pub fn longhands_to_css<'a, W, I>(
        &self,
        declarations: I,
        dest: &mut CssWriter<W>,
    ) -> fmt::Result
    where
        W: Write,
        I: Iterator<Item=&'a PropertyDeclaration>,
    {
        match *self {
            ShorthandId::All => {
                // No need to try to serialize the declarations as the 'all'
                // shorthand, since it only accepts CSS-wide keywords (and
                // variable references), which will be handled in
                // get_shorthand_appendable_value.
                Err(fmt::Error)
            }
                ShorthandId::Background => {
                    match shorthands::background::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BackgroundPosition => {
                    match shorthands::background_position::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderColor => {
                    match shorthands::border_color::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderStyle => {
                    match shorthands::border_style::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderWidth => {
                    match shorthands::border_width::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderTop => {
                    match shorthands::border_top::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderLeft => {
                    match shorthands::border_left::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBottom => {
                    match shorthands::border_bottom::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderRight => {
                    match shorthands::border_right::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBlockStart => {
                    match shorthands::border_block_start::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderBlockEnd => {
                    match shorthands::border_block_end::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderInlineStart => {
                    match shorthands::border_inline_start::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderInlineEnd => {
                    match shorthands::border_inline_end::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Border => {
                    match shorthands::border::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderRadius => {
                    match shorthands::border_radius::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::BorderImage => {
                    match shorthands::border_image::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Overflow => {
                    match shorthands::overflow::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::OverflowClipBox => {
                    match shorthands::overflow_clip_box::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Transition => {
                    match shorthands::transition::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Animation => {
                    match shorthands::animation::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ScrollSnapType => {
                    match shorthands::scroll_snap_type::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::OverscrollBehavior => {
                    match shorthands::overscroll_behavior::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::MozTransform => {
                    match shorthands::_moz_transform::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Columns => {
                    match shorthands::columns::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ColumnRule => {
                    match shorthands::column_rule::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Font => {
                    match shorthands::font::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::FontVariant => {
                    match shorthands::font_variant::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::TextEmphasis => {
                    match shorthands::text_emphasis::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::WebkitTextStroke => {
                    match shorthands::_webkit_text_stroke::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::ListStyle => {
                    match shorthands::list_style::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Margin => {
                    match shorthands::margin::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Mask => {
                    match shorthands::mask::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::MaskPosition => {
                    match shorthands::mask_position::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Outline => {
                    match shorthands::outline::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::MozOutlineRadius => {
                    match shorthands::_moz_outline_radius::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Padding => {
                    match shorthands::padding::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::FlexFlow => {
                    match shorthands::flex_flow::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Flex => {
                    match shorthands::flex::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridGap => {
                    match shorthands::grid_gap::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridRow => {
                    match shorthands::grid_row::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridColumn => {
                    match shorthands::grid_column::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridArea => {
                    match shorthands::grid_area::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::GridTemplate => {
                    match shorthands::grid_template::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Grid => {
                    match shorthands::grid::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceContent => {
                    match shorthands::place_content::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceSelf => {
                    match shorthands::place_self::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::PlaceItems => {
                    match shorthands::place_items::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::Marker => {
                    match shorthands::marker::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
                ShorthandId::TextDecoration => {
                    match shorthands::text_decoration::LonghandsToSerialize::from_iter(declarations) {
                        Ok(longhands) => longhands.to_css(dest),
                        Err(_) => Err(fmt::Error)
                    }
                },
        }
    }

    /// Finds and returns an appendable value for the given declarations.
    ///
    /// Returns the optional appendable value.
    pub fn get_shorthand_appendable_value<'a, I>(
        self,
        declarations: I,
    ) -> Option<AppendableValue<'a, I::IntoIter>>
    where
        I: IntoIterator<Item=&'a PropertyDeclaration>,
        I::IntoIter: Clone,
    {
        let declarations = declarations.into_iter();

        // Only cloning iterators (a few pointers each) not declarations.
        let mut declarations2 = declarations.clone();
        let mut declarations3 = declarations.clone();

        let first_declaration = declarations2.next()?;

        // https://drafts.csswg.org/css-variables/#variables-in-shorthands
        if let Some(css) = first_declaration.with_variables_from_shorthand(self) {
            if declarations2.all(|d| d.with_variables_from_shorthand(self) == Some(css)) {
               return Some(AppendableValue::Css {
                   css: CssStringBorrow::from(css),
                   with_variables: true,
               });
            }
            return None;
        }

        // Check whether they are all the same CSS-wide keyword.
        if let Some(keyword) = first_declaration.get_css_wide_keyword() {
            if declarations2.all(|d| d.get_css_wide_keyword() == Some(keyword)) {
                return Some(AppendableValue::Css {
                    css: CssStringBorrow::from(keyword.to_str()),
                    with_variables: false,
                });
            }
            return None;
        }

        // Check whether all declarations can be serialized as part of shorthand.
        if declarations3.all(|d| d.may_serialize_as_part_of_shorthand()) {
            return Some(AppendableValue::DeclarationsForShorthand(self, declarations));
        }

        None
    }

    /// Returns PropertyFlags for given shorthand property.
    pub fn flags(&self) -> PropertyFlags {
        match *self {
                ShorthandId::Background =>
                    PropertyFlags::empty(),
                ShorthandId::BackgroundPosition =>
                    PropertyFlags::empty(),
                ShorthandId::BorderColor =>
                    PropertyFlags::empty(),
                ShorthandId::BorderStyle =>
                    PropertyFlags::empty(),
                ShorthandId::BorderWidth =>
                    PropertyFlags::empty(),
                ShorthandId::BorderTop =>
                    PropertyFlags::empty(),
                ShorthandId::BorderLeft =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBottom =>
                    PropertyFlags::empty(),
                ShorthandId::BorderRight =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBlockStart =>
                    PropertyFlags::empty(),
                ShorthandId::BorderBlockEnd =>
                    PropertyFlags::empty(),
                ShorthandId::BorderInlineStart =>
                    PropertyFlags::empty(),
                ShorthandId::BorderInlineEnd =>
                    PropertyFlags::empty(),
                ShorthandId::Border =>
                    PropertyFlags::empty(),
                ShorthandId::BorderRadius =>
                    PropertyFlags::empty(),
                ShorthandId::BorderImage =>
                    PropertyFlags::empty(),
                ShorthandId::Overflow =>
                    PropertyFlags::empty(),
                ShorthandId::OverflowClipBox =>
                    PropertyFlags::empty(),
                ShorthandId::Transition =>
                    PropertyFlags::empty(),
                ShorthandId::Animation =>
                    PropertyFlags::empty(),
                ShorthandId::ScrollSnapType =>
                    PropertyFlags::empty(),
                ShorthandId::OverscrollBehavior =>
                    PropertyFlags::empty(),
                ShorthandId::MozTransform =>
                        PropertyFlags::SHORTHAND_ALIAS_PROPERTY |
                    PropertyFlags::empty(),
                ShorthandId::Columns =>
                    PropertyFlags::empty(),
                ShorthandId::ColumnRule =>
                    PropertyFlags::empty(),
                ShorthandId::Font =>
                    PropertyFlags::empty(),
                ShorthandId::FontVariant =>
                    PropertyFlags::empty(),
                ShorthandId::TextEmphasis =>
                    PropertyFlags::empty(),
                ShorthandId::WebkitTextStroke =>
                    PropertyFlags::empty(),
                ShorthandId::ListStyle =>
                    PropertyFlags::empty(),
                ShorthandId::Margin =>
                    PropertyFlags::empty(),
                ShorthandId::Mask =>
                    PropertyFlags::empty(),
                ShorthandId::MaskPosition =>
                    PropertyFlags::empty(),
                ShorthandId::Outline =>
                    PropertyFlags::empty(),
                ShorthandId::MozOutlineRadius =>
                    PropertyFlags::empty(),
                ShorthandId::Padding =>
                    PropertyFlags::empty(),
                ShorthandId::FlexFlow =>
                    PropertyFlags::empty(),
                ShorthandId::Flex =>
                    PropertyFlags::empty(),
                ShorthandId::GridGap =>
                    PropertyFlags::empty(),
                ShorthandId::GridRow =>
                    PropertyFlags::empty(),
                ShorthandId::GridColumn =>
                    PropertyFlags::empty(),
                ShorthandId::GridArea =>
                    PropertyFlags::empty(),
                ShorthandId::GridTemplate =>
                    PropertyFlags::empty(),
                ShorthandId::Grid =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceContent =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceSelf =>
                    PropertyFlags::empty(),
                ShorthandId::PlaceItems =>
                    PropertyFlags::empty(),
                ShorthandId::Marker =>
                    PropertyFlags::empty(),
                ShorthandId::TextDecoration =>
                    PropertyFlags::empty(),
                ShorthandId::All =>
                    PropertyFlags::empty(),
        }
    }

    fn parse_into<'i, 't>(
        &self,
        declarations: &mut SourcePropertyDeclaration,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(), ParseError<'i>> {
        match *self {
                ShorthandId::Background => {
                    shorthands::background::parse_into(declarations, context, input)
                }
                ShorthandId::BackgroundPosition => {
                    shorthands::background_position::parse_into(declarations, context, input)
                }
                ShorthandId::BorderColor => {
                    shorthands::border_color::parse_into(declarations, context, input)
                }
                ShorthandId::BorderStyle => {
                    shorthands::border_style::parse_into(declarations, context, input)
                }
                ShorthandId::BorderWidth => {
                    shorthands::border_width::parse_into(declarations, context, input)
                }
                ShorthandId::BorderTop => {
                    shorthands::border_top::parse_into(declarations, context, input)
                }
                ShorthandId::BorderLeft => {
                    shorthands::border_left::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBottom => {
                    shorthands::border_bottom::parse_into(declarations, context, input)
                }
                ShorthandId::BorderRight => {
                    shorthands::border_right::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBlockStart => {
                    shorthands::border_block_start::parse_into(declarations, context, input)
                }
                ShorthandId::BorderBlockEnd => {
                    shorthands::border_block_end::parse_into(declarations, context, input)
                }
                ShorthandId::BorderInlineStart => {
                    shorthands::border_inline_start::parse_into(declarations, context, input)
                }
                ShorthandId::BorderInlineEnd => {
                    shorthands::border_inline_end::parse_into(declarations, context, input)
                }
                ShorthandId::Border => {
                    shorthands::border::parse_into(declarations, context, input)
                }
                ShorthandId::BorderRadius => {
                    shorthands::border_radius::parse_into(declarations, context, input)
                }
                ShorthandId::BorderImage => {
                    shorthands::border_image::parse_into(declarations, context, input)
                }
                ShorthandId::Overflow => {
                    shorthands::overflow::parse_into(declarations, context, input)
                }
                ShorthandId::OverflowClipBox => {
                    shorthands::overflow_clip_box::parse_into(declarations, context, input)
                }
                ShorthandId::Transition => {
                    shorthands::transition::parse_into(declarations, context, input)
                }
                ShorthandId::Animation => {
                    shorthands::animation::parse_into(declarations, context, input)
                }
                ShorthandId::ScrollSnapType => {
                    shorthands::scroll_snap_type::parse_into(declarations, context, input)
                }
                ShorthandId::OverscrollBehavior => {
                    shorthands::overscroll_behavior::parse_into(declarations, context, input)
                }
                ShorthandId::MozTransform => {
                    shorthands::_moz_transform::parse_into(declarations, context, input)
                }
                ShorthandId::Columns => {
                    shorthands::columns::parse_into(declarations, context, input)
                }
                ShorthandId::ColumnRule => {
                    shorthands::column_rule::parse_into(declarations, context, input)
                }
                ShorthandId::Font => {
                    shorthands::font::parse_into(declarations, context, input)
                }
                ShorthandId::FontVariant => {
                    shorthands::font_variant::parse_into(declarations, context, input)
                }
                ShorthandId::TextEmphasis => {
                    shorthands::text_emphasis::parse_into(declarations, context, input)
                }
                ShorthandId::WebkitTextStroke => {
                    shorthands::_webkit_text_stroke::parse_into(declarations, context, input)
                }
                ShorthandId::ListStyle => {
                    shorthands::list_style::parse_into(declarations, context, input)
                }
                ShorthandId::Margin => {
                    shorthands::margin::parse_into(declarations, context, input)
                }
                ShorthandId::Mask => {
                    shorthands::mask::parse_into(declarations, context, input)
                }
                ShorthandId::MaskPosition => {
                    shorthands::mask_position::parse_into(declarations, context, input)
                }
                ShorthandId::Outline => {
                    shorthands::outline::parse_into(declarations, context, input)
                }
                ShorthandId::MozOutlineRadius => {
                    shorthands::_moz_outline_radius::parse_into(declarations, context, input)
                }
                ShorthandId::Padding => {
                    shorthands::padding::parse_into(declarations, context, input)
                }
                ShorthandId::FlexFlow => {
                    shorthands::flex_flow::parse_into(declarations, context, input)
                }
                ShorthandId::Flex => {
                    shorthands::flex::parse_into(declarations, context, input)
                }
                ShorthandId::GridGap => {
                    shorthands::grid_gap::parse_into(declarations, context, input)
                }
                ShorthandId::GridRow => {
                    shorthands::grid_row::parse_into(declarations, context, input)
                }
                ShorthandId::GridColumn => {
                    shorthands::grid_column::parse_into(declarations, context, input)
                }
                ShorthandId::GridArea => {
                    shorthands::grid_area::parse_into(declarations, context, input)
                }
                ShorthandId::GridTemplate => {
                    shorthands::grid_template::parse_into(declarations, context, input)
                }
                ShorthandId::Grid => {
                    shorthands::grid::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceContent => {
                    shorthands::place_content::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceSelf => {
                    shorthands::place_self::parse_into(declarations, context, input)
                }
                ShorthandId::PlaceItems => {
                    shorthands::place_items::parse_into(declarations, context, input)
                }
                ShorthandId::Marker => {
                    shorthands::marker::parse_into(declarations, context, input)
                }
                ShorthandId::TextDecoration => {
                    shorthands::text_decoration::parse_into(declarations, context, input)
                }
            // 'all' accepts no value other than CSS-wide keywords
            ShorthandId::All => Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }
}

/// Servo's representation of a declared value for a given `T`, which is the
/// declared value for that property.
#[derive(Clone, Debug, Eq, PartialEq)]
pub enum DeclaredValue<'a, T: 'a> {
    /// A known specified value from the stylesheet.
    Value(&'a T),
    /// An unparsed value that contains `var()` functions.
    WithVariables(&'a Arc<UnparsedValue>),
    /// An CSS-wide keyword.
    CSSWideKeyword(CSSWideKeyword),
}

/// A variant of DeclaredValue that owns its data. This separation exists so
/// that PropertyDeclaration can avoid embedding a DeclaredValue (and its
/// extra discriminant word) and synthesize dependent DeclaredValues for
/// PropertyDeclaration instances as needed.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, Debug, Eq, PartialEq)]
pub enum DeclaredValueOwned<T> {
    /// A known specified value from the stylesheet.
    Value(T),
    /// An unparsed value that contains `var()` functions.
    WithVariables(
        #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
        Arc<UnparsedValue>
    ),
    /// An CSS-wide keyword.
    CSSWideKeyword(CSSWideKeyword),
}

impl<T> DeclaredValueOwned<T> {
    /// Creates a dependent DeclaredValue from this DeclaredValueOwned.
    fn borrow(&self) -> DeclaredValue<T> {
        match *self {
            DeclaredValueOwned::Value(ref v) => DeclaredValue::Value(v),
            DeclaredValueOwned::WithVariables(ref v) => DeclaredValue::WithVariables(v),
            DeclaredValueOwned::CSSWideKeyword(v) => DeclaredValue::CSSWideKeyword(v),
        }
    }
}

/// An unparsed property value that contains `var()` functions.
#[derive(Debug, Eq, PartialEq)]
pub struct UnparsedValue {
    /// The css serialization for this value.
    css: String,
    /// The first token type for this serialization.
    first_token_type: TokenSerializationType,
    /// The url data for resolving url values.
    url_data: UrlExtraData,
    /// The shorthand this came from.
    from_shorthand: Option<ShorthandId>,
}

impl UnparsedValue {
    fn substitute_variables(
        &self,
        longhand_id: LonghandId,
        custom_properties: Option<&Arc<::custom_properties::CustomPropertiesMap>>,
        quirks_mode: QuirksMode,
    ) -> PropertyDeclaration {
        ::custom_properties::substitute(&self.css, self.first_token_type, custom_properties)
        .ok()
        .and_then(|css| {
            // As of this writing, only the base URL is used for property
            // values.
            let context = ParserContext::new(
                Origin::Author,
                &self.url_data,
                None,
                ParsingMode::DEFAULT,
                quirks_mode,
            );

            let mut input = ParserInput::new(&css);
            Parser::new(&mut input).parse_entirely(|input| {
                match self.from_shorthand {
                    None => longhand_id.parse_value(&context, input),
                    Some(ShorthandId::All) => {
                        // No need to parse the 'all' shorthand as anything other than a CSS-wide
                        // keyword, after variable substitution.
                        Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent("all".into())))
                    }
                        Some(ShorthandId::Background) => {
                            shorthands::background::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BackgroundColor => {
                                            PropertyDeclaration::BackgroundColor(
                                                longhands.background_color
                                            )
                                        }
                                        LonghandId::BackgroundPositionX => {
                                            PropertyDeclaration::BackgroundPositionX(
                                                longhands.background_position_x
                                            )
                                        }
                                        LonghandId::BackgroundPositionY => {
                                            PropertyDeclaration::BackgroundPositionY(
                                                longhands.background_position_y
                                            )
                                        }
                                        LonghandId::BackgroundRepeat => {
                                            PropertyDeclaration::BackgroundRepeat(
                                                longhands.background_repeat
                                            )
                                        }
                                        LonghandId::BackgroundAttachment => {
                                            PropertyDeclaration::BackgroundAttachment(
                                                longhands.background_attachment
                                            )
                                        }
                                        LonghandId::BackgroundImage => {
                                            PropertyDeclaration::BackgroundImage(
                                                longhands.background_image
                                            )
                                        }
                                        LonghandId::BackgroundSize => {
                                            PropertyDeclaration::BackgroundSize(
                                                longhands.background_size
                                            )
                                        }
                                        LonghandId::BackgroundOrigin => {
                                            PropertyDeclaration::BackgroundOrigin(
                                                longhands.background_origin
                                            )
                                        }
                                        LonghandId::BackgroundClip => {
                                            PropertyDeclaration::BackgroundClip(
                                                longhands.background_clip
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BackgroundPosition) => {
                            shorthands::background_position::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BackgroundPositionX => {
                                            PropertyDeclaration::BackgroundPositionX(
                                                longhands.background_position_x
                                            )
                                        }
                                        LonghandId::BackgroundPositionY => {
                                            PropertyDeclaration::BackgroundPositionY(
                                                longhands.background_position_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderColor) => {
                            shorthands::border_color::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderStyle) => {
                            shorthands::border_style::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderWidth) => {
                            shorthands::border_width::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderTop) => {
                            shorthands::border_top::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderLeft) => {
                            shorthands::border_left::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBottom) => {
                            shorthands::border_bottom::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderRight) => {
                            shorthands::border_right::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBlockStart) => {
                            shorthands::border_block_start::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBlockStartColor => {
                                            PropertyDeclaration::BorderBlockStartColor(
                                                longhands.border_block_start_color
                                            )
                                        }
                                        LonghandId::BorderBlockStartStyle => {
                                            PropertyDeclaration::BorderBlockStartStyle(
                                                longhands.border_block_start_style
                                            )
                                        }
                                        LonghandId::BorderBlockStartWidth => {
                                            PropertyDeclaration::BorderBlockStartWidth(
                                                longhands.border_block_start_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderBlockEnd) => {
                            shorthands::border_block_end::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderBlockEndColor => {
                                            PropertyDeclaration::BorderBlockEndColor(
                                                longhands.border_block_end_color
                                            )
                                        }
                                        LonghandId::BorderBlockEndStyle => {
                                            PropertyDeclaration::BorderBlockEndStyle(
                                                longhands.border_block_end_style
                                            )
                                        }
                                        LonghandId::BorderBlockEndWidth => {
                                            PropertyDeclaration::BorderBlockEndWidth(
                                                longhands.border_block_end_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderInlineStart) => {
                            shorthands::border_inline_start::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderInlineStartColor => {
                                            PropertyDeclaration::BorderInlineStartColor(
                                                longhands.border_inline_start_color
                                            )
                                        }
                                        LonghandId::BorderInlineStartStyle => {
                                            PropertyDeclaration::BorderInlineStartStyle(
                                                longhands.border_inline_start_style
                                            )
                                        }
                                        LonghandId::BorderInlineStartWidth => {
                                            PropertyDeclaration::BorderInlineStartWidth(
                                                longhands.border_inline_start_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderInlineEnd) => {
                            shorthands::border_inline_end::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderInlineEndColor => {
                                            PropertyDeclaration::BorderInlineEndColor(
                                                longhands.border_inline_end_color
                                            )
                                        }
                                        LonghandId::BorderInlineEndStyle => {
                                            PropertyDeclaration::BorderInlineEndStyle(
                                                longhands.border_inline_end_style
                                            )
                                        }
                                        LonghandId::BorderInlineEndWidth => {
                                            PropertyDeclaration::BorderInlineEndWidth(
                                                longhands.border_inline_end_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Border) => {
                            shorthands::border::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopColor => {
                                            PropertyDeclaration::BorderTopColor(
                                                longhands.border_top_color
                                            )
                                        }
                                        LonghandId::BorderTopStyle => {
                                            PropertyDeclaration::BorderTopStyle(
                                                longhands.border_top_style
                                            )
                                        }
                                        LonghandId::BorderTopWidth => {
                                            PropertyDeclaration::BorderTopWidth(
                                                longhands.border_top_width
                                            )
                                        }
                                        LonghandId::BorderLeftColor => {
                                            PropertyDeclaration::BorderLeftColor(
                                                longhands.border_left_color
                                            )
                                        }
                                        LonghandId::BorderLeftStyle => {
                                            PropertyDeclaration::BorderLeftStyle(
                                                longhands.border_left_style
                                            )
                                        }
                                        LonghandId::BorderLeftWidth => {
                                            PropertyDeclaration::BorderLeftWidth(
                                                longhands.border_left_width
                                            )
                                        }
                                        LonghandId::BorderBottomColor => {
                                            PropertyDeclaration::BorderBottomColor(
                                                longhands.border_bottom_color
                                            )
                                        }
                                        LonghandId::BorderBottomStyle => {
                                            PropertyDeclaration::BorderBottomStyle(
                                                longhands.border_bottom_style
                                            )
                                        }
                                        LonghandId::BorderBottomWidth => {
                                            PropertyDeclaration::BorderBottomWidth(
                                                longhands.border_bottom_width
                                            )
                                        }
                                        LonghandId::BorderRightColor => {
                                            PropertyDeclaration::BorderRightColor(
                                                longhands.border_right_color
                                            )
                                        }
                                        LonghandId::BorderRightStyle => {
                                            PropertyDeclaration::BorderRightStyle(
                                                longhands.border_right_style
                                            )
                                        }
                                        LonghandId::BorderRightWidth => {
                                            PropertyDeclaration::BorderRightWidth(
                                                longhands.border_right_width
                                            )
                                        }
                                        LonghandId::BorderImageOutset => {
                                            PropertyDeclaration::BorderImageOutset(
                                                longhands.border_image_outset
                                            )
                                        }
                                        LonghandId::BorderImageRepeat => {
                                            PropertyDeclaration::BorderImageRepeat(
                                                longhands.border_image_repeat
                                            )
                                        }
                                        LonghandId::BorderImageSlice => {
                                            PropertyDeclaration::BorderImageSlice(
                                                longhands.border_image_slice
                                            )
                                        }
                                        LonghandId::BorderImageSource => {
                                            PropertyDeclaration::BorderImageSource(
                                                longhands.border_image_source
                                            )
                                        }
                                        LonghandId::BorderImageWidth => {
                                            PropertyDeclaration::BorderImageWidth(
                                                longhands.border_image_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderRadius) => {
                            shorthands::border_radius::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderTopLeftRadius => {
                                            PropertyDeclaration::BorderTopLeftRadius(
                                                longhands.border_top_left_radius
                                            )
                                        }
                                        LonghandId::BorderTopRightRadius => {
                                            PropertyDeclaration::BorderTopRightRadius(
                                                longhands.border_top_right_radius
                                            )
                                        }
                                        LonghandId::BorderBottomRightRadius => {
                                            PropertyDeclaration::BorderBottomRightRadius(
                                                longhands.border_bottom_right_radius
                                            )
                                        }
                                        LonghandId::BorderBottomLeftRadius => {
                                            PropertyDeclaration::BorderBottomLeftRadius(
                                                longhands.border_bottom_left_radius
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::BorderImage) => {
                            shorthands::border_image::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::BorderImageOutset => {
                                            PropertyDeclaration::BorderImageOutset(
                                                longhands.border_image_outset
                                            )
                                        }
                                        LonghandId::BorderImageRepeat => {
                                            PropertyDeclaration::BorderImageRepeat(
                                                longhands.border_image_repeat
                                            )
                                        }
                                        LonghandId::BorderImageSlice => {
                                            PropertyDeclaration::BorderImageSlice(
                                                longhands.border_image_slice
                                            )
                                        }
                                        LonghandId::BorderImageSource => {
                                            PropertyDeclaration::BorderImageSource(
                                                longhands.border_image_source
                                            )
                                        }
                                        LonghandId::BorderImageWidth => {
                                            PropertyDeclaration::BorderImageWidth(
                                                longhands.border_image_width
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Overflow) => {
                            shorthands::overflow::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverflowX => {
                                            PropertyDeclaration::OverflowX(
                                                longhands.overflow_x
                                            )
                                        }
                                        LonghandId::OverflowY => {
                                            PropertyDeclaration::OverflowY(
                                                longhands.overflow_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::OverflowClipBox) => {
                            shorthands::overflow_clip_box::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverflowClipBoxBlock => {
                                            PropertyDeclaration::OverflowClipBoxBlock(
                                                longhands.overflow_clip_box_block
                                            )
                                        }
                                        LonghandId::OverflowClipBoxInline => {
                                            PropertyDeclaration::OverflowClipBoxInline(
                                                longhands.overflow_clip_box_inline
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Transition) => {
                            shorthands::transition::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TransitionProperty => {
                                            PropertyDeclaration::TransitionProperty(
                                                longhands.transition_property
                                            )
                                        }
                                        LonghandId::TransitionDuration => {
                                            PropertyDeclaration::TransitionDuration(
                                                longhands.transition_duration
                                            )
                                        }
                                        LonghandId::TransitionTimingFunction => {
                                            PropertyDeclaration::TransitionTimingFunction(
                                                longhands.transition_timing_function
                                            )
                                        }
                                        LonghandId::TransitionDelay => {
                                            PropertyDeclaration::TransitionDelay(
                                                longhands.transition_delay
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Animation) => {
                            shorthands::animation::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AnimationName => {
                                            PropertyDeclaration::AnimationName(
                                                longhands.animation_name
                                            )
                                        }
                                        LonghandId::AnimationDuration => {
                                            PropertyDeclaration::AnimationDuration(
                                                longhands.animation_duration
                                            )
                                        }
                                        LonghandId::AnimationTimingFunction => {
                                            PropertyDeclaration::AnimationTimingFunction(
                                                longhands.animation_timing_function
                                            )
                                        }
                                        LonghandId::AnimationDelay => {
                                            PropertyDeclaration::AnimationDelay(
                                                longhands.animation_delay
                                            )
                                        }
                                        LonghandId::AnimationIterationCount => {
                                            PropertyDeclaration::AnimationIterationCount(
                                                longhands.animation_iteration_count
                                            )
                                        }
                                        LonghandId::AnimationDirection => {
                                            PropertyDeclaration::AnimationDirection(
                                                longhands.animation_direction
                                            )
                                        }
                                        LonghandId::AnimationFillMode => {
                                            PropertyDeclaration::AnimationFillMode(
                                                longhands.animation_fill_mode
                                            )
                                        }
                                        LonghandId::AnimationPlayState => {
                                            PropertyDeclaration::AnimationPlayState(
                                                longhands.animation_play_state
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ScrollSnapType) => {
                            shorthands::scroll_snap_type::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ScrollSnapTypeX => {
                                            PropertyDeclaration::ScrollSnapTypeX(
                                                longhands.scroll_snap_type_x
                                            )
                                        }
                                        LonghandId::ScrollSnapTypeY => {
                                            PropertyDeclaration::ScrollSnapTypeY(
                                                longhands.scroll_snap_type_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::OverscrollBehavior) => {
                            shorthands::overscroll_behavior::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OverscrollBehaviorX => {
                                            PropertyDeclaration::OverscrollBehaviorX(
                                                longhands.overscroll_behavior_x
                                            )
                                        }
                                        LonghandId::OverscrollBehaviorY => {
                                            PropertyDeclaration::OverscrollBehaviorY(
                                                longhands.overscroll_behavior_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::MozTransform) => {
                            shorthands::_moz_transform::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::Transform => {
                                            PropertyDeclaration::Transform(
                                                longhands.transform
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Columns) => {
                            shorthands::columns::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ColumnWidth => {
                                            PropertyDeclaration::ColumnWidth(
                                                longhands.column_width
                                            )
                                        }
                                        LonghandId::ColumnCount => {
                                            PropertyDeclaration::ColumnCount(
                                                longhands.column_count
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ColumnRule) => {
                            shorthands::column_rule::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ColumnRuleWidth => {
                                            PropertyDeclaration::ColumnRuleWidth(
                                                longhands.column_rule_width
                                            )
                                        }
                                        LonghandId::ColumnRuleStyle => {
                                            PropertyDeclaration::ColumnRuleStyle(
                                                longhands.column_rule_style
                                            )
                                        }
                                        LonghandId::ColumnRuleColor => {
                                            PropertyDeclaration::ColumnRuleColor(
                                                longhands.column_rule_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Font) => {
                            shorthands::font::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FontStyle => {
                                            PropertyDeclaration::FontStyle(
                                                longhands.font_style
                                            )
                                        }
                                        LonghandId::FontVariantCaps => {
                                            PropertyDeclaration::FontVariantCaps(
                                                longhands.font_variant_caps
                                            )
                                        }
                                        LonghandId::FontWeight => {
                                            PropertyDeclaration::FontWeight(
                                                longhands.font_weight
                                            )
                                        }
                                        LonghandId::FontStretch => {
                                            PropertyDeclaration::FontStretch(
                                                longhands.font_stretch
                                            )
                                        }
                                        LonghandId::FontSize => {
                                            PropertyDeclaration::FontSize(
                                                longhands.font_size
                                            )
                                        }
                                        LonghandId::LineHeight => {
                                            PropertyDeclaration::LineHeight(
                                                longhands.line_height
                                            )
                                        }
                                        LonghandId::FontFamily => {
                                            PropertyDeclaration::FontFamily(
                                                longhands.font_family
                                            )
                                        }
                                        LonghandId::FontSizeAdjust => {
                                            PropertyDeclaration::FontSizeAdjust(
                                                longhands.font_size_adjust
                                            )
                                        }
                                        LonghandId::FontKerning => {
                                            PropertyDeclaration::FontKerning(
                                                longhands.font_kerning
                                            )
                                        }
                                        LonghandId::FontVariantAlternates => {
                                            PropertyDeclaration::FontVariantAlternates(
                                                longhands.font_variant_alternates
                                            )
                                        }
                                        LonghandId::FontVariantEastAsian => {
                                            PropertyDeclaration::FontVariantEastAsian(
                                                longhands.font_variant_east_asian
                                            )
                                        }
                                        LonghandId::FontVariantLigatures => {
                                            PropertyDeclaration::FontVariantLigatures(
                                                longhands.font_variant_ligatures
                                            )
                                        }
                                        LonghandId::FontVariantNumeric => {
                                            PropertyDeclaration::FontVariantNumeric(
                                                longhands.font_variant_numeric
                                            )
                                        }
                                        LonghandId::FontVariantPosition => {
                                            PropertyDeclaration::FontVariantPosition(
                                                longhands.font_variant_position
                                            )
                                        }
                                        LonghandId::FontLanguageOverride => {
                                            PropertyDeclaration::FontLanguageOverride(
                                                longhands.font_language_override
                                            )
                                        }
                                        LonghandId::FontFeatureSettings => {
                                            PropertyDeclaration::FontFeatureSettings(
                                                longhands.font_feature_settings
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::FontVariant) => {
                            shorthands::font_variant::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FontVariantCaps => {
                                            PropertyDeclaration::FontVariantCaps(
                                                longhands.font_variant_caps
                                            )
                                        }
                                        LonghandId::FontVariantAlternates => {
                                            PropertyDeclaration::FontVariantAlternates(
                                                longhands.font_variant_alternates
                                            )
                                        }
                                        LonghandId::FontVariantEastAsian => {
                                            PropertyDeclaration::FontVariantEastAsian(
                                                longhands.font_variant_east_asian
                                            )
                                        }
                                        LonghandId::FontVariantLigatures => {
                                            PropertyDeclaration::FontVariantLigatures(
                                                longhands.font_variant_ligatures
                                            )
                                        }
                                        LonghandId::FontVariantNumeric => {
                                            PropertyDeclaration::FontVariantNumeric(
                                                longhands.font_variant_numeric
                                            )
                                        }
                                        LonghandId::FontVariantPosition => {
                                            PropertyDeclaration::FontVariantPosition(
                                                longhands.font_variant_position
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::TextEmphasis) => {
                            shorthands::text_emphasis::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TextEmphasisStyle => {
                                            PropertyDeclaration::TextEmphasisStyle(
                                                longhands.text_emphasis_style
                                            )
                                        }
                                        LonghandId::TextEmphasisColor => {
                                            PropertyDeclaration::TextEmphasisColor(
                                                longhands.text_emphasis_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::WebkitTextStroke) => {
                            shorthands::_webkit_text_stroke::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::WebkitTextStrokeWidth => {
                                            PropertyDeclaration::WebkitTextStrokeWidth(
                                                longhands._webkit_text_stroke_width
                                            )
                                        }
                                        LonghandId::WebkitTextStrokeColor => {
                                            PropertyDeclaration::WebkitTextStrokeColor(
                                                longhands._webkit_text_stroke_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::ListStyle) => {
                            shorthands::list_style::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::ListStylePosition => {
                                            PropertyDeclaration::ListStylePosition(
                                                longhands.list_style_position
                                            )
                                        }
                                        LonghandId::ListStyleImage => {
                                            PropertyDeclaration::ListStyleImage(
                                                longhands.list_style_image
                                            )
                                        }
                                        LonghandId::ListStyleType => {
                                            PropertyDeclaration::ListStyleType(
                                                longhands.list_style_type
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Margin) => {
                            shorthands::margin::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MarginTop => {
                                            PropertyDeclaration::MarginTop(
                                                longhands.margin_top
                                            )
                                        }
                                        LonghandId::MarginRight => {
                                            PropertyDeclaration::MarginRight(
                                                longhands.margin_right
                                            )
                                        }
                                        LonghandId::MarginBottom => {
                                            PropertyDeclaration::MarginBottom(
                                                longhands.margin_bottom
                                            )
                                        }
                                        LonghandId::MarginLeft => {
                                            PropertyDeclaration::MarginLeft(
                                                longhands.margin_left
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Mask) => {
                            shorthands::mask::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MaskMode => {
                                            PropertyDeclaration::MaskMode(
                                                longhands.mask_mode
                                            )
                                        }
                                        LonghandId::MaskRepeat => {
                                            PropertyDeclaration::MaskRepeat(
                                                longhands.mask_repeat
                                            )
                                        }
                                        LonghandId::MaskClip => {
                                            PropertyDeclaration::MaskClip(
                                                longhands.mask_clip
                                            )
                                        }
                                        LonghandId::MaskOrigin => {
                                            PropertyDeclaration::MaskOrigin(
                                                longhands.mask_origin
                                            )
                                        }
                                        LonghandId::MaskComposite => {
                                            PropertyDeclaration::MaskComposite(
                                                longhands.mask_composite
                                            )
                                        }
                                        LonghandId::MaskPositionX => {
                                            PropertyDeclaration::MaskPositionX(
                                                longhands.mask_position_x
                                            )
                                        }
                                        LonghandId::MaskPositionY => {
                                            PropertyDeclaration::MaskPositionY(
                                                longhands.mask_position_y
                                            )
                                        }
                                        LonghandId::MaskSize => {
                                            PropertyDeclaration::MaskSize(
                                                longhands.mask_size
                                            )
                                        }
                                        LonghandId::MaskImage => {
                                            PropertyDeclaration::MaskImage(
                                                longhands.mask_image
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::MaskPosition) => {
                            shorthands::mask_position::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MaskPositionX => {
                                            PropertyDeclaration::MaskPositionX(
                                                longhands.mask_position_x
                                            )
                                        }
                                        LonghandId::MaskPositionY => {
                                            PropertyDeclaration::MaskPositionY(
                                                longhands.mask_position_y
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Outline) => {
                            shorthands::outline::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::OutlineWidth => {
                                            PropertyDeclaration::OutlineWidth(
                                                longhands.outline_width
                                            )
                                        }
                                        LonghandId::OutlineStyle => {
                                            PropertyDeclaration::OutlineStyle(
                                                longhands.outline_style
                                            )
                                        }
                                        LonghandId::OutlineColor => {
                                            PropertyDeclaration::OutlineColor(
                                                longhands.outline_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::MozOutlineRadius) => {
                            shorthands::_moz_outline_radius::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MozOutlineRadiusTopleft => {
                                            PropertyDeclaration::MozOutlineRadiusTopleft(
                                                longhands._moz_outline_radius_topleft
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusTopright => {
                                            PropertyDeclaration::MozOutlineRadiusTopright(
                                                longhands._moz_outline_radius_topright
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusBottomright => {
                                            PropertyDeclaration::MozOutlineRadiusBottomright(
                                                longhands._moz_outline_radius_bottomright
                                            )
                                        }
                                        LonghandId::MozOutlineRadiusBottomleft => {
                                            PropertyDeclaration::MozOutlineRadiusBottomleft(
                                                longhands._moz_outline_radius_bottomleft
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Padding) => {
                            shorthands::padding::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::PaddingTop => {
                                            PropertyDeclaration::PaddingTop(
                                                longhands.padding_top
                                            )
                                        }
                                        LonghandId::PaddingRight => {
                                            PropertyDeclaration::PaddingRight(
                                                longhands.padding_right
                                            )
                                        }
                                        LonghandId::PaddingBottom => {
                                            PropertyDeclaration::PaddingBottom(
                                                longhands.padding_bottom
                                            )
                                        }
                                        LonghandId::PaddingLeft => {
                                            PropertyDeclaration::PaddingLeft(
                                                longhands.padding_left
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::FlexFlow) => {
                            shorthands::flex_flow::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FlexDirection => {
                                            PropertyDeclaration::FlexDirection(
                                                longhands.flex_direction
                                            )
                                        }
                                        LonghandId::FlexWrap => {
                                            PropertyDeclaration::FlexWrap(
                                                longhands.flex_wrap
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Flex) => {
                            shorthands::flex::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::FlexGrow => {
                                            PropertyDeclaration::FlexGrow(
                                                longhands.flex_grow
                                            )
                                        }
                                        LonghandId::FlexShrink => {
                                            PropertyDeclaration::FlexShrink(
                                                longhands.flex_shrink
                                            )
                                        }
                                        LonghandId::FlexBasis => {
                                            PropertyDeclaration::FlexBasis(
                                                longhands.flex_basis
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridGap) => {
                            shorthands::grid_gap::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowGap => {
                                            PropertyDeclaration::GridRowGap(
                                                longhands.grid_row_gap
                                            )
                                        }
                                        LonghandId::GridColumnGap => {
                                            PropertyDeclaration::GridColumnGap(
                                                longhands.grid_column_gap
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridRow) => {
                            shorthands::grid_row::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowStart => {
                                            PropertyDeclaration::GridRowStart(
                                                longhands.grid_row_start
                                            )
                                        }
                                        LonghandId::GridRowEnd => {
                                            PropertyDeclaration::GridRowEnd(
                                                longhands.grid_row_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridColumn) => {
                            shorthands::grid_column::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridColumnStart => {
                                            PropertyDeclaration::GridColumnStart(
                                                longhands.grid_column_start
                                            )
                                        }
                                        LonghandId::GridColumnEnd => {
                                            PropertyDeclaration::GridColumnEnd(
                                                longhands.grid_column_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridArea) => {
                            shorthands::grid_area::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridRowStart => {
                                            PropertyDeclaration::GridRowStart(
                                                longhands.grid_row_start
                                            )
                                        }
                                        LonghandId::GridRowEnd => {
                                            PropertyDeclaration::GridRowEnd(
                                                longhands.grid_row_end
                                            )
                                        }
                                        LonghandId::GridColumnStart => {
                                            PropertyDeclaration::GridColumnStart(
                                                longhands.grid_column_start
                                            )
                                        }
                                        LonghandId::GridColumnEnd => {
                                            PropertyDeclaration::GridColumnEnd(
                                                longhands.grid_column_end
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::GridTemplate) => {
                            shorthands::grid_template::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridTemplateRows => {
                                            PropertyDeclaration::GridTemplateRows(
                                                longhands.grid_template_rows
                                            )
                                        }
                                        LonghandId::GridTemplateColumns => {
                                            PropertyDeclaration::GridTemplateColumns(
                                                longhands.grid_template_columns
                                            )
                                        }
                                        LonghandId::GridTemplateAreas => {
                                            PropertyDeclaration::GridTemplateAreas(
                                                longhands.grid_template_areas
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Grid) => {
                            shorthands::grid::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::GridTemplateRows => {
                                            PropertyDeclaration::GridTemplateRows(
                                                longhands.grid_template_rows
                                            )
                                        }
                                        LonghandId::GridTemplateColumns => {
                                            PropertyDeclaration::GridTemplateColumns(
                                                longhands.grid_template_columns
                                            )
                                        }
                                        LonghandId::GridTemplateAreas => {
                                            PropertyDeclaration::GridTemplateAreas(
                                                longhands.grid_template_areas
                                            )
                                        }
                                        LonghandId::GridAutoRows => {
                                            PropertyDeclaration::GridAutoRows(
                                                longhands.grid_auto_rows
                                            )
                                        }
                                        LonghandId::GridAutoColumns => {
                                            PropertyDeclaration::GridAutoColumns(
                                                longhands.grid_auto_columns
                                            )
                                        }
                                        LonghandId::GridAutoFlow => {
                                            PropertyDeclaration::GridAutoFlow(
                                                longhands.grid_auto_flow
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceContent) => {
                            shorthands::place_content::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignContent => {
                                            PropertyDeclaration::AlignContent(
                                                longhands.align_content
                                            )
                                        }
                                        LonghandId::JustifyContent => {
                                            PropertyDeclaration::JustifyContent(
                                                longhands.justify_content
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceSelf) => {
                            shorthands::place_self::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignSelf => {
                                            PropertyDeclaration::AlignSelf(
                                                longhands.align_self
                                            )
                                        }
                                        LonghandId::JustifySelf => {
                                            PropertyDeclaration::JustifySelf(
                                                longhands.justify_self
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::PlaceItems) => {
                            shorthands::place_items::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::AlignItems => {
                                            PropertyDeclaration::AlignItems(
                                                longhands.align_items
                                            )
                                        }
                                        LonghandId::JustifyItems => {
                                            PropertyDeclaration::JustifyItems(
                                                longhands.justify_items
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::Marker) => {
                            shorthands::marker::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::MarkerStart => {
                                            PropertyDeclaration::MarkerStart(
                                                longhands.marker_start
                                            )
                                        }
                                        LonghandId::MarkerEnd => {
                                            PropertyDeclaration::MarkerEnd(
                                                longhands.marker_end
                                            )
                                        }
                                        LonghandId::MarkerMid => {
                                            PropertyDeclaration::MarkerMid(
                                                longhands.marker_mid
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                        Some(ShorthandId::TextDecoration) => {
                            shorthands::text_decoration::parse_value(&context, input)
                            .map(|longhands| {
                                match longhand_id {
                                        LonghandId::TextDecorationLine => {
                                            PropertyDeclaration::TextDecorationLine(
                                                longhands.text_decoration_line
                                            )
                                        }
                                        LonghandId::TextDecorationStyle => {
                                            PropertyDeclaration::TextDecorationStyle(
                                                longhands.text_decoration_style
                                            )
                                        }
                                        LonghandId::TextDecorationColor => {
                                            PropertyDeclaration::TextDecorationColor(
                                                longhands.text_decoration_color
                                            )
                                        }
                                    _ => unreachable!()
                                }
                            })
                        }
                }
            })
            .ok()
        })
        .unwrap_or_else(|| {
            // Invalid at computed-value time.
            let keyword = if longhand_id.inherited() {
                CSSWideKeyword::Inherit
            } else {
                CSSWideKeyword::Initial
            };
            PropertyDeclaration::CSSWideKeyword(longhand_id, keyword)
        })
    }
}

impl<'a, T: ToCss> ToCss for DeclaredValue<'a, T> {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            DeclaredValue::Value(ref inner) => inner.to_css(dest),
            DeclaredValue::WithVariables(ref with_variables) => {
                // https://drafts.csswg.org/css-variables/#variables-in-shorthands
                if with_variables.from_shorthand.is_none() {
                    dest.write_str(&*with_variables.css)?
                }
                Ok(())
            },
            DeclaredValue::CSSWideKeyword(ref keyword) => keyword.to_css(dest),
        }
    }
}

/// An identifier for a given property declaration, which can be either a
/// longhand or a custom property.
#[derive(Clone, Copy, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum PropertyDeclarationId<'a> {
    /// A longhand.
    Longhand(LonghandId),
    /// A custom property declaration.
    Custom(&'a ::custom_properties::Name),
}

impl<'a> ToCss for PropertyDeclarationId<'a> {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            PropertyDeclarationId::Longhand(id) => dest.write_str(id.name()),
            PropertyDeclarationId::Custom(_) => {
                serialize_identifier(&self.name(), dest)
            }
        }
    }
}

impl<'a> PropertyDeclarationId<'a> {
    /// Whether a given declaration id is either the same as `other`, or a
    /// longhand of it.
    pub fn is_or_is_longhand_of(&self, other: &PropertyId) -> bool {
        match *self {
            PropertyDeclarationId::Longhand(id) => {
                match *other {
                    PropertyId::Longhand(other_id) |
                    PropertyId::LonghandAlias(other_id, _) => id == other_id,
                    PropertyId::Shorthand(shorthand) |
                    PropertyId::ShorthandAlias(shorthand, _) => self.is_longhand_of(shorthand),
                    PropertyId::Custom(_) => false,
                }
            }
            PropertyDeclarationId::Custom(name) => {
                matches!(*other, PropertyId::Custom(ref other_name) if name == other_name)
            }
        }
    }

    /// Whether a given declaration id is a longhand belonging to this
    /// shorthand.
    pub fn is_longhand_of(&self, shorthand: ShorthandId) -> bool {
        match *self {
            PropertyDeclarationId::Longhand(ref id) => id.shorthands().contains(&shorthand),
            _ => false,
        }
    }

    /// Returns the name of the property without CSS escaping.
    pub fn name(&self) -> Cow<'static, str> {
        match *self {
            PropertyDeclarationId::Longhand(id) => id.name().into(),
            PropertyDeclarationId::Custom(name) => {
                let mut s = String::new();
                write!(&mut s, "--{}", name).unwrap();
                s.into()
            }
        }
    }
}

/// Servo's representation of a CSS property, that is, either a longhand, a
/// shorthand, or a custom property.
#[derive(Clone, Eq, PartialEq)]
pub enum PropertyId {
    /// A longhand property.
    Longhand(LonghandId),
    /// A shorthand property.
    Shorthand(ShorthandId),
    /// An alias for a longhand property.
    LonghandAlias(LonghandId, AliasId),
    /// An alias for a shorthand property.
    ShorthandAlias(ShorthandId, AliasId),
    /// A custom property.
    Custom(::custom_properties::Name),
}

impl fmt::Debug for PropertyId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        self.to_css(&mut CssWriter::new(formatter))
    }
}

impl ToCss for PropertyId {
    fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
    where
        W: Write,
    {
        match *self {
            PropertyId::Longhand(id) => dest.write_str(id.name()),
            PropertyId::Shorthand(id) => dest.write_str(id.name()),
            PropertyId::LonghandAlias(id, _) => dest.write_str(id.name()),
            PropertyId::ShorthandAlias(id, _) => dest.write_str(id.name()),
            PropertyId::Custom(_) => {
                serialize_identifier(&self.name(), dest)
            }
        }
    }
}

impl PropertyId {
    /// Return the longhand id that this property id represents.
    #[inline]
    pub fn longhand_id(&self) -> Option<LonghandId> {
        Some(match *self {
            PropertyId::Longhand(id) => id,
            PropertyId::LonghandAlias(id, _) => id,
            _ => return None,
        })
    }

    /// Returns a given property from the string `s`.
    ///
    /// Returns Err(()) for unknown non-custom properties.
    pub fn parse(property_name: &str) -> Result<Self, ()> {
        // FIXME(https://github.com/rust-lang/rust/issues/33156): remove this
        // enum and use PropertyId when stable Rust allows destructors in
        // statics.
        //
        // ShorthandAlias is not used in the Servo build.
        // That's why we need to allow dead_code.
        #[allow(dead_code)]
        pub enum StaticId {
            Longhand(LonghandId),
            Shorthand(ShorthandId),
            LonghandAlias(LonghandId, AliasId),
            ShorthandAlias(ShorthandId, AliasId),
        }
        ascii_case_insensitive_phf_map! {
            static_id -> StaticId = {
                        "background-color" => StaticId::Longhand(LonghandId::BackgroundColor),
                        "background-image" => StaticId::Longhand(LonghandId::BackgroundImage),
                        "background-position-x" => StaticId::Longhand(LonghandId::BackgroundPositionX),
                        "background-position-y" => StaticId::Longhand(LonghandId::BackgroundPositionY),
                        "background-repeat" => StaticId::Longhand(LonghandId::BackgroundRepeat),
                        "background-attachment" => StaticId::Longhand(LonghandId::BackgroundAttachment),
                        "background-clip" => StaticId::Longhand(LonghandId::BackgroundClip),
                            "-webkit-background-clip" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundClip,
                                                       AliasId::WebkitBackgroundClip)
                            },
                        "background-origin" => StaticId::Longhand(LonghandId::BackgroundOrigin),
                            "-webkit-background-origin" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundOrigin,
                                                       AliasId::WebkitBackgroundOrigin)
                            },
                        "background-size" => StaticId::Longhand(LonghandId::BackgroundSize),
                            "-webkit-background-size" => {
                                StaticId::LonghandAlias(LonghandId::BackgroundSize,
                                                       AliasId::WebkitBackgroundSize)
                            },
                        "background-blend-mode" => StaticId::Longhand(LonghandId::BackgroundBlendMode),
                        "border-top-color" => StaticId::Longhand(LonghandId::BorderTopColor),
                        "border-top-style" => StaticId::Longhand(LonghandId::BorderTopStyle),
                        "border-top-width" => StaticId::Longhand(LonghandId::BorderTopWidth),
                        "border-left-color" => StaticId::Longhand(LonghandId::BorderLeftColor),
                        "border-left-style" => StaticId::Longhand(LonghandId::BorderLeftStyle),
                        "border-left-width" => StaticId::Longhand(LonghandId::BorderLeftWidth),
                        "border-bottom-color" => StaticId::Longhand(LonghandId::BorderBottomColor),
                        "border-bottom-style" => StaticId::Longhand(LonghandId::BorderBottomStyle),
                        "border-bottom-width" => StaticId::Longhand(LonghandId::BorderBottomWidth),
                        "border-right-color" => StaticId::Longhand(LonghandId::BorderRightColor),
                        "border-right-style" => StaticId::Longhand(LonghandId::BorderRightStyle),
                        "border-right-width" => StaticId::Longhand(LonghandId::BorderRightWidth),
                        "border-block-start-color" => StaticId::Longhand(LonghandId::BorderBlockStartColor),
                        "border-block-start-style" => StaticId::Longhand(LonghandId::BorderBlockStartStyle),
                        "border-block-start-width" => StaticId::Longhand(LonghandId::BorderBlockStartWidth),
                        "border-block-end-color" => StaticId::Longhand(LonghandId::BorderBlockEndColor),
                        "border-block-end-style" => StaticId::Longhand(LonghandId::BorderBlockEndStyle),
                        "border-block-end-width" => StaticId::Longhand(LonghandId::BorderBlockEndWidth),
                        "border-inline-start-color" => StaticId::Longhand(LonghandId::BorderInlineStartColor),
                            "-moz-border-start-color" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartColor,
                                                       AliasId::MozBorderStartColor)
                            },
                        "border-inline-start-style" => StaticId::Longhand(LonghandId::BorderInlineStartStyle),
                            "-moz-border-start-style" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartStyle,
                                                       AliasId::MozBorderStartStyle)
                            },
                        "border-inline-start-width" => StaticId::Longhand(LonghandId::BorderInlineStartWidth),
                            "-moz-border-start-width" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineStartWidth,
                                                       AliasId::MozBorderStartWidth)
                            },
                        "border-inline-end-color" => StaticId::Longhand(LonghandId::BorderInlineEndColor),
                            "-moz-border-end-color" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndColor,
                                                       AliasId::MozBorderEndColor)
                            },
                        "border-inline-end-style" => StaticId::Longhand(LonghandId::BorderInlineEndStyle),
                            "-moz-border-end-style" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndStyle,
                                                       AliasId::MozBorderEndStyle)
                            },
                        "border-inline-end-width" => StaticId::Longhand(LonghandId::BorderInlineEndWidth),
                            "-moz-border-end-width" => {
                                StaticId::LonghandAlias(LonghandId::BorderInlineEndWidth,
                                                       AliasId::MozBorderEndWidth)
                            },
                        "border-top-left-radius" => StaticId::Longhand(LonghandId::BorderTopLeftRadius),
                            "-webkit-border-top-left-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderTopLeftRadius,
                                                       AliasId::WebkitBorderTopLeftRadius)
                            },
                        "border-top-right-radius" => StaticId::Longhand(LonghandId::BorderTopRightRadius),
                            "-webkit-border-top-right-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderTopRightRadius,
                                                       AliasId::WebkitBorderTopRightRadius)
                            },
                        "border-bottom-right-radius" => StaticId::Longhand(LonghandId::BorderBottomRightRadius),
                            "-webkit-border-bottom-right-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderBottomRightRadius,
                                                       AliasId::WebkitBorderBottomRightRadius)
                            },
                        "border-bottom-left-radius" => StaticId::Longhand(LonghandId::BorderBottomLeftRadius),
                            "-webkit-border-bottom-left-radius" => {
                                StaticId::LonghandAlias(LonghandId::BorderBottomLeftRadius,
                                                       AliasId::WebkitBorderBottomLeftRadius)
                            },
                        "-moz-border-top-colors" => StaticId::Longhand(LonghandId::MozBorderTopColors),
                        "-moz-border-left-colors" => StaticId::Longhand(LonghandId::MozBorderLeftColors),
                        "-moz-border-bottom-colors" => StaticId::Longhand(LonghandId::MozBorderBottomColors),
                        "-moz-border-right-colors" => StaticId::Longhand(LonghandId::MozBorderRightColors),
                        "box-decoration-break" => StaticId::Longhand(LonghandId::BoxDecorationBreak),
                        "-moz-float-edge" => StaticId::Longhand(LonghandId::MozFloatEdge),
                        "border-image-source" => StaticId::Longhand(LonghandId::BorderImageSource),
                        "border-image-outset" => StaticId::Longhand(LonghandId::BorderImageOutset),
                        "border-image-repeat" => StaticId::Longhand(LonghandId::BorderImageRepeat),
                        "border-image-width" => StaticId::Longhand(LonghandId::BorderImageWidth),
                        "border-image-slice" => StaticId::Longhand(LonghandId::BorderImageSlice),
                        "display" => StaticId::Longhand(LonghandId::Display),
                        "-moz-top-layer" => StaticId::Longhand(LonghandId::MozTopLayer),
                        "position" => StaticId::Longhand(LonghandId::Position),
                        "float" => StaticId::Longhand(LonghandId::Float),
                        "clear" => StaticId::Longhand(LonghandId::Clear),
                        "vertical-align" => StaticId::Longhand(LonghandId::VerticalAlign),
                        "overflow-clip-box-inline" => StaticId::Longhand(LonghandId::OverflowClipBoxInline),
                        "overflow-clip-box-block" => StaticId::Longhand(LonghandId::OverflowClipBoxBlock),
                        "overflow-x" => StaticId::Longhand(LonghandId::OverflowX),
                        "overflow-y" => StaticId::Longhand(LonghandId::OverflowY),
                        "transition-duration" => StaticId::Longhand(LonghandId::TransitionDuration),
                            "-moz-transition-duration" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDuration,
                                                       AliasId::MozTransitionDuration)
                            },
                            "-webkit-transition-duration" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDuration,
                                                       AliasId::WebkitTransitionDuration)
                            },
                        "transition-timing-function" => StaticId::Longhand(LonghandId::TransitionTimingFunction),
                            "-moz-transition-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::TransitionTimingFunction,
                                                       AliasId::MozTransitionTimingFunction)
                            },
                            "-webkit-transition-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::TransitionTimingFunction,
                                                       AliasId::WebkitTransitionTimingFunction)
                            },
                        "transition-property" => StaticId::Longhand(LonghandId::TransitionProperty),
                            "-moz-transition-property" => {
                                StaticId::LonghandAlias(LonghandId::TransitionProperty,
                                                       AliasId::MozTransitionProperty)
                            },
                            "-webkit-transition-property" => {
                                StaticId::LonghandAlias(LonghandId::TransitionProperty,
                                                       AliasId::WebkitTransitionProperty)
                            },
                        "transition-delay" => StaticId::Longhand(LonghandId::TransitionDelay),
                            "-moz-transition-delay" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDelay,
                                                       AliasId::MozTransitionDelay)
                            },
                            "-webkit-transition-delay" => {
                                StaticId::LonghandAlias(LonghandId::TransitionDelay,
                                                       AliasId::WebkitTransitionDelay)
                            },
                        "animation-name" => StaticId::Longhand(LonghandId::AnimationName),
                            "-moz-animation-name" => {
                                StaticId::LonghandAlias(LonghandId::AnimationName,
                                                       AliasId::MozAnimationName)
                            },
                            "-webkit-animation-name" => {
                                StaticId::LonghandAlias(LonghandId::AnimationName,
                                                       AliasId::WebkitAnimationName)
                            },
                        "animation-duration" => StaticId::Longhand(LonghandId::AnimationDuration),
                            "-moz-animation-duration" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDuration,
                                                       AliasId::MozAnimationDuration)
                            },
                            "-webkit-animation-duration" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDuration,
                                                       AliasId::WebkitAnimationDuration)
                            },
                        "animation-timing-function" => StaticId::Longhand(LonghandId::AnimationTimingFunction),
                            "-moz-animation-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::AnimationTimingFunction,
                                                       AliasId::MozAnimationTimingFunction)
                            },
                            "-webkit-animation-timing-function" => {
                                StaticId::LonghandAlias(LonghandId::AnimationTimingFunction,
                                                       AliasId::WebkitAnimationTimingFunction)
                            },
                        "animation-iteration-count" => StaticId::Longhand(LonghandId::AnimationIterationCount),
                            "-moz-animation-iteration-count" => {
                                StaticId::LonghandAlias(LonghandId::AnimationIterationCount,
                                                       AliasId::MozAnimationIterationCount)
                            },
                            "-webkit-animation-iteration-count" => {
                                StaticId::LonghandAlias(LonghandId::AnimationIterationCount,
                                                       AliasId::WebkitAnimationIterationCount)
                            },
                        "animation-direction" => StaticId::Longhand(LonghandId::AnimationDirection),
                            "-moz-animation-direction" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDirection,
                                                       AliasId::MozAnimationDirection)
                            },
                            "-webkit-animation-direction" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDirection,
                                                       AliasId::WebkitAnimationDirection)
                            },
                        "animation-play-state" => StaticId::Longhand(LonghandId::AnimationPlayState),
                            "-moz-animation-play-state" => {
                                StaticId::LonghandAlias(LonghandId::AnimationPlayState,
                                                       AliasId::MozAnimationPlayState)
                            },
                            "-webkit-animation-play-state" => {
                                StaticId::LonghandAlias(LonghandId::AnimationPlayState,
                                                       AliasId::WebkitAnimationPlayState)
                            },
                        "animation-fill-mode" => StaticId::Longhand(LonghandId::AnimationFillMode),
                            "-moz-animation-fill-mode" => {
                                StaticId::LonghandAlias(LonghandId::AnimationFillMode,
                                                       AliasId::MozAnimationFillMode)
                            },
                            "-webkit-animation-fill-mode" => {
                                StaticId::LonghandAlias(LonghandId::AnimationFillMode,
                                                       AliasId::WebkitAnimationFillMode)
                            },
                        "animation-delay" => StaticId::Longhand(LonghandId::AnimationDelay),
                            "-moz-animation-delay" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDelay,
                                                       AliasId::MozAnimationDelay)
                            },
                            "-webkit-animation-delay" => {
                                StaticId::LonghandAlias(LonghandId::AnimationDelay,
                                                       AliasId::WebkitAnimationDelay)
                            },
                        "scroll-snap-points-x" => StaticId::Longhand(LonghandId::ScrollSnapPointsX),
                        "scroll-snap-points-y" => StaticId::Longhand(LonghandId::ScrollSnapPointsY),
                        "scroll-snap-destination" => StaticId::Longhand(LonghandId::ScrollSnapDestination),
                        "scroll-snap-coordinate" => StaticId::Longhand(LonghandId::ScrollSnapCoordinate),
                        "transform" => StaticId::Longhand(LonghandId::Transform),
                            "-webkit-transform" => {
                                StaticId::LonghandAlias(LonghandId::Transform,
                                                       AliasId::WebkitTransform)
                            },
                        "scroll-behavior" => StaticId::Longhand(LonghandId::ScrollBehavior),
                        "scroll-snap-type-x" => StaticId::Longhand(LonghandId::ScrollSnapTypeX),
                        "scroll-snap-type-y" => StaticId::Longhand(LonghandId::ScrollSnapTypeY),
                        "overscroll-behavior-x" => StaticId::Longhand(LonghandId::OverscrollBehaviorX),
                        "overscroll-behavior-y" => StaticId::Longhand(LonghandId::OverscrollBehaviorY),
                        "isolation" => StaticId::Longhand(LonghandId::Isolation),
                        "page-break-after" => StaticId::Longhand(LonghandId::PageBreakAfter),
                        "page-break-before" => StaticId::Longhand(LonghandId::PageBreakBefore),
                        "page-break-inside" => StaticId::Longhand(LonghandId::PageBreakInside),
                        "resize" => StaticId::Longhand(LonghandId::Resize),
                        "perspective" => StaticId::Longhand(LonghandId::Perspective),
                            "-moz-perspective" => {
                                StaticId::LonghandAlias(LonghandId::Perspective,
                                                       AliasId::MozPerspective)
                            },
                            "-webkit-perspective" => {
                                StaticId::LonghandAlias(LonghandId::Perspective,
                                                       AliasId::WebkitPerspective)
                            },
                        "perspective-origin" => StaticId::Longhand(LonghandId::PerspectiveOrigin),
                            "-moz-perspective-origin" => {
                                StaticId::LonghandAlias(LonghandId::PerspectiveOrigin,
                                                       AliasId::MozPerspectiveOrigin)
                            },
                            "-webkit-perspective-origin" => {
                                StaticId::LonghandAlias(LonghandId::PerspectiveOrigin,
                                                       AliasId::WebkitPerspectiveOrigin)
                            },
                        "backface-visibility" => StaticId::Longhand(LonghandId::BackfaceVisibility),
                            "-moz-backface-visibility" => {
                                StaticId::LonghandAlias(LonghandId::BackfaceVisibility,
                                                       AliasId::MozBackfaceVisibility)
                            },
                            "-webkit-backface-visibility" => {
                                StaticId::LonghandAlias(LonghandId::BackfaceVisibility,
                                                       AliasId::WebkitBackfaceVisibility)
                            },
                        "transform-box" => StaticId::Longhand(LonghandId::TransformBox),
                        "transform-style" => StaticId::Longhand(LonghandId::TransformStyle),
                            "-moz-transform-style" => {
                                StaticId::LonghandAlias(LonghandId::TransformStyle,
                                                       AliasId::MozTransformStyle)
                            },
                            "-webkit-transform-style" => {
                                StaticId::LonghandAlias(LonghandId::TransformStyle,
                                                       AliasId::WebkitTransformStyle)
                            },
                        "transform-origin" => StaticId::Longhand(LonghandId::TransformOrigin),
                            "-moz-transform-origin" => {
                                StaticId::LonghandAlias(LonghandId::TransformOrigin,
                                                       AliasId::MozTransformOrigin)
                            },
                            "-webkit-transform-origin" => {
                                StaticId::LonghandAlias(LonghandId::TransformOrigin,
                                                       AliasId::WebkitTransformOrigin)
                            },
                        "contain" => StaticId::Longhand(LonghandId::Contain),
                        "-moz-appearance" => StaticId::Longhand(LonghandId::MozAppearance),
                        "-moz-binding" => StaticId::Longhand(LonghandId::MozBinding),
                        "-moz-orient" => StaticId::Longhand(LonghandId::MozOrient),
                        "will-change" => StaticId::Longhand(LonghandId::WillChange),
                        "shape-image-threshold" => StaticId::Longhand(LonghandId::ShapeImageThreshold),
                        "shape-outside" => StaticId::Longhand(LonghandId::ShapeOutside),
                        "touch-action" => StaticId::Longhand(LonghandId::TouchAction),
                        "color" => StaticId::Longhand(LonghandId::Color),
                        "column-width" => StaticId::Longhand(LonghandId::ColumnWidth),
                            "-moz-column-width" => {
                                StaticId::LonghandAlias(LonghandId::ColumnWidth,
                                                       AliasId::MozColumnWidth)
                            },
                        "column-count" => StaticId::Longhand(LonghandId::ColumnCount),
                            "-moz-column-count" => {
                                StaticId::LonghandAlias(LonghandId::ColumnCount,
                                                       AliasId::MozColumnCount)
                            },
                        "column-gap" => StaticId::Longhand(LonghandId::ColumnGap),
                            "-moz-column-gap" => {
                                StaticId::LonghandAlias(LonghandId::ColumnGap,
                                                       AliasId::MozColumnGap)
                            },
                        "column-fill" => StaticId::Longhand(LonghandId::ColumnFill),
                            "-moz-column-fill" => {
                                StaticId::LonghandAlias(LonghandId::ColumnFill,
                                                       AliasId::MozColumnFill)
                            },
                        "column-rule-width" => StaticId::Longhand(LonghandId::ColumnRuleWidth),
                            "-moz-column-rule-width" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleWidth,
                                                       AliasId::MozColumnRuleWidth)
                            },
                        "column-rule-color" => StaticId::Longhand(LonghandId::ColumnRuleColor),
                            "-moz-column-rule-color" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleColor,
                                                       AliasId::MozColumnRuleColor)
                            },
                        "column-span" => StaticId::Longhand(LonghandId::ColumnSpan),
                            "-moz-column-span" => {
                                StaticId::LonghandAlias(LonghandId::ColumnSpan,
                                                       AliasId::MozColumnSpan)
                            },
                        "column-rule-style" => StaticId::Longhand(LonghandId::ColumnRuleStyle),
                            "-moz-column-rule-style" => {
                                StaticId::LonghandAlias(LonghandId::ColumnRuleStyle,
                                                       AliasId::MozColumnRuleStyle)
                            },
                        "content" => StaticId::Longhand(LonghandId::Content),
                        "counter-increment" => StaticId::Longhand(LonghandId::CounterIncrement),
                        "counter-reset" => StaticId::Longhand(LonghandId::CounterReset),
                        "opacity" => StaticId::Longhand(LonghandId::Opacity),
                        "box-shadow" => StaticId::Longhand(LonghandId::BoxShadow),
                            "-webkit-box-shadow" => {
                                StaticId::LonghandAlias(LonghandId::BoxShadow,
                                                       AliasId::WebkitBoxShadow)
                            },
                        "clip" => StaticId::Longhand(LonghandId::Clip),
                        "filter" => StaticId::Longhand(LonghandId::Filter),
                            "-webkit-filter" => {
                                StaticId::LonghandAlias(LonghandId::Filter,
                                                       AliasId::WebkitFilter)
                            },
                        "mix-blend-mode" => StaticId::Longhand(LonghandId::MixBlendMode),
                        "font-family" => StaticId::Longhand(LonghandId::FontFamily),
                        "font-style" => StaticId::Longhand(LonghandId::FontStyle),
                        "font-variant-caps" => StaticId::Longhand(LonghandId::FontVariantCaps),
                        "font-weight" => StaticId::Longhand(LonghandId::FontWeight),
                        "font-size" => StaticId::Longhand(LonghandId::FontSize),
                        "font-size-adjust" => StaticId::Longhand(LonghandId::FontSizeAdjust),
                        "font-synthesis" => StaticId::Longhand(LonghandId::FontSynthesis),
                        "font-stretch" => StaticId::Longhand(LonghandId::FontStretch),
                        "font-kerning" => StaticId::Longhand(LonghandId::FontKerning),
                        "font-variant-alternates" => StaticId::Longhand(LonghandId::FontVariantAlternates),
                        "font-variant-east-asian" => StaticId::Longhand(LonghandId::FontVariantEastAsian),
                        "font-variant-ligatures" => StaticId::Longhand(LonghandId::FontVariantLigatures),
                        "font-variant-numeric" => StaticId::Longhand(LonghandId::FontVariantNumeric),
                        "font-variant-position" => StaticId::Longhand(LonghandId::FontVariantPosition),
                        "font-feature-settings" => StaticId::Longhand(LonghandId::FontFeatureSettings),
                            "-moz-font-feature-settings" => {
                                StaticId::LonghandAlias(LonghandId::FontFeatureSettings,
                                                       AliasId::MozFontFeatureSettings)
                            },
                        "font-variation-settings" => StaticId::Longhand(LonghandId::FontVariationSettings),
                        "font-language-override" => StaticId::Longhand(LonghandId::FontLanguageOverride),
                            "-moz-font-language-override" => {
                                StaticId::LonghandAlias(LonghandId::FontLanguageOverride,
                                                       AliasId::MozFontLanguageOverride)
                            },
                        "-x-lang" => StaticId::Longhand(LonghandId::XLang),
                        "-moz-script-size-multiplier" => StaticId::Longhand(LonghandId::MozScriptSizeMultiplier),
                        "-moz-script-level" => StaticId::Longhand(LonghandId::MozScriptLevel),
                        "-moz-math-display" => StaticId::Longhand(LonghandId::MozMathDisplay),
                        "-moz-math-variant" => StaticId::Longhand(LonghandId::MozMathVariant),
                        "-moz-script-min-size" => StaticId::Longhand(LonghandId::MozScriptMinSize),
                        "-x-text-zoom" => StaticId::Longhand(LonghandId::XTextZoom),
                        "-moz-osx-font-smoothing" => StaticId::Longhand(LonghandId::MozOsxFontSmoothing),
                        "-moz-font-smoothing-background-color" => StaticId::Longhand(LonghandId::MozFontSmoothingBackgroundColor),
                        "-moz-min-font-size-ratio" => StaticId::Longhand(LonghandId::MozMinFontSizeRatio),
                        "visibility" => StaticId::Longhand(LonghandId::Visibility),
                        "writing-mode" => StaticId::Longhand(LonghandId::WritingMode),
                        "direction" => StaticId::Longhand(LonghandId::Direction),
                        "text-orientation" => StaticId::Longhand(LonghandId::TextOrientation),
                        "color-adjust" => StaticId::Longhand(LonghandId::ColorAdjust),
                        "image-rendering" => StaticId::Longhand(LonghandId::ImageRendering),
                        "image-orientation" => StaticId::Longhand(LonghandId::ImageOrientation),
                        "border-collapse" => StaticId::Longhand(LonghandId::BorderCollapse),
                        "empty-cells" => StaticId::Longhand(LonghandId::EmptyCells),
                        "caption-side" => StaticId::Longhand(LonghandId::CaptionSide),
                        "border-spacing" => StaticId::Longhand(LonghandId::BorderSpacing),
                        "line-height" => StaticId::Longhand(LonghandId::LineHeight),
                        "text-transform" => StaticId::Longhand(LonghandId::TextTransform),
                        "hyphens" => StaticId::Longhand(LonghandId::Hyphens),
                            "-moz-hyphens" => {
                                StaticId::LonghandAlias(LonghandId::Hyphens,
                                                       AliasId::MozHyphens)
                            },
                        "-moz-text-size-adjust" => StaticId::Longhand(LonghandId::MozTextSizeAdjust),
                            "-webkit-text-size-adjust" => {
                                StaticId::LonghandAlias(LonghandId::MozTextSizeAdjust,
                                                       AliasId::WebkitTextSizeAdjust)
                            },
                        "text-indent" => StaticId::Longhand(LonghandId::TextIndent),
                        "overflow-wrap" => StaticId::Longhand(LonghandId::OverflowWrap),
                            "word-wrap" => {
                                StaticId::LonghandAlias(LonghandId::OverflowWrap,
                                                       AliasId::WordWrap)
                            },
                        "word-break" => StaticId::Longhand(LonghandId::WordBreak),
                        "text-justify" => StaticId::Longhand(LonghandId::TextJustify),
                        "text-align-last" => StaticId::Longhand(LonghandId::TextAlignLast),
                        "text-align" => StaticId::Longhand(LonghandId::TextAlign),
                        "letter-spacing" => StaticId::Longhand(LonghandId::LetterSpacing),
                        "word-spacing" => StaticId::Longhand(LonghandId::WordSpacing),
                        "white-space" => StaticId::Longhand(LonghandId::WhiteSpace),
                        "text-shadow" => StaticId::Longhand(LonghandId::TextShadow),
                        "text-emphasis-style" => StaticId::Longhand(LonghandId::TextEmphasisStyle),
                        "text-emphasis-position" => StaticId::Longhand(LonghandId::TextEmphasisPosition),
                        "text-emphasis-color" => StaticId::Longhand(LonghandId::TextEmphasisColor),
                        "-moz-tab-size" => StaticId::Longhand(LonghandId::MozTabSize),
                        "-webkit-text-fill-color" => StaticId::Longhand(LonghandId::WebkitTextFillColor),
                        "-webkit-text-stroke-color" => StaticId::Longhand(LonghandId::WebkitTextStrokeColor),
                        "-webkit-text-stroke-width" => StaticId::Longhand(LonghandId::WebkitTextStrokeWidth),
                        "ruby-align" => StaticId::Longhand(LonghandId::RubyAlign),
                        "ruby-position" => StaticId::Longhand(LonghandId::RubyPosition),
                        "text-combine-upright" => StaticId::Longhand(LonghandId::TextCombineUpright),
                        "text-rendering" => StaticId::Longhand(LonghandId::TextRendering),
                        "-moz-control-character-visibility" => StaticId::Longhand(LonghandId::MozControlCharacterVisibility),
                        "list-style-position" => StaticId::Longhand(LonghandId::ListStylePosition),
                        "list-style-type" => StaticId::Longhand(LonghandId::ListStyleType),
                        "list-style-image" => StaticId::Longhand(LonghandId::ListStyleImage),
                        "quotes" => StaticId::Longhand(LonghandId::Quotes),
                        "-moz-image-region" => StaticId::Longhand(LonghandId::MozImageRegion),
                        "margin-top" => StaticId::Longhand(LonghandId::MarginTop),
                        "margin-left" => StaticId::Longhand(LonghandId::MarginLeft),
                        "margin-bottom" => StaticId::Longhand(LonghandId::MarginBottom),
                        "margin-right" => StaticId::Longhand(LonghandId::MarginRight),
                        "margin-block-start" => StaticId::Longhand(LonghandId::MarginBlockStart),
                        "margin-block-end" => StaticId::Longhand(LonghandId::MarginBlockEnd),
                        "margin-inline-start" => StaticId::Longhand(LonghandId::MarginInlineStart),
                            "-moz-margin-start" => {
                                StaticId::LonghandAlias(LonghandId::MarginInlineStart,
                                                       AliasId::MozMarginStart)
                            },
                        "margin-inline-end" => StaticId::Longhand(LonghandId::MarginInlineEnd),
                            "-moz-margin-end" => {
                                StaticId::LonghandAlias(LonghandId::MarginInlineEnd,
                                                       AliasId::MozMarginEnd)
                            },
                        "outline-color" => StaticId::Longhand(LonghandId::OutlineColor),
                        "outline-style" => StaticId::Longhand(LonghandId::OutlineStyle),
                        "outline-width" => StaticId::Longhand(LonghandId::OutlineWidth),
                        "-moz-outline-radius-topleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopleft),
                        "-moz-outline-radius-topright" => StaticId::Longhand(LonghandId::MozOutlineRadiusTopright),
                        "-moz-outline-radius-bottomright" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomright),
                        "-moz-outline-radius-bottomleft" => StaticId::Longhand(LonghandId::MozOutlineRadiusBottomleft),
                        "outline-offset" => StaticId::Longhand(LonghandId::OutlineOffset),
                        "padding-top" => StaticId::Longhand(LonghandId::PaddingTop),
                        "padding-left" => StaticId::Longhand(LonghandId::PaddingLeft),
                        "padding-bottom" => StaticId::Longhand(LonghandId::PaddingBottom),
                        "padding-right" => StaticId::Longhand(LonghandId::PaddingRight),
                        "padding-block-start" => StaticId::Longhand(LonghandId::PaddingBlockStart),
                        "padding-block-end" => StaticId::Longhand(LonghandId::PaddingBlockEnd),
                        "padding-inline-start" => StaticId::Longhand(LonghandId::PaddingInlineStart),
                            "-moz-padding-start" => {
                                StaticId::LonghandAlias(LonghandId::PaddingInlineStart,
                                                       AliasId::MozPaddingStart)
                            },
                        "padding-inline-end" => StaticId::Longhand(LonghandId::PaddingInlineEnd),
                            "-moz-padding-end" => {
                                StaticId::LonghandAlias(LonghandId::PaddingInlineEnd,
                                                       AliasId::MozPaddingEnd)
                            },
                        "cursor" => StaticId::Longhand(LonghandId::Cursor),
                        "pointer-events" => StaticId::Longhand(LonghandId::PointerEvents),
                        "-moz-user-input" => StaticId::Longhand(LonghandId::MozUserInput),
                        "-moz-user-modify" => StaticId::Longhand(LonghandId::MozUserModify),
                        "-moz-user-focus" => StaticId::Longhand(LonghandId::MozUserFocus),
                        "caret-color" => StaticId::Longhand(LonghandId::CaretColor),
                        "top" => StaticId::Longhand(LonghandId::Top),
                        "left" => StaticId::Longhand(LonghandId::Left),
                        "bottom" => StaticId::Longhand(LonghandId::Bottom),
                        "right" => StaticId::Longhand(LonghandId::Right),
                        "offset-block-start" => StaticId::Longhand(LonghandId::OffsetBlockStart),
                        "offset-block-end" => StaticId::Longhand(LonghandId::OffsetBlockEnd),
                        "offset-inline-start" => StaticId::Longhand(LonghandId::OffsetInlineStart),
                        "offset-inline-end" => StaticId::Longhand(LonghandId::OffsetInlineEnd),
                        "z-index" => StaticId::Longhand(LonghandId::ZIndex),
                        "flex-direction" => StaticId::Longhand(LonghandId::FlexDirection),
                            "-webkit-flex-direction" => {
                                StaticId::LonghandAlias(LonghandId::FlexDirection,
                                                       AliasId::WebkitFlexDirection)
                            },
                        "flex-wrap" => StaticId::Longhand(LonghandId::FlexWrap),
                            "-webkit-flex-wrap" => {
                                StaticId::LonghandAlias(LonghandId::FlexWrap,
                                                       AliasId::WebkitFlexWrap)
                            },
                        "justify-content" => StaticId::Longhand(LonghandId::JustifyContent),
                            "-webkit-justify-content" => {
                                StaticId::LonghandAlias(LonghandId::JustifyContent,
                                                       AliasId::WebkitJustifyContent)
                            },
                        "align-content" => StaticId::Longhand(LonghandId::AlignContent),
                            "-webkit-align-content" => {
                                StaticId::LonghandAlias(LonghandId::AlignContent,
                                                       AliasId::WebkitAlignContent)
                            },
                        "align-items" => StaticId::Longhand(LonghandId::AlignItems),
                            "-webkit-align-items" => {
                                StaticId::LonghandAlias(LonghandId::AlignItems,
                                                       AliasId::WebkitAlignItems)
                            },
                        "justify-items" => StaticId::Longhand(LonghandId::JustifyItems),
                        "flex-grow" => StaticId::Longhand(LonghandId::FlexGrow),
                            "-webkit-flex-grow" => {
                                StaticId::LonghandAlias(LonghandId::FlexGrow,
                                                       AliasId::WebkitFlexGrow)
                            },
                        "flex-shrink" => StaticId::Longhand(LonghandId::FlexShrink),
                            "-webkit-flex-shrink" => {
                                StaticId::LonghandAlias(LonghandId::FlexShrink,
                                                       AliasId::WebkitFlexShrink)
                            },
                        "align-self" => StaticId::Longhand(LonghandId::AlignSelf),
                            "-webkit-align-self" => {
                                StaticId::LonghandAlias(LonghandId::AlignSelf,
                                                       AliasId::WebkitAlignSelf)
                            },
                        "justify-self" => StaticId::Longhand(LonghandId::JustifySelf),
                        "order" => StaticId::Longhand(LonghandId::Order),
                            "-webkit-order" => {
                                StaticId::LonghandAlias(LonghandId::Order,
                                                       AliasId::WebkitOrder)
                            },
                        "flex-basis" => StaticId::Longhand(LonghandId::FlexBasis),
                            "-webkit-flex-basis" => {
                                StaticId::LonghandAlias(LonghandId::FlexBasis,
                                                       AliasId::WebkitFlexBasis)
                            },
                        "width" => StaticId::Longhand(LonghandId::Width),
                        "min-width" => StaticId::Longhand(LonghandId::MinWidth),
                        "max-width" => StaticId::Longhand(LonghandId::MaxWidth),
                        "height" => StaticId::Longhand(LonghandId::Height),
                        "min-height" => StaticId::Longhand(LonghandId::MinHeight),
                        "max-height" => StaticId::Longhand(LonghandId::MaxHeight),
                        "block-size" => StaticId::Longhand(LonghandId::BlockSize),
                        "min-block-size" => StaticId::Longhand(LonghandId::MinBlockSize),
                        "max-block-size" => StaticId::Longhand(LonghandId::MaxBlockSize),
                        "inline-size" => StaticId::Longhand(LonghandId::InlineSize),
                        "min-inline-size" => StaticId::Longhand(LonghandId::MinInlineSize),
                        "max-inline-size" => StaticId::Longhand(LonghandId::MaxInlineSize),
                        "box-sizing" => StaticId::Longhand(LonghandId::BoxSizing),
                            "-moz-box-sizing" => {
                                StaticId::LonghandAlias(LonghandId::BoxSizing,
                                                       AliasId::MozBoxSizing)
                            },
                            "-webkit-box-sizing" => {
                                StaticId::LonghandAlias(LonghandId::BoxSizing,
                                                       AliasId::WebkitBoxSizing)
                            },
                        "object-fit" => StaticId::Longhand(LonghandId::ObjectFit),
                        "object-position" => StaticId::Longhand(LonghandId::ObjectPosition),
                        "grid-row-gap" => StaticId::Longhand(LonghandId::GridRowGap),
                        "grid-row-start" => StaticId::Longhand(LonghandId::GridRowStart),
                        "grid-row-end" => StaticId::Longhand(LonghandId::GridRowEnd),
                        "grid-auto-rows" => StaticId::Longhand(LonghandId::GridAutoRows),
                        "grid-template-rows" => StaticId::Longhand(LonghandId::GridTemplateRows),
                        "grid-column-gap" => StaticId::Longhand(LonghandId::GridColumnGap),
                        "grid-column-start" => StaticId::Longhand(LonghandId::GridColumnStart),
                        "grid-column-end" => StaticId::Longhand(LonghandId::GridColumnEnd),
                        "grid-auto-columns" => StaticId::Longhand(LonghandId::GridAutoColumns),
                        "grid-template-columns" => StaticId::Longhand(LonghandId::GridTemplateColumns),
                        "grid-auto-flow" => StaticId::Longhand(LonghandId::GridAutoFlow),
                        "grid-template-areas" => StaticId::Longhand(LonghandId::GridTemplateAreas),
                        "table-layout" => StaticId::Longhand(LonghandId::TableLayout),
                        "-x-span" => StaticId::Longhand(LonghandId::XSpan),
                        "text-overflow" => StaticId::Longhand(LonghandId::TextOverflow),
                        "unicode-bidi" => StaticId::Longhand(LonghandId::UnicodeBidi),
                        "text-decoration-line" => StaticId::Longhand(LonghandId::TextDecorationLine),
                        "text-decoration-style" => StaticId::Longhand(LonghandId::TextDecorationStyle),
                        "text-decoration-color" => StaticId::Longhand(LonghandId::TextDecorationColor),
                        "initial-letter" => StaticId::Longhand(LonghandId::InitialLetter),
                        "ime-mode" => StaticId::Longhand(LonghandId::ImeMode),
                        "-moz-user-select" => StaticId::Longhand(LonghandId::MozUserSelect),
                            "-webkit-user-select" => {
                                StaticId::LonghandAlias(LonghandId::MozUserSelect,
                                                       AliasId::WebkitUserSelect)
                            },
                        "-moz-window-dragging" => StaticId::Longhand(LonghandId::MozWindowDragging),
                        "-moz-window-shadow" => StaticId::Longhand(LonghandId::MozWindowShadow),
                        "-moz-window-opacity" => StaticId::Longhand(LonghandId::MozWindowOpacity),
                        "-moz-window-transform" => StaticId::Longhand(LonghandId::MozWindowTransform),
                        "-moz-window-transform-origin" => StaticId::Longhand(LonghandId::MozWindowTransformOrigin),
                        "-moz-force-broken-image-icon" => StaticId::Longhand(LonghandId::MozForceBrokenImageIcon),
                        "text-anchor" => StaticId::Longhand(LonghandId::TextAnchor),
                        "color-interpolation" => StaticId::Longhand(LonghandId::ColorInterpolation),
                        "color-interpolation-filters" => StaticId::Longhand(LonghandId::ColorInterpolationFilters),
                        "fill" => StaticId::Longhand(LonghandId::Fill),
                        "fill-opacity" => StaticId::Longhand(LonghandId::FillOpacity),
                        "fill-rule" => StaticId::Longhand(LonghandId::FillRule),
                        "shape-rendering" => StaticId::Longhand(LonghandId::ShapeRendering),
                        "stroke" => StaticId::Longhand(LonghandId::Stroke),
                        "stroke-width" => StaticId::Longhand(LonghandId::StrokeWidth),
                        "stroke-linecap" => StaticId::Longhand(LonghandId::StrokeLinecap),
                        "stroke-linejoin" => StaticId::Longhand(LonghandId::StrokeLinejoin),
                        "stroke-miterlimit" => StaticId::Longhand(LonghandId::StrokeMiterlimit),
                        "stroke-opacity" => StaticId::Longhand(LonghandId::StrokeOpacity),
                        "stroke-dasharray" => StaticId::Longhand(LonghandId::StrokeDasharray),
                        "stroke-dashoffset" => StaticId::Longhand(LonghandId::StrokeDashoffset),
                        "clip-rule" => StaticId::Longhand(LonghandId::ClipRule),
                        "marker-start" => StaticId::Longhand(LonghandId::MarkerStart),
                        "marker-mid" => StaticId::Longhand(LonghandId::MarkerMid),
                        "marker-end" => StaticId::Longhand(LonghandId::MarkerEnd),
                        "paint-order" => StaticId::Longhand(LonghandId::PaintOrder),
                        "-moz-context-properties" => StaticId::Longhand(LonghandId::MozContextProperties),
                        "dominant-baseline" => StaticId::Longhand(LonghandId::DominantBaseline),
                        "vector-effect" => StaticId::Longhand(LonghandId::VectorEffect),
                        "stop-color" => StaticId::Longhand(LonghandId::StopColor),
                        "stop-opacity" => StaticId::Longhand(LonghandId::StopOpacity),
                        "flood-color" => StaticId::Longhand(LonghandId::FloodColor),
                        "flood-opacity" => StaticId::Longhand(LonghandId::FloodOpacity),
                        "lighting-color" => StaticId::Longhand(LonghandId::LightingColor),
                        "mask-type" => StaticId::Longhand(LonghandId::MaskType),
                        "clip-path" => StaticId::Longhand(LonghandId::ClipPath),
                        "mask-mode" => StaticId::Longhand(LonghandId::MaskMode),
                        "mask-repeat" => StaticId::Longhand(LonghandId::MaskRepeat),
                            "-webkit-mask-repeat" => {
                                StaticId::LonghandAlias(LonghandId::MaskRepeat,
                                                       AliasId::WebkitMaskRepeat)
                            },
                        "mask-position-x" => StaticId::Longhand(LonghandId::MaskPositionX),
                            "-webkit-mask-position-x" => {
                                StaticId::LonghandAlias(LonghandId::MaskPositionX,
                                                       AliasId::WebkitMaskPositionX)
                            },
                        "mask-position-y" => StaticId::Longhand(LonghandId::MaskPositionY),
                            "-webkit-mask-position-y" => {
                                StaticId::LonghandAlias(LonghandId::MaskPositionY,
                                                       AliasId::WebkitMaskPositionY)
                            },
                        "mask-clip" => StaticId::Longhand(LonghandId::MaskClip),
                            "-webkit-mask-clip" => {
                                StaticId::LonghandAlias(LonghandId::MaskClip,
                                                       AliasId::WebkitMaskClip)
                            },
                        "mask-origin" => StaticId::Longhand(LonghandId::MaskOrigin),
                            "-webkit-mask-origin" => {
                                StaticId::LonghandAlias(LonghandId::MaskOrigin,
                                                       AliasId::WebkitMaskOrigin)
                            },
                        "mask-size" => StaticId::Longhand(LonghandId::MaskSize),
                            "-webkit-mask-size" => {
                                StaticId::LonghandAlias(LonghandId::MaskSize,
                                                       AliasId::WebkitMaskSize)
                            },
                        "mask-composite" => StaticId::Longhand(LonghandId::MaskComposite),
                            "-webkit-mask-composite" => {
                                StaticId::LonghandAlias(LonghandId::MaskComposite,
                                                       AliasId::WebkitMaskComposite)
                            },
                        "mask-image" => StaticId::Longhand(LonghandId::MaskImage),
                            "-webkit-mask-image" => {
                                StaticId::LonghandAlias(LonghandId::MaskImage,
                                                       AliasId::WebkitMaskImage)
                            },
                        "-moz-box-align" => StaticId::Longhand(LonghandId::MozBoxAlign),
                            "-webkit-box-align" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxAlign,
                                                       AliasId::WebkitBoxAlign)
                            },
                        "-moz-box-direction" => StaticId::Longhand(LonghandId::MozBoxDirection),
                            "-webkit-box-direction" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxDirection,
                                                       AliasId::WebkitBoxDirection)
                            },
                        "-moz-box-flex" => StaticId::Longhand(LonghandId::MozBoxFlex),
                            "-webkit-box-flex" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxFlex,
                                                       AliasId::WebkitBoxFlex)
                            },
                        "-moz-box-orient" => StaticId::Longhand(LonghandId::MozBoxOrient),
                            "-webkit-box-orient" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxOrient,
                                                       AliasId::WebkitBoxOrient)
                            },
                        "-moz-box-pack" => StaticId::Longhand(LonghandId::MozBoxPack),
                            "-webkit-box-pack" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxPack,
                                                       AliasId::WebkitBoxPack)
                            },
                        "-moz-stack-sizing" => StaticId::Longhand(LonghandId::MozStackSizing),
                        "-moz-box-ordinal-group" => StaticId::Longhand(LonghandId::MozBoxOrdinalGroup),
                            "-webkit-box-ordinal-group" => {
                                StaticId::LonghandAlias(LonghandId::MozBoxOrdinalGroup,
                                                       AliasId::WebkitBoxOrdinalGroup)
                            },
                        "background" => StaticId::Shorthand(ShorthandId::Background),
                        "background-position" => StaticId::Shorthand(ShorthandId::BackgroundPosition),
                        "border-color" => StaticId::Shorthand(ShorthandId::BorderColor),
                        "border-style" => StaticId::Shorthand(ShorthandId::BorderStyle),
                        "border-width" => StaticId::Shorthand(ShorthandId::BorderWidth),
                        "border-top" => StaticId::Shorthand(ShorthandId::BorderTop),
                        "border-left" => StaticId::Shorthand(ShorthandId::BorderLeft),
                        "border-bottom" => StaticId::Shorthand(ShorthandId::BorderBottom),
                        "border-right" => StaticId::Shorthand(ShorthandId::BorderRight),
                        "border-block-start" => StaticId::Shorthand(ShorthandId::BorderBlockStart),
                        "border-block-end" => StaticId::Shorthand(ShorthandId::BorderBlockEnd),
                        "border-inline-start" => StaticId::Shorthand(ShorthandId::BorderInlineStart),
                            "-moz-border-start" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderInlineStart,
                                                       AliasId::MozBorderStart)
                            },
                        "border-inline-end" => StaticId::Shorthand(ShorthandId::BorderInlineEnd),
                            "-moz-border-end" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderInlineEnd,
                                                       AliasId::MozBorderEnd)
                            },
                        "border" => StaticId::Shorthand(ShorthandId::Border),
                        "border-radius" => StaticId::Shorthand(ShorthandId::BorderRadius),
                            "-webkit-border-radius" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderRadius,
                                                       AliasId::WebkitBorderRadius)
                            },
                        "border-image" => StaticId::Shorthand(ShorthandId::BorderImage),
                            "-moz-border-image" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderImage,
                                                       AliasId::MozBorderImage)
                            },
                            "-webkit-border-image" => {
                                StaticId::ShorthandAlias(ShorthandId::BorderImage,
                                                       AliasId::WebkitBorderImage)
                            },
                        "overflow" => StaticId::Shorthand(ShorthandId::Overflow),
                        "overflow-clip-box" => StaticId::Shorthand(ShorthandId::OverflowClipBox),
                        "transition" => StaticId::Shorthand(ShorthandId::Transition),
                            "-moz-transition" => {
                                StaticId::ShorthandAlias(ShorthandId::Transition,
                                                       AliasId::MozTransition)
                            },
                            "-webkit-transition" => {
                                StaticId::ShorthandAlias(ShorthandId::Transition,
                                                       AliasId::WebkitTransition)
                            },
                        "animation" => StaticId::Shorthand(ShorthandId::Animation),
                            "-moz-animation" => {
                                StaticId::ShorthandAlias(ShorthandId::Animation,
                                                       AliasId::MozAnimation)
                            },
                            "-webkit-animation" => {
                                StaticId::ShorthandAlias(ShorthandId::Animation,
                                                       AliasId::WebkitAnimation)
                            },
                        "scroll-snap-type" => StaticId::Shorthand(ShorthandId::ScrollSnapType),
                        "overscroll-behavior" => StaticId::Shorthand(ShorthandId::OverscrollBehavior),
                        "-moz-transform" => StaticId::Shorthand(ShorthandId::MozTransform),
                        "columns" => StaticId::Shorthand(ShorthandId::Columns),
                            "-moz-columns" => {
                                StaticId::ShorthandAlias(ShorthandId::Columns,
                                                       AliasId::MozColumns)
                            },
                        "column-rule" => StaticId::Shorthand(ShorthandId::ColumnRule),
                            "-moz-column-rule" => {
                                StaticId::ShorthandAlias(ShorthandId::ColumnRule,
                                                       AliasId::MozColumnRule)
                            },
                        "font" => StaticId::Shorthand(ShorthandId::Font),
                        "font-variant" => StaticId::Shorthand(ShorthandId::FontVariant),
                        "text-emphasis" => StaticId::Shorthand(ShorthandId::TextEmphasis),
                        "-webkit-text-stroke" => StaticId::Shorthand(ShorthandId::WebkitTextStroke),
                        "list-style" => StaticId::Shorthand(ShorthandId::ListStyle),
                        "margin" => StaticId::Shorthand(ShorthandId::Margin),
                        "mask" => StaticId::Shorthand(ShorthandId::Mask),
                            "-webkit-mask" => {
                                StaticId::ShorthandAlias(ShorthandId::Mask,
                                                       AliasId::WebkitMask)
                            },
                        "mask-position" => StaticId::Shorthand(ShorthandId::MaskPosition),
                            "-webkit-mask-position" => {
                                StaticId::ShorthandAlias(ShorthandId::MaskPosition,
                                                       AliasId::WebkitMaskPosition)
                            },
                        "outline" => StaticId::Shorthand(ShorthandId::Outline),
                        "-moz-outline-radius" => StaticId::Shorthand(ShorthandId::MozOutlineRadius),
                        "padding" => StaticId::Shorthand(ShorthandId::Padding),
                        "flex-flow" => StaticId::Shorthand(ShorthandId::FlexFlow),
                            "-webkit-flex-flow" => {
                                StaticId::ShorthandAlias(ShorthandId::FlexFlow,
                                                       AliasId::WebkitFlexFlow)
                            },
                        "flex" => StaticId::Shorthand(ShorthandId::Flex),
                            "-webkit-flex" => {
                                StaticId::ShorthandAlias(ShorthandId::Flex,
                                                       AliasId::WebkitFlex)
                            },
                        "grid-gap" => StaticId::Shorthand(ShorthandId::GridGap),
                        "grid-row" => StaticId::Shorthand(ShorthandId::GridRow),
                        "grid-column" => StaticId::Shorthand(ShorthandId::GridColumn),
                        "grid-area" => StaticId::Shorthand(ShorthandId::GridArea),
                        "grid-template" => StaticId::Shorthand(ShorthandId::GridTemplate),
                        "grid" => StaticId::Shorthand(ShorthandId::Grid),
                        "place-content" => StaticId::Shorthand(ShorthandId::PlaceContent),
                        "place-self" => StaticId::Shorthand(ShorthandId::PlaceSelf),
                        "place-items" => StaticId::Shorthand(ShorthandId::PlaceItems),
                        "marker" => StaticId::Shorthand(ShorthandId::Marker),
                        "text-decoration" => StaticId::Shorthand(ShorthandId::TextDecoration),
                        "all" => StaticId::Shorthand(ShorthandId::All),
            }
        }

        Ok(match static_id(property_name) {
            Some(&StaticId::Longhand(id)) => {
                PropertyId::Longhand(id)
            },
            Some(&StaticId::Shorthand(id)) => {
                PropertyId::Shorthand(id)
            },
            Some(&StaticId::LonghandAlias(id, alias)) => {
                PropertyId::LonghandAlias(id, alias)
            },
            Some(&StaticId::ShorthandAlias(id, alias)) => {
                PropertyId::ShorthandAlias(id, alias)
            },
            None => {
                return ::custom_properties::parse_name(property_name).map(|name| {
                    PropertyId::Custom(::custom_properties::Name::from(name))
                })
            },
        })
    }

    /// Returns a property id from Gecko's nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    pub fn from_nscsspropertyid(id: nsCSSPropertyID) -> Result<Self, ()> {
        use gecko_bindings::structs::*;
        match id {
                
    nsCSSPropertyID::eCSSProperty_background_color => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundColor))
                }
                
    nsCSSPropertyID::eCSSProperty_background_image => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundImage))
                }
                
    nsCSSPropertyID::eCSSProperty_background_position_x => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundPositionX))
                }
                
    nsCSSPropertyID::eCSSProperty_background_position_y => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundPositionY))
                }
                
    nsCSSPropertyID::eCSSProperty_background_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundRepeat))
                }
                
    nsCSSPropertyID::eCSSProperty_background_attachment => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundAttachment))
                }
                
    nsCSSPropertyID::eCSSProperty_background_clip => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundClip))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundClip => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundClip,
                            AliasId::WebkitBackgroundClip
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_origin => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundOrigin,
                            AliasId::WebkitBackgroundOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_size => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundSize))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundSize => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackgroundSize,
                            AliasId::WebkitBackgroundSize
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background_blend_mode => {
                    Ok(PropertyId::Longhand(LonghandId::BackgroundBlendMode))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_left_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_left_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_left_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderLeftWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderRightWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockStartWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBlockEndWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartColor,
                            AliasId::MozBorderStartColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartStyle,
                            AliasId::MozBorderStartStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineStartWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineStartWidth,
                            AliasId::MozBorderStartWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_color => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndColor,
                            AliasId::MozBorderEndColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_style => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndStyle,
                            AliasId::MozBorderEndStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderInlineEndWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderInlineEndWidth,
                            AliasId::MozBorderEndWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_top_left_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopLeftRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopLeftRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderTopLeftRadius,
                            AliasId::WebkitBorderTopLeftRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_top_right_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderTopRightRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopRightRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderTopRightRadius,
                            AliasId::WebkitBorderTopRightRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_right_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomRightRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomRightRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderBottomRightRadius,
                            AliasId::WebkitBorderBottomRightRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_bottom_left_radius => {
                    Ok(PropertyId::Longhand(LonghandId::BorderBottomLeftRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomLeftRadius => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BorderBottomLeftRadius,
                            AliasId::WebkitBorderBottomLeftRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_border_top_colors => {
                    Ok(PropertyId::Longhand(LonghandId::MozBorderTopColors))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_border_left_colors => {
                    Ok(PropertyId::Longhand(LonghandId::MozBorderLeftColors))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_border_bottom_colors => {
                    Ok(PropertyId::Longhand(LonghandId::MozBorderBottomColors))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_border_right_colors => {
                    Ok(PropertyId::Longhand(LonghandId::MozBorderRightColors))
                }
                
    nsCSSPropertyID::eCSSProperty_box_decoration_break => {
                    Ok(PropertyId::Longhand(LonghandId::BoxDecorationBreak))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_float_edge => {
                    Ok(PropertyId::Longhand(LonghandId::MozFloatEdge))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_source => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageSource))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_outset => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageOutset))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageRepeat))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_width => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_image_slice => {
                    Ok(PropertyId::Longhand(LonghandId::BorderImageSlice))
                }
                
    nsCSSPropertyID::eCSSProperty_display => {
                    Ok(PropertyId::Longhand(LonghandId::Display))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_top_layer => {
                    Ok(PropertyId::Longhand(LonghandId::MozTopLayer))
                }
                
    nsCSSPropertyID::eCSSProperty_position => {
                    Ok(PropertyId::Longhand(LonghandId::Position))
                }
                
    nsCSSPropertyID::eCSSProperty_float_ => {
                    Ok(PropertyId::Longhand(LonghandId::Float))
                }
                
    nsCSSPropertyID::eCSSProperty_clear => {
                    Ok(PropertyId::Longhand(LonghandId::Clear))
                }
                
    nsCSSPropertyID::eCSSProperty_vertical_align => {
                    Ok(PropertyId::Longhand(LonghandId::VerticalAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowClipBoxInline))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box_block => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowClipBoxBlock))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_x => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowX))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_y => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowY))
                }
                
    nsCSSPropertyID::eCSSProperty_transition_duration => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionDuration))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDuration,
                            AliasId::MozTransitionDuration
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDuration,
                            AliasId::WebkitTransitionDuration
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_timing_function => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionTimingFunction))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionTimingFunction,
                            AliasId::MozTransitionTimingFunction
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionTimingFunction,
                            AliasId::WebkitTransitionTimingFunction
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_property => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionProperty))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionProperty => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionProperty,
                            AliasId::MozTransitionProperty
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionProperty => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionProperty,
                            AliasId::WebkitTransitionProperty
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transition_delay => {
                    Ok(PropertyId::Longhand(LonghandId::TransitionDelay))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDelay,
                            AliasId::MozTransitionDelay
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransitionDelay,
                            AliasId::WebkitTransitionDelay
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_name => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationName))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationName => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationName,
                            AliasId::MozAnimationName
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationName => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationName,
                            AliasId::WebkitAnimationName
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_duration => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDuration))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDuration,
                            AliasId::MozAnimationDuration
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDuration => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDuration,
                            AliasId::WebkitAnimationDuration
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_timing_function => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationTimingFunction))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationTimingFunction,
                            AliasId::MozAnimationTimingFunction
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationTimingFunction => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationTimingFunction,
                            AliasId::WebkitAnimationTimingFunction
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_iteration_count => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationIterationCount))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationIterationCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationIterationCount,
                            AliasId::MozAnimationIterationCount
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationIterationCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationIterationCount,
                            AliasId::WebkitAnimationIterationCount
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_direction => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDirection,
                            AliasId::MozAnimationDirection
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDirection,
                            AliasId::WebkitAnimationDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_play_state => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationPlayState))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationPlayState => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationPlayState,
                            AliasId::MozAnimationPlayState
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationPlayState => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationPlayState,
                            AliasId::WebkitAnimationPlayState
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_fill_mode => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationFillMode))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationFillMode => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationFillMode,
                            AliasId::MozAnimationFillMode
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationFillMode => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationFillMode,
                            AliasId::WebkitAnimationFillMode
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation_delay => {
                    Ok(PropertyId::Longhand(LonghandId::AnimationDelay))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDelay,
                            AliasId::MozAnimationDelay
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDelay => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AnimationDelay,
                            AliasId::WebkitAnimationDelay
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_x => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapPointsX))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_points_y => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapPointsY))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_destination => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapDestination))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_coordinate => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapCoordinate))
                }
                
    nsCSSPropertyID::eCSSProperty_transform => {
                    Ok(PropertyId::Longhand(LonghandId::Transform))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransform => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Transform,
                            AliasId::WebkitTransform
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_scroll_behavior => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollBehavior))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_x => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapTypeX))
                }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type_y => {
                    Ok(PropertyId::Longhand(LonghandId::ScrollSnapTypeY))
                }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_x => {
                    Ok(PropertyId::Longhand(LonghandId::OverscrollBehaviorX))
                }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior_y => {
                    Ok(PropertyId::Longhand(LonghandId::OverscrollBehaviorY))
                }
                
    nsCSSPropertyID::eCSSProperty_isolation => {
                    Ok(PropertyId::Longhand(LonghandId::Isolation))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_after => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakAfter))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_before => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakBefore))
                }
                
    nsCSSPropertyID::eCSSProperty_page_break_inside => {
                    Ok(PropertyId::Longhand(LonghandId::PageBreakInside))
                }
                
    nsCSSPropertyID::eCSSProperty_resize => {
                    Ok(PropertyId::Longhand(LonghandId::Resize))
                }
                
    nsCSSPropertyID::eCSSProperty_perspective => {
                    Ok(PropertyId::Longhand(LonghandId::Perspective))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspective => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Perspective,
                            AliasId::MozPerspective
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspective => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Perspective,
                            AliasId::WebkitPerspective
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_perspective_origin => {
                    Ok(PropertyId::Longhand(LonghandId::PerspectiveOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspectiveOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PerspectiveOrigin,
                            AliasId::MozPerspectiveOrigin
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspectiveOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PerspectiveOrigin,
                            AliasId::WebkitPerspectiveOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_backface_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::BackfaceVisibility))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBackfaceVisibility => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackfaceVisibility,
                            AliasId::MozBackfaceVisibility
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackfaceVisibility => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BackfaceVisibility,
                            AliasId::WebkitBackfaceVisibility
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transform_box => {
                    Ok(PropertyId::Longhand(LonghandId::TransformBox))
                }
                
    nsCSSPropertyID::eCSSProperty_transform_style => {
                    Ok(PropertyId::Longhand(LonghandId::TransformStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformStyle,
                            AliasId::MozTransformStyle
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformStyle,
                            AliasId::WebkitTransformStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_transform_origin => {
                    Ok(PropertyId::Longhand(LonghandId::TransformOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformOrigin,
                            AliasId::MozTransformOrigin
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::TransformOrigin,
                            AliasId::WebkitTransformOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_contain => {
                    Ok(PropertyId::Longhand(LonghandId::Contain))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_appearance => {
                    Ok(PropertyId::Longhand(LonghandId::MozAppearance))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_binding => {
                    Ok(PropertyId::Longhand(LonghandId::MozBinding))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_orient => {
                    Ok(PropertyId::Longhand(LonghandId::MozOrient))
                }
                
    nsCSSPropertyID::eCSSProperty_will_change => {
                    Ok(PropertyId::Longhand(LonghandId::WillChange))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_image_threshold => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeImageThreshold))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_outside => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeOutside))
                }
                
    nsCSSPropertyID::eCSSProperty_touch_action => {
                    Ok(PropertyId::Longhand(LonghandId::TouchAction))
                }
                
    nsCSSPropertyID::eCSSProperty_color => {
                    Ok(PropertyId::Longhand(LonghandId::Color))
                }
                
    nsCSSPropertyID::eCSSProperty_column_width => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnWidth,
                            AliasId::MozColumnWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_count => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnCount))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnCount => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnCount,
                            AliasId::MozColumnCount
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_gap => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnGap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnGap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnGap,
                            AliasId::MozColumnGap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_fill => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnFill))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnFill => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnFill,
                            AliasId::MozColumnFill
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule_width => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleWidth))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleWidth => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleWidth,
                            AliasId::MozColumnRuleWidth
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule_color => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleColor))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleColor => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleColor,
                            AliasId::MozColumnRuleColor
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_span => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnSpan))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnSpan => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnSpan,
                            AliasId::MozColumnSpan
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule_style => {
                    Ok(PropertyId::Longhand(LonghandId::ColumnRuleStyle))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleStyle => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::ColumnRuleStyle,
                            AliasId::MozColumnRuleStyle
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_content => {
                    Ok(PropertyId::Longhand(LonghandId::Content))
                }
                
    nsCSSPropertyID::eCSSProperty_counter_increment => {
                    Ok(PropertyId::Longhand(LonghandId::CounterIncrement))
                }
                
    nsCSSPropertyID::eCSSProperty_counter_reset => {
                    Ok(PropertyId::Longhand(LonghandId::CounterReset))
                }
                
    nsCSSPropertyID::eCSSProperty_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::Opacity))
                }
                
    nsCSSPropertyID::eCSSProperty_box_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::BoxShadow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxShadow => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxShadow,
                            AliasId::WebkitBoxShadow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_clip => {
                    Ok(PropertyId::Longhand(LonghandId::Clip))
                }
                
    nsCSSPropertyID::eCSSProperty_filter => {
                    Ok(PropertyId::Longhand(LonghandId::Filter))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFilter => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Filter,
                            AliasId::WebkitFilter
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mix_blend_mode => {
                    Ok(PropertyId::Longhand(LonghandId::MixBlendMode))
                }
                
    nsCSSPropertyID::eCSSProperty_font_family => {
                    Ok(PropertyId::Longhand(LonghandId::FontFamily))
                }
                
    nsCSSPropertyID::eCSSProperty_font_style => {
                    Ok(PropertyId::Longhand(LonghandId::FontStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_caps => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantCaps))
                }
                
    nsCSSPropertyID::eCSSProperty_font_weight => {
                    Ok(PropertyId::Longhand(LonghandId::FontWeight))
                }
                
    nsCSSPropertyID::eCSSProperty_font_size => {
                    Ok(PropertyId::Longhand(LonghandId::FontSize))
                }
                
    nsCSSPropertyID::eCSSProperty_font_size_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::FontSizeAdjust))
                }
                
    nsCSSPropertyID::eCSSProperty_font_synthesis => {
                    Ok(PropertyId::Longhand(LonghandId::FontSynthesis))
                }
                
    nsCSSPropertyID::eCSSProperty_font_stretch => {
                    Ok(PropertyId::Longhand(LonghandId::FontStretch))
                }
                
    nsCSSPropertyID::eCSSProperty_font_kerning => {
                    Ok(PropertyId::Longhand(LonghandId::FontKerning))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_alternates => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantAlternates))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_east_asian => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantEastAsian))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_ligatures => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantLigatures))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_numeric => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantNumeric))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant_position => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariantPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_font_feature_settings => {
                    Ok(PropertyId::Longhand(LonghandId::FontFeatureSettings))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontFeatureSettings => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FontFeatureSettings,
                            AliasId::MozFontFeatureSettings
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font_variation_settings => {
                    Ok(PropertyId::Longhand(LonghandId::FontVariationSettings))
                }
                
    nsCSSPropertyID::eCSSProperty_font_language_override => {
                    Ok(PropertyId::Longhand(LonghandId::FontLanguageOverride))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontLanguageOverride => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FontLanguageOverride,
                            AliasId::MozFontLanguageOverride
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__x_lang => {
                    Ok(PropertyId::Longhand(LonghandId::XLang))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_size_multiplier => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptSizeMultiplier))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_level => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptLevel))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_math_display => {
                    Ok(PropertyId::Longhand(LonghandId::MozMathDisplay))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_math_variant => {
                    Ok(PropertyId::Longhand(LonghandId::MozMathVariant))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_script_min_size => {
                    Ok(PropertyId::Longhand(LonghandId::MozScriptMinSize))
                }
                
    nsCSSPropertyID::eCSSProperty__x_text_zoom => {
                    Ok(PropertyId::Longhand(LonghandId::XTextZoom))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing => {
                    Ok(PropertyId::Longhand(LonghandId::MozOsxFontSmoothing))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_font_smoothing_background_color => {
                    Ok(PropertyId::Longhand(LonghandId::MozFontSmoothingBackgroundColor))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio => {
                    Ok(PropertyId::Longhand(LonghandId::MozMinFontSizeRatio))
                }
                
    nsCSSPropertyID::eCSSProperty_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::Visibility))
                }
                
    nsCSSPropertyID::eCSSProperty_writing_mode => {
                    Ok(PropertyId::Longhand(LonghandId::WritingMode))
                }
                
    nsCSSPropertyID::eCSSProperty_direction => {
                    Ok(PropertyId::Longhand(LonghandId::Direction))
                }
                
    nsCSSPropertyID::eCSSProperty_text_orientation => {
                    Ok(PropertyId::Longhand(LonghandId::TextOrientation))
                }
                
    nsCSSPropertyID::eCSSProperty_color_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::ColorAdjust))
                }
                
    nsCSSPropertyID::eCSSProperty_image_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::ImageRendering))
                }
                
    nsCSSPropertyID::eCSSProperty_image_orientation => {
                    Ok(PropertyId::Longhand(LonghandId::ImageOrientation))
                }
                
    nsCSSPropertyID::eCSSProperty_border_collapse => {
                    Ok(PropertyId::Longhand(LonghandId::BorderCollapse))
                }
                
    nsCSSPropertyID::eCSSProperty_empty_cells => {
                    Ok(PropertyId::Longhand(LonghandId::EmptyCells))
                }
                
    nsCSSPropertyID::eCSSProperty_caption_side => {
                    Ok(PropertyId::Longhand(LonghandId::CaptionSide))
                }
                
    nsCSSPropertyID::eCSSProperty_border_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::BorderSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty_line_height => {
                    Ok(PropertyId::Longhand(LonghandId::LineHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_text_transform => {
                    Ok(PropertyId::Longhand(LonghandId::TextTransform))
                }
                
    nsCSSPropertyID::eCSSProperty_hyphens => {
                    Ok(PropertyId::Longhand(LonghandId::Hyphens))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozHyphens => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Hyphens,
                            AliasId::MozHyphens
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_text_size_adjust => {
                    Ok(PropertyId::Longhand(LonghandId::MozTextSizeAdjust))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTextSizeAdjust => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozTextSizeAdjust,
                            AliasId::WebkitTextSizeAdjust
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_text_indent => {
                    Ok(PropertyId::Longhand(LonghandId::TextIndent))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_wrap => {
                    Ok(PropertyId::Longhand(LonghandId::OverflowWrap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WordWrap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::OverflowWrap,
                            AliasId::WordWrap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_word_break => {
                    Ok(PropertyId::Longhand(LonghandId::WordBreak))
                }
                
    nsCSSPropertyID::eCSSProperty_text_justify => {
                    Ok(PropertyId::Longhand(LonghandId::TextJustify))
                }
                
    nsCSSPropertyID::eCSSProperty_text_align_last => {
                    Ok(PropertyId::Longhand(LonghandId::TextAlignLast))
                }
                
    nsCSSPropertyID::eCSSProperty_text_align => {
                    Ok(PropertyId::Longhand(LonghandId::TextAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_letter_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::LetterSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty_word_spacing => {
                    Ok(PropertyId::Longhand(LonghandId::WordSpacing))
                }
                
    nsCSSPropertyID::eCSSProperty_white_space => {
                    Ok(PropertyId::Longhand(LonghandId::WhiteSpace))
                }
                
    nsCSSPropertyID::eCSSProperty_text_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::TextShadow))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_style => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_position => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis_color => {
                    Ok(PropertyId::Longhand(LonghandId::TextEmphasisColor))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_tab_size => {
                    Ok(PropertyId::Longhand(LonghandId::MozTabSize))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_fill_color => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextFillColor))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextStrokeColor))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width => {
                    Ok(PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_ruby_align => {
                    Ok(PropertyId::Longhand(LonghandId::RubyAlign))
                }
                
    nsCSSPropertyID::eCSSProperty_ruby_position => {
                    Ok(PropertyId::Longhand(LonghandId::RubyPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_text_combine_upright => {
                    Ok(PropertyId::Longhand(LonghandId::TextCombineUpright))
                }
                
    nsCSSPropertyID::eCSSProperty_text_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::TextRendering))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_control_character_visibility => {
                    Ok(PropertyId::Longhand(LonghandId::MozControlCharacterVisibility))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_position => {
                    Ok(PropertyId::Longhand(LonghandId::ListStylePosition))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_type => {
                    Ok(PropertyId::Longhand(LonghandId::ListStyleType))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style_image => {
                    Ok(PropertyId::Longhand(LonghandId::ListStyleImage))
                }
                
    nsCSSPropertyID::eCSSProperty_quotes => {
                    Ok(PropertyId::Longhand(LonghandId::Quotes))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_image_region => {
                    Ok(PropertyId::Longhand(LonghandId::MozImageRegion))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_top => {
                    Ok(PropertyId::Longhand(LonghandId::MarginTop))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_left => {
                    Ok(PropertyId::Longhand(LonghandId::MarginLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_right => {
                    Ok(PropertyId::Longhand(LonghandId::MarginRight))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarginBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_margin_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarginInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginStart => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MarginInlineStart,
                            AliasId::MozMarginStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_margin_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarginInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginEnd => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MarginInlineEnd,
                            AliasId::MozMarginEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_outline_color => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineColor))
                }
                
    nsCSSPropertyID::eCSSProperty_outline_style => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_outline_width => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineWidth))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topleft => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_topright => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomright => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius_bottomleft => {
                    Ok(PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft))
                }
                
    nsCSSPropertyID::eCSSProperty_outline_offset => {
                    Ok(PropertyId::Longhand(LonghandId::OutlineOffset))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_top => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingTop))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_left => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_right => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingRight))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_padding_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingStart => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PaddingInlineStart,
                            AliasId::MozPaddingStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_padding_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::PaddingInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingEnd => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::PaddingInlineEnd,
                            AliasId::MozPaddingEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_cursor => {
                    Ok(PropertyId::Longhand(LonghandId::Cursor))
                }
                
    nsCSSPropertyID::eCSSProperty_pointer_events => {
                    Ok(PropertyId::Longhand(LonghandId::PointerEvents))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_input => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserInput))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_modify => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserModify))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_focus => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserFocus))
                }
                
    nsCSSPropertyID::eCSSProperty_caret_color => {
                    Ok(PropertyId::Longhand(LonghandId::CaretColor))
                }
                
    nsCSSPropertyID::eCSSProperty_top => {
                    Ok(PropertyId::Longhand(LonghandId::Top))
                }
                
    nsCSSPropertyID::eCSSProperty_left => {
                    Ok(PropertyId::Longhand(LonghandId::Left))
                }
                
    nsCSSPropertyID::eCSSProperty_bottom => {
                    Ok(PropertyId::Longhand(LonghandId::Bottom))
                }
                
    nsCSSPropertyID::eCSSProperty_right => {
                    Ok(PropertyId::Longhand(LonghandId::Right))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_block_start => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_block_end => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_inline_start => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetInlineStart))
                }
                
    nsCSSPropertyID::eCSSProperty_offset_inline_end => {
                    Ok(PropertyId::Longhand(LonghandId::OffsetInlineEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_z_index => {
                    Ok(PropertyId::Longhand(LonghandId::ZIndex))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_direction => {
                    Ok(PropertyId::Longhand(LonghandId::FlexDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexDirection,
                            AliasId::WebkitFlexDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex_wrap => {
                    Ok(PropertyId::Longhand(LonghandId::FlexWrap))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexWrap => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexWrap,
                            AliasId::WebkitFlexWrap
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_justify_content => {
                    Ok(PropertyId::Longhand(LonghandId::JustifyContent))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitJustifyContent => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::JustifyContent,
                            AliasId::WebkitJustifyContent
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_align_content => {
                    Ok(PropertyId::Longhand(LonghandId::AlignContent))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignContent => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignContent,
                            AliasId::WebkitAlignContent
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_align_items => {
                    Ok(PropertyId::Longhand(LonghandId::AlignItems))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignItems => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignItems,
                            AliasId::WebkitAlignItems
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_justify_items => {
                    Ok(PropertyId::Longhand(LonghandId::JustifyItems))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_grow => {
                    Ok(PropertyId::Longhand(LonghandId::FlexGrow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexGrow => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexGrow,
                            AliasId::WebkitFlexGrow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex_shrink => {
                    Ok(PropertyId::Longhand(LonghandId::FlexShrink))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexShrink => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexShrink,
                            AliasId::WebkitFlexShrink
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_align_self => {
                    Ok(PropertyId::Longhand(LonghandId::AlignSelf))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignSelf => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::AlignSelf,
                            AliasId::WebkitAlignSelf
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_justify_self => {
                    Ok(PropertyId::Longhand(LonghandId::JustifySelf))
                }
                
    nsCSSPropertyID::eCSSProperty_order => {
                    Ok(PropertyId::Longhand(LonghandId::Order))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitOrder => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::Order,
                            AliasId::WebkitOrder
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex_basis => {
                    Ok(PropertyId::Longhand(LonghandId::FlexBasis))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexBasis => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::FlexBasis,
                            AliasId::WebkitFlexBasis
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_width => {
                    Ok(PropertyId::Longhand(LonghandId::Width))
                }
                
    nsCSSPropertyID::eCSSProperty_min_width => {
                    Ok(PropertyId::Longhand(LonghandId::MinWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_max_width => {
                    Ok(PropertyId::Longhand(LonghandId::MaxWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_height => {
                    Ok(PropertyId::Longhand(LonghandId::Height))
                }
                
    nsCSSPropertyID::eCSSProperty_min_height => {
                    Ok(PropertyId::Longhand(LonghandId::MinHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_max_height => {
                    Ok(PropertyId::Longhand(LonghandId::MaxHeight))
                }
                
    nsCSSPropertyID::eCSSProperty_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::BlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_min_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::MinBlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_max_block_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaxBlockSize))
                }
                
    nsCSSPropertyID::eCSSProperty_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::InlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_min_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::MinInlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_max_inline_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaxInlineSize))
                }
                
    nsCSSPropertyID::eCSSProperty_box_sizing => {
                    Ok(PropertyId::Longhand(LonghandId::BoxSizing))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBoxSizing => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxSizing,
                            AliasId::MozBoxSizing
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxSizing => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::BoxSizing,
                            AliasId::WebkitBoxSizing
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_object_fit => {
                    Ok(PropertyId::Longhand(LonghandId::ObjectFit))
                }
                
    nsCSSPropertyID::eCSSProperty_object_position => {
                    Ok(PropertyId::Longhand(LonghandId::ObjectPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_gap => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowGap))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_start => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowStart))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row_end => {
                    Ok(PropertyId::Longhand(LonghandId::GridRowEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_rows => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoRows))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_rows => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateRows))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_gap => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnGap))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_start => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnStart))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column_end => {
                    Ok(PropertyId::Longhand(LonghandId::GridColumnEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_columns => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoColumns))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_columns => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateColumns))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_auto_flow => {
                    Ok(PropertyId::Longhand(LonghandId::GridAutoFlow))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template_areas => {
                    Ok(PropertyId::Longhand(LonghandId::GridTemplateAreas))
                }
                
    nsCSSPropertyID::eCSSProperty_table_layout => {
                    Ok(PropertyId::Longhand(LonghandId::TableLayout))
                }
                
    nsCSSPropertyID::eCSSProperty__x_span => {
                    Ok(PropertyId::Longhand(LonghandId::XSpan))
                }
                
    nsCSSPropertyID::eCSSProperty_text_overflow => {
                    Ok(PropertyId::Longhand(LonghandId::TextOverflow))
                }
                
    nsCSSPropertyID::eCSSProperty_unicode_bidi => {
                    Ok(PropertyId::Longhand(LonghandId::UnicodeBidi))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_line => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationLine))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_style => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration_color => {
                    Ok(PropertyId::Longhand(LonghandId::TextDecorationColor))
                }
                
    nsCSSPropertyID::eCSSProperty_initial_letter => {
                    Ok(PropertyId::Longhand(LonghandId::InitialLetter))
                }
                
    nsCSSPropertyID::eCSSProperty_ime_mode => {
                    Ok(PropertyId::Longhand(LonghandId::ImeMode))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_user_select => {
                    Ok(PropertyId::Longhand(LonghandId::MozUserSelect))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitUserSelect => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozUserSelect,
                            AliasId::WebkitUserSelect
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_window_dragging => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowDragging))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_shadow => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowShadow))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowTransform))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_window_transform_origin => {
                    Ok(PropertyId::Longhand(LonghandId::MozWindowTransformOrigin))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon => {
                    Ok(PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon))
                }
                
    nsCSSPropertyID::eCSSProperty_text_anchor => {
                    Ok(PropertyId::Longhand(LonghandId::TextAnchor))
                }
                
    nsCSSPropertyID::eCSSProperty_color_interpolation => {
                    Ok(PropertyId::Longhand(LonghandId::ColorInterpolation))
                }
                
    nsCSSPropertyID::eCSSProperty_color_interpolation_filters => {
                    Ok(PropertyId::Longhand(LonghandId::ColorInterpolationFilters))
                }
                
    nsCSSPropertyID::eCSSProperty_fill => {
                    Ok(PropertyId::Longhand(LonghandId::Fill))
                }
                
    nsCSSPropertyID::eCSSProperty_fill_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::FillOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_fill_rule => {
                    Ok(PropertyId::Longhand(LonghandId::FillRule))
                }
                
    nsCSSPropertyID::eCSSProperty_shape_rendering => {
                    Ok(PropertyId::Longhand(LonghandId::ShapeRendering))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke => {
                    Ok(PropertyId::Longhand(LonghandId::Stroke))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_width => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_linecap => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeLinecap))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_linejoin => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeLinejoin))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_miterlimit => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeMiterlimit))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_dasharray => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeDasharray))
                }
                
    nsCSSPropertyID::eCSSProperty_stroke_dashoffset => {
                    Ok(PropertyId::Longhand(LonghandId::StrokeDashoffset))
                }
                
    nsCSSPropertyID::eCSSProperty_clip_rule => {
                    Ok(PropertyId::Longhand(LonghandId::ClipRule))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_start => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerStart))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_mid => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerMid))
                }
                
    nsCSSPropertyID::eCSSProperty_marker_end => {
                    Ok(PropertyId::Longhand(LonghandId::MarkerEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_paint_order => {
                    Ok(PropertyId::Longhand(LonghandId::PaintOrder))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_context_properties => {
                    Ok(PropertyId::Longhand(LonghandId::MozContextProperties))
                }
                
    nsCSSPropertyID::eCSSProperty_dominant_baseline => {
                    Ok(PropertyId::Longhand(LonghandId::DominantBaseline))
                }
                
    nsCSSPropertyID::eCSSProperty_vector_effect => {
                    Ok(PropertyId::Longhand(LonghandId::VectorEffect))
                }
                
    nsCSSPropertyID::eCSSProperty_stop_color => {
                    Ok(PropertyId::Longhand(LonghandId::StopColor))
                }
                
    nsCSSPropertyID::eCSSProperty_stop_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::StopOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_flood_color => {
                    Ok(PropertyId::Longhand(LonghandId::FloodColor))
                }
                
    nsCSSPropertyID::eCSSProperty_flood_opacity => {
                    Ok(PropertyId::Longhand(LonghandId::FloodOpacity))
                }
                
    nsCSSPropertyID::eCSSProperty_lighting_color => {
                    Ok(PropertyId::Longhand(LonghandId::LightingColor))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_type => {
                    Ok(PropertyId::Longhand(LonghandId::MaskType))
                }
                
    nsCSSPropertyID::eCSSProperty_clip_path => {
                    Ok(PropertyId::Longhand(LonghandId::ClipPath))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_mode => {
                    Ok(PropertyId::Longhand(LonghandId::MaskMode))
                }
                
    nsCSSPropertyID::eCSSProperty_mask_repeat => {
                    Ok(PropertyId::Longhand(LonghandId::MaskRepeat))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskRepeat => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskRepeat,
                            AliasId::WebkitMaskRepeat
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position_x => {
                    Ok(PropertyId::Longhand(LonghandId::MaskPositionX))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionX => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskPositionX,
                            AliasId::WebkitMaskPositionX
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position_y => {
                    Ok(PropertyId::Longhand(LonghandId::MaskPositionY))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionY => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskPositionY,
                            AliasId::WebkitMaskPositionY
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_clip => {
                    Ok(PropertyId::Longhand(LonghandId::MaskClip))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskClip => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskClip,
                            AliasId::WebkitMaskClip
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_origin => {
                    Ok(PropertyId::Longhand(LonghandId::MaskOrigin))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskOrigin => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskOrigin,
                            AliasId::WebkitMaskOrigin
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_size => {
                    Ok(PropertyId::Longhand(LonghandId::MaskSize))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskSize => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskSize,
                            AliasId::WebkitMaskSize
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_composite => {
                    Ok(PropertyId::Longhand(LonghandId::MaskComposite))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskComposite => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskComposite,
                            AliasId::WebkitMaskComposite
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_image => {
                    Ok(PropertyId::Longhand(LonghandId::MaskImage))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskImage => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MaskImage,
                            AliasId::WebkitMaskImage
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_align => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxAlign))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxAlign => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxAlign,
                            AliasId::WebkitBoxAlign
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_direction => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxDirection))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxDirection => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxDirection,
                            AliasId::WebkitBoxDirection
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_flex => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxFlex))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxFlex => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxFlex,
                            AliasId::WebkitBoxFlex
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_orient => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxOrient))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrient => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxOrient,
                            AliasId::WebkitBoxOrient
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_box_pack => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxPack))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxPack => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxPack,
                            AliasId::WebkitBoxPack
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty__moz_stack_sizing => {
                    Ok(PropertyId::Longhand(LonghandId::MozStackSizing))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group => {
                    Ok(PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrdinalGroup => {
                        Ok(PropertyId::LonghandAlias(
                            LonghandId::MozBoxOrdinalGroup,
                            AliasId::WebkitBoxOrdinalGroup
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_background => {
                    Ok(PropertyId::Shorthand(ShorthandId::Background))
                }
                
    nsCSSPropertyID::eCSSProperty_background_position => {
                    Ok(PropertyId::Shorthand(ShorthandId::BackgroundPosition))
                }
                
    nsCSSPropertyID::eCSSProperty_border_color => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderColor))
                }
                
    nsCSSPropertyID::eCSSProperty_border_style => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_border_width => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderWidth))
                }
                
    nsCSSPropertyID::eCSSProperty_border_top => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderTop))
                }
                
    nsCSSPropertyID::eCSSProperty_border_left => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderLeft))
                }
                
    nsCSSPropertyID::eCSSProperty_border_bottom => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBottom))
                }
                
    nsCSSPropertyID::eCSSProperty_border_right => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderRight))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_start => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBlockStart))
                }
                
    nsCSSPropertyID::eCSSProperty_border_block_end => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderBlockEnd))
                }
                
    nsCSSPropertyID::eCSSProperty_border_inline_start => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderInlineStart))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStart => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderInlineStart,
                            AliasId::MozBorderStart
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_inline_end => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderInlineEnd))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEnd => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderInlineEnd,
                            AliasId::MozBorderEnd
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border => {
                    Ok(PropertyId::Shorthand(ShorthandId::Border))
                }
                
    nsCSSPropertyID::eCSSProperty_border_radius => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderRadius))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderRadius => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderRadius,
                            AliasId::WebkitBorderRadius
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_border_image => {
                    Ok(PropertyId::Shorthand(ShorthandId::BorderImage))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderImage => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderImage,
                            AliasId::MozBorderImage
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderImage => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::BorderImage,
                            AliasId::WebkitBorderImage
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_overflow => {
                    Ok(PropertyId::Shorthand(ShorthandId::Overflow))
                }
                
    nsCSSPropertyID::eCSSProperty_overflow_clip_box => {
                    Ok(PropertyId::Shorthand(ShorthandId::OverflowClipBox))
                }
                
    nsCSSPropertyID::eCSSProperty_transition => {
                    Ok(PropertyId::Shorthand(ShorthandId::Transition))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Transition,
                            AliasId::MozTransition
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Transition,
                            AliasId::WebkitTransition
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_animation => {
                    Ok(PropertyId::Shorthand(ShorthandId::Animation))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimation => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Animation,
                            AliasId::MozAnimation
                        ))
                    }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimation => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Animation,
                            AliasId::WebkitAnimation
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_scroll_snap_type => {
                    Ok(PropertyId::Shorthand(ShorthandId::ScrollSnapType))
                }
                
    nsCSSPropertyID::eCSSProperty_overscroll_behavior => {
                    Ok(PropertyId::Shorthand(ShorthandId::OverscrollBehavior))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_transform => {
                    Ok(PropertyId::Shorthand(ShorthandId::MozTransform))
                }
                
    nsCSSPropertyID::eCSSProperty_columns => {
                    Ok(PropertyId::Shorthand(ShorthandId::Columns))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumns => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Columns,
                            AliasId::MozColumns
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_column_rule => {
                    Ok(PropertyId::Shorthand(ShorthandId::ColumnRule))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRule => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::ColumnRule,
                            AliasId::MozColumnRule
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_font => {
                    Ok(PropertyId::Shorthand(ShorthandId::Font))
                }
                
    nsCSSPropertyID::eCSSProperty_font_variant => {
                    Ok(PropertyId::Shorthand(ShorthandId::FontVariant))
                }
                
    nsCSSPropertyID::eCSSProperty_text_emphasis => {
                    Ok(PropertyId::Shorthand(ShorthandId::TextEmphasis))
                }
                
    nsCSSPropertyID::eCSSProperty__webkit_text_stroke => {
                    Ok(PropertyId::Shorthand(ShorthandId::WebkitTextStroke))
                }
                
    nsCSSPropertyID::eCSSProperty_list_style => {
                    Ok(PropertyId::Shorthand(ShorthandId::ListStyle))
                }
                
    nsCSSPropertyID::eCSSProperty_margin => {
                    Ok(PropertyId::Shorthand(ShorthandId::Margin))
                }
                
    nsCSSPropertyID::eCSSProperty_mask => {
                    Ok(PropertyId::Shorthand(ShorthandId::Mask))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMask => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Mask,
                            AliasId::WebkitMask
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_mask_position => {
                    Ok(PropertyId::Shorthand(ShorthandId::MaskPosition))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPosition => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::MaskPosition,
                            AliasId::WebkitMaskPosition
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_outline => {
                    Ok(PropertyId::Shorthand(ShorthandId::Outline))
                }
                
    nsCSSPropertyID::eCSSProperty__moz_outline_radius => {
                    Ok(PropertyId::Shorthand(ShorthandId::MozOutlineRadius))
                }
                
    nsCSSPropertyID::eCSSProperty_padding => {
                    Ok(PropertyId::Shorthand(ShorthandId::Padding))
                }
                
    nsCSSPropertyID::eCSSProperty_flex_flow => {
                    Ok(PropertyId::Shorthand(ShorthandId::FlexFlow))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexFlow => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::FlexFlow,
                            AliasId::WebkitFlexFlow
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_flex => {
                    Ok(PropertyId::Shorthand(ShorthandId::Flex))
                }
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlex => {
                        Ok(PropertyId::ShorthandAlias(
                            ShorthandId::Flex,
                            AliasId::WebkitFlex
                        ))
                    }
                
    nsCSSPropertyID::eCSSProperty_grid_gap => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridGap))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_row => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridRow))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_column => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridColumn))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_area => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridArea))
                }
                
    nsCSSPropertyID::eCSSProperty_grid_template => {
                    Ok(PropertyId::Shorthand(ShorthandId::GridTemplate))
                }
                
    nsCSSPropertyID::eCSSProperty_grid => {
                    Ok(PropertyId::Shorthand(ShorthandId::Grid))
                }
                
    nsCSSPropertyID::eCSSProperty_place_content => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceContent))
                }
                
    nsCSSPropertyID::eCSSProperty_place_self => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceSelf))
                }
                
    nsCSSPropertyID::eCSSProperty_place_items => {
                    Ok(PropertyId::Shorthand(ShorthandId::PlaceItems))
                }
                
    nsCSSPropertyID::eCSSProperty_marker => {
                    Ok(PropertyId::Shorthand(ShorthandId::Marker))
                }
                
    nsCSSPropertyID::eCSSProperty_text_decoration => {
                    Ok(PropertyId::Shorthand(ShorthandId::TextDecoration))
                }
                
    nsCSSPropertyID::eCSSProperty_all => {
                    Ok(PropertyId::Shorthand(ShorthandId::All))
                }
            _ => Err(())
        }
    }

    /// Returns an nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    pub fn to_nscsspropertyid(&self) -> Result<nsCSSPropertyID, ()> {
        match *self {
            PropertyId::Longhand(id) => Ok(id.to_nscsspropertyid()),
            PropertyId::Shorthand(id) => Ok(id.to_nscsspropertyid()),
            PropertyId::LonghandAlias(_, alias) => Ok(alias.to_nscsspropertyid()),
            PropertyId::ShorthandAlias(_, alias) => Ok(alias.to_nscsspropertyid()),
            _ => Err(())
        }
    }

    /// Given this property id, get it either as a shorthand or as a
    /// `PropertyDeclarationId`.
    pub fn as_shorthand(&self) -> Result<ShorthandId, PropertyDeclarationId> {
        match *self {
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => Ok(id),
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => Err(PropertyDeclarationId::Longhand(id)),
            PropertyId::Custom(ref name) => Err(PropertyDeclarationId::Custom(name)),
        }
    }

    /// Returns the name of the property without CSS escaping.
    pub fn name(&self) -> Cow<'static, str> {
        match *self {
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => id.name().into(),
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => id.name().into(),
            PropertyId::Custom(ref name) => {
                let mut s = String::new();
                write!(&mut s, "--{}", name).unwrap();
                s.into()
            }
        }
    }

    fn allowed_in(&self, context: &ParserContext) -> bool {
        let id: NonCustomPropertyId = match *self {
            // Custom properties are allowed everywhere
            PropertyId::Custom(_) => return true,
            PropertyId::Shorthand(shorthand_id) => shorthand_id.into(),
            PropertyId::Longhand(longhand_id) => longhand_id.into(),
            PropertyId::ShorthandAlias(_, alias_id) => alias_id.into(),
            PropertyId::LonghandAlias(_, alias_id) => alias_id.into(),
        };

        debug_assert!(
            matches!(
                context.rule_type(),
                CssRuleType::Keyframe | CssRuleType::Page | CssRuleType::Style
            ),
            "Declarations are only expected inside a keyframe, page, or style rule."
        );

        

        
static DISALLOWED_IN_KEYFRAME_BLOCK: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x80000000, 0x7c, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x2000000, 0x0, 0x1ff86000, 0x0, 0x60000000, 0x0]
};

        
static DISALLOWED_IN_PAGE_RULE: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x3ffffff, 0xfffffffc, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffef, 0xffffffff, 0xfe7fffff, 0xffffffff, 0x1f]
};

        match context.rule_type() {
            CssRuleType::Keyframe if DISALLOWED_IN_KEYFRAME_BLOCK.contains(id) => {
                return false;
            }
            CssRuleType::Page if DISALLOWED_IN_PAGE_RULE.contains(id) => {
                return false;
            }
            _ => {}
        }

        // The semantics of these are kinda hard to reason about, what follows
        // is a description of the different combinations that can happen with
        // these three sets.
        //
        // Experimental properties are generally controlled by prefs, but an
        // experimental property explicitly enabled in certain context (UA or
        // chrome sheets) is always usable in the context regardless of the
        // pref value.
        //
        // Non-experimental properties are either normal properties which are
        // usable everywhere, or internal-only properties which are only usable
        // in certain context they are explicitly enabled in.
        
static ENABLED_IN_UA_SHEETS: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x18403c0, 0x0, 0x0, 0xc300, 0x0, 0x0, 0x0, 0x780000, 0x0, 0x800000, 0x0, 0x0, 0x0, 0x0, 0x0]
};

        
static ENABLED_IN_CHROME: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x3c0, 0x0, 0x0, 0x4000, 0x0, 0x0, 0x0, 0x780000, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0]
};

        
static EXPERIMENTAL: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x200, 0x1800400, 0x1203f780, 0x10080e, 0x502010, 0x4e004, 0x0, 0x0, 0x8000, 0x800, 0x1c800000, 0x800004, 0x0, 0x4000, 0x0, 0x0]
};

        
static ALWAYS_ENABLED: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xfffffdff, 0xfe7bf83f, 0xedfc087f, 0xffeff7f1, 0xffaf002f, 0xfffb1ffb, 0xffffffff, 0xffffffff, 0xff877dff, 0xfffff7ff, 0xe37fffff, 0xff7ffffb, 0xffffffff, 0xffffbfff, 0xffffffff, 0x1f]
};


        let passes_pref_check = || {
                unsafe { structs::nsCSSProps_gPropertyEnabled[self.to_nscsspropertyid().unwrap() as usize] }
        };

        if ALWAYS_ENABLED.contains(id) {
            return true
        }

        if EXPERIMENTAL.contains(id) && passes_pref_check() {
            return true
        }

        if context.stylesheet_origin == Origin::UserAgent &&
            ENABLED_IN_UA_SHEETS.contains(id)
        {
            return true
        }

        if context.chrome_rules_enabled() && ENABLED_IN_CHROME.contains(id) {
            return true
        }

        false
    }
}

/// Servo's representation for a property declaration.
#[cfg_attr(feature = "gecko", derive(MallocSizeOf))]
#[derive(Clone, PartialEq)]
pub enum PropertyDeclaration {
        /// background-color
            BackgroundColor(longhands::background_color::SpecifiedValue),
        /// background-image
            BackgroundImage(longhands::background_image::SpecifiedValue),
        /// background-position-x
            BackgroundPositionX(longhands::background_position_x::SpecifiedValue),
        /// background-position-y
            BackgroundPositionY(longhands::background_position_y::SpecifiedValue),
        /// background-repeat
            BackgroundRepeat(longhands::background_repeat::SpecifiedValue),
        /// background-attachment
            BackgroundAttachment(longhands::background_attachment::SpecifiedValue),
        /// background-clip
            BackgroundClip(longhands::background_clip::SpecifiedValue),
        /// background-origin
            BackgroundOrigin(longhands::background_origin::SpecifiedValue),
        /// background-size
            BackgroundSize(longhands::background_size::SpecifiedValue),
        /// background-blend-mode
            BackgroundBlendMode(longhands::background_blend_mode::SpecifiedValue),
        /// border-top-color
            BorderTopColor(longhands::border_top_color::SpecifiedValue),
        /// border-top-style
            BorderTopStyle(longhands::border_top_style::SpecifiedValue),
        /// border-top-width
            BorderTopWidth(longhands::border_top_width::SpecifiedValue),
        /// border-left-color
            BorderLeftColor(longhands::border_left_color::SpecifiedValue),
        /// border-left-style
            BorderLeftStyle(longhands::border_left_style::SpecifiedValue),
        /// border-left-width
            BorderLeftWidth(longhands::border_left_width::SpecifiedValue),
        /// border-bottom-color
            BorderBottomColor(longhands::border_bottom_color::SpecifiedValue),
        /// border-bottom-style
            BorderBottomStyle(longhands::border_bottom_style::SpecifiedValue),
        /// border-bottom-width
            BorderBottomWidth(longhands::border_bottom_width::SpecifiedValue),
        /// border-right-color
            BorderRightColor(longhands::border_right_color::SpecifiedValue),
        /// border-right-style
            BorderRightStyle(longhands::border_right_style::SpecifiedValue),
        /// border-right-width
            BorderRightWidth(longhands::border_right_width::SpecifiedValue),
        /// border-block-start-color
            BorderBlockStartColor(longhands::border_block_start_color::SpecifiedValue),
        /// border-block-start-style
            BorderBlockStartStyle(longhands::border_block_start_style::SpecifiedValue),
        /// border-block-start-width
            BorderBlockStartWidth(longhands::border_block_start_width::SpecifiedValue),
        /// border-block-end-color
            BorderBlockEndColor(longhands::border_block_end_color::SpecifiedValue),
        /// border-block-end-style
            BorderBlockEndStyle(longhands::border_block_end_style::SpecifiedValue),
        /// border-block-end-width
            BorderBlockEndWidth(longhands::border_block_end_width::SpecifiedValue),
        /// border-inline-start-color
            BorderInlineStartColor(longhands::border_inline_start_color::SpecifiedValue),
        /// border-inline-start-style
            BorderInlineStartStyle(longhands::border_inline_start_style::SpecifiedValue),
        /// border-inline-start-width
            BorderInlineStartWidth(longhands::border_inline_start_width::SpecifiedValue),
        /// border-inline-end-color
            BorderInlineEndColor(longhands::border_inline_end_color::SpecifiedValue),
        /// border-inline-end-style
            BorderInlineEndStyle(longhands::border_inline_end_style::SpecifiedValue),
        /// border-inline-end-width
            BorderInlineEndWidth(longhands::border_inline_end_width::SpecifiedValue),
        /// border-top-left-radius
            BorderTopLeftRadius(Box<longhands::border_top_left_radius::SpecifiedValue>),
        /// border-top-right-radius
            BorderTopRightRadius(Box<longhands::border_top_right_radius::SpecifiedValue>),
        /// border-bottom-right-radius
            BorderBottomRightRadius(Box<longhands::border_bottom_right_radius::SpecifiedValue>),
        /// border-bottom-left-radius
            BorderBottomLeftRadius(Box<longhands::border_bottom_left_radius::SpecifiedValue>),
        /// -moz-border-top-colors
            MozBorderTopColors(longhands::_moz_border_top_colors::SpecifiedValue),
        /// -moz-border-left-colors
            MozBorderLeftColors(longhands::_moz_border_left_colors::SpecifiedValue),
        /// -moz-border-bottom-colors
            MozBorderBottomColors(longhands::_moz_border_bottom_colors::SpecifiedValue),
        /// -moz-border-right-colors
            MozBorderRightColors(longhands::_moz_border_right_colors::SpecifiedValue),
        /// box-decoration-break
            BoxDecorationBreak(longhands::box_decoration_break::SpecifiedValue),
        /// -moz-float-edge
            MozFloatEdge(longhands::_moz_float_edge::SpecifiedValue),
        /// border-image-source
            BorderImageSource(Box<longhands::border_image_source::SpecifiedValue>),
        /// border-image-outset
            BorderImageOutset(Box<longhands::border_image_outset::SpecifiedValue>),
        /// border-image-repeat
            BorderImageRepeat(longhands::border_image_repeat::SpecifiedValue),
        /// border-image-width
            BorderImageWidth(Box<longhands::border_image_width::SpecifiedValue>),
        /// border-image-slice
            BorderImageSlice(Box<longhands::border_image_slice::SpecifiedValue>),
        /// display
            Display(longhands::display::SpecifiedValue),
        /// -moz-top-layer
            MozTopLayer(longhands::_moz_top_layer::SpecifiedValue),
        /// position
            Position(longhands::position::SpecifiedValue),
        /// float
            Float(longhands::float::SpecifiedValue),
        /// clear
            Clear(longhands::clear::SpecifiedValue),
        /// vertical-align
            VerticalAlign(longhands::vertical_align::SpecifiedValue),
        /// overflow-clip-box-inline
            OverflowClipBoxInline(longhands::overflow_clip_box_inline::SpecifiedValue),
        /// overflow-clip-box-block
            OverflowClipBoxBlock(longhands::overflow_clip_box_block::SpecifiedValue),
        /// overflow-x
            OverflowX(longhands::overflow_x::SpecifiedValue),
        /// overflow-y
            OverflowY(longhands::overflow_y::SpecifiedValue),
        /// transition-duration
            TransitionDuration(longhands::transition_duration::SpecifiedValue),
        /// transition-timing-function
            TransitionTimingFunction(longhands::transition_timing_function::SpecifiedValue),
        /// transition-property
            TransitionProperty(longhands::transition_property::SpecifiedValue),
        /// transition-delay
            TransitionDelay(longhands::transition_delay::SpecifiedValue),
        /// animation-name
            AnimationName(longhands::animation_name::SpecifiedValue),
        /// animation-duration
            AnimationDuration(longhands::animation_duration::SpecifiedValue),
        /// animation-timing-function
            AnimationTimingFunction(longhands::animation_timing_function::SpecifiedValue),
        /// animation-iteration-count
            AnimationIterationCount(longhands::animation_iteration_count::SpecifiedValue),
        /// animation-direction
            AnimationDirection(longhands::animation_direction::SpecifiedValue),
        /// animation-play-state
            AnimationPlayState(longhands::animation_play_state::SpecifiedValue),
        /// animation-fill-mode
            AnimationFillMode(longhands::animation_fill_mode::SpecifiedValue),
        /// animation-delay
            AnimationDelay(longhands::animation_delay::SpecifiedValue),
        /// scroll-snap-points-x
            ScrollSnapPointsX(longhands::scroll_snap_points_x::SpecifiedValue),
        /// scroll-snap-points-y
            ScrollSnapPointsY(longhands::scroll_snap_points_y::SpecifiedValue),
        /// scroll-snap-destination
            ScrollSnapDestination(Box<longhands::scroll_snap_destination::SpecifiedValue>),
        /// scroll-snap-coordinate
            ScrollSnapCoordinate(longhands::scroll_snap_coordinate::SpecifiedValue),
        /// transform
            Transform(longhands::transform::SpecifiedValue),
        /// scroll-behavior
            ScrollBehavior(longhands::scroll_behavior::SpecifiedValue),
        /// scroll-snap-type-x
            ScrollSnapTypeX(longhands::scroll_snap_type_x::SpecifiedValue),
        /// scroll-snap-type-y
            ScrollSnapTypeY(longhands::scroll_snap_type_y::SpecifiedValue),
        /// overscroll-behavior-x
            OverscrollBehaviorX(longhands::overscroll_behavior_x::SpecifiedValue),
        /// overscroll-behavior-y
            OverscrollBehaviorY(longhands::overscroll_behavior_y::SpecifiedValue),
        /// isolation
            Isolation(longhands::isolation::SpecifiedValue),
        /// page-break-after
            PageBreakAfter(longhands::page_break_after::SpecifiedValue),
        /// page-break-before
            PageBreakBefore(longhands::page_break_before::SpecifiedValue),
        /// page-break-inside
            PageBreakInside(longhands::page_break_inside::SpecifiedValue),
        /// resize
            Resize(longhands::resize::SpecifiedValue),
        /// perspective
            Perspective(longhands::perspective::SpecifiedValue),
        /// perspective-origin
            PerspectiveOrigin(Box<longhands::perspective_origin::SpecifiedValue>),
        /// backface-visibility
            BackfaceVisibility(longhands::backface_visibility::SpecifiedValue),
        /// transform-box
            TransformBox(longhands::transform_box::SpecifiedValue),
        /// transform-style
            TransformStyle(longhands::transform_style::SpecifiedValue),
        /// transform-origin
            TransformOrigin(Box<longhands::transform_origin::SpecifiedValue>),
        /// contain
            Contain(longhands::contain::SpecifiedValue),
        /// -moz-appearance
            MozAppearance(longhands::_moz_appearance::SpecifiedValue),
        /// -moz-binding
            MozBinding(Box<longhands::_moz_binding::SpecifiedValue>),
        /// -moz-orient
            MozOrient(longhands::_moz_orient::SpecifiedValue),
        /// will-change
            WillChange(longhands::will_change::SpecifiedValue),
        /// shape-image-threshold
            ShapeImageThreshold(longhands::shape_image_threshold::SpecifiedValue),
        /// shape-outside
            ShapeOutside(Box<longhands::shape_outside::SpecifiedValue>),
        /// touch-action
            TouchAction(longhands::touch_action::SpecifiedValue),
        /// color
            Color(longhands::color::SpecifiedValue),
        /// column-width
            ColumnWidth(longhands::column_width::SpecifiedValue),
        /// column-count
            ColumnCount(longhands::column_count::SpecifiedValue),
        /// column-gap
            ColumnGap(longhands::column_gap::SpecifiedValue),
        /// column-fill
            ColumnFill(longhands::column_fill::SpecifiedValue),
        /// column-rule-width
            ColumnRuleWidth(longhands::column_rule_width::SpecifiedValue),
        /// column-rule-color
            ColumnRuleColor(longhands::column_rule_color::SpecifiedValue),
        /// column-span
            ColumnSpan(longhands::column_span::SpecifiedValue),
        /// column-rule-style
            ColumnRuleStyle(longhands::column_rule_style::SpecifiedValue),
        /// content
            Content(Box<longhands::content::SpecifiedValue>),
        /// counter-increment
            CounterIncrement(longhands::counter_increment::SpecifiedValue),
        /// counter-reset
            CounterReset(longhands::counter_reset::SpecifiedValue),
        /// opacity
            Opacity(longhands::opacity::SpecifiedValue),
        /// box-shadow
            BoxShadow(longhands::box_shadow::SpecifiedValue),
        /// clip
            Clip(Box<longhands::clip::SpecifiedValue>),
        /// filter
            Filter(longhands::filter::SpecifiedValue),
        /// mix-blend-mode
            MixBlendMode(longhands::mix_blend_mode::SpecifiedValue),
        /// font-family
            FontFamily(longhands::font_family::SpecifiedValue),
        /// font-style
            FontStyle(longhands::font_style::SpecifiedValue),
        /// font-variant-caps
            FontVariantCaps(longhands::font_variant_caps::SpecifiedValue),
        /// font-weight
            FontWeight(longhands::font_weight::SpecifiedValue),
        /// font-size
            FontSize(longhands::font_size::SpecifiedValue),
        /// font-size-adjust
            FontSizeAdjust(longhands::font_size_adjust::SpecifiedValue),
        /// font-synthesis
            FontSynthesis(longhands::font_synthesis::SpecifiedValue),
        /// font-stretch
            FontStretch(longhands::font_stretch::SpecifiedValue),
        /// font-kerning
            FontKerning(longhands::font_kerning::SpecifiedValue),
        /// font-variant-alternates
            FontVariantAlternates(longhands::font_variant_alternates::SpecifiedValue),
        /// font-variant-east-asian
            FontVariantEastAsian(longhands::font_variant_east_asian::SpecifiedValue),
        /// font-variant-ligatures
            FontVariantLigatures(longhands::font_variant_ligatures::SpecifiedValue),
        /// font-variant-numeric
            FontVariantNumeric(longhands::font_variant_numeric::SpecifiedValue),
        /// font-variant-position
            FontVariantPosition(longhands::font_variant_position::SpecifiedValue),
        /// font-feature-settings
            FontFeatureSettings(Box<longhands::font_feature_settings::SpecifiedValue>),
        /// font-variation-settings
            FontVariationSettings(longhands::font_variation_settings::SpecifiedValue),
        /// font-language-override
            FontLanguageOverride(longhands::font_language_override::SpecifiedValue),
        /// -x-lang
            XLang(longhands::_x_lang::SpecifiedValue),
        /// -moz-script-size-multiplier
            MozScriptSizeMultiplier(longhands::_moz_script_size_multiplier::SpecifiedValue),
        /// -moz-script-level
            MozScriptLevel(longhands::_moz_script_level::SpecifiedValue),
        /// -moz-math-display
            MozMathDisplay(longhands::_moz_math_display::SpecifiedValue),
        /// -moz-math-variant
            MozMathVariant(longhands::_moz_math_variant::SpecifiedValue),
        /// -moz-script-min-size
            MozScriptMinSize(longhands::_moz_script_min_size::SpecifiedValue),
        /// -x-text-zoom
            XTextZoom(longhands::_x_text_zoom::SpecifiedValue),
        /// -moz-osx-font-smoothing
            MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::SpecifiedValue),
        /// -moz-font-smoothing-background-color
            MozFontSmoothingBackgroundColor(longhands::_moz_font_smoothing_background_color::SpecifiedValue),
        /// -moz-min-font-size-ratio
            MozMinFontSizeRatio(longhands::_moz_min_font_size_ratio::SpecifiedValue),
        /// visibility
            Visibility(longhands::visibility::SpecifiedValue),
        /// writing-mode
            WritingMode(longhands::writing_mode::SpecifiedValue),
        /// direction
            Direction(longhands::direction::SpecifiedValue),
        /// text-orientation
            TextOrientation(longhands::text_orientation::SpecifiedValue),
        /// color-adjust
            ColorAdjust(longhands::color_adjust::SpecifiedValue),
        /// image-rendering
            ImageRendering(longhands::image_rendering::SpecifiedValue),
        /// image-orientation
            ImageOrientation(longhands::image_orientation::SpecifiedValue),
        /// border-collapse
            BorderCollapse(longhands::border_collapse::SpecifiedValue),
        /// empty-cells
            EmptyCells(longhands::empty_cells::SpecifiedValue),
        /// caption-side
            CaptionSide(longhands::caption_side::SpecifiedValue),
        /// border-spacing
            BorderSpacing(Box<longhands::border_spacing::SpecifiedValue>),
        /// line-height
            LineHeight(longhands::line_height::SpecifiedValue),
        /// text-transform
            TextTransform(longhands::text_transform::SpecifiedValue),
        /// hyphens
            Hyphens(longhands::hyphens::SpecifiedValue),
        /// -moz-text-size-adjust
            MozTextSizeAdjust(longhands::_moz_text_size_adjust::SpecifiedValue),
        /// text-indent
            TextIndent(longhands::text_indent::SpecifiedValue),
        /// overflow-wrap
            OverflowWrap(longhands::overflow_wrap::SpecifiedValue),
        /// word-break
            WordBreak(longhands::word_break::SpecifiedValue),
        /// text-justify
            TextJustify(longhands::text_justify::SpecifiedValue),
        /// text-align-last
            TextAlignLast(longhands::text_align_last::SpecifiedValue),
        /// text-align
            TextAlign(longhands::text_align::SpecifiedValue),
        /// letter-spacing
            LetterSpacing(longhands::letter_spacing::SpecifiedValue),
        /// word-spacing
            WordSpacing(longhands::word_spacing::SpecifiedValue),
        /// white-space
            WhiteSpace(longhands::white_space::SpecifiedValue),
        /// text-shadow
            TextShadow(longhands::text_shadow::SpecifiedValue),
        /// text-emphasis-style
            TextEmphasisStyle(Box<longhands::text_emphasis_style::SpecifiedValue>),
        /// text-emphasis-position
            TextEmphasisPosition(longhands::text_emphasis_position::SpecifiedValue),
        /// text-emphasis-color
            TextEmphasisColor(longhands::text_emphasis_color::SpecifiedValue),
        /// -moz-tab-size
            MozTabSize(longhands::_moz_tab_size::SpecifiedValue),
        /// -webkit-text-fill-color
            WebkitTextFillColor(longhands::_webkit_text_fill_color::SpecifiedValue),
        /// -webkit-text-stroke-color
            WebkitTextStrokeColor(longhands::_webkit_text_stroke_color::SpecifiedValue),
        /// -webkit-text-stroke-width
            WebkitTextStrokeWidth(longhands::_webkit_text_stroke_width::SpecifiedValue),
        /// ruby-align
            RubyAlign(longhands::ruby_align::SpecifiedValue),
        /// ruby-position
            RubyPosition(longhands::ruby_position::SpecifiedValue),
        /// text-combine-upright
            TextCombineUpright(longhands::text_combine_upright::SpecifiedValue),
        /// text-rendering
            TextRendering(longhands::text_rendering::SpecifiedValue),
        /// -moz-control-character-visibility
            MozControlCharacterVisibility(longhands::_moz_control_character_visibility::SpecifiedValue),
        /// list-style-position
            ListStylePosition(longhands::list_style_position::SpecifiedValue),
        /// list-style-type
            ListStyleType(Box<longhands::list_style_type::SpecifiedValue>),
        /// list-style-image
            ListStyleImage(Box<longhands::list_style_image::SpecifiedValue>),
        /// quotes
            Quotes(longhands::quotes::SpecifiedValue),
        /// -moz-image-region
            MozImageRegion(Box<longhands::_moz_image_region::SpecifiedValue>),
        /// margin-top
            MarginTop(longhands::margin_top::SpecifiedValue),
        /// margin-left
            MarginLeft(longhands::margin_left::SpecifiedValue),
        /// margin-bottom
            MarginBottom(longhands::margin_bottom::SpecifiedValue),
        /// margin-right
            MarginRight(longhands::margin_right::SpecifiedValue),
        /// margin-block-start
            MarginBlockStart(longhands::margin_block_start::SpecifiedValue),
        /// margin-block-end
            MarginBlockEnd(longhands::margin_block_end::SpecifiedValue),
        /// margin-inline-start
            MarginInlineStart(longhands::margin_inline_start::SpecifiedValue),
        /// margin-inline-end
            MarginInlineEnd(longhands::margin_inline_end::SpecifiedValue),
        /// outline-color
            OutlineColor(longhands::outline_color::SpecifiedValue),
        /// outline-style
            OutlineStyle(longhands::outline_style::SpecifiedValue),
        /// outline-width
            OutlineWidth(longhands::outline_width::SpecifiedValue),
        /// -moz-outline-radius-topleft
            MozOutlineRadiusTopleft(Box<longhands::_moz_outline_radius_topleft::SpecifiedValue>),
        /// -moz-outline-radius-topright
            MozOutlineRadiusTopright(Box<longhands::_moz_outline_radius_topright::SpecifiedValue>),
        /// -moz-outline-radius-bottomright
            MozOutlineRadiusBottomright(Box<longhands::_moz_outline_radius_bottomright::SpecifiedValue>),
        /// -moz-outline-radius-bottomleft
            MozOutlineRadiusBottomleft(Box<longhands::_moz_outline_radius_bottomleft::SpecifiedValue>),
        /// outline-offset
            OutlineOffset(longhands::outline_offset::SpecifiedValue),
        /// padding-top
            PaddingTop(longhands::padding_top::SpecifiedValue),
        /// padding-left
            PaddingLeft(longhands::padding_left::SpecifiedValue),
        /// padding-bottom
            PaddingBottom(longhands::padding_bottom::SpecifiedValue),
        /// padding-right
            PaddingRight(longhands::padding_right::SpecifiedValue),
        /// padding-block-start
            PaddingBlockStart(longhands::padding_block_start::SpecifiedValue),
        /// padding-block-end
            PaddingBlockEnd(longhands::padding_block_end::SpecifiedValue),
        /// padding-inline-start
            PaddingInlineStart(longhands::padding_inline_start::SpecifiedValue),
        /// padding-inline-end
            PaddingInlineEnd(longhands::padding_inline_end::SpecifiedValue),
        /// cursor
            Cursor(longhands::cursor::SpecifiedValue),
        /// pointer-events
            PointerEvents(longhands::pointer_events::SpecifiedValue),
        /// -moz-user-input
            MozUserInput(longhands::_moz_user_input::SpecifiedValue),
        /// -moz-user-modify
            MozUserModify(longhands::_moz_user_modify::SpecifiedValue),
        /// -moz-user-focus
            MozUserFocus(longhands::_moz_user_focus::SpecifiedValue),
        /// caret-color
            CaretColor(longhands::caret_color::SpecifiedValue),
        /// top
            Top(longhands::top::SpecifiedValue),
        /// left
            Left(longhands::left::SpecifiedValue),
        /// bottom
            Bottom(longhands::bottom::SpecifiedValue),
        /// right
            Right(longhands::right::SpecifiedValue),
        /// offset-block-start
            OffsetBlockStart(longhands::offset_block_start::SpecifiedValue),
        /// offset-block-end
            OffsetBlockEnd(longhands::offset_block_end::SpecifiedValue),
        /// offset-inline-start
            OffsetInlineStart(longhands::offset_inline_start::SpecifiedValue),
        /// offset-inline-end
            OffsetInlineEnd(longhands::offset_inline_end::SpecifiedValue),
        /// z-index
            ZIndex(longhands::z_index::SpecifiedValue),
        /// flex-direction
            FlexDirection(longhands::flex_direction::SpecifiedValue),
        /// flex-wrap
            FlexWrap(longhands::flex_wrap::SpecifiedValue),
        /// justify-content
            JustifyContent(longhands::justify_content::SpecifiedValue),
        /// align-content
            AlignContent(longhands::align_content::SpecifiedValue),
        /// align-items
            AlignItems(longhands::align_items::SpecifiedValue),
        /// justify-items
            JustifyItems(longhands::justify_items::SpecifiedValue),
        /// flex-grow
            FlexGrow(longhands::flex_grow::SpecifiedValue),
        /// flex-shrink
            FlexShrink(longhands::flex_shrink::SpecifiedValue),
        /// align-self
            AlignSelf(longhands::align_self::SpecifiedValue),
        /// justify-self
            JustifySelf(longhands::justify_self::SpecifiedValue),
        /// order
            Order(longhands::order::SpecifiedValue),
        /// flex-basis
            FlexBasis(longhands::flex_basis::SpecifiedValue),
        /// width
            Width(longhands::width::SpecifiedValue),
        /// min-width
            MinWidth(longhands::min_width::SpecifiedValue),
        /// max-width
            MaxWidth(longhands::max_width::SpecifiedValue),
        /// height
            Height(longhands::height::SpecifiedValue),
        /// min-height
            MinHeight(longhands::min_height::SpecifiedValue),
        /// max-height
            MaxHeight(longhands::max_height::SpecifiedValue),
        /// block-size
            BlockSize(longhands::block_size::SpecifiedValue),
        /// min-block-size
            MinBlockSize(longhands::min_block_size::SpecifiedValue),
        /// max-block-size
            MaxBlockSize(longhands::max_block_size::SpecifiedValue),
        /// inline-size
            InlineSize(longhands::inline_size::SpecifiedValue),
        /// min-inline-size
            MinInlineSize(longhands::min_inline_size::SpecifiedValue),
        /// max-inline-size
            MaxInlineSize(longhands::max_inline_size::SpecifiedValue),
        /// box-sizing
            BoxSizing(longhands::box_sizing::SpecifiedValue),
        /// object-fit
            ObjectFit(longhands::object_fit::SpecifiedValue),
        /// object-position
            ObjectPosition(Box<longhands::object_position::SpecifiedValue>),
        /// grid-row-gap
            GridRowGap(longhands::grid_row_gap::SpecifiedValue),
        /// grid-row-start
            GridRowStart(Box<longhands::grid_row_start::SpecifiedValue>),
        /// grid-row-end
            GridRowEnd(Box<longhands::grid_row_end::SpecifiedValue>),
        /// grid-auto-rows
            GridAutoRows(Box<longhands::grid_auto_rows::SpecifiedValue>),
        /// grid-template-rows
            GridTemplateRows(Box<longhands::grid_template_rows::SpecifiedValue>),
        /// grid-column-gap
            GridColumnGap(longhands::grid_column_gap::SpecifiedValue),
        /// grid-column-start
            GridColumnStart(Box<longhands::grid_column_start::SpecifiedValue>),
        /// grid-column-end
            GridColumnEnd(Box<longhands::grid_column_end::SpecifiedValue>),
        /// grid-auto-columns
            GridAutoColumns(Box<longhands::grid_auto_columns::SpecifiedValue>),
        /// grid-template-columns
            GridTemplateColumns(Box<longhands::grid_template_columns::SpecifiedValue>),
        /// grid-auto-flow
            GridAutoFlow(longhands::grid_auto_flow::SpecifiedValue),
        /// grid-template-areas
            GridTemplateAreas(Box<longhands::grid_template_areas::SpecifiedValue>),
        /// table-layout
            TableLayout(longhands::table_layout::SpecifiedValue),
        /// -x-span
            XSpan(longhands::_x_span::SpecifiedValue),
        /// text-overflow
            TextOverflow(Box<longhands::text_overflow::SpecifiedValue>),
        /// unicode-bidi
            UnicodeBidi(longhands::unicode_bidi::SpecifiedValue),
        /// text-decoration-line
            TextDecorationLine(longhands::text_decoration_line::SpecifiedValue),
        /// text-decoration-style
            TextDecorationStyle(longhands::text_decoration_style::SpecifiedValue),
        /// text-decoration-color
            TextDecorationColor(longhands::text_decoration_color::SpecifiedValue),
        /// initial-letter
            InitialLetter(longhands::initial_letter::SpecifiedValue),
        /// ime-mode
            ImeMode(longhands::ime_mode::SpecifiedValue),
        /// -moz-user-select
            MozUserSelect(longhands::_moz_user_select::SpecifiedValue),
        /// -moz-window-dragging
            MozWindowDragging(longhands::_moz_window_dragging::SpecifiedValue),
        /// -moz-window-shadow
            MozWindowShadow(longhands::_moz_window_shadow::SpecifiedValue),
        /// -moz-window-opacity
            MozWindowOpacity(longhands::_moz_window_opacity::SpecifiedValue),
        /// -moz-window-transform
            MozWindowTransform(longhands::_moz_window_transform::SpecifiedValue),
        /// -moz-window-transform-origin
            MozWindowTransformOrigin(Box<longhands::_moz_window_transform_origin::SpecifiedValue>),
        /// -moz-force-broken-image-icon
            MozForceBrokenImageIcon(longhands::_moz_force_broken_image_icon::SpecifiedValue),
        /// text-anchor
            TextAnchor(longhands::text_anchor::SpecifiedValue),
        /// color-interpolation
            ColorInterpolation(longhands::color_interpolation::SpecifiedValue),
        /// color-interpolation-filters
            ColorInterpolationFilters(longhands::color_interpolation_filters::SpecifiedValue),
        /// fill
            Fill(Box<longhands::fill::SpecifiedValue>),
        /// fill-opacity
            FillOpacity(longhands::fill_opacity::SpecifiedValue),
        /// fill-rule
            FillRule(longhands::fill_rule::SpecifiedValue),
        /// shape-rendering
            ShapeRendering(longhands::shape_rendering::SpecifiedValue),
        /// stroke
            Stroke(Box<longhands::stroke::SpecifiedValue>),
        /// stroke-width
            StrokeWidth(longhands::stroke_width::SpecifiedValue),
        /// stroke-linecap
            StrokeLinecap(longhands::stroke_linecap::SpecifiedValue),
        /// stroke-linejoin
            StrokeLinejoin(longhands::stroke_linejoin::SpecifiedValue),
        /// stroke-miterlimit
            StrokeMiterlimit(longhands::stroke_miterlimit::SpecifiedValue),
        /// stroke-opacity
            StrokeOpacity(longhands::stroke_opacity::SpecifiedValue),
        /// stroke-dasharray
            StrokeDasharray(longhands::stroke_dasharray::SpecifiedValue),
        /// stroke-dashoffset
            StrokeDashoffset(longhands::stroke_dashoffset::SpecifiedValue),
        /// clip-rule
            ClipRule(longhands::clip_rule::SpecifiedValue),
        /// marker-start
            MarkerStart(Box<longhands::marker_start::SpecifiedValue>),
        /// marker-mid
            MarkerMid(Box<longhands::marker_mid::SpecifiedValue>),
        /// marker-end
            MarkerEnd(Box<longhands::marker_end::SpecifiedValue>),
        /// paint-order
            PaintOrder(longhands::paint_order::SpecifiedValue),
        /// -moz-context-properties
            MozContextProperties(longhands::_moz_context_properties::SpecifiedValue),
        /// dominant-baseline
            DominantBaseline(longhands::dominant_baseline::SpecifiedValue),
        /// vector-effect
            VectorEffect(longhands::vector_effect::SpecifiedValue),
        /// stop-color
            StopColor(longhands::stop_color::SpecifiedValue),
        /// stop-opacity
            StopOpacity(longhands::stop_opacity::SpecifiedValue),
        /// flood-color
            FloodColor(longhands::flood_color::SpecifiedValue),
        /// flood-opacity
            FloodOpacity(longhands::flood_opacity::SpecifiedValue),
        /// lighting-color
            LightingColor(longhands::lighting_color::SpecifiedValue),
        /// mask-type
            MaskType(longhands::mask_type::SpecifiedValue),
        /// clip-path
            ClipPath(Box<longhands::clip_path::SpecifiedValue>),
        /// mask-mode
            MaskMode(longhands::mask_mode::SpecifiedValue),
        /// mask-repeat
            MaskRepeat(longhands::mask_repeat::SpecifiedValue),
        /// mask-position-x
            MaskPositionX(longhands::mask_position_x::SpecifiedValue),
        /// mask-position-y
            MaskPositionY(longhands::mask_position_y::SpecifiedValue),
        /// mask-clip
            MaskClip(longhands::mask_clip::SpecifiedValue),
        /// mask-origin
            MaskOrigin(longhands::mask_origin::SpecifiedValue),
        /// mask-size
            MaskSize(longhands::mask_size::SpecifiedValue),
        /// mask-composite
            MaskComposite(longhands::mask_composite::SpecifiedValue),
        /// mask-image
            MaskImage(longhands::mask_image::SpecifiedValue),
        /// -moz-box-align
            MozBoxAlign(longhands::_moz_box_align::SpecifiedValue),
        /// -moz-box-direction
            MozBoxDirection(longhands::_moz_box_direction::SpecifiedValue),
        /// -moz-box-flex
            MozBoxFlex(longhands::_moz_box_flex::SpecifiedValue),
        /// -moz-box-orient
            MozBoxOrient(longhands::_moz_box_orient::SpecifiedValue),
        /// -moz-box-pack
            MozBoxPack(longhands::_moz_box_pack::SpecifiedValue),
        /// -moz-stack-sizing
            MozStackSizing(longhands::_moz_stack_sizing::SpecifiedValue),
        /// -moz-box-ordinal-group
            MozBoxOrdinalGroup(longhands::_moz_box_ordinal_group::SpecifiedValue),
    /// A css-wide keyword.
    CSSWideKeyword(LonghandId, CSSWideKeyword),
    /// An unparsed value that contains `var()` functions.
    WithVariables(
        LonghandId,
        #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
        Arc<UnparsedValue>
    ),
    /// A custom property declaration, with the property name and the declared
    /// value.
    #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
    Custom(
        ::custom_properties::Name,
        #[cfg_attr(feature = "gecko", ignore_malloc_size_of = "XXX: how to handle this?")]
        DeclaredValueOwned<Arc<::custom_properties::SpecifiedValue>>
    ),
}

impl fmt::Debug for PropertyDeclaration {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        self.id().to_css(&mut CssWriter::new(f))?;
        f.write_str(": ")?;

        // Because PropertyDeclaration::to_css requires CssStringWriter, we can't write
        // it directly to f, and need to allocate an intermediate string. This is
        // fine for debug-only code.
        let mut s = CssString::new();
        self.to_css(&mut s)?;
        write!(f, "{}", s)
    }
}

impl PropertyDeclaration {
    /// Like the method on ToCss, but without the type parameter to avoid
    /// accidentally monomorphizing this large function multiple times for
    /// different writers.
    pub fn to_css(&self, dest: &mut CssStringWriter) -> fmt::Result {
        match *self {
            PropertyDeclaration::BackgroundColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundImage(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundPositionX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundPositionY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundRepeat(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundAttachment(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundClip(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundOrigin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackgroundBlendMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderTopColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderTopStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderTopWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderLeftColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderLeftStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderLeftWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBottomColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBottomStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBottomWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderRightColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderRightStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderRightWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderTopRightRadius(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBorderTopColors(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBorderLeftColors(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBorderBottomColors(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBorderRightColors(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BoxDecorationBreak(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozFloatEdge(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderImageSource(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderImageOutset(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderImageRepeat(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderImageWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderImageSlice(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Display(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozTopLayer(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Position(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Float(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Clear(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::VerticalAlign(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverflowX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverflowY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransitionDuration(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransitionTimingFunction(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransitionProperty(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransitionDelay(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationName(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationDuration(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationTimingFunction(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationIterationCount(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationDirection(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationPlayState(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationFillMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AnimationDelay(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapPointsX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapPointsY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapDestination(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapCoordinate(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Transform(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollBehavior(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapTypeX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ScrollSnapTypeY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Isolation(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PageBreakAfter(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PageBreakBefore(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PageBreakInside(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Resize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Perspective(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PerspectiveOrigin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BackfaceVisibility(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransformBox(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransformStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TransformOrigin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Contain(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozAppearance(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBinding(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOrient(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WillChange(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ShapeImageThreshold(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ShapeOutside(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TouchAction(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Color(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnCount(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnGap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnFill(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnRuleWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnRuleColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnSpan(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColumnRuleStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Content(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::CounterIncrement(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::CounterReset(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Opacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BoxShadow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Clip(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Filter(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MixBlendMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontFamily(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantCaps(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontWeight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontSizeAdjust(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontSynthesis(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontStretch(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontKerning(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantAlternates(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantLigatures(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantNumeric(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariantPosition(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontFeatureSettings(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontVariationSettings(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FontLanguageOverride(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::XLang(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozScriptSizeMultiplier(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozScriptLevel(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozMathDisplay(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozMathVariant(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozScriptMinSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::XTextZoom(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOsxFontSmoothing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozFontSmoothingBackgroundColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozMinFontSizeRatio(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Visibility(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WritingMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Direction(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextOrientation(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColorAdjust(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ImageRendering(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ImageOrientation(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderCollapse(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::EmptyCells(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::CaptionSide(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BorderSpacing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::LineHeight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextTransform(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Hyphens(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozTextSizeAdjust(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextIndent(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OverflowWrap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WordBreak(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextJustify(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextAlignLast(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextAlign(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::LetterSpacing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WordSpacing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WhiteSpace(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextShadow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextEmphasisPosition(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextEmphasisColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozTabSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WebkitTextFillColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::RubyAlign(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::RubyPosition(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextCombineUpright(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextRendering(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozControlCharacterVisibility(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ListStylePosition(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ListStyleType(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ListStyleImage(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Quotes(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozImageRegion(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginTop(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginLeft(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginBottom(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginRight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginBlockStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginBlockEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginInlineStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarginInlineEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OutlineColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OutlineStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OutlineWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOutlineRadiusTopleft(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOutlineRadiusTopright(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOutlineRadiusBottomright(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozOutlineRadiusBottomleft(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OutlineOffset(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingTop(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingLeft(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingBottom(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingRight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingBlockStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingBlockEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingInlineStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaddingInlineEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Cursor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PointerEvents(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozUserInput(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozUserModify(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozUserFocus(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::CaretColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Top(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Left(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Bottom(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Right(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OffsetBlockStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OffsetBlockEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OffsetInlineStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::OffsetInlineEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ZIndex(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FlexDirection(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FlexWrap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::JustifyContent(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AlignContent(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AlignItems(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::JustifyItems(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FlexGrow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FlexShrink(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::AlignSelf(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::JustifySelf(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Order(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FlexBasis(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Width(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MinWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaxWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Height(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MinHeight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaxHeight(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BlockSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MinBlockSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaxBlockSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::InlineSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MinInlineSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaxInlineSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::BoxSizing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ObjectFit(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ObjectPosition(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridRowGap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridRowStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridRowEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridAutoRows(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridTemplateRows(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridColumnGap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridColumnStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridColumnEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridAutoColumns(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridTemplateColumns(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridAutoFlow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::GridTemplateAreas(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TableLayout(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::XSpan(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextOverflow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::UnicodeBidi(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextDecorationLine(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextDecorationStyle(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextDecorationColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::InitialLetter(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ImeMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozUserSelect(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozWindowDragging(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozWindowShadow(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozWindowOpacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozWindowTransform(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozWindowTransformOrigin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozForceBrokenImageIcon(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::TextAnchor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColorInterpolation(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ColorInterpolationFilters(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Fill(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FillOpacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FillRule(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ShapeRendering(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::Stroke(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeWidth(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeLinecap(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeLinejoin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeMiterlimit(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeOpacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeDasharray(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StrokeDashoffset(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ClipRule(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarkerStart(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarkerMid(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MarkerEnd(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::PaintOrder(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozContextProperties(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::DominantBaseline(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::VectorEffect(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StopColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::StopOpacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FloodColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::FloodOpacity(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::LightingColor(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskType(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::ClipPath(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskMode(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskRepeat(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskPositionX(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskPositionY(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskClip(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskOrigin(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskSize(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskComposite(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MaskImage(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxAlign(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxDirection(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxFlex(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxOrient(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxPack(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozStackSizing(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::MozBoxOrdinalGroup(ref value) => {
                value.to_css(&mut CssWriter::new(dest))
            }
            PropertyDeclaration::CSSWideKeyword(_, keyword) => {
                keyword.to_css(&mut CssWriter::new(dest))
            },
            PropertyDeclaration::WithVariables(_, ref with_variables) => {
                // https://drafts.csswg.org/css-variables/#variables-in-shorthands
                match with_variables.from_shorthand {
                    // Normally, we shouldn't be printing variables here if they came from
                    // shorthands. But we should allow properties that came from shorthand
                    // aliases. That also matches with the Gecko behavior.
                    Some(shorthand) if shorthand.flags().contains(PropertyFlags::SHORTHAND_ALIAS_PROPERTY) =>
                        dest.write_str(&*with_variables.css)?,
                    None => dest.write_str(&*with_variables.css)?,
                    _ => {},
                }
                Ok(())
            },
            PropertyDeclaration::Custom(_, ref value) => {
                value.borrow().to_css(&mut CssWriter::new(dest))
            },
        }
    }
}

impl PropertyDeclaration {
    /// Given a property declaration, return the property declaration id.
    pub fn id(&self) -> PropertyDeclarationId {
        match *self {
            PropertyDeclaration::Custom(ref name, _) => {
                return PropertyDeclarationId::Custom(name)
            }
            PropertyDeclaration::CSSWideKeyword(id, _) |
            PropertyDeclaration::WithVariables(id, _) => {
                return PropertyDeclarationId::Longhand(id)
            }
            _ => {}
        }
        let longhand_id = match *self {
                PropertyDeclaration::BackgroundColor(..) => {
                    LonghandId::BackgroundColor
                }
                PropertyDeclaration::BackgroundImage(..) => {
                    LonghandId::BackgroundImage
                }
                PropertyDeclaration::BackgroundPositionX(..) => {
                    LonghandId::BackgroundPositionX
                }
                PropertyDeclaration::BackgroundPositionY(..) => {
                    LonghandId::BackgroundPositionY
                }
                PropertyDeclaration::BackgroundRepeat(..) => {
                    LonghandId::BackgroundRepeat
                }
                PropertyDeclaration::BackgroundAttachment(..) => {
                    LonghandId::BackgroundAttachment
                }
                PropertyDeclaration::BackgroundClip(..) => {
                    LonghandId::BackgroundClip
                }
                PropertyDeclaration::BackgroundOrigin(..) => {
                    LonghandId::BackgroundOrigin
                }
                PropertyDeclaration::BackgroundSize(..) => {
                    LonghandId::BackgroundSize
                }
                PropertyDeclaration::BackgroundBlendMode(..) => {
                    LonghandId::BackgroundBlendMode
                }
                PropertyDeclaration::BorderTopColor(..) => {
                    LonghandId::BorderTopColor
                }
                PropertyDeclaration::BorderTopStyle(..) => {
                    LonghandId::BorderTopStyle
                }
                PropertyDeclaration::BorderTopWidth(..) => {
                    LonghandId::BorderTopWidth
                }
                PropertyDeclaration::BorderLeftColor(..) => {
                    LonghandId::BorderLeftColor
                }
                PropertyDeclaration::BorderLeftStyle(..) => {
                    LonghandId::BorderLeftStyle
                }
                PropertyDeclaration::BorderLeftWidth(..) => {
                    LonghandId::BorderLeftWidth
                }
                PropertyDeclaration::BorderBottomColor(..) => {
                    LonghandId::BorderBottomColor
                }
                PropertyDeclaration::BorderBottomStyle(..) => {
                    LonghandId::BorderBottomStyle
                }
                PropertyDeclaration::BorderBottomWidth(..) => {
                    LonghandId::BorderBottomWidth
                }
                PropertyDeclaration::BorderRightColor(..) => {
                    LonghandId::BorderRightColor
                }
                PropertyDeclaration::BorderRightStyle(..) => {
                    LonghandId::BorderRightStyle
                }
                PropertyDeclaration::BorderRightWidth(..) => {
                    LonghandId::BorderRightWidth
                }
                PropertyDeclaration::BorderBlockStartColor(..) => {
                    LonghandId::BorderBlockStartColor
                }
                PropertyDeclaration::BorderBlockStartStyle(..) => {
                    LonghandId::BorderBlockStartStyle
                }
                PropertyDeclaration::BorderBlockStartWidth(..) => {
                    LonghandId::BorderBlockStartWidth
                }
                PropertyDeclaration::BorderBlockEndColor(..) => {
                    LonghandId::BorderBlockEndColor
                }
                PropertyDeclaration::BorderBlockEndStyle(..) => {
                    LonghandId::BorderBlockEndStyle
                }
                PropertyDeclaration::BorderBlockEndWidth(..) => {
                    LonghandId::BorderBlockEndWidth
                }
                PropertyDeclaration::BorderInlineStartColor(..) => {
                    LonghandId::BorderInlineStartColor
                }
                PropertyDeclaration::BorderInlineStartStyle(..) => {
                    LonghandId::BorderInlineStartStyle
                }
                PropertyDeclaration::BorderInlineStartWidth(..) => {
                    LonghandId::BorderInlineStartWidth
                }
                PropertyDeclaration::BorderInlineEndColor(..) => {
                    LonghandId::BorderInlineEndColor
                }
                PropertyDeclaration::BorderInlineEndStyle(..) => {
                    LonghandId::BorderInlineEndStyle
                }
                PropertyDeclaration::BorderInlineEndWidth(..) => {
                    LonghandId::BorderInlineEndWidth
                }
                PropertyDeclaration::BorderTopLeftRadius(..) => {
                    LonghandId::BorderTopLeftRadius
                }
                PropertyDeclaration::BorderTopRightRadius(..) => {
                    LonghandId::BorderTopRightRadius
                }
                PropertyDeclaration::BorderBottomRightRadius(..) => {
                    LonghandId::BorderBottomRightRadius
                }
                PropertyDeclaration::BorderBottomLeftRadius(..) => {
                    LonghandId::BorderBottomLeftRadius
                }
                PropertyDeclaration::MozBorderTopColors(..) => {
                    LonghandId::MozBorderTopColors
                }
                PropertyDeclaration::MozBorderLeftColors(..) => {
                    LonghandId::MozBorderLeftColors
                }
                PropertyDeclaration::MozBorderBottomColors(..) => {
                    LonghandId::MozBorderBottomColors
                }
                PropertyDeclaration::MozBorderRightColors(..) => {
                    LonghandId::MozBorderRightColors
                }
                PropertyDeclaration::BoxDecorationBreak(..) => {
                    LonghandId::BoxDecorationBreak
                }
                PropertyDeclaration::MozFloatEdge(..) => {
                    LonghandId::MozFloatEdge
                }
                PropertyDeclaration::BorderImageSource(..) => {
                    LonghandId::BorderImageSource
                }
                PropertyDeclaration::BorderImageOutset(..) => {
                    LonghandId::BorderImageOutset
                }
                PropertyDeclaration::BorderImageRepeat(..) => {
                    LonghandId::BorderImageRepeat
                }
                PropertyDeclaration::BorderImageWidth(..) => {
                    LonghandId::BorderImageWidth
                }
                PropertyDeclaration::BorderImageSlice(..) => {
                    LonghandId::BorderImageSlice
                }
                PropertyDeclaration::Display(..) => {
                    LonghandId::Display
                }
                PropertyDeclaration::MozTopLayer(..) => {
                    LonghandId::MozTopLayer
                }
                PropertyDeclaration::Position(..) => {
                    LonghandId::Position
                }
                PropertyDeclaration::Float(..) => {
                    LonghandId::Float
                }
                PropertyDeclaration::Clear(..) => {
                    LonghandId::Clear
                }
                PropertyDeclaration::VerticalAlign(..) => {
                    LonghandId::VerticalAlign
                }
                PropertyDeclaration::OverflowClipBoxInline(..) => {
                    LonghandId::OverflowClipBoxInline
                }
                PropertyDeclaration::OverflowClipBoxBlock(..) => {
                    LonghandId::OverflowClipBoxBlock
                }
                PropertyDeclaration::OverflowX(..) => {
                    LonghandId::OverflowX
                }
                PropertyDeclaration::OverflowY(..) => {
                    LonghandId::OverflowY
                }
                PropertyDeclaration::TransitionDuration(..) => {
                    LonghandId::TransitionDuration
                }
                PropertyDeclaration::TransitionTimingFunction(..) => {
                    LonghandId::TransitionTimingFunction
                }
                PropertyDeclaration::TransitionProperty(..) => {
                    LonghandId::TransitionProperty
                }
                PropertyDeclaration::TransitionDelay(..) => {
                    LonghandId::TransitionDelay
                }
                PropertyDeclaration::AnimationName(..) => {
                    LonghandId::AnimationName
                }
                PropertyDeclaration::AnimationDuration(..) => {
                    LonghandId::AnimationDuration
                }
                PropertyDeclaration::AnimationTimingFunction(..) => {
                    LonghandId::AnimationTimingFunction
                }
                PropertyDeclaration::AnimationIterationCount(..) => {
                    LonghandId::AnimationIterationCount
                }
                PropertyDeclaration::AnimationDirection(..) => {
                    LonghandId::AnimationDirection
                }
                PropertyDeclaration::AnimationPlayState(..) => {
                    LonghandId::AnimationPlayState
                }
                PropertyDeclaration::AnimationFillMode(..) => {
                    LonghandId::AnimationFillMode
                }
                PropertyDeclaration::AnimationDelay(..) => {
                    LonghandId::AnimationDelay
                }
                PropertyDeclaration::ScrollSnapPointsX(..) => {
                    LonghandId::ScrollSnapPointsX
                }
                PropertyDeclaration::ScrollSnapPointsY(..) => {
                    LonghandId::ScrollSnapPointsY
                }
                PropertyDeclaration::ScrollSnapDestination(..) => {
                    LonghandId::ScrollSnapDestination
                }
                PropertyDeclaration::ScrollSnapCoordinate(..) => {
                    LonghandId::ScrollSnapCoordinate
                }
                PropertyDeclaration::Transform(..) => {
                    LonghandId::Transform
                }
                PropertyDeclaration::ScrollBehavior(..) => {
                    LonghandId::ScrollBehavior
                }
                PropertyDeclaration::ScrollSnapTypeX(..) => {
                    LonghandId::ScrollSnapTypeX
                }
                PropertyDeclaration::ScrollSnapTypeY(..) => {
                    LonghandId::ScrollSnapTypeY
                }
                PropertyDeclaration::OverscrollBehaviorX(..) => {
                    LonghandId::OverscrollBehaviorX
                }
                PropertyDeclaration::OverscrollBehaviorY(..) => {
                    LonghandId::OverscrollBehaviorY
                }
                PropertyDeclaration::Isolation(..) => {
                    LonghandId::Isolation
                }
                PropertyDeclaration::PageBreakAfter(..) => {
                    LonghandId::PageBreakAfter
                }
                PropertyDeclaration::PageBreakBefore(..) => {
                    LonghandId::PageBreakBefore
                }
                PropertyDeclaration::PageBreakInside(..) => {
                    LonghandId::PageBreakInside
                }
                PropertyDeclaration::Resize(..) => {
                    LonghandId::Resize
                }
                PropertyDeclaration::Perspective(..) => {
                    LonghandId::Perspective
                }
                PropertyDeclaration::PerspectiveOrigin(..) => {
                    LonghandId::PerspectiveOrigin
                }
                PropertyDeclaration::BackfaceVisibility(..) => {
                    LonghandId::BackfaceVisibility
                }
                PropertyDeclaration::TransformBox(..) => {
                    LonghandId::TransformBox
                }
                PropertyDeclaration::TransformStyle(..) => {
                    LonghandId::TransformStyle
                }
                PropertyDeclaration::TransformOrigin(..) => {
                    LonghandId::TransformOrigin
                }
                PropertyDeclaration::Contain(..) => {
                    LonghandId::Contain
                }
                PropertyDeclaration::MozAppearance(..) => {
                    LonghandId::MozAppearance
                }
                PropertyDeclaration::MozBinding(..) => {
                    LonghandId::MozBinding
                }
                PropertyDeclaration::MozOrient(..) => {
                    LonghandId::MozOrient
                }
                PropertyDeclaration::WillChange(..) => {
                    LonghandId::WillChange
                }
                PropertyDeclaration::ShapeImageThreshold(..) => {
                    LonghandId::ShapeImageThreshold
                }
                PropertyDeclaration::ShapeOutside(..) => {
                    LonghandId::ShapeOutside
                }
                PropertyDeclaration::TouchAction(..) => {
                    LonghandId::TouchAction
                }
                PropertyDeclaration::Color(..) => {
                    LonghandId::Color
                }
                PropertyDeclaration::ColumnWidth(..) => {
                    LonghandId::ColumnWidth
                }
                PropertyDeclaration::ColumnCount(..) => {
                    LonghandId::ColumnCount
                }
                PropertyDeclaration::ColumnGap(..) => {
                    LonghandId::ColumnGap
                }
                PropertyDeclaration::ColumnFill(..) => {
                    LonghandId::ColumnFill
                }
                PropertyDeclaration::ColumnRuleWidth(..) => {
                    LonghandId::ColumnRuleWidth
                }
                PropertyDeclaration::ColumnRuleColor(..) => {
                    LonghandId::ColumnRuleColor
                }
                PropertyDeclaration::ColumnSpan(..) => {
                    LonghandId::ColumnSpan
                }
                PropertyDeclaration::ColumnRuleStyle(..) => {
                    LonghandId::ColumnRuleStyle
                }
                PropertyDeclaration::Content(..) => {
                    LonghandId::Content
                }
                PropertyDeclaration::CounterIncrement(..) => {
                    LonghandId::CounterIncrement
                }
                PropertyDeclaration::CounterReset(..) => {
                    LonghandId::CounterReset
                }
                PropertyDeclaration::Opacity(..) => {
                    LonghandId::Opacity
                }
                PropertyDeclaration::BoxShadow(..) => {
                    LonghandId::BoxShadow
                }
                PropertyDeclaration::Clip(..) => {
                    LonghandId::Clip
                }
                PropertyDeclaration::Filter(..) => {
                    LonghandId::Filter
                }
                PropertyDeclaration::MixBlendMode(..) => {
                    LonghandId::MixBlendMode
                }
                PropertyDeclaration::FontFamily(..) => {
                    LonghandId::FontFamily
                }
                PropertyDeclaration::FontStyle(..) => {
                    LonghandId::FontStyle
                }
                PropertyDeclaration::FontVariantCaps(..) => {
                    LonghandId::FontVariantCaps
                }
                PropertyDeclaration::FontWeight(..) => {
                    LonghandId::FontWeight
                }
                PropertyDeclaration::FontSize(..) => {
                    LonghandId::FontSize
                }
                PropertyDeclaration::FontSizeAdjust(..) => {
                    LonghandId::FontSizeAdjust
                }
                PropertyDeclaration::FontSynthesis(..) => {
                    LonghandId::FontSynthesis
                }
                PropertyDeclaration::FontStretch(..) => {
                    LonghandId::FontStretch
                }
                PropertyDeclaration::FontKerning(..) => {
                    LonghandId::FontKerning
                }
                PropertyDeclaration::FontVariantAlternates(..) => {
                    LonghandId::FontVariantAlternates
                }
                PropertyDeclaration::FontVariantEastAsian(..) => {
                    LonghandId::FontVariantEastAsian
                }
                PropertyDeclaration::FontVariantLigatures(..) => {
                    LonghandId::FontVariantLigatures
                }
                PropertyDeclaration::FontVariantNumeric(..) => {
                    LonghandId::FontVariantNumeric
                }
                PropertyDeclaration::FontVariantPosition(..) => {
                    LonghandId::FontVariantPosition
                }
                PropertyDeclaration::FontFeatureSettings(..) => {
                    LonghandId::FontFeatureSettings
                }
                PropertyDeclaration::FontVariationSettings(..) => {
                    LonghandId::FontVariationSettings
                }
                PropertyDeclaration::FontLanguageOverride(..) => {
                    LonghandId::FontLanguageOverride
                }
                PropertyDeclaration::XLang(..) => {
                    LonghandId::XLang
                }
                PropertyDeclaration::MozScriptSizeMultiplier(..) => {
                    LonghandId::MozScriptSizeMultiplier
                }
                PropertyDeclaration::MozScriptLevel(..) => {
                    LonghandId::MozScriptLevel
                }
                PropertyDeclaration::MozMathDisplay(..) => {
                    LonghandId::MozMathDisplay
                }
                PropertyDeclaration::MozMathVariant(..) => {
                    LonghandId::MozMathVariant
                }
                PropertyDeclaration::MozScriptMinSize(..) => {
                    LonghandId::MozScriptMinSize
                }
                PropertyDeclaration::XTextZoom(..) => {
                    LonghandId::XTextZoom
                }
                PropertyDeclaration::MozOsxFontSmoothing(..) => {
                    LonghandId::MozOsxFontSmoothing
                }
                PropertyDeclaration::MozFontSmoothingBackgroundColor(..) => {
                    LonghandId::MozFontSmoothingBackgroundColor
                }
                PropertyDeclaration::MozMinFontSizeRatio(..) => {
                    LonghandId::MozMinFontSizeRatio
                }
                PropertyDeclaration::Visibility(..) => {
                    LonghandId::Visibility
                }
                PropertyDeclaration::WritingMode(..) => {
                    LonghandId::WritingMode
                }
                PropertyDeclaration::Direction(..) => {
                    LonghandId::Direction
                }
                PropertyDeclaration::TextOrientation(..) => {
                    LonghandId::TextOrientation
                }
                PropertyDeclaration::ColorAdjust(..) => {
                    LonghandId::ColorAdjust
                }
                PropertyDeclaration::ImageRendering(..) => {
                    LonghandId::ImageRendering
                }
                PropertyDeclaration::ImageOrientation(..) => {
                    LonghandId::ImageOrientation
                }
                PropertyDeclaration::BorderCollapse(..) => {
                    LonghandId::BorderCollapse
                }
                PropertyDeclaration::EmptyCells(..) => {
                    LonghandId::EmptyCells
                }
                PropertyDeclaration::CaptionSide(..) => {
                    LonghandId::CaptionSide
                }
                PropertyDeclaration::BorderSpacing(..) => {
                    LonghandId::BorderSpacing
                }
                PropertyDeclaration::LineHeight(..) => {
                    LonghandId::LineHeight
                }
                PropertyDeclaration::TextTransform(..) => {
                    LonghandId::TextTransform
                }
                PropertyDeclaration::Hyphens(..) => {
                    LonghandId::Hyphens
                }
                PropertyDeclaration::MozTextSizeAdjust(..) => {
                    LonghandId::MozTextSizeAdjust
                }
                PropertyDeclaration::TextIndent(..) => {
                    LonghandId::TextIndent
                }
                PropertyDeclaration::OverflowWrap(..) => {
                    LonghandId::OverflowWrap
                }
                PropertyDeclaration::WordBreak(..) => {
                    LonghandId::WordBreak
                }
                PropertyDeclaration::TextJustify(..) => {
                    LonghandId::TextJustify
                }
                PropertyDeclaration::TextAlignLast(..) => {
                    LonghandId::TextAlignLast
                }
                PropertyDeclaration::TextAlign(..) => {
                    LonghandId::TextAlign
                }
                PropertyDeclaration::LetterSpacing(..) => {
                    LonghandId::LetterSpacing
                }
                PropertyDeclaration::WordSpacing(..) => {
                    LonghandId::WordSpacing
                }
                PropertyDeclaration::WhiteSpace(..) => {
                    LonghandId::WhiteSpace
                }
                PropertyDeclaration::TextShadow(..) => {
                    LonghandId::TextShadow
                }
                PropertyDeclaration::TextEmphasisStyle(..) => {
                    LonghandId::TextEmphasisStyle
                }
                PropertyDeclaration::TextEmphasisPosition(..) => {
                    LonghandId::TextEmphasisPosition
                }
                PropertyDeclaration::TextEmphasisColor(..) => {
                    LonghandId::TextEmphasisColor
                }
                PropertyDeclaration::MozTabSize(..) => {
                    LonghandId::MozTabSize
                }
                PropertyDeclaration::WebkitTextFillColor(..) => {
                    LonghandId::WebkitTextFillColor
                }
                PropertyDeclaration::WebkitTextStrokeColor(..) => {
                    LonghandId::WebkitTextStrokeColor
                }
                PropertyDeclaration::WebkitTextStrokeWidth(..) => {
                    LonghandId::WebkitTextStrokeWidth
                }
                PropertyDeclaration::RubyAlign(..) => {
                    LonghandId::RubyAlign
                }
                PropertyDeclaration::RubyPosition(..) => {
                    LonghandId::RubyPosition
                }
                PropertyDeclaration::TextCombineUpright(..) => {
                    LonghandId::TextCombineUpright
                }
                PropertyDeclaration::TextRendering(..) => {
                    LonghandId::TextRendering
                }
                PropertyDeclaration::MozControlCharacterVisibility(..) => {
                    LonghandId::MozControlCharacterVisibility
                }
                PropertyDeclaration::ListStylePosition(..) => {
                    LonghandId::ListStylePosition
                }
                PropertyDeclaration::ListStyleType(..) => {
                    LonghandId::ListStyleType
                }
                PropertyDeclaration::ListStyleImage(..) => {
                    LonghandId::ListStyleImage
                }
                PropertyDeclaration::Quotes(..) => {
                    LonghandId::Quotes
                }
                PropertyDeclaration::MozImageRegion(..) => {
                    LonghandId::MozImageRegion
                }
                PropertyDeclaration::MarginTop(..) => {
                    LonghandId::MarginTop
                }
                PropertyDeclaration::MarginLeft(..) => {
                    LonghandId::MarginLeft
                }
                PropertyDeclaration::MarginBottom(..) => {
                    LonghandId::MarginBottom
                }
                PropertyDeclaration::MarginRight(..) => {
                    LonghandId::MarginRight
                }
                PropertyDeclaration::MarginBlockStart(..) => {
                    LonghandId::MarginBlockStart
                }
                PropertyDeclaration::MarginBlockEnd(..) => {
                    LonghandId::MarginBlockEnd
                }
                PropertyDeclaration::MarginInlineStart(..) => {
                    LonghandId::MarginInlineStart
                }
                PropertyDeclaration::MarginInlineEnd(..) => {
                    LonghandId::MarginInlineEnd
                }
                PropertyDeclaration::OutlineColor(..) => {
                    LonghandId::OutlineColor
                }
                PropertyDeclaration::OutlineStyle(..) => {
                    LonghandId::OutlineStyle
                }
                PropertyDeclaration::OutlineWidth(..) => {
                    LonghandId::OutlineWidth
                }
                PropertyDeclaration::MozOutlineRadiusTopleft(..) => {
                    LonghandId::MozOutlineRadiusTopleft
                }
                PropertyDeclaration::MozOutlineRadiusTopright(..) => {
                    LonghandId::MozOutlineRadiusTopright
                }
                PropertyDeclaration::MozOutlineRadiusBottomright(..) => {
                    LonghandId::MozOutlineRadiusBottomright
                }
                PropertyDeclaration::MozOutlineRadiusBottomleft(..) => {
                    LonghandId::MozOutlineRadiusBottomleft
                }
                PropertyDeclaration::OutlineOffset(..) => {
                    LonghandId::OutlineOffset
                }
                PropertyDeclaration::PaddingTop(..) => {
                    LonghandId::PaddingTop
                }
                PropertyDeclaration::PaddingLeft(..) => {
                    LonghandId::PaddingLeft
                }
                PropertyDeclaration::PaddingBottom(..) => {
                    LonghandId::PaddingBottom
                }
                PropertyDeclaration::PaddingRight(..) => {
                    LonghandId::PaddingRight
                }
                PropertyDeclaration::PaddingBlockStart(..) => {
                    LonghandId::PaddingBlockStart
                }
                PropertyDeclaration::PaddingBlockEnd(..) => {
                    LonghandId::PaddingBlockEnd
                }
                PropertyDeclaration::PaddingInlineStart(..) => {
                    LonghandId::PaddingInlineStart
                }
                PropertyDeclaration::PaddingInlineEnd(..) => {
                    LonghandId::PaddingInlineEnd
                }
                PropertyDeclaration::Cursor(..) => {
                    LonghandId::Cursor
                }
                PropertyDeclaration::PointerEvents(..) => {
                    LonghandId::PointerEvents
                }
                PropertyDeclaration::MozUserInput(..) => {
                    LonghandId::MozUserInput
                }
                PropertyDeclaration::MozUserModify(..) => {
                    LonghandId::MozUserModify
                }
                PropertyDeclaration::MozUserFocus(..) => {
                    LonghandId::MozUserFocus
                }
                PropertyDeclaration::CaretColor(..) => {
                    LonghandId::CaretColor
                }
                PropertyDeclaration::Top(..) => {
                    LonghandId::Top
                }
                PropertyDeclaration::Left(..) => {
                    LonghandId::Left
                }
                PropertyDeclaration::Bottom(..) => {
                    LonghandId::Bottom
                }
                PropertyDeclaration::Right(..) => {
                    LonghandId::Right
                }
                PropertyDeclaration::OffsetBlockStart(..) => {
                    LonghandId::OffsetBlockStart
                }
                PropertyDeclaration::OffsetBlockEnd(..) => {
                    LonghandId::OffsetBlockEnd
                }
                PropertyDeclaration::OffsetInlineStart(..) => {
                    LonghandId::OffsetInlineStart
                }
                PropertyDeclaration::OffsetInlineEnd(..) => {
                    LonghandId::OffsetInlineEnd
                }
                PropertyDeclaration::ZIndex(..) => {
                    LonghandId::ZIndex
                }
                PropertyDeclaration::FlexDirection(..) => {
                    LonghandId::FlexDirection
                }
                PropertyDeclaration::FlexWrap(..) => {
                    LonghandId::FlexWrap
                }
                PropertyDeclaration::JustifyContent(..) => {
                    LonghandId::JustifyContent
                }
                PropertyDeclaration::AlignContent(..) => {
                    LonghandId::AlignContent
                }
                PropertyDeclaration::AlignItems(..) => {
                    LonghandId::AlignItems
                }
                PropertyDeclaration::JustifyItems(..) => {
                    LonghandId::JustifyItems
                }
                PropertyDeclaration::FlexGrow(..) => {
                    LonghandId::FlexGrow
                }
                PropertyDeclaration::FlexShrink(..) => {
                    LonghandId::FlexShrink
                }
                PropertyDeclaration::AlignSelf(..) => {
                    LonghandId::AlignSelf
                }
                PropertyDeclaration::JustifySelf(..) => {
                    LonghandId::JustifySelf
                }
                PropertyDeclaration::Order(..) => {
                    LonghandId::Order
                }
                PropertyDeclaration::FlexBasis(..) => {
                    LonghandId::FlexBasis
                }
                PropertyDeclaration::Width(..) => {
                    LonghandId::Width
                }
                PropertyDeclaration::MinWidth(..) => {
                    LonghandId::MinWidth
                }
                PropertyDeclaration::MaxWidth(..) => {
                    LonghandId::MaxWidth
                }
                PropertyDeclaration::Height(..) => {
                    LonghandId::Height
                }
                PropertyDeclaration::MinHeight(..) => {
                    LonghandId::MinHeight
                }
                PropertyDeclaration::MaxHeight(..) => {
                    LonghandId::MaxHeight
                }
                PropertyDeclaration::BlockSize(..) => {
                    LonghandId::BlockSize
                }
                PropertyDeclaration::MinBlockSize(..) => {
                    LonghandId::MinBlockSize
                }
                PropertyDeclaration::MaxBlockSize(..) => {
                    LonghandId::MaxBlockSize
                }
                PropertyDeclaration::InlineSize(..) => {
                    LonghandId::InlineSize
                }
                PropertyDeclaration::MinInlineSize(..) => {
                    LonghandId::MinInlineSize
                }
                PropertyDeclaration::MaxInlineSize(..) => {
                    LonghandId::MaxInlineSize
                }
                PropertyDeclaration::BoxSizing(..) => {
                    LonghandId::BoxSizing
                }
                PropertyDeclaration::ObjectFit(..) => {
                    LonghandId::ObjectFit
                }
                PropertyDeclaration::ObjectPosition(..) => {
                    LonghandId::ObjectPosition
                }
                PropertyDeclaration::GridRowGap(..) => {
                    LonghandId::GridRowGap
                }
                PropertyDeclaration::GridRowStart(..) => {
                    LonghandId::GridRowStart
                }
                PropertyDeclaration::GridRowEnd(..) => {
                    LonghandId::GridRowEnd
                }
                PropertyDeclaration::GridAutoRows(..) => {
                    LonghandId::GridAutoRows
                }
                PropertyDeclaration::GridTemplateRows(..) => {
                    LonghandId::GridTemplateRows
                }
                PropertyDeclaration::GridColumnGap(..) => {
                    LonghandId::GridColumnGap
                }
                PropertyDeclaration::GridColumnStart(..) => {
                    LonghandId::GridColumnStart
                }
                PropertyDeclaration::GridColumnEnd(..) => {
                    LonghandId::GridColumnEnd
                }
                PropertyDeclaration::GridAutoColumns(..) => {
                    LonghandId::GridAutoColumns
                }
                PropertyDeclaration::GridTemplateColumns(..) => {
                    LonghandId::GridTemplateColumns
                }
                PropertyDeclaration::GridAutoFlow(..) => {
                    LonghandId::GridAutoFlow
                }
                PropertyDeclaration::GridTemplateAreas(..) => {
                    LonghandId::GridTemplateAreas
                }
                PropertyDeclaration::TableLayout(..) => {
                    LonghandId::TableLayout
                }
                PropertyDeclaration::XSpan(..) => {
                    LonghandId::XSpan
                }
                PropertyDeclaration::TextOverflow(..) => {
                    LonghandId::TextOverflow
                }
                PropertyDeclaration::UnicodeBidi(..) => {
                    LonghandId::UnicodeBidi
                }
                PropertyDeclaration::TextDecorationLine(..) => {
                    LonghandId::TextDecorationLine
                }
                PropertyDeclaration::TextDecorationStyle(..) => {
                    LonghandId::TextDecorationStyle
                }
                PropertyDeclaration::TextDecorationColor(..) => {
                    LonghandId::TextDecorationColor
                }
                PropertyDeclaration::InitialLetter(..) => {
                    LonghandId::InitialLetter
                }
                PropertyDeclaration::ImeMode(..) => {
                    LonghandId::ImeMode
                }
                PropertyDeclaration::MozUserSelect(..) => {
                    LonghandId::MozUserSelect
                }
                PropertyDeclaration::MozWindowDragging(..) => {
                    LonghandId::MozWindowDragging
                }
                PropertyDeclaration::MozWindowShadow(..) => {
                    LonghandId::MozWindowShadow
                }
                PropertyDeclaration::MozWindowOpacity(..) => {
                    LonghandId::MozWindowOpacity
                }
                PropertyDeclaration::MozWindowTransform(..) => {
                    LonghandId::MozWindowTransform
                }
                PropertyDeclaration::MozWindowTransformOrigin(..) => {
                    LonghandId::MozWindowTransformOrigin
                }
                PropertyDeclaration::MozForceBrokenImageIcon(..) => {
                    LonghandId::MozForceBrokenImageIcon
                }
                PropertyDeclaration::TextAnchor(..) => {
                    LonghandId::TextAnchor
                }
                PropertyDeclaration::ColorInterpolation(..) => {
                    LonghandId::ColorInterpolation
                }
                PropertyDeclaration::ColorInterpolationFilters(..) => {
                    LonghandId::ColorInterpolationFilters
                }
                PropertyDeclaration::Fill(..) => {
                    LonghandId::Fill
                }
                PropertyDeclaration::FillOpacity(..) => {
                    LonghandId::FillOpacity
                }
                PropertyDeclaration::FillRule(..) => {
                    LonghandId::FillRule
                }
                PropertyDeclaration::ShapeRendering(..) => {
                    LonghandId::ShapeRendering
                }
                PropertyDeclaration::Stroke(..) => {
                    LonghandId::Stroke
                }
                PropertyDeclaration::StrokeWidth(..) => {
                    LonghandId::StrokeWidth
                }
                PropertyDeclaration::StrokeLinecap(..) => {
                    LonghandId::StrokeLinecap
                }
                PropertyDeclaration::StrokeLinejoin(..) => {
                    LonghandId::StrokeLinejoin
                }
                PropertyDeclaration::StrokeMiterlimit(..) => {
                    LonghandId::StrokeMiterlimit
                }
                PropertyDeclaration::StrokeOpacity(..) => {
                    LonghandId::StrokeOpacity
                }
                PropertyDeclaration::StrokeDasharray(..) => {
                    LonghandId::StrokeDasharray
                }
                PropertyDeclaration::StrokeDashoffset(..) => {
                    LonghandId::StrokeDashoffset
                }
                PropertyDeclaration::ClipRule(..) => {
                    LonghandId::ClipRule
                }
                PropertyDeclaration::MarkerStart(..) => {
                    LonghandId::MarkerStart
                }
                PropertyDeclaration::MarkerMid(..) => {
                    LonghandId::MarkerMid
                }
                PropertyDeclaration::MarkerEnd(..) => {
                    LonghandId::MarkerEnd
                }
                PropertyDeclaration::PaintOrder(..) => {
                    LonghandId::PaintOrder
                }
                PropertyDeclaration::MozContextProperties(..) => {
                    LonghandId::MozContextProperties
                }
                PropertyDeclaration::DominantBaseline(..) => {
                    LonghandId::DominantBaseline
                }
                PropertyDeclaration::VectorEffect(..) => {
                    LonghandId::VectorEffect
                }
                PropertyDeclaration::StopColor(..) => {
                    LonghandId::StopColor
                }
                PropertyDeclaration::StopOpacity(..) => {
                    LonghandId::StopOpacity
                }
                PropertyDeclaration::FloodColor(..) => {
                    LonghandId::FloodColor
                }
                PropertyDeclaration::FloodOpacity(..) => {
                    LonghandId::FloodOpacity
                }
                PropertyDeclaration::LightingColor(..) => {
                    LonghandId::LightingColor
                }
                PropertyDeclaration::MaskType(..) => {
                    LonghandId::MaskType
                }
                PropertyDeclaration::ClipPath(..) => {
                    LonghandId::ClipPath
                }
                PropertyDeclaration::MaskMode(..) => {
                    LonghandId::MaskMode
                }
                PropertyDeclaration::MaskRepeat(..) => {
                    LonghandId::MaskRepeat
                }
                PropertyDeclaration::MaskPositionX(..) => {
                    LonghandId::MaskPositionX
                }
                PropertyDeclaration::MaskPositionY(..) => {
                    LonghandId::MaskPositionY
                }
                PropertyDeclaration::MaskClip(..) => {
                    LonghandId::MaskClip
                }
                PropertyDeclaration::MaskOrigin(..) => {
                    LonghandId::MaskOrigin
                }
                PropertyDeclaration::MaskSize(..) => {
                    LonghandId::MaskSize
                }
                PropertyDeclaration::MaskComposite(..) => {
                    LonghandId::MaskComposite
                }
                PropertyDeclaration::MaskImage(..) => {
                    LonghandId::MaskImage
                }
                PropertyDeclaration::MozBoxAlign(..) => {
                    LonghandId::MozBoxAlign
                }
                PropertyDeclaration::MozBoxDirection(..) => {
                    LonghandId::MozBoxDirection
                }
                PropertyDeclaration::MozBoxFlex(..) => {
                    LonghandId::MozBoxFlex
                }
                PropertyDeclaration::MozBoxOrient(..) => {
                    LonghandId::MozBoxOrient
                }
                PropertyDeclaration::MozBoxPack(..) => {
                    LonghandId::MozBoxPack
                }
                PropertyDeclaration::MozStackSizing(..) => {
                    LonghandId::MozStackSizing
                }
                PropertyDeclaration::MozBoxOrdinalGroup(..) => {
                    LonghandId::MozBoxOrdinalGroup
                }
            PropertyDeclaration::CSSWideKeyword(..) |
            PropertyDeclaration::WithVariables(..) |
            PropertyDeclaration::Custom(..) => {
                debug_assert!(false, "unreachable");
                // This value is never used, but having an expression of the same "shape"
                // as for other variants helps the optimizer compile this `match` expression
                // to a lookup table.
                LonghandId::BackgroundColor
            }
        };
        PropertyDeclarationId::Longhand(longhand_id)
    }

    fn with_variables_from_shorthand(&self, shorthand: ShorthandId) -> Option< &str> {
        match *self {
            PropertyDeclaration::WithVariables(_, ref with_variables) => {
                if let Some(s) = with_variables.from_shorthand {
                    if s == shorthand {
                        Some(&*with_variables.css)
                    } else { None }
                } else {
                    // Normally, longhand property that doesn't come from a shorthand
                    // should return None here. But we return Some to longhands if they
                    // came from a shorthand alias. Because for example, we should be able to
                    // get -moz-transform's value from transform.
                    if shorthand.flags().contains(PropertyFlags::SHORTHAND_ALIAS_PROPERTY) {
                        return Some(&*with_variables.css);
                    }
                    None
                }
            },
            _ => None,
        }
    }

    /// Returns a CSS-wide keyword if the declaration's value is one.
    pub fn get_css_wide_keyword(&self) -> Option<CSSWideKeyword> {
        match *self {
            PropertyDeclaration::CSSWideKeyword(_, keyword) => Some(keyword),
            _ => None,
        }
    }

    /// Returns whether or not the property is set by a system font
    #[cfg(feature = "gecko")]
    pub fn get_system(&self) -> Option<SystemFont> {
        match *self {
                PropertyDeclaration::FontFamily(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontSize(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStyle(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantCaps(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStretch(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontKerning(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantPosition(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontWeight(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontSizeAdjust(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantAlternates(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantLigatures(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantEastAsian(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontVariantNumeric(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontLanguageOverride(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontFeatureSettings(ref prop) => {
                    prop.get_system()
                }
            _ => None,
        }
    }

    /// Is it the default value of line-height?
    pub fn is_default_line_height(&self) -> bool {
        match *self {
            PropertyDeclaration::LineHeight(LineHeight::Normal) => true,
            _ => false
        }
    }

    #[cfg(feature = "servo")]
    /// Dummy method to avoid cfg()s
    pub fn get_system(&self) -> Option<()> {
        None
    }

    /// Returns whether the declaration may be serialized as part of a shorthand.
    ///
    /// This method returns false if this declaration contains variable or has a
    /// CSS-wide keyword value, since these values cannot be serialized as part
    /// of a shorthand.
    ///
    /// Caller should check `with_variables_from_shorthand()` and whether all
    /// needed declarations has the same CSS-wide keyword first.
    ///
    /// Note that, serialization of a shorthand may still fail because of other
    /// property-specific requirement even when this method returns true for all
    /// the longhand declarations.
    pub fn may_serialize_as_part_of_shorthand(&self) -> bool {
        match *self {
            PropertyDeclaration::CSSWideKeyword(..) |
            PropertyDeclaration::WithVariables(..) => false,
            PropertyDeclaration::Custom(..) =>
                unreachable!("Serializing a custom property as part of shorthand?"),
            _ => true,
        }
    }

    /// Return whether the value is stored as it was in the CSS source,
    /// preserving whitespace (as opposed to being parsed into a more abstract
    /// data structure).
    ///
    /// This is the case of custom properties and values that contain
    /// unsubstituted variables.
    pub fn value_is_unparsed(&self) -> bool {
      match *self {
          PropertyDeclaration::WithVariables(..) => true,
          PropertyDeclaration::Custom(_, ref value) => {
            !matches!(value.borrow(), DeclaredValue::CSSWideKeyword(..))
          }
          _ => false,
      }
    }

    /// The shorthands that this longhand is part of.
    pub fn shorthands(&self) -> &'static [ShorthandId] {
        match self.id() {
            PropertyDeclarationId::Longhand(id) => id.shorthands(),
            PropertyDeclarationId::Custom(..) => &[],
        }
    }

    /// Returns true if this property declaration is for one of the animatable
    /// properties.
    pub fn is_animatable(&self) -> bool {
        match *self {
            PropertyDeclaration::BackgroundColor(_) => {
                    true
            }
            PropertyDeclaration::BackgroundImage(_) => {
                    true
            }
            PropertyDeclaration::BackgroundPositionX(_) => {
                    true
            }
            PropertyDeclaration::BackgroundPositionY(_) => {
                    true
            }
            PropertyDeclaration::BackgroundRepeat(_) => {
                    true
            }
            PropertyDeclaration::BackgroundAttachment(_) => {
                    true
            }
            PropertyDeclaration::BackgroundClip(_) => {
                    true
            }
            PropertyDeclaration::BackgroundOrigin(_) => {
                    true
            }
            PropertyDeclaration::BackgroundSize(_) => {
                    true
            }
            PropertyDeclaration::BackgroundBlendMode(_) => {
                    true
            }
            PropertyDeclaration::BorderTopColor(_) => {
                    true
            }
            PropertyDeclaration::BorderTopStyle(_) => {
                    true
            }
            PropertyDeclaration::BorderTopWidth(_) => {
                    true
            }
            PropertyDeclaration::BorderLeftColor(_) => {
                    true
            }
            PropertyDeclaration::BorderLeftStyle(_) => {
                    true
            }
            PropertyDeclaration::BorderLeftWidth(_) => {
                    true
            }
            PropertyDeclaration::BorderBottomColor(_) => {
                    true
            }
            PropertyDeclaration::BorderBottomStyle(_) => {
                    true
            }
            PropertyDeclaration::BorderBottomWidth(_) => {
                    true
            }
            PropertyDeclaration::BorderRightColor(_) => {
                    true
            }
            PropertyDeclaration::BorderRightStyle(_) => {
                    true
            }
            PropertyDeclaration::BorderRightWidth(_) => {
                    true
            }
            PropertyDeclaration::BorderBlockStartColor(_) => {
                    false
            }
            PropertyDeclaration::BorderBlockStartStyle(_) => {
                    false
            }
            PropertyDeclaration::BorderBlockStartWidth(_) => {
                    false
            }
            PropertyDeclaration::BorderBlockEndColor(_) => {
                    false
            }
            PropertyDeclaration::BorderBlockEndStyle(_) => {
                    false
            }
            PropertyDeclaration::BorderBlockEndWidth(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineStartColor(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineStartStyle(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineStartWidth(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineEndColor(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineEndStyle(_) => {
                    false
            }
            PropertyDeclaration::BorderInlineEndWidth(_) => {
                    false
            }
            PropertyDeclaration::BorderTopLeftRadius(_) => {
                    true
            }
            PropertyDeclaration::BorderTopRightRadius(_) => {
                    true
            }
            PropertyDeclaration::BorderBottomRightRadius(_) => {
                    true
            }
            PropertyDeclaration::BorderBottomLeftRadius(_) => {
                    true
            }
            PropertyDeclaration::MozBorderTopColors(_) => {
                    true
            }
            PropertyDeclaration::MozBorderLeftColors(_) => {
                    true
            }
            PropertyDeclaration::MozBorderBottomColors(_) => {
                    true
            }
            PropertyDeclaration::MozBorderRightColors(_) => {
                    true
            }
            PropertyDeclaration::BoxDecorationBreak(_) => {
                    true
            }
            PropertyDeclaration::MozFloatEdge(_) => {
                    true
            }
            PropertyDeclaration::BorderImageSource(_) => {
                    true
            }
            PropertyDeclaration::BorderImageOutset(_) => {
                    true
            }
            PropertyDeclaration::BorderImageRepeat(_) => {
                    true
            }
            PropertyDeclaration::BorderImageWidth(_) => {
                    true
            }
            PropertyDeclaration::BorderImageSlice(_) => {
                    true
            }
            PropertyDeclaration::Display(_) => {
                    true
            }
            PropertyDeclaration::MozTopLayer(_) => {
                    false
            }
            PropertyDeclaration::Position(_) => {
                    true
            }
            PropertyDeclaration::Float(_) => {
                    true
            }
            PropertyDeclaration::Clear(_) => {
                    true
            }
            PropertyDeclaration::VerticalAlign(_) => {
                    true
            }
            PropertyDeclaration::OverflowClipBoxInline(_) => {
                    true
            }
            PropertyDeclaration::OverflowClipBoxBlock(_) => {
                    true
            }
            PropertyDeclaration::OverflowX(_) => {
                    true
            }
            PropertyDeclaration::OverflowY(_) => {
                    true
            }
            PropertyDeclaration::TransitionDuration(_) => {
                    false
            }
            PropertyDeclaration::TransitionTimingFunction(_) => {
                    false
            }
            PropertyDeclaration::TransitionProperty(_) => {
                    false
            }
            PropertyDeclaration::TransitionDelay(_) => {
                    false
            }
            PropertyDeclaration::AnimationName(_) => {
                    false
            }
            PropertyDeclaration::AnimationDuration(_) => {
                    false
            }
            PropertyDeclaration::AnimationTimingFunction(_) => {
                    false
            }
            PropertyDeclaration::AnimationIterationCount(_) => {
                    false
            }
            PropertyDeclaration::AnimationDirection(_) => {
                    false
            }
            PropertyDeclaration::AnimationPlayState(_) => {
                    false
            }
            PropertyDeclaration::AnimationFillMode(_) => {
                    false
            }
            PropertyDeclaration::AnimationDelay(_) => {
                    false
            }
            PropertyDeclaration::ScrollSnapPointsX(_) => {
                    true
            }
            PropertyDeclaration::ScrollSnapPointsY(_) => {
                    true
            }
            PropertyDeclaration::ScrollSnapDestination(_) => {
                    true
            }
            PropertyDeclaration::ScrollSnapCoordinate(_) => {
                    true
            }
            PropertyDeclaration::Transform(_) => {
                    true
            }
            PropertyDeclaration::ScrollBehavior(_) => {
                    true
            }
            PropertyDeclaration::ScrollSnapTypeX(_) => {
                    true
            }
            PropertyDeclaration::ScrollSnapTypeY(_) => {
                    true
            }
            PropertyDeclaration::OverscrollBehaviorX(_) => {
                    true
            }
            PropertyDeclaration::OverscrollBehaviorY(_) => {
                    true
            }
            PropertyDeclaration::Isolation(_) => {
                    true
            }
            PropertyDeclaration::PageBreakAfter(_) => {
                    true
            }
            PropertyDeclaration::PageBreakBefore(_) => {
                    true
            }
            PropertyDeclaration::PageBreakInside(_) => {
                    true
            }
            PropertyDeclaration::Resize(_) => {
                    true
            }
            PropertyDeclaration::Perspective(_) => {
                    true
            }
            PropertyDeclaration::PerspectiveOrigin(_) => {
                    true
            }
            PropertyDeclaration::BackfaceVisibility(_) => {
                    true
            }
            PropertyDeclaration::TransformBox(_) => {
                    true
            }
            PropertyDeclaration::TransformStyle(_) => {
                    true
            }
            PropertyDeclaration::TransformOrigin(_) => {
                    true
            }
            PropertyDeclaration::Contain(_) => {
                    true
            }
            PropertyDeclaration::MozAppearance(_) => {
                    true
            }
            PropertyDeclaration::MozBinding(_) => {
                    false
            }
            PropertyDeclaration::MozOrient(_) => {
                    true
            }
            PropertyDeclaration::WillChange(_) => {
                    true
            }
            PropertyDeclaration::ShapeImageThreshold(_) => {
                    true
            }
            PropertyDeclaration::ShapeOutside(_) => {
                    true
            }
            PropertyDeclaration::TouchAction(_) => {
                    true
            }
            PropertyDeclaration::Color(_) => {
                    true
            }
            PropertyDeclaration::ColumnWidth(_) => {
                    true
            }
            PropertyDeclaration::ColumnCount(_) => {
                    true
            }
            PropertyDeclaration::ColumnGap(_) => {
                    true
            }
            PropertyDeclaration::ColumnFill(_) => {
                    true
            }
            PropertyDeclaration::ColumnRuleWidth(_) => {
                    true
            }
            PropertyDeclaration::ColumnRuleColor(_) => {
                    true
            }
            PropertyDeclaration::ColumnSpan(_) => {
                    true
            }
            PropertyDeclaration::ColumnRuleStyle(_) => {
                    true
            }
            PropertyDeclaration::Content(_) => {
                    true
            }
            PropertyDeclaration::CounterIncrement(_) => {
                    true
            }
            PropertyDeclaration::CounterReset(_) => {
                    true
            }
            PropertyDeclaration::Opacity(_) => {
                    true
            }
            PropertyDeclaration::BoxShadow(_) => {
                    true
            }
            PropertyDeclaration::Clip(_) => {
                    true
            }
            PropertyDeclaration::Filter(_) => {
                    true
            }
            PropertyDeclaration::MixBlendMode(_) => {
                    true
            }
            PropertyDeclaration::FontFamily(_) => {
                    true
            }
            PropertyDeclaration::FontStyle(_) => {
                    true
            }
            PropertyDeclaration::FontVariantCaps(_) => {
                    true
            }
            PropertyDeclaration::FontWeight(_) => {
                    true
            }
            PropertyDeclaration::FontSize(_) => {
                    true
            }
            PropertyDeclaration::FontSizeAdjust(_) => {
                    true
            }
            PropertyDeclaration::FontSynthesis(_) => {
                    true
            }
            PropertyDeclaration::FontStretch(_) => {
                    true
            }
            PropertyDeclaration::FontKerning(_) => {
                    true
            }
            PropertyDeclaration::FontVariantAlternates(_) => {
                    true
            }
            PropertyDeclaration::FontVariantEastAsian(_) => {
                    true
            }
            PropertyDeclaration::FontVariantLigatures(_) => {
                    true
            }
            PropertyDeclaration::FontVariantNumeric(_) => {
                    true
            }
            PropertyDeclaration::FontVariantPosition(_) => {
                    true
            }
            PropertyDeclaration::FontFeatureSettings(_) => {
                    true
            }
            PropertyDeclaration::FontVariationSettings(_) => {
                    true
            }
            PropertyDeclaration::FontLanguageOverride(_) => {
                    true
            }
            PropertyDeclaration::XLang(_) => {
                    false
            }
            PropertyDeclaration::MozScriptSizeMultiplier(_) => {
                    false
            }
            PropertyDeclaration::MozScriptLevel(_) => {
                    false
            }
            PropertyDeclaration::MozMathDisplay(_) => {
                    false
            }
            PropertyDeclaration::MozMathVariant(_) => {
                    false
            }
            PropertyDeclaration::MozScriptMinSize(_) => {
                    false
            }
            PropertyDeclaration::XTextZoom(_) => {
                    false
            }
            PropertyDeclaration::MozOsxFontSmoothing(_) => {
                    true
            }
            PropertyDeclaration::MozFontSmoothingBackgroundColor(_) => {
                    true
            }
            PropertyDeclaration::MozMinFontSizeRatio(_) => {
                    false
            }
            PropertyDeclaration::Visibility(_) => {
                    true
            }
            PropertyDeclaration::WritingMode(_) => {
                    true
            }
            PropertyDeclaration::Direction(_) => {
                    true
            }
            PropertyDeclaration::TextOrientation(_) => {
                    true
            }
            PropertyDeclaration::ColorAdjust(_) => {
                    true
            }
            PropertyDeclaration::ImageRendering(_) => {
                    true
            }
            PropertyDeclaration::ImageOrientation(_) => {
                    true
            }
            PropertyDeclaration::BorderCollapse(_) => {
                    true
            }
            PropertyDeclaration::EmptyCells(_) => {
                    true
            }
            PropertyDeclaration::CaptionSide(_) => {
                    true
            }
            PropertyDeclaration::BorderSpacing(_) => {
                    true
            }
            PropertyDeclaration::LineHeight(_) => {
                    true
            }
            PropertyDeclaration::TextTransform(_) => {
                    true
            }
            PropertyDeclaration::Hyphens(_) => {
                    true
            }
            PropertyDeclaration::MozTextSizeAdjust(_) => {
                    true
            }
            PropertyDeclaration::TextIndent(_) => {
                    true
            }
            PropertyDeclaration::OverflowWrap(_) => {
                    true
            }
            PropertyDeclaration::WordBreak(_) => {
                    true
            }
            PropertyDeclaration::TextJustify(_) => {
                    true
            }
            PropertyDeclaration::TextAlignLast(_) => {
                    true
            }
            PropertyDeclaration::TextAlign(_) => {
                    true
            }
            PropertyDeclaration::LetterSpacing(_) => {
                    true
            }
            PropertyDeclaration::WordSpacing(_) => {
                    true
            }
            PropertyDeclaration::WhiteSpace(_) => {
                    true
            }
            PropertyDeclaration::TextShadow(_) => {
                    true
            }
            PropertyDeclaration::TextEmphasisStyle(_) => {
                    true
            }
            PropertyDeclaration::TextEmphasisPosition(_) => {
                    true
            }
            PropertyDeclaration::TextEmphasisColor(_) => {
                    true
            }
            PropertyDeclaration::MozTabSize(_) => {
                    true
            }
            PropertyDeclaration::WebkitTextFillColor(_) => {
                    true
            }
            PropertyDeclaration::WebkitTextStrokeColor(_) => {
                    true
            }
            PropertyDeclaration::WebkitTextStrokeWidth(_) => {
                    true
            }
            PropertyDeclaration::RubyAlign(_) => {
                    true
            }
            PropertyDeclaration::RubyPosition(_) => {
                    true
            }
            PropertyDeclaration::TextCombineUpright(_) => {
                    true
            }
            PropertyDeclaration::TextRendering(_) => {
                    true
            }
            PropertyDeclaration::MozControlCharacterVisibility(_) => {
                    false
            }
            PropertyDeclaration::ListStylePosition(_) => {
                    true
            }
            PropertyDeclaration::ListStyleType(_) => {
                    true
            }
            PropertyDeclaration::ListStyleImage(_) => {
                    true
            }
            PropertyDeclaration::Quotes(_) => {
                    true
            }
            PropertyDeclaration::MozImageRegion(_) => {
                    true
            }
            PropertyDeclaration::MarginTop(_) => {
                    true
            }
            PropertyDeclaration::MarginLeft(_) => {
                    true
            }
            PropertyDeclaration::MarginBottom(_) => {
                    true
            }
            PropertyDeclaration::MarginRight(_) => {
                    true
            }
            PropertyDeclaration::MarginBlockStart(_) => {
                    false
            }
            PropertyDeclaration::MarginBlockEnd(_) => {
                    false
            }
            PropertyDeclaration::MarginInlineStart(_) => {
                    false
            }
            PropertyDeclaration::MarginInlineEnd(_) => {
                    false
            }
            PropertyDeclaration::OutlineColor(_) => {
                    true
            }
            PropertyDeclaration::OutlineStyle(_) => {
                    true
            }
            PropertyDeclaration::OutlineWidth(_) => {
                    true
            }
            PropertyDeclaration::MozOutlineRadiusTopleft(_) => {
                    true
            }
            PropertyDeclaration::MozOutlineRadiusTopright(_) => {
                    true
            }
            PropertyDeclaration::MozOutlineRadiusBottomright(_) => {
                    true
            }
            PropertyDeclaration::MozOutlineRadiusBottomleft(_) => {
                    true
            }
            PropertyDeclaration::OutlineOffset(_) => {
                    true
            }
            PropertyDeclaration::PaddingTop(_) => {
                    true
            }
            PropertyDeclaration::PaddingLeft(_) => {
                    true
            }
            PropertyDeclaration::PaddingBottom(_) => {
                    true
            }
            PropertyDeclaration::PaddingRight(_) => {
                    true
            }
            PropertyDeclaration::PaddingBlockStart(_) => {
                    false
            }
            PropertyDeclaration::PaddingBlockEnd(_) => {
                    false
            }
            PropertyDeclaration::PaddingInlineStart(_) => {
                    false
            }
            PropertyDeclaration::PaddingInlineEnd(_) => {
                    false
            }
            PropertyDeclaration::Cursor(_) => {
                    true
            }
            PropertyDeclaration::PointerEvents(_) => {
                    true
            }
            PropertyDeclaration::MozUserInput(_) => {
                    true
            }
            PropertyDeclaration::MozUserModify(_) => {
                    true
            }
            PropertyDeclaration::MozUserFocus(_) => {
                    true
            }
            PropertyDeclaration::CaretColor(_) => {
                    true
            }
            PropertyDeclaration::Top(_) => {
                    true
            }
            PropertyDeclaration::Left(_) => {
                    true
            }
            PropertyDeclaration::Bottom(_) => {
                    true
            }
            PropertyDeclaration::Right(_) => {
                    true
            }
            PropertyDeclaration::OffsetBlockStart(_) => {
                    false
            }
            PropertyDeclaration::OffsetBlockEnd(_) => {
                    false
            }
            PropertyDeclaration::OffsetInlineStart(_) => {
                    false
            }
            PropertyDeclaration::OffsetInlineEnd(_) => {
                    false
            }
            PropertyDeclaration::ZIndex(_) => {
                    true
            }
            PropertyDeclaration::FlexDirection(_) => {
                    true
            }
            PropertyDeclaration::FlexWrap(_) => {
                    true
            }
            PropertyDeclaration::JustifyContent(_) => {
                    true
            }
            PropertyDeclaration::AlignContent(_) => {
                    true
            }
            PropertyDeclaration::AlignItems(_) => {
                    true
            }
            PropertyDeclaration::JustifyItems(_) => {
                    true
            }
            PropertyDeclaration::FlexGrow(_) => {
                    true
            }
            PropertyDeclaration::FlexShrink(_) => {
                    true
            }
            PropertyDeclaration::AlignSelf(_) => {
                    true
            }
            PropertyDeclaration::JustifySelf(_) => {
                    true
            }
            PropertyDeclaration::Order(_) => {
                    true
            }
            PropertyDeclaration::FlexBasis(_) => {
                    true
            }
            PropertyDeclaration::Width(_) => {
                    true
            }
            PropertyDeclaration::MinWidth(_) => {
                    true
            }
            PropertyDeclaration::MaxWidth(_) => {
                    true
            }
            PropertyDeclaration::Height(_) => {
                    true
            }
            PropertyDeclaration::MinHeight(_) => {
                    true
            }
            PropertyDeclaration::MaxHeight(_) => {
                    true
            }
            PropertyDeclaration::BlockSize(_) => {
                    false
            }
            PropertyDeclaration::MinBlockSize(_) => {
                    false
            }
            PropertyDeclaration::MaxBlockSize(_) => {
                    false
            }
            PropertyDeclaration::InlineSize(_) => {
                    false
            }
            PropertyDeclaration::MinInlineSize(_) => {
                    false
            }
            PropertyDeclaration::MaxInlineSize(_) => {
                    false
            }
            PropertyDeclaration::BoxSizing(_) => {
                    true
            }
            PropertyDeclaration::ObjectFit(_) => {
                    true
            }
            PropertyDeclaration::ObjectPosition(_) => {
                    true
            }
            PropertyDeclaration::GridRowGap(_) => {
                    true
            }
            PropertyDeclaration::GridRowStart(_) => {
                    true
            }
            PropertyDeclaration::GridRowEnd(_) => {
                    true
            }
            PropertyDeclaration::GridAutoRows(_) => {
                    true
            }
            PropertyDeclaration::GridTemplateRows(_) => {
                    true
            }
            PropertyDeclaration::GridColumnGap(_) => {
                    true
            }
            PropertyDeclaration::GridColumnStart(_) => {
                    true
            }
            PropertyDeclaration::GridColumnEnd(_) => {
                    true
            }
            PropertyDeclaration::GridAutoColumns(_) => {
                    true
            }
            PropertyDeclaration::GridTemplateColumns(_) => {
                    true
            }
            PropertyDeclaration::GridAutoFlow(_) => {
                    true
            }
            PropertyDeclaration::GridTemplateAreas(_) => {
                    true
            }
            PropertyDeclaration::TableLayout(_) => {
                    true
            }
            PropertyDeclaration::XSpan(_) => {
                    false
            }
            PropertyDeclaration::TextOverflow(_) => {
                    true
            }
            PropertyDeclaration::UnicodeBidi(_) => {
                    true
            }
            PropertyDeclaration::TextDecorationLine(_) => {
                    true
            }
            PropertyDeclaration::TextDecorationStyle(_) => {
                    true
            }
            PropertyDeclaration::TextDecorationColor(_) => {
                    true
            }
            PropertyDeclaration::InitialLetter(_) => {
                    true
            }
            PropertyDeclaration::ImeMode(_) => {
                    true
            }
            PropertyDeclaration::MozUserSelect(_) => {
                    true
            }
            PropertyDeclaration::MozWindowDragging(_) => {
                    true
            }
            PropertyDeclaration::MozWindowShadow(_) => {
                    true
            }
            PropertyDeclaration::MozWindowOpacity(_) => {
                    true
            }
            PropertyDeclaration::MozWindowTransform(_) => {
                    true
            }
            PropertyDeclaration::MozWindowTransformOrigin(_) => {
                    true
            }
            PropertyDeclaration::MozForceBrokenImageIcon(_) => {
                    true
            }
            PropertyDeclaration::TextAnchor(_) => {
                    true
            }
            PropertyDeclaration::ColorInterpolation(_) => {
                    true
            }
            PropertyDeclaration::ColorInterpolationFilters(_) => {
                    true
            }
            PropertyDeclaration::Fill(_) => {
                    true
            }
            PropertyDeclaration::FillOpacity(_) => {
                    true
            }
            PropertyDeclaration::FillRule(_) => {
                    true
            }
            PropertyDeclaration::ShapeRendering(_) => {
                    true
            }
            PropertyDeclaration::Stroke(_) => {
                    true
            }
            PropertyDeclaration::StrokeWidth(_) => {
                    true
            }
            PropertyDeclaration::StrokeLinecap(_) => {
                    true
            }
            PropertyDeclaration::StrokeLinejoin(_) => {
                    true
            }
            PropertyDeclaration::StrokeMiterlimit(_) => {
                    true
            }
            PropertyDeclaration::StrokeOpacity(_) => {
                    true
            }
            PropertyDeclaration::StrokeDasharray(_) => {
                    true
            }
            PropertyDeclaration::StrokeDashoffset(_) => {
                    true
            }
            PropertyDeclaration::ClipRule(_) => {
                    true
            }
            PropertyDeclaration::MarkerStart(_) => {
                    true
            }
            PropertyDeclaration::MarkerMid(_) => {
                    true
            }
            PropertyDeclaration::MarkerEnd(_) => {
                    true
            }
            PropertyDeclaration::PaintOrder(_) => {
                    true
            }
            PropertyDeclaration::MozContextProperties(_) => {
                    false
            }
            PropertyDeclaration::DominantBaseline(_) => {
                    true
            }
            PropertyDeclaration::VectorEffect(_) => {
                    true
            }
            PropertyDeclaration::StopColor(_) => {
                    true
            }
            PropertyDeclaration::StopOpacity(_) => {
                    true
            }
            PropertyDeclaration::FloodColor(_) => {
                    true
            }
            PropertyDeclaration::FloodOpacity(_) => {
                    true
            }
            PropertyDeclaration::LightingColor(_) => {
                    true
            }
            PropertyDeclaration::MaskType(_) => {
                    true
            }
            PropertyDeclaration::ClipPath(_) => {
                    true
            }
            PropertyDeclaration::MaskMode(_) => {
                    true
            }
            PropertyDeclaration::MaskRepeat(_) => {
                    true
            }
            PropertyDeclaration::MaskPositionX(_) => {
                    true
            }
            PropertyDeclaration::MaskPositionY(_) => {
                    true
            }
            PropertyDeclaration::MaskClip(_) => {
                    true
            }
            PropertyDeclaration::MaskOrigin(_) => {
                    true
            }
            PropertyDeclaration::MaskSize(_) => {
                    true
            }
            PropertyDeclaration::MaskComposite(_) => {
                    true
            }
            PropertyDeclaration::MaskImage(_) => {
                    true
            }
            PropertyDeclaration::MozBoxAlign(_) => {
                    true
            }
            PropertyDeclaration::MozBoxDirection(_) => {
                    true
            }
            PropertyDeclaration::MozBoxFlex(_) => {
                    true
            }
            PropertyDeclaration::MozBoxOrient(_) => {
                    true
            }
            PropertyDeclaration::MozBoxPack(_) => {
                    true
            }
            PropertyDeclaration::MozStackSizing(_) => {
                    true
            }
            PropertyDeclaration::MozBoxOrdinalGroup(_) => {
                    true
            }
            PropertyDeclaration::CSSWideKeyword(id, _) |
            PropertyDeclaration::WithVariables(id, _) => match id {
                LonghandId::BackgroundColor => {
                        true
                }
                LonghandId::BackgroundImage => {
                        true
                }
                LonghandId::BackgroundPositionX => {
                        true
                }
                LonghandId::BackgroundPositionY => {
                        true
                }
                LonghandId::BackgroundRepeat => {
                        true
                }
                LonghandId::BackgroundAttachment => {
                        true
                }
                LonghandId::BackgroundClip => {
                        true
                }
                LonghandId::BackgroundOrigin => {
                        true
                }
                LonghandId::BackgroundSize => {
                        true
                }
                LonghandId::BackgroundBlendMode => {
                        true
                }
                LonghandId::BorderTopColor => {
                        true
                }
                LonghandId::BorderTopStyle => {
                        true
                }
                LonghandId::BorderTopWidth => {
                        true
                }
                LonghandId::BorderLeftColor => {
                        true
                }
                LonghandId::BorderLeftStyle => {
                        true
                }
                LonghandId::BorderLeftWidth => {
                        true
                }
                LonghandId::BorderBottomColor => {
                        true
                }
                LonghandId::BorderBottomStyle => {
                        true
                }
                LonghandId::BorderBottomWidth => {
                        true
                }
                LonghandId::BorderRightColor => {
                        true
                }
                LonghandId::BorderRightStyle => {
                        true
                }
                LonghandId::BorderRightWidth => {
                        true
                }
                LonghandId::BorderBlockStartColor => {
                        false
                }
                LonghandId::BorderBlockStartStyle => {
                        false
                }
                LonghandId::BorderBlockStartWidth => {
                        false
                }
                LonghandId::BorderBlockEndColor => {
                        false
                }
                LonghandId::BorderBlockEndStyle => {
                        false
                }
                LonghandId::BorderBlockEndWidth => {
                        false
                }
                LonghandId::BorderInlineStartColor => {
                        false
                }
                LonghandId::BorderInlineStartStyle => {
                        false
                }
                LonghandId::BorderInlineStartWidth => {
                        false
                }
                LonghandId::BorderInlineEndColor => {
                        false
                }
                LonghandId::BorderInlineEndStyle => {
                        false
                }
                LonghandId::BorderInlineEndWidth => {
                        false
                }
                LonghandId::BorderTopLeftRadius => {
                        true
                }
                LonghandId::BorderTopRightRadius => {
                        true
                }
                LonghandId::BorderBottomRightRadius => {
                        true
                }
                LonghandId::BorderBottomLeftRadius => {
                        true
                }
                LonghandId::MozBorderTopColors => {
                        true
                }
                LonghandId::MozBorderLeftColors => {
                        true
                }
                LonghandId::MozBorderBottomColors => {
                        true
                }
                LonghandId::MozBorderRightColors => {
                        true
                }
                LonghandId::BoxDecorationBreak => {
                        true
                }
                LonghandId::MozFloatEdge => {
                        true
                }
                LonghandId::BorderImageSource => {
                        true
                }
                LonghandId::BorderImageOutset => {
                        true
                }
                LonghandId::BorderImageRepeat => {
                        true
                }
                LonghandId::BorderImageWidth => {
                        true
                }
                LonghandId::BorderImageSlice => {
                        true
                }
                LonghandId::Display => {
                        true
                }
                LonghandId::MozTopLayer => {
                        false
                }
                LonghandId::Position => {
                        true
                }
                LonghandId::Float => {
                        true
                }
                LonghandId::Clear => {
                        true
                }
                LonghandId::VerticalAlign => {
                        true
                }
                LonghandId::OverflowClipBoxInline => {
                        true
                }
                LonghandId::OverflowClipBoxBlock => {
                        true
                }
                LonghandId::OverflowX => {
                        true
                }
                LonghandId::OverflowY => {
                        true
                }
                LonghandId::TransitionDuration => {
                        false
                }
                LonghandId::TransitionTimingFunction => {
                        false
                }
                LonghandId::TransitionProperty => {
                        false
                }
                LonghandId::TransitionDelay => {
                        false
                }
                LonghandId::AnimationName => {
                        false
                }
                LonghandId::AnimationDuration => {
                        false
                }
                LonghandId::AnimationTimingFunction => {
                        false
                }
                LonghandId::AnimationIterationCount => {
                        false
                }
                LonghandId::AnimationDirection => {
                        false
                }
                LonghandId::AnimationPlayState => {
                        false
                }
                LonghandId::AnimationFillMode => {
                        false
                }
                LonghandId::AnimationDelay => {
                        false
                }
                LonghandId::ScrollSnapPointsX => {
                        true
                }
                LonghandId::ScrollSnapPointsY => {
                        true
                }
                LonghandId::ScrollSnapDestination => {
                        true
                }
                LonghandId::ScrollSnapCoordinate => {
                        true
                }
                LonghandId::Transform => {
                        true
                }
                LonghandId::ScrollBehavior => {
                        true
                }
                LonghandId::ScrollSnapTypeX => {
                        true
                }
                LonghandId::ScrollSnapTypeY => {
                        true
                }
                LonghandId::OverscrollBehaviorX => {
                        true
                }
                LonghandId::OverscrollBehaviorY => {
                        true
                }
                LonghandId::Isolation => {
                        true
                }
                LonghandId::PageBreakAfter => {
                        true
                }
                LonghandId::PageBreakBefore => {
                        true
                }
                LonghandId::PageBreakInside => {
                        true
                }
                LonghandId::Resize => {
                        true
                }
                LonghandId::Perspective => {
                        true
                }
                LonghandId::PerspectiveOrigin => {
                        true
                }
                LonghandId::BackfaceVisibility => {
                        true
                }
                LonghandId::TransformBox => {
                        true
                }
                LonghandId::TransformStyle => {
                        true
                }
                LonghandId::TransformOrigin => {
                        true
                }
                LonghandId::Contain => {
                        true
                }
                LonghandId::MozAppearance => {
                        true
                }
                LonghandId::MozBinding => {
                        false
                }
                LonghandId::MozOrient => {
                        true
                }
                LonghandId::WillChange => {
                        true
                }
                LonghandId::ShapeImageThreshold => {
                        true
                }
                LonghandId::ShapeOutside => {
                        true
                }
                LonghandId::TouchAction => {
                        true
                }
                LonghandId::Color => {
                        true
                }
                LonghandId::ColumnWidth => {
                        true
                }
                LonghandId::ColumnCount => {
                        true
                }
                LonghandId::ColumnGap => {
                        true
                }
                LonghandId::ColumnFill => {
                        true
                }
                LonghandId::ColumnRuleWidth => {
                        true
                }
                LonghandId::ColumnRuleColor => {
                        true
                }
                LonghandId::ColumnSpan => {
                        true
                }
                LonghandId::ColumnRuleStyle => {
                        true
                }
                LonghandId::Content => {
                        true
                }
                LonghandId::CounterIncrement => {
                        true
                }
                LonghandId::CounterReset => {
                        true
                }
                LonghandId::Opacity => {
                        true
                }
                LonghandId::BoxShadow => {
                        true
                }
                LonghandId::Clip => {
                        true
                }
                LonghandId::Filter => {
                        true
                }
                LonghandId::MixBlendMode => {
                        true
                }
                LonghandId::FontFamily => {
                        true
                }
                LonghandId::FontStyle => {
                        true
                }
                LonghandId::FontVariantCaps => {
                        true
                }
                LonghandId::FontWeight => {
                        true
                }
                LonghandId::FontSize => {
                        true
                }
                LonghandId::FontSizeAdjust => {
                        true
                }
                LonghandId::FontSynthesis => {
                        true
                }
                LonghandId::FontStretch => {
                        true
                }
                LonghandId::FontKerning => {
                        true
                }
                LonghandId::FontVariantAlternates => {
                        true
                }
                LonghandId::FontVariantEastAsian => {
                        true
                }
                LonghandId::FontVariantLigatures => {
                        true
                }
                LonghandId::FontVariantNumeric => {
                        true
                }
                LonghandId::FontVariantPosition => {
                        true
                }
                LonghandId::FontFeatureSettings => {
                        true
                }
                LonghandId::FontVariationSettings => {
                        true
                }
                LonghandId::FontLanguageOverride => {
                        true
                }
                LonghandId::XLang => {
                        false
                }
                LonghandId::MozScriptSizeMultiplier => {
                        false
                }
                LonghandId::MozScriptLevel => {
                        false
                }
                LonghandId::MozMathDisplay => {
                        false
                }
                LonghandId::MozMathVariant => {
                        false
                }
                LonghandId::MozScriptMinSize => {
                        false
                }
                LonghandId::XTextZoom => {
                        false
                }
                LonghandId::MozOsxFontSmoothing => {
                        true
                }
                LonghandId::MozFontSmoothingBackgroundColor => {
                        true
                }
                LonghandId::MozMinFontSizeRatio => {
                        false
                }
                LonghandId::Visibility => {
                        true
                }
                LonghandId::WritingMode => {
                        true
                }
                LonghandId::Direction => {
                        true
                }
                LonghandId::TextOrientation => {
                        true
                }
                LonghandId::ColorAdjust => {
                        true
                }
                LonghandId::ImageRendering => {
                        true
                }
                LonghandId::ImageOrientation => {
                        true
                }
                LonghandId::BorderCollapse => {
                        true
                }
                LonghandId::EmptyCells => {
                        true
                }
                LonghandId::CaptionSide => {
                        true
                }
                LonghandId::BorderSpacing => {
                        true
                }
                LonghandId::LineHeight => {
                        true
                }
                LonghandId::TextTransform => {
                        true
                }
                LonghandId::Hyphens => {
                        true
                }
                LonghandId::MozTextSizeAdjust => {
                        true
                }
                LonghandId::TextIndent => {
                        true
                }
                LonghandId::OverflowWrap => {
                        true
                }
                LonghandId::WordBreak => {
                        true
                }
                LonghandId::TextJustify => {
                        true
                }
                LonghandId::TextAlignLast => {
                        true
                }
                LonghandId::TextAlign => {
                        true
                }
                LonghandId::LetterSpacing => {
                        true
                }
                LonghandId::WordSpacing => {
                        true
                }
                LonghandId::WhiteSpace => {
                        true
                }
                LonghandId::TextShadow => {
                        true
                }
                LonghandId::TextEmphasisStyle => {
                        true
                }
                LonghandId::TextEmphasisPosition => {
                        true
                }
                LonghandId::TextEmphasisColor => {
                        true
                }
                LonghandId::MozTabSize => {
                        true
                }
                LonghandId::WebkitTextFillColor => {
                        true
                }
                LonghandId::WebkitTextStrokeColor => {
                        true
                }
                LonghandId::WebkitTextStrokeWidth => {
                        true
                }
                LonghandId::RubyAlign => {
                        true
                }
                LonghandId::RubyPosition => {
                        true
                }
                LonghandId::TextCombineUpright => {
                        true
                }
                LonghandId::TextRendering => {
                        true
                }
                LonghandId::MozControlCharacterVisibility => {
                        false
                }
                LonghandId::ListStylePosition => {
                        true
                }
                LonghandId::ListStyleType => {
                        true
                }
                LonghandId::ListStyleImage => {
                        true
                }
                LonghandId::Quotes => {
                        true
                }
                LonghandId::MozImageRegion => {
                        true
                }
                LonghandId::MarginTop => {
                        true
                }
                LonghandId::MarginLeft => {
                        true
                }
                LonghandId::MarginBottom => {
                        true
                }
                LonghandId::MarginRight => {
                        true
                }
                LonghandId::MarginBlockStart => {
                        false
                }
                LonghandId::MarginBlockEnd => {
                        false
                }
                LonghandId::MarginInlineStart => {
                        false
                }
                LonghandId::MarginInlineEnd => {
                        false
                }
                LonghandId::OutlineColor => {
                        true
                }
                LonghandId::OutlineStyle => {
                        true
                }
                LonghandId::OutlineWidth => {
                        true
                }
                LonghandId::MozOutlineRadiusTopleft => {
                        true
                }
                LonghandId::MozOutlineRadiusTopright => {
                        true
                }
                LonghandId::MozOutlineRadiusBottomright => {
                        true
                }
                LonghandId::MozOutlineRadiusBottomleft => {
                        true
                }
                LonghandId::OutlineOffset => {
                        true
                }
                LonghandId::PaddingTop => {
                        true
                }
                LonghandId::PaddingLeft => {
                        true
                }
                LonghandId::PaddingBottom => {
                        true
                }
                LonghandId::PaddingRight => {
                        true
                }
                LonghandId::PaddingBlockStart => {
                        false
                }
                LonghandId::PaddingBlockEnd => {
                        false
                }
                LonghandId::PaddingInlineStart => {
                        false
                }
                LonghandId::PaddingInlineEnd => {
                        false
                }
                LonghandId::Cursor => {
                        true
                }
                LonghandId::PointerEvents => {
                        true
                }
                LonghandId::MozUserInput => {
                        true
                }
                LonghandId::MozUserModify => {
                        true
                }
                LonghandId::MozUserFocus => {
                        true
                }
                LonghandId::CaretColor => {
                        true
                }
                LonghandId::Top => {
                        true
                }
                LonghandId::Left => {
                        true
                }
                LonghandId::Bottom => {
                        true
                }
                LonghandId::Right => {
                        true
                }
                LonghandId::OffsetBlockStart => {
                        false
                }
                LonghandId::OffsetBlockEnd => {
                        false
                }
                LonghandId::OffsetInlineStart => {
                        false
                }
                LonghandId::OffsetInlineEnd => {
                        false
                }
                LonghandId::ZIndex => {
                        true
                }
                LonghandId::FlexDirection => {
                        true
                }
                LonghandId::FlexWrap => {
                        true
                }
                LonghandId::JustifyContent => {
                        true
                }
                LonghandId::AlignContent => {
                        true
                }
                LonghandId::AlignItems => {
                        true
                }
                LonghandId::JustifyItems => {
                        true
                }
                LonghandId::FlexGrow => {
                        true
                }
                LonghandId::FlexShrink => {
                        true
                }
                LonghandId::AlignSelf => {
                        true
                }
                LonghandId::JustifySelf => {
                        true
                }
                LonghandId::Order => {
                        true
                }
                LonghandId::FlexBasis => {
                        true
                }
                LonghandId::Width => {
                        true
                }
                LonghandId::MinWidth => {
                        true
                }
                LonghandId::MaxWidth => {
                        true
                }
                LonghandId::Height => {
                        true
                }
                LonghandId::MinHeight => {
                        true
                }
                LonghandId::MaxHeight => {
                        true
                }
                LonghandId::BlockSize => {
                        false
                }
                LonghandId::MinBlockSize => {
                        false
                }
                LonghandId::MaxBlockSize => {
                        false
                }
                LonghandId::InlineSize => {
                        false
                }
                LonghandId::MinInlineSize => {
                        false
                }
                LonghandId::MaxInlineSize => {
                        false
                }
                LonghandId::BoxSizing => {
                        true
                }
                LonghandId::ObjectFit => {
                        true
                }
                LonghandId::ObjectPosition => {
                        true
                }
                LonghandId::GridRowGap => {
                        true
                }
                LonghandId::GridRowStart => {
                        true
                }
                LonghandId::GridRowEnd => {
                        true
                }
                LonghandId::GridAutoRows => {
                        true
                }
                LonghandId::GridTemplateRows => {
                        true
                }
                LonghandId::GridColumnGap => {
                        true
                }
                LonghandId::GridColumnStart => {
                        true
                }
                LonghandId::GridColumnEnd => {
                        true
                }
                LonghandId::GridAutoColumns => {
                        true
                }
                LonghandId::GridTemplateColumns => {
                        true
                }
                LonghandId::GridAutoFlow => {
                        true
                }
                LonghandId::GridTemplateAreas => {
                        true
                }
                LonghandId::TableLayout => {
                        true
                }
                LonghandId::XSpan => {
                        false
                }
                LonghandId::TextOverflow => {
                        true
                }
                LonghandId::UnicodeBidi => {
                        true
                }
                LonghandId::TextDecorationLine => {
                        true
                }
                LonghandId::TextDecorationStyle => {
                        true
                }
                LonghandId::TextDecorationColor => {
                        true
                }
                LonghandId::InitialLetter => {
                        true
                }
                LonghandId::ImeMode => {
                        true
                }
                LonghandId::MozUserSelect => {
                        true
                }
                LonghandId::MozWindowDragging => {
                        true
                }
                LonghandId::MozWindowShadow => {
                        true
                }
                LonghandId::MozWindowOpacity => {
                        true
                }
                LonghandId::MozWindowTransform => {
                        true
                }
                LonghandId::MozWindowTransformOrigin => {
                        true
                }
                LonghandId::MozForceBrokenImageIcon => {
                        true
                }
                LonghandId::TextAnchor => {
                        true
                }
                LonghandId::ColorInterpolation => {
                        true
                }
                LonghandId::ColorInterpolationFilters => {
                        true
                }
                LonghandId::Fill => {
                        true
                }
                LonghandId::FillOpacity => {
                        true
                }
                LonghandId::FillRule => {
                        true
                }
                LonghandId::ShapeRendering => {
                        true
                }
                LonghandId::Stroke => {
                        true
                }
                LonghandId::StrokeWidth => {
                        true
                }
                LonghandId::StrokeLinecap => {
                        true
                }
                LonghandId::StrokeLinejoin => {
                        true
                }
                LonghandId::StrokeMiterlimit => {
                        true
                }
                LonghandId::StrokeOpacity => {
                        true
                }
                LonghandId::StrokeDasharray => {
                        true
                }
                LonghandId::StrokeDashoffset => {
                        true
                }
                LonghandId::ClipRule => {
                        true
                }
                LonghandId::MarkerStart => {
                        true
                }
                LonghandId::MarkerMid => {
                        true
                }
                LonghandId::MarkerEnd => {
                        true
                }
                LonghandId::PaintOrder => {
                        true
                }
                LonghandId::MozContextProperties => {
                        false
                }
                LonghandId::DominantBaseline => {
                        true
                }
                LonghandId::VectorEffect => {
                        true
                }
                LonghandId::StopColor => {
                        true
                }
                LonghandId::StopOpacity => {
                        true
                }
                LonghandId::FloodColor => {
                        true
                }
                LonghandId::FloodOpacity => {
                        true
                }
                LonghandId::LightingColor => {
                        true
                }
                LonghandId::MaskType => {
                        true
                }
                LonghandId::ClipPath => {
                        true
                }
                LonghandId::MaskMode => {
                        true
                }
                LonghandId::MaskRepeat => {
                        true
                }
                LonghandId::MaskPositionX => {
                        true
                }
                LonghandId::MaskPositionY => {
                        true
                }
                LonghandId::MaskClip => {
                        true
                }
                LonghandId::MaskOrigin => {
                        true
                }
                LonghandId::MaskSize => {
                        true
                }
                LonghandId::MaskComposite => {
                        true
                }
                LonghandId::MaskImage => {
                        true
                }
                LonghandId::MozBoxAlign => {
                        true
                }
                LonghandId::MozBoxDirection => {
                        true
                }
                LonghandId::MozBoxFlex => {
                        true
                }
                LonghandId::MozBoxOrient => {
                        true
                }
                LonghandId::MozBoxPack => {
                        true
                }
                LonghandId::MozStackSizing => {
                        true
                }
                LonghandId::MozBoxOrdinalGroup => {
                        true
                }
            },
            PropertyDeclaration::Custom(..) => false,
        }
    }

    /// Returns true if this property is a custom property, false
    /// otherwise.
    pub fn is_custom(&self) -> bool {
        matches!(*self, PropertyDeclaration::Custom(_, _))
    }

    /// The `context` parameter controls this:
    ///
    /// <https://drafts.csswg.org/css-animations/#keyframes>
    /// > The <declaration-list> inside of <keyframe-block> accepts any CSS property
    /// > except those defined in this specification,
    /// > but does accept the `animation-play-state` property and interprets it specially.
    ///
    /// This will not actually parse Importance values, and will always set things
    /// to Importance::Normal. Parsing Importance values is the job of PropertyDeclarationParser,
    /// we only set them here so that we don't have to reallocate
    pub fn parse_into<'i, 't>(
        declarations: &mut SourcePropertyDeclaration,
        id: PropertyId,
        name: CowRcStr<'i>,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(), ParseError<'i>> {
        assert!(declarations.is_empty());

        if !id.allowed_in(context) {
            return Err(input.new_custom_error(
                StyleParseErrorKind::UnknownProperty(name)
            ));
        }

        let start = input.state();
        match id {
            PropertyId::Custom(property_name) => {
                // FIXME: fully implement https://github.com/w3c/csswg-drafts/issues/774
                // before adding skip_whitespace here.
                // This probably affects some test results.
                let value = match input.try(|i| CSSWideKeyword::parse(i)) {
                    Ok(keyword) => DeclaredValueOwned::CSSWideKeyword(keyword),
                    Err(()) => match ::custom_properties::SpecifiedValue::parse(input) {
                        Ok(value) => DeclaredValueOwned::Value(value),
                        Err(e) => return Err(StyleParseErrorKind::new_invalid(name, e)),
                    }
                };
                declarations.push(PropertyDeclaration::Custom(property_name, value));
                Ok(())
            }
            PropertyId::LonghandAlias(id, _) |
            PropertyId::Longhand(id) => {
                input.skip_whitespace();  // Unnecessary for correctness, but may help try() rewind less.
                input.try(|i| CSSWideKeyword::parse(i)).map(|keyword| {
                    PropertyDeclaration::CSSWideKeyword(id, keyword)
                }).or_else(|()| {
                    input.look_for_var_functions();
                    input.parse_entirely(|input| id.parse_value(context, input))
                    .or_else(|err| {
                        while let Ok(_) = input.next() {}  // Look for var() after the error.
                        if input.seen_var_functions() {
                            input.reset(&start);
                            let (first_token_type, css) =
                                ::custom_properties::parse_non_custom_with_var(input).map_err(|e| {
                                    StyleParseErrorKind::new_invalid(name, e)
                                })?;
                            Ok(PropertyDeclaration::WithVariables(id, Arc::new(UnparsedValue {
                                css: css.into_owned(),
                                first_token_type: first_token_type,
                                url_data: context.url_data.clone(),
                                from_shorthand: None,
                            })))
                        } else {
                            Err(StyleParseErrorKind::new_invalid(name, err))
                        }
                    })
                }).map(|declaration| {
                    declarations.push(declaration)
                })
            }
            PropertyId::ShorthandAlias(id, _) |
            PropertyId::Shorthand(id) => {
                input.skip_whitespace();  // Unnecessary for correctness, but may help try() rewind less.
                if let Ok(keyword) = input.try(|i| CSSWideKeyword::parse(i)) {
                    if id == ShorthandId::All {
                        declarations.all_shorthand = AllShorthand::CSSWideKeyword(keyword)
                    } else {
                        for &longhand in id.longhands() {
                            declarations.push(PropertyDeclaration::CSSWideKeyword(longhand, keyword))
                        }
                    }
                    Ok(())
                } else {
                    input.look_for_var_functions();
                    // Not using parse_entirely here: each text_decoration::parse_into function
                    // needs to do so *before* pushing to `declarations`.
                    id.parse_into(declarations, context, input).or_else(|err| {
                        while let Ok(_) = input.next() {}  // Look for var() after the error.
                        if input.seen_var_functions() {
                            input.reset(&start);
                            let (first_token_type, css) =
                                ::custom_properties::parse_non_custom_with_var(input).map_err(|e| {
                                    StyleParseErrorKind::new_invalid(name, e)
                                })?;
                            let unparsed = Arc::new(UnparsedValue {
                                css: css.into_owned(),
                                first_token_type: first_token_type,
                                url_data: context.url_data.clone(),
                                from_shorthand: Some(id),
                            });
                            if id == ShorthandId::All {
                                declarations.all_shorthand = AllShorthand::WithVariables(unparsed)
                            } else {
                                for &longhand in id.longhands() {
                                    declarations.push(
                                        PropertyDeclaration::WithVariables(longhand, unparsed.clone())
                                    )
                                }
                            }
                            Ok(())
                        } else {
                            Err(StyleParseErrorKind::new_invalid(name, err))
                        }
                    })
                }
            }
        }
    }
}

const MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL: usize =
    17;

type SourcePropertyDeclarationArray =
    [PropertyDeclaration; MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL];

/// A stack-allocated vector of `PropertyDeclaration`
/// large enough to parse one CSS `key: value` declaration.
/// (Shorthands expand to multiple `PropertyDeclaration`s.)
pub struct SourcePropertyDeclaration {
    declarations: ::arrayvec::ArrayVec<SourcePropertyDeclarationArray>,

    /// Stored separately to keep MAX_SUB_PROPERTIES_PER_SHORTHAND_EXCEPT_ALL smaller.
    all_shorthand: AllShorthand,
}

impl SourcePropertyDeclaration {
    /// Create one. It’s big, try not to move it around.
    #[inline]
    pub fn new() -> Self {
        SourcePropertyDeclaration {
            declarations: ::arrayvec::ArrayVec::new(),
            all_shorthand: AllShorthand::NotSet,
        }
    }

    /// Similar to Vec::drain: leaves this empty when the return value is dropped.
    pub fn drain(&mut self) -> SourcePropertyDeclarationDrain {
        SourcePropertyDeclarationDrain {
            declarations: self.declarations.drain(..),
            all_shorthand: mem::replace(&mut self.all_shorthand, AllShorthand::NotSet),
        }
    }

    /// Reset to initial state
    pub fn clear(&mut self) {
        self.declarations.clear();
        self.all_shorthand = AllShorthand::NotSet;
    }

    fn is_empty(&self) -> bool {
        self.declarations.is_empty() && matches!(self.all_shorthand, AllShorthand::NotSet)
    }

    fn push(&mut self, declaration: PropertyDeclaration) {
        let _result = self.declarations.try_push(declaration);
        debug_assert!(_result.is_ok());
    }
}

/// Return type of SourcePropertyDeclaration::drain
pub struct SourcePropertyDeclarationDrain<'a> {
    declarations: ::arrayvec::Drain<'a, SourcePropertyDeclarationArray>,
    all_shorthand: AllShorthand,
}

enum AllShorthand {
    NotSet,
    CSSWideKeyword(CSSWideKeyword),
    WithVariables(Arc<UnparsedValue>)
}

#[cfg(feature = "gecko")]
pub use gecko_properties::style_structs;

/// The module where all the style structs are defined.
#[cfg(feature = "servo")]
pub mod style_structs {
    use fnv::FnvHasher;
    use super::longhands;
    use std::hash::{Hash, Hasher};
    use logical_geometry::WritingMode;
    use media_queries::Device;
    use values::computed::NonNegativeLength;

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Background style struct.
        pub struct Background {
                /// The background-color computed value.
                pub background_color: longhands::background_color::computed_value::T,
                /// The background-image computed value.
                pub background_image: longhands::background_image::computed_value::T,
                /// The background-position-x computed value.
                pub background_position_x: longhands::background_position_x::computed_value::T,
                /// The background-position-y computed value.
                pub background_position_y: longhands::background_position_y::computed_value::T,
                /// The background-repeat computed value.
                pub background_repeat: longhands::background_repeat::computed_value::T,
                /// The background-attachment computed value.
                pub background_attachment: longhands::background_attachment::computed_value::T,
                /// The background-clip computed value.
                pub background_clip: longhands::background_clip::computed_value::T,
                /// The background-origin computed value.
                pub background_origin: longhands::background_origin::computed_value::T,
                /// The background-size computed value.
                pub background_size: longhands::background_size::computed_value::T,
                /// The background-blend-mode computed value.
                pub background_blend_mode: longhands::background_blend_mode::computed_value::T,
        }

        impl Background {
                        /// Set background-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_color(&mut self, v: longhands::background_color::computed_value::T) {
                            self.background_color = v;
                        }
                        /// Set background-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_color_from(&mut self, other: &Self) {
                            self.background_color = other.background_color.clone();
                        }
                    /// Reset background-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_color(&mut self, other: &Self) {
                        self.copy_background_color_from(other)
                    }

                    /// Get the computed value for background-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_color(&self) -> longhands::background_color::computed_value::T {
                        self.background_color.clone()
                    }
                        /// Set background-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_image<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_image
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_image = longhands::background_image::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_image_from(&mut self, other: &Self) {
                            self.background_image = other.background_image.clone();
                        }
                    /// Reset background-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_image(&mut self, other: &Self) {
                        self.copy_background_image_from(other)
                    }

                    /// Get the computed value for background-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_image(&self) -> longhands::background_image::computed_value::T {
                        self.background_image.clone()
                    }
                        /// Set background-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_x<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_position_x
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_position_x = longhands::background_position_x::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_x_from(&mut self, other: &Self) {
                            self.background_position_x = other.background_position_x.clone();
                        }
                    /// Reset background-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_x(&mut self, other: &Self) {
                        self.copy_background_position_x_from(other)
                    }

                    /// Get the computed value for background-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_x(&self) -> longhands::background_position_x::computed_value::T {
                        self.background_position_x.clone()
                    }
                        /// Set background-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_y<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_position_y
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_position_y = longhands::background_position_y::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_y_from(&mut self, other: &Self) {
                            self.background_position_y = other.background_position_y.clone();
                        }
                    /// Reset background-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_y(&mut self, other: &Self) {
                        self.copy_background_position_y_from(other)
                    }

                    /// Get the computed value for background-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_y(&self) -> longhands::background_position_y::computed_value::T {
                        self.background_position_y.clone()
                    }
                        /// Set background-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_repeat<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_repeat
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_repeat = longhands::background_repeat::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_repeat_from(&mut self, other: &Self) {
                            self.background_repeat = other.background_repeat.clone();
                        }
                    /// Reset background-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_repeat(&mut self, other: &Self) {
                        self.copy_background_repeat_from(other)
                    }

                    /// Get the computed value for background-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_repeat(&self) -> longhands::background_repeat::computed_value::T {
                        self.background_repeat.clone()
                    }
                        /// Set background-attachment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_attachment<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_attachment
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_attachment = longhands::background_attachment::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-attachment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_attachment_from(&mut self, other: &Self) {
                            self.background_attachment = other.background_attachment.clone();
                        }
                    /// Reset background-attachment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_attachment(&mut self, other: &Self) {
                        self.copy_background_attachment_from(other)
                    }

                    /// Get the computed value for background-attachment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_attachment(&self) -> longhands::background_attachment::computed_value::T {
                        self.background_attachment.clone()
                    }
                        /// Set background-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_clip<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_clip
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_clip = longhands::background_clip::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_clip_from(&mut self, other: &Self) {
                            self.background_clip = other.background_clip.clone();
                        }
                    /// Reset background-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_clip(&mut self, other: &Self) {
                        self.copy_background_clip_from(other)
                    }

                    /// Get the computed value for background-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_clip(&self) -> longhands::background_clip::computed_value::T {
                        self.background_clip.clone()
                    }
                        /// Set background-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_origin<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_origin
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_origin = longhands::background_origin::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_origin_from(&mut self, other: &Self) {
                            self.background_origin = other.background_origin.clone();
                        }
                    /// Reset background-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_origin(&mut self, other: &Self) {
                        self.copy_background_origin_from(other)
                    }

                    /// Get the computed value for background-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_origin(&self) -> longhands::background_origin::computed_value::T {
                        self.background_origin.clone()
                    }
                        /// Set background-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_size<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_size
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_size = longhands::background_size::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_size_from(&mut self, other: &Self) {
                            self.background_size = other.background_size.clone();
                        }
                    /// Reset background-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_size(&mut self, other: &Self) {
                        self.copy_background_size_from(other)
                    }

                    /// Get the computed value for background-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_size(&self) -> longhands::background_size::computed_value::T {
                        self.background_size.clone()
                    }
                        /// Set background-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_blend_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::background_blend_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.background_blend_mode = longhands::background_blend_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set background-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_blend_mode_from(&mut self, other: &Self) {
                            self.background_blend_mode = other.background_blend_mode.clone();
                        }
                    /// Reset background-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_blend_mode(&mut self, other: &Self) {
                        self.copy_background_blend_mode_from(other)
                    }

                    /// Get the computed value for background-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_blend_mode(&self) -> longhands::background_blend_mode::computed_value::T {
                        self.background_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Border style struct.
        pub struct Border {
                /// The border-top-color computed value.
                pub border_top_color: longhands::border_top_color::computed_value::T,
                /// The border-top-style computed value.
                pub border_top_style: longhands::border_top_style::computed_value::T,
                /// The border-top-width computed value.
                pub border_top_width: longhands::border_top_width::computed_value::T,
                /// The border-left-color computed value.
                pub border_left_color: longhands::border_left_color::computed_value::T,
                /// The border-left-style computed value.
                pub border_left_style: longhands::border_left_style::computed_value::T,
                /// The border-left-width computed value.
                pub border_left_width: longhands::border_left_width::computed_value::T,
                /// The border-bottom-color computed value.
                pub border_bottom_color: longhands::border_bottom_color::computed_value::T,
                /// The border-bottom-style computed value.
                pub border_bottom_style: longhands::border_bottom_style::computed_value::T,
                /// The border-bottom-width computed value.
                pub border_bottom_width: longhands::border_bottom_width::computed_value::T,
                /// The border-right-color computed value.
                pub border_right_color: longhands::border_right_color::computed_value::T,
                /// The border-right-style computed value.
                pub border_right_style: longhands::border_right_style::computed_value::T,
                /// The border-right-width computed value.
                pub border_right_width: longhands::border_right_width::computed_value::T,
                /// The border-block-start-color computed value.
                pub border_block_start_color: longhands::border_block_start_color::computed_value::T,
                /// The border-block-start-style computed value.
                pub border_block_start_style: longhands::border_block_start_style::computed_value::T,
                /// The border-block-start-width computed value.
                pub border_block_start_width: longhands::border_block_start_width::computed_value::T,
                /// The border-block-end-color computed value.
                pub border_block_end_color: longhands::border_block_end_color::computed_value::T,
                /// The border-block-end-style computed value.
                pub border_block_end_style: longhands::border_block_end_style::computed_value::T,
                /// The border-block-end-width computed value.
                pub border_block_end_width: longhands::border_block_end_width::computed_value::T,
                /// The border-inline-start-color computed value.
                pub border_inline_start_color: longhands::border_inline_start_color::computed_value::T,
                /// The border-inline-start-style computed value.
                pub border_inline_start_style: longhands::border_inline_start_style::computed_value::T,
                /// The border-inline-start-width computed value.
                pub border_inline_start_width: longhands::border_inline_start_width::computed_value::T,
                /// The border-inline-end-color computed value.
                pub border_inline_end_color: longhands::border_inline_end_color::computed_value::T,
                /// The border-inline-end-style computed value.
                pub border_inline_end_style: longhands::border_inline_end_style::computed_value::T,
                /// The border-inline-end-width computed value.
                pub border_inline_end_width: longhands::border_inline_end_width::computed_value::T,
                /// The border-top-left-radius computed value.
                pub border_top_left_radius: longhands::border_top_left_radius::computed_value::T,
                /// The border-top-right-radius computed value.
                pub border_top_right_radius: longhands::border_top_right_radius::computed_value::T,
                /// The border-bottom-right-radius computed value.
                pub border_bottom_right_radius: longhands::border_bottom_right_radius::computed_value::T,
                /// The border-bottom-left-radius computed value.
                pub border_bottom_left_radius: longhands::border_bottom_left_radius::computed_value::T,
                /// The -moz-border-top-colors computed value.
                pub _moz_border_top_colors: longhands::_moz_border_top_colors::computed_value::T,
                /// The -moz-border-left-colors computed value.
                pub _moz_border_left_colors: longhands::_moz_border_left_colors::computed_value::T,
                /// The -moz-border-bottom-colors computed value.
                pub _moz_border_bottom_colors: longhands::_moz_border_bottom_colors::computed_value::T,
                /// The -moz-border-right-colors computed value.
                pub _moz_border_right_colors: longhands::_moz_border_right_colors::computed_value::T,
                /// The box-decoration-break computed value.
                pub box_decoration_break: longhands::box_decoration_break::computed_value::T,
                /// The -moz-float-edge computed value.
                pub _moz_float_edge: longhands::_moz_float_edge::computed_value::T,
                /// The border-image-source computed value.
                pub border_image_source: longhands::border_image_source::computed_value::T,
                /// The border-image-outset computed value.
                pub border_image_outset: longhands::border_image_outset::computed_value::T,
                /// The border-image-repeat computed value.
                pub border_image_repeat: longhands::border_image_repeat::computed_value::T,
                /// The border-image-width computed value.
                pub border_image_width: longhands::border_image_width::computed_value::T,
                /// The border-image-slice computed value.
                pub border_image_slice: longhands::border_image_slice::computed_value::T,
        }

        impl Border {
                        /// Set border-top-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_color(&mut self, v: longhands::border_top_color::computed_value::T) {
                            self.border_top_color = v;
                        }
                        /// Set border-top-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_color_from(&mut self, other: &Self) {
                            self.border_top_color = other.border_top_color.clone();
                        }
                    /// Reset border-top-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_color(&mut self, other: &Self) {
                        self.copy_border_top_color_from(other)
                    }

                    /// Get the computed value for border-top-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_color(&self) -> longhands::border_top_color::computed_value::T {
                        self.border_top_color.clone()
                    }
                        /// Set border-top-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_style(&mut self, v: longhands::border_top_style::computed_value::T) {
                            self.border_top_style = v;
                        }
                        /// Set border-top-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_style_from(&mut self, other: &Self) {
                            self.border_top_style = other.border_top_style.clone();
                        }
                    /// Reset border-top-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_style(&mut self, other: &Self) {
                        self.copy_border_top_style_from(other)
                    }

                    /// Get the computed value for border-top-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_style(&self) -> longhands::border_top_style::computed_value::T {
                        self.border_top_style.clone()
                    }
                        /// Set border-top-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_width(&mut self, v: longhands::border_top_width::computed_value::T) {
                            self.border_top_width = v;
                        }
                        /// Set border-top-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_width_from(&mut self, other: &Self) {
                            self.border_top_width = other.border_top_width.clone();
                        }
                    /// Reset border-top-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_width(&mut self, other: &Self) {
                        self.copy_border_top_width_from(other)
                    }

                    /// Get the computed value for border-top-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_width(&self) -> longhands::border_top_width::computed_value::T {
                        self.border_top_width.clone()
                    }
                        /// Set border-left-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_color(&mut self, v: longhands::border_left_color::computed_value::T) {
                            self.border_left_color = v;
                        }
                        /// Set border-left-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_color_from(&mut self, other: &Self) {
                            self.border_left_color = other.border_left_color.clone();
                        }
                    /// Reset border-left-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_color(&mut self, other: &Self) {
                        self.copy_border_left_color_from(other)
                    }

                    /// Get the computed value for border-left-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_color(&self) -> longhands::border_left_color::computed_value::T {
                        self.border_left_color.clone()
                    }
                        /// Set border-left-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_style(&mut self, v: longhands::border_left_style::computed_value::T) {
                            self.border_left_style = v;
                        }
                        /// Set border-left-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_style_from(&mut self, other: &Self) {
                            self.border_left_style = other.border_left_style.clone();
                        }
                    /// Reset border-left-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_style(&mut self, other: &Self) {
                        self.copy_border_left_style_from(other)
                    }

                    /// Get the computed value for border-left-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_style(&self) -> longhands::border_left_style::computed_value::T {
                        self.border_left_style.clone()
                    }
                        /// Set border-left-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_width(&mut self, v: longhands::border_left_width::computed_value::T) {
                            self.border_left_width = v;
                        }
                        /// Set border-left-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_width_from(&mut self, other: &Self) {
                            self.border_left_width = other.border_left_width.clone();
                        }
                    /// Reset border-left-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_width(&mut self, other: &Self) {
                        self.copy_border_left_width_from(other)
                    }

                    /// Get the computed value for border-left-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_width(&self) -> longhands::border_left_width::computed_value::T {
                        self.border_left_width.clone()
                    }
                        /// Set border-bottom-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_color(&mut self, v: longhands::border_bottom_color::computed_value::T) {
                            self.border_bottom_color = v;
                        }
                        /// Set border-bottom-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_color_from(&mut self, other: &Self) {
                            self.border_bottom_color = other.border_bottom_color.clone();
                        }
                    /// Reset border-bottom-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_color(&mut self, other: &Self) {
                        self.copy_border_bottom_color_from(other)
                    }

                    /// Get the computed value for border-bottom-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_color(&self) -> longhands::border_bottom_color::computed_value::T {
                        self.border_bottom_color.clone()
                    }
                        /// Set border-bottom-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_style(&mut self, v: longhands::border_bottom_style::computed_value::T) {
                            self.border_bottom_style = v;
                        }
                        /// Set border-bottom-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_style_from(&mut self, other: &Self) {
                            self.border_bottom_style = other.border_bottom_style.clone();
                        }
                    /// Reset border-bottom-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_style(&mut self, other: &Self) {
                        self.copy_border_bottom_style_from(other)
                    }

                    /// Get the computed value for border-bottom-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_style(&self) -> longhands::border_bottom_style::computed_value::T {
                        self.border_bottom_style.clone()
                    }
                        /// Set border-bottom-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_width(&mut self, v: longhands::border_bottom_width::computed_value::T) {
                            self.border_bottom_width = v;
                        }
                        /// Set border-bottom-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_width_from(&mut self, other: &Self) {
                            self.border_bottom_width = other.border_bottom_width.clone();
                        }
                    /// Reset border-bottom-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_width(&mut self, other: &Self) {
                        self.copy_border_bottom_width_from(other)
                    }

                    /// Get the computed value for border-bottom-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_width(&self) -> longhands::border_bottom_width::computed_value::T {
                        self.border_bottom_width.clone()
                    }
                        /// Set border-right-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_color(&mut self, v: longhands::border_right_color::computed_value::T) {
                            self.border_right_color = v;
                        }
                        /// Set border-right-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_color_from(&mut self, other: &Self) {
                            self.border_right_color = other.border_right_color.clone();
                        }
                    /// Reset border-right-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_color(&mut self, other: &Self) {
                        self.copy_border_right_color_from(other)
                    }

                    /// Get the computed value for border-right-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_color(&self) -> longhands::border_right_color::computed_value::T {
                        self.border_right_color.clone()
                    }
                        /// Set border-right-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_style(&mut self, v: longhands::border_right_style::computed_value::T) {
                            self.border_right_style = v;
                        }
                        /// Set border-right-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_style_from(&mut self, other: &Self) {
                            self.border_right_style = other.border_right_style.clone();
                        }
                    /// Reset border-right-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_style(&mut self, other: &Self) {
                        self.copy_border_right_style_from(other)
                    }

                    /// Get the computed value for border-right-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_style(&self) -> longhands::border_right_style::computed_value::T {
                        self.border_right_style.clone()
                    }
                        /// Set border-right-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_width(&mut self, v: longhands::border_right_width::computed_value::T) {
                            self.border_right_width = v;
                        }
                        /// Set border-right-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_width_from(&mut self, other: &Self) {
                            self.border_right_width = other.border_right_width.clone();
                        }
                    /// Reset border-right-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_width(&mut self, other: &Self) {
                        self.copy_border_right_width_from(other)
                    }

                    /// Get the computed value for border-right-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_width(&self) -> longhands::border_right_width::computed_value::T {
                        self.border_right_width.clone()
                    }
                    
    /// Set the appropriate physical property for border-block-start-color given a writing mode.
    pub fn set_border_block_start_color(&mut self,
                                      v: longhands::border_block_start_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-color
    /// given a writing mode.
    pub fn copy_border_block_start_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-color
    /// given a writing mode.
    pub fn reset_border_block_start_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-color given a writing mode.
    pub fn clone_border_block_start_color(&self, wm: WritingMode)
        -> longhands::border_block_start_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-start-style given a writing mode.
    pub fn set_border_block_start_style(&mut self,
                                      v: longhands::border_block_start_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-style
    /// given a writing mode.
    pub fn copy_border_block_start_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-style
    /// given a writing mode.
    pub fn reset_border_block_start_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-style given a writing mode.
    pub fn clone_border_block_start_style(&self, wm: WritingMode)
        -> longhands::border_block_start_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-start-width given a writing mode.
    pub fn set_border_block_start_width(&mut self,
                                      v: longhands::border_block_start_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-width
    /// given a writing mode.
    pub fn copy_border_block_start_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-start-width
    /// given a writing mode.
    pub fn reset_border_block_start_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_start_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-start-width given a writing mode.
    pub fn clone_border_block_start_width(&self, wm: WritingMode)
        -> longhands::border_block_start_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-color given a writing mode.
    pub fn set_border_block_end_color(&mut self,
                                      v: longhands::border_block_end_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-color
    /// given a writing mode.
    pub fn copy_border_block_end_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-color
    /// given a writing mode.
    pub fn reset_border_block_end_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-color given a writing mode.
    pub fn clone_border_block_end_color(&self, wm: WritingMode)
        -> longhands::border_block_end_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-style given a writing mode.
    pub fn set_border_block_end_style(&mut self,
                                      v: longhands::border_block_end_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-style
    /// given a writing mode.
    pub fn copy_border_block_end_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-style
    /// given a writing mode.
    pub fn reset_border_block_end_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-style given a writing mode.
    pub fn clone_border_block_end_style(&self, wm: WritingMode)
        -> longhands::border_block_end_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-block-end-width given a writing mode.
    pub fn set_border_block_end_width(&mut self,
                                      v: longhands::border_block_end_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-width
    /// given a writing mode.
    pub fn copy_border_block_end_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-block-end-width
    /// given a writing mode.
    pub fn reset_border_block_end_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_block_end_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-block-end-width given a writing mode.
    pub fn clone_border_block_end_width(&self, wm: WritingMode)
        -> longhands::border_block_end_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-color given a writing mode.
    pub fn set_border_inline_start_color(&mut self,
                                      v: longhands::border_inline_start_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-color
    /// given a writing mode.
    pub fn copy_border_inline_start_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-color
    /// given a writing mode.
    pub fn reset_border_inline_start_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-color given a writing mode.
    pub fn clone_border_inline_start_color(&self, wm: WritingMode)
        -> longhands::border_inline_start_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-style given a writing mode.
    pub fn set_border_inline_start_style(&mut self,
                                      v: longhands::border_inline_start_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-style
    /// given a writing mode.
    pub fn copy_border_inline_start_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-style
    /// given a writing mode.
    pub fn reset_border_inline_start_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-style given a writing mode.
    pub fn clone_border_inline_start_style(&self, wm: WritingMode)
        -> longhands::border_inline_start_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-start-width given a writing mode.
    pub fn set_border_inline_start_width(&mut self,
                                      v: longhands::border_inline_start_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-width
    /// given a writing mode.
    pub fn copy_border_inline_start_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-start-width
    /// given a writing mode.
    pub fn reset_border_inline_start_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_start_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-start-width given a writing mode.
    pub fn clone_border_inline_start_width(&self, wm: WritingMode)
        -> longhands::border_inline_start_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-color given a writing mode.
    pub fn set_border_inline_end_color(&mut self,
                                      v: longhands::border_inline_end_color::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_color(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_color(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_color(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_color(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-color
    /// given a writing mode.
    pub fn copy_border_inline_end_color_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_color_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_color_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_color_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_color_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-color
    /// given a writing mode.
    pub fn reset_border_inline_end_color(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_color_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-color given a writing mode.
    pub fn clone_border_inline_end_color(&self, wm: WritingMode)
        -> longhands::border_inline_end_color::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_color()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_color()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_color()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_color()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-style given a writing mode.
    pub fn set_border_inline_end_style(&mut self,
                                      v: longhands::border_inline_end_style::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_style(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_style(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_style(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_style(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-style
    /// given a writing mode.
    pub fn copy_border_inline_end_style_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_style_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_style_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_style_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_style_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-style
    /// given a writing mode.
    pub fn reset_border_inline_end_style(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_style_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-style given a writing mode.
    pub fn clone_border_inline_end_style(&self, wm: WritingMode)
        -> longhands::border_inline_end_style::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_style()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_style()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_style()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_style()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for border-inline-end-width given a writing mode.
    pub fn set_border_inline_end_width(&mut self,
                                      v: longhands::border_inline_end_width::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_border_top_width(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_border_left_width(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_border_bottom_width(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_border_right_width(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-width
    /// given a writing mode.
    pub fn copy_border_inline_end_width_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_border_top_width_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_border_left_width_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_border_bottom_width_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_border_right_width_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for border-inline-end-width
    /// given a writing mode.
    pub fn reset_border_inline_end_width(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_border_inline_end_width_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// border-inline-end-width given a writing mode.
    pub fn clone_border_inline_end_width(&self, wm: WritingMode)
        -> longhands::border_inline_end_width::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_border_top_width()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_border_left_width()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_border_bottom_width()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_border_right_width()
        
                }
        }

    }

                        /// Set border-top-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_left_radius(&mut self, v: longhands::border_top_left_radius::computed_value::T) {
                            self.border_top_left_radius = v;
                        }
                        /// Set border-top-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_left_radius_from(&mut self, other: &Self) {
                            self.border_top_left_radius = other.border_top_left_radius.clone();
                        }
                    /// Reset border-top-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_left_radius(&mut self, other: &Self) {
                        self.copy_border_top_left_radius_from(other)
                    }

                    /// Get the computed value for border-top-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_left_radius(&self) -> longhands::border_top_left_radius::computed_value::T {
                        self.border_top_left_radius.clone()
                    }
                        /// Set border-top-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_right_radius(&mut self, v: longhands::border_top_right_radius::computed_value::T) {
                            self.border_top_right_radius = v;
                        }
                        /// Set border-top-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_right_radius_from(&mut self, other: &Self) {
                            self.border_top_right_radius = other.border_top_right_radius.clone();
                        }
                    /// Reset border-top-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_right_radius(&mut self, other: &Self) {
                        self.copy_border_top_right_radius_from(other)
                    }

                    /// Get the computed value for border-top-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_right_radius(&self) -> longhands::border_top_right_radius::computed_value::T {
                        self.border_top_right_radius.clone()
                    }
                        /// Set border-bottom-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_right_radius(&mut self, v: longhands::border_bottom_right_radius::computed_value::T) {
                            self.border_bottom_right_radius = v;
                        }
                        /// Set border-bottom-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_right_radius_from(&mut self, other: &Self) {
                            self.border_bottom_right_radius = other.border_bottom_right_radius.clone();
                        }
                    /// Reset border-bottom-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_right_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_right_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_right_radius(&self) -> longhands::border_bottom_right_radius::computed_value::T {
                        self.border_bottom_right_radius.clone()
                    }
                        /// Set border-bottom-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_left_radius(&mut self, v: longhands::border_bottom_left_radius::computed_value::T) {
                            self.border_bottom_left_radius = v;
                        }
                        /// Set border-bottom-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_left_radius_from(&mut self, other: &Self) {
                            self.border_bottom_left_radius = other.border_bottom_left_radius.clone();
                        }
                    /// Reset border-bottom-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_left_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_left_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_left_radius(&self) -> longhands::border_bottom_left_radius::computed_value::T {
                        self.border_bottom_left_radius.clone()
                    }
                        /// Set -moz-border-top-colors.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_border_top_colors(&mut self, v: longhands::_moz_border_top_colors::computed_value::T) {
                            self._moz_border_top_colors = v;
                        }
                        /// Set -moz-border-top-colors from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_border_top_colors_from(&mut self, other: &Self) {
                            self._moz_border_top_colors = other._moz_border_top_colors.clone();
                        }
                    /// Reset -moz-border-top-colors from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_border_top_colors(&mut self, other: &Self) {
                        self.copy__moz_border_top_colors_from(other)
                    }

                    /// Get the computed value for -moz-border-top-colors.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_border_top_colors(&self) -> longhands::_moz_border_top_colors::computed_value::T {
                        self._moz_border_top_colors.clone()
                    }
                        /// Set -moz-border-left-colors.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_border_left_colors(&mut self, v: longhands::_moz_border_left_colors::computed_value::T) {
                            self._moz_border_left_colors = v;
                        }
                        /// Set -moz-border-left-colors from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_border_left_colors_from(&mut self, other: &Self) {
                            self._moz_border_left_colors = other._moz_border_left_colors.clone();
                        }
                    /// Reset -moz-border-left-colors from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_border_left_colors(&mut self, other: &Self) {
                        self.copy__moz_border_left_colors_from(other)
                    }

                    /// Get the computed value for -moz-border-left-colors.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_border_left_colors(&self) -> longhands::_moz_border_left_colors::computed_value::T {
                        self._moz_border_left_colors.clone()
                    }
                        /// Set -moz-border-bottom-colors.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_border_bottom_colors(&mut self, v: longhands::_moz_border_bottom_colors::computed_value::T) {
                            self._moz_border_bottom_colors = v;
                        }
                        /// Set -moz-border-bottom-colors from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_border_bottom_colors_from(&mut self, other: &Self) {
                            self._moz_border_bottom_colors = other._moz_border_bottom_colors.clone();
                        }
                    /// Reset -moz-border-bottom-colors from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_border_bottom_colors(&mut self, other: &Self) {
                        self.copy__moz_border_bottom_colors_from(other)
                    }

                    /// Get the computed value for -moz-border-bottom-colors.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_border_bottom_colors(&self) -> longhands::_moz_border_bottom_colors::computed_value::T {
                        self._moz_border_bottom_colors.clone()
                    }
                        /// Set -moz-border-right-colors.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_border_right_colors(&mut self, v: longhands::_moz_border_right_colors::computed_value::T) {
                            self._moz_border_right_colors = v;
                        }
                        /// Set -moz-border-right-colors from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_border_right_colors_from(&mut self, other: &Self) {
                            self._moz_border_right_colors = other._moz_border_right_colors.clone();
                        }
                    /// Reset -moz-border-right-colors from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_border_right_colors(&mut self, other: &Self) {
                        self.copy__moz_border_right_colors_from(other)
                    }

                    /// Get the computed value for -moz-border-right-colors.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_border_right_colors(&self) -> longhands::_moz_border_right_colors::computed_value::T {
                        self._moz_border_right_colors.clone()
                    }
                        /// Set box-decoration-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_decoration_break(&mut self, v: longhands::box_decoration_break::computed_value::T) {
                            self.box_decoration_break = v;
                        }
                        /// Set box-decoration-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_decoration_break_from(&mut self, other: &Self) {
                            self.box_decoration_break = other.box_decoration_break.clone();
                        }
                    /// Reset box-decoration-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_decoration_break(&mut self, other: &Self) {
                        self.copy_box_decoration_break_from(other)
                    }

                    /// Get the computed value for box-decoration-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_decoration_break(&self) -> longhands::box_decoration_break::computed_value::T {
                        self.box_decoration_break.clone()
                    }
                        /// Set -moz-float-edge.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_float_edge(&mut self, v: longhands::_moz_float_edge::computed_value::T) {
                            self._moz_float_edge = v;
                        }
                        /// Set -moz-float-edge from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_float_edge_from(&mut self, other: &Self) {
                            self._moz_float_edge = other._moz_float_edge.clone();
                        }
                    /// Reset -moz-float-edge from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_float_edge(&mut self, other: &Self) {
                        self.copy__moz_float_edge_from(other)
                    }

                    /// Get the computed value for -moz-float-edge.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_float_edge(&self) -> longhands::_moz_float_edge::computed_value::T {
                        self._moz_float_edge.clone()
                    }
                        /// Set border-image-source.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_source(&mut self, v: longhands::border_image_source::computed_value::T) {
                            self.border_image_source = v;
                        }
                        /// Set border-image-source from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_source_from(&mut self, other: &Self) {
                            self.border_image_source = other.border_image_source.clone();
                        }
                    /// Reset border-image-source from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_source(&mut self, other: &Self) {
                        self.copy_border_image_source_from(other)
                    }

                    /// Get the computed value for border-image-source.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_source(&self) -> longhands::border_image_source::computed_value::T {
                        self.border_image_source.clone()
                    }
                        /// Set border-image-outset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_outset(&mut self, v: longhands::border_image_outset::computed_value::T) {
                            self.border_image_outset = v;
                        }
                        /// Set border-image-outset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_outset_from(&mut self, other: &Self) {
                            self.border_image_outset = other.border_image_outset.clone();
                        }
                    /// Reset border-image-outset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_outset(&mut self, other: &Self) {
                        self.copy_border_image_outset_from(other)
                    }

                    /// Get the computed value for border-image-outset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_outset(&self) -> longhands::border_image_outset::computed_value::T {
                        self.border_image_outset.clone()
                    }
                        /// Set border-image-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_repeat(&mut self, v: longhands::border_image_repeat::computed_value::T) {
                            self.border_image_repeat = v;
                        }
                        /// Set border-image-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_repeat_from(&mut self, other: &Self) {
                            self.border_image_repeat = other.border_image_repeat.clone();
                        }
                    /// Reset border-image-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_repeat(&mut self, other: &Self) {
                        self.copy_border_image_repeat_from(other)
                    }

                    /// Get the computed value for border-image-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_repeat(&self) -> longhands::border_image_repeat::computed_value::T {
                        self.border_image_repeat.clone()
                    }
                        /// Set border-image-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_width(&mut self, v: longhands::border_image_width::computed_value::T) {
                            self.border_image_width = v;
                        }
                        /// Set border-image-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_width_from(&mut self, other: &Self) {
                            self.border_image_width = other.border_image_width.clone();
                        }
                    /// Reset border-image-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_width(&mut self, other: &Self) {
                        self.copy_border_image_width_from(other)
                    }

                    /// Get the computed value for border-image-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_width(&self) -> longhands::border_image_width::computed_value::T {
                        self.border_image_width.clone()
                    }
                        /// Set border-image-slice.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_slice(&mut self, v: longhands::border_image_slice::computed_value::T) {
                            self.border_image_slice = v;
                        }
                        /// Set border-image-slice from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_slice_from(&mut self, other: &Self) {
                            self.border_image_slice = other.border_image_slice.clone();
                        }
                    /// Reset border-image-slice from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_slice(&mut self, other: &Self) {
                        self.copy_border_image_slice_from(other)
                    }

                    /// Get the computed value for border-image-slice.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_slice(&self) -> longhands::border_image_slice::computed_value::T {
                        self.border_image_slice.clone()
                    }
                    /// Whether the border-top property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_top_has_nonzero_width(&self) -> bool {
                        self.border_top_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-right property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_right_has_nonzero_width(&self) -> bool {
                        self.border_right_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-bottom property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_bottom_has_nonzero_width(&self) -> bool {
                        self.border_bottom_width != NonNegativeLength::zero()
                    }
                    /// Whether the border-left property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_left_has_nonzero_width(&self) -> bool {
                        self.border_left_width != NonNegativeLength::zero()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Box style struct.
        pub struct Box {
                /// The display computed value.
                pub display: longhands::display::computed_value::T,
                /// The -moz-top-layer computed value.
                pub _moz_top_layer: longhands::_moz_top_layer::computed_value::T,
                /// The position computed value.
                pub position: longhands::position::computed_value::T,
                /// The float computed value.
                pub float: longhands::float::computed_value::T,
                /// The clear computed value.
                pub clear: longhands::clear::computed_value::T,
                /// The vertical-align computed value.
                pub vertical_align: longhands::vertical_align::computed_value::T,
                /// The overflow-clip-box-inline computed value.
                pub overflow_clip_box_inline: longhands::overflow_clip_box_inline::computed_value::T,
                /// The overflow-clip-box-block computed value.
                pub overflow_clip_box_block: longhands::overflow_clip_box_block::computed_value::T,
                /// The overflow-x computed value.
                pub overflow_x: longhands::overflow_x::computed_value::T,
                /// The overflow-y computed value.
                pub overflow_y: longhands::overflow_y::computed_value::T,
                /// The transition-duration computed value.
                pub transition_duration: longhands::transition_duration::computed_value::T,
                /// The transition-timing-function computed value.
                pub transition_timing_function: longhands::transition_timing_function::computed_value::T,
                /// The transition-property computed value.
                pub transition_property: longhands::transition_property::computed_value::T,
                /// The transition-delay computed value.
                pub transition_delay: longhands::transition_delay::computed_value::T,
                /// The animation-name computed value.
                pub animation_name: longhands::animation_name::computed_value::T,
                /// The animation-duration computed value.
                pub animation_duration: longhands::animation_duration::computed_value::T,
                /// The animation-timing-function computed value.
                pub animation_timing_function: longhands::animation_timing_function::computed_value::T,
                /// The animation-iteration-count computed value.
                pub animation_iteration_count: longhands::animation_iteration_count::computed_value::T,
                /// The animation-direction computed value.
                pub animation_direction: longhands::animation_direction::computed_value::T,
                /// The animation-play-state computed value.
                pub animation_play_state: longhands::animation_play_state::computed_value::T,
                /// The animation-fill-mode computed value.
                pub animation_fill_mode: longhands::animation_fill_mode::computed_value::T,
                /// The animation-delay computed value.
                pub animation_delay: longhands::animation_delay::computed_value::T,
                /// The scroll-snap-points-x computed value.
                pub scroll_snap_points_x: longhands::scroll_snap_points_x::computed_value::T,
                /// The scroll-snap-points-y computed value.
                pub scroll_snap_points_y: longhands::scroll_snap_points_y::computed_value::T,
                /// The scroll-snap-destination computed value.
                pub scroll_snap_destination: longhands::scroll_snap_destination::computed_value::T,
                /// The scroll-snap-coordinate computed value.
                pub scroll_snap_coordinate: longhands::scroll_snap_coordinate::computed_value::T,
                /// The transform computed value.
                pub transform: longhands::transform::computed_value::T,
                /// The scroll-behavior computed value.
                pub scroll_behavior: longhands::scroll_behavior::computed_value::T,
                /// The scroll-snap-type-x computed value.
                pub scroll_snap_type_x: longhands::scroll_snap_type_x::computed_value::T,
                /// The scroll-snap-type-y computed value.
                pub scroll_snap_type_y: longhands::scroll_snap_type_y::computed_value::T,
                /// The overscroll-behavior-x computed value.
                pub overscroll_behavior_x: longhands::overscroll_behavior_x::computed_value::T,
                /// The overscroll-behavior-y computed value.
                pub overscroll_behavior_y: longhands::overscroll_behavior_y::computed_value::T,
                /// The isolation computed value.
                pub isolation: longhands::isolation::computed_value::T,
                /// The page-break-after computed value.
                pub page_break_after: longhands::page_break_after::computed_value::T,
                /// The page-break-before computed value.
                pub page_break_before: longhands::page_break_before::computed_value::T,
                /// The page-break-inside computed value.
                pub page_break_inside: longhands::page_break_inside::computed_value::T,
                /// The resize computed value.
                pub resize: longhands::resize::computed_value::T,
                /// The perspective computed value.
                pub perspective: longhands::perspective::computed_value::T,
                /// The perspective-origin computed value.
                pub perspective_origin: longhands::perspective_origin::computed_value::T,
                /// The backface-visibility computed value.
                pub backface_visibility: longhands::backface_visibility::computed_value::T,
                /// The transform-box computed value.
                pub transform_box: longhands::transform_box::computed_value::T,
                /// The transform-style computed value.
                pub transform_style: longhands::transform_style::computed_value::T,
                /// The transform-origin computed value.
                pub transform_origin: longhands::transform_origin::computed_value::T,
                /// The contain computed value.
                pub contain: longhands::contain::computed_value::T,
                /// The -moz-appearance computed value.
                pub _moz_appearance: longhands::_moz_appearance::computed_value::T,
                /// The -moz-binding computed value.
                pub _moz_binding: longhands::_moz_binding::computed_value::T,
                /// The -moz-orient computed value.
                pub _moz_orient: longhands::_moz_orient::computed_value::T,
                /// The will-change computed value.
                pub will_change: longhands::will_change::computed_value::T,
                /// The shape-image-threshold computed value.
                pub shape_image_threshold: longhands::shape_image_threshold::computed_value::T,
                /// The shape-outside computed value.
                pub shape_outside: longhands::shape_outside::computed_value::T,
                /// The touch-action computed value.
                pub touch_action: longhands::touch_action::computed_value::T,
                /// The display value specified by the CSS stylesheets (without any style adjustments),
                /// which is needed for hypothetical layout boxes.
                pub original_display: longhands::display::computed_value::T,
        }

        impl Box {
                        /// Set `display`.
                        ///
                        /// We need to keep track of the original display for hypothetical boxes,
                        /// so we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_display(&mut self, v: longhands::display::computed_value::T) {
                            self.display = v;
                            self.original_display = v;
                        }
                        /// Set `display` from other struct.
                        ///
                        /// Same as `set_display` above.
                        /// Thus, we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_display_from(&mut self, other: &Self) {
                            self.display = other.display.clone();
                            self.original_display = other.display.clone();
                        }
                    /// Reset display from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_display(&mut self, other: &Self) {
                        self.copy_display_from(other)
                    }

                    /// Get the computed value for display.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_display(&self) -> longhands::display::computed_value::T {
                        self.display.clone()
                    }
                        /// Set -moz-top-layer.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_top_layer(&mut self, v: longhands::_moz_top_layer::computed_value::T) {
                            self._moz_top_layer = v;
                        }
                        /// Set -moz-top-layer from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_top_layer_from(&mut self, other: &Self) {
                            self._moz_top_layer = other._moz_top_layer.clone();
                        }
                    /// Reset -moz-top-layer from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_top_layer(&mut self, other: &Self) {
                        self.copy__moz_top_layer_from(other)
                    }

                    /// Get the computed value for -moz-top-layer.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_top_layer(&self) -> longhands::_moz_top_layer::computed_value::T {
                        self._moz_top_layer.clone()
                    }
                        /// Set position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position(&mut self, v: longhands::position::computed_value::T) {
                            self.position = v;
                        }
                        /// Set position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_from(&mut self, other: &Self) {
                            self.position = other.position.clone();
                        }
                    /// Reset position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position(&mut self, other: &Self) {
                        self.copy_position_from(other)
                    }

                    /// Get the computed value for position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position(&self) -> longhands::position::computed_value::T {
                        self.position.clone()
                    }
                        /// Set float.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_float(&mut self, v: longhands::float::computed_value::T) {
                            self.float = v;
                        }
                        /// Set float from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_float_from(&mut self, other: &Self) {
                            self.float = other.float.clone();
                        }
                    /// Reset float from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_float(&mut self, other: &Self) {
                        self.copy_float_from(other)
                    }

                    /// Get the computed value for float.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_float(&self) -> longhands::float::computed_value::T {
                        self.float.clone()
                    }
                        /// Set clear.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clear(&mut self, v: longhands::clear::computed_value::T) {
                            self.clear = v;
                        }
                        /// Set clear from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clear_from(&mut self, other: &Self) {
                            self.clear = other.clear.clone();
                        }
                    /// Reset clear from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clear(&mut self, other: &Self) {
                        self.copy_clear_from(other)
                    }

                    /// Get the computed value for clear.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clear(&self) -> longhands::clear::computed_value::T {
                        self.clear.clone()
                    }
                        /// Set vertical-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vertical_align(&mut self, v: longhands::vertical_align::computed_value::T) {
                            self.vertical_align = v;
                        }
                        /// Set vertical-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vertical_align_from(&mut self, other: &Self) {
                            self.vertical_align = other.vertical_align.clone();
                        }
                    /// Reset vertical-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vertical_align(&mut self, other: &Self) {
                        self.copy_vertical_align_from(other)
                    }

                    /// Get the computed value for vertical-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vertical_align(&self) -> longhands::vertical_align::computed_value::T {
                        self.vertical_align.clone()
                    }
                        /// Set overflow-clip-box-inline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_inline(&mut self, v: longhands::overflow_clip_box_inline::computed_value::T) {
                            self.overflow_clip_box_inline = v;
                        }
                        /// Set overflow-clip-box-inline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_inline_from(&mut self, other: &Self) {
                            self.overflow_clip_box_inline = other.overflow_clip_box_inline.clone();
                        }
                    /// Reset overflow-clip-box-inline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_inline(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_inline_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-inline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_inline(&self) -> longhands::overflow_clip_box_inline::computed_value::T {
                        self.overflow_clip_box_inline.clone()
                    }
                        /// Set overflow-clip-box-block.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_block(&mut self, v: longhands::overflow_clip_box_block::computed_value::T) {
                            self.overflow_clip_box_block = v;
                        }
                        /// Set overflow-clip-box-block from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_block_from(&mut self, other: &Self) {
                            self.overflow_clip_box_block = other.overflow_clip_box_block.clone();
                        }
                    /// Reset overflow-clip-box-block from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_block(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_block_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-block.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_block(&self) -> longhands::overflow_clip_box_block::computed_value::T {
                        self.overflow_clip_box_block.clone()
                    }
                        /// Set overflow-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_x(&mut self, v: longhands::overflow_x::computed_value::T) {
                            self.overflow_x = v;
                        }
                        /// Set overflow-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_x_from(&mut self, other: &Self) {
                            self.overflow_x = other.overflow_x.clone();
                        }
                    /// Reset overflow-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_x(&mut self, other: &Self) {
                        self.copy_overflow_x_from(other)
                    }

                    /// Get the computed value for overflow-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_x(&self) -> longhands::overflow_x::computed_value::T {
                        self.overflow_x.clone()
                    }
                        /// Set overflow-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_y(&mut self, v: longhands::overflow_y::computed_value::T) {
                            self.overflow_y = v;
                        }
                        /// Set overflow-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_y_from(&mut self, other: &Self) {
                            self.overflow_y = other.overflow_y.clone();
                        }
                    /// Reset overflow-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_y(&mut self, other: &Self) {
                        self.copy_overflow_y_from(other)
                    }

                    /// Get the computed value for overflow-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_y(&self) -> longhands::overflow_y::computed_value::T {
                        self.overflow_y.clone()
                    }
                        /// Set transition-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_duration<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_duration
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_duration = longhands::transition_duration::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_duration_from(&mut self, other: &Self) {
                            self.transition_duration = other.transition_duration.clone();
                        }
                    /// Reset transition-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_duration(&mut self, other: &Self) {
                        self.copy_transition_duration_from(other)
                    }

                    /// Get the computed value for transition-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_duration(&self) -> longhands::transition_duration::computed_value::T {
                        self.transition_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_count(&self) -> usize {
                        self.transition_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_at(&self, index: usize)
                        -> longhands::transition_duration::computed_value::SingleComputedValue {
                        self.transition_duration.0[index].clone()
                    }
                        /// Set transition-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_timing_function<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_timing_function
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_timing_function = longhands::transition_timing_function::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_timing_function_from(&mut self, other: &Self) {
                            self.transition_timing_function = other.transition_timing_function.clone();
                        }
                    /// Reset transition-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_timing_function(&mut self, other: &Self) {
                        self.copy_transition_timing_function_from(other)
                    }

                    /// Get the computed value for transition-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_timing_function(&self) -> longhands::transition_timing_function::computed_value::T {
                        self.transition_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_count(&self) -> usize {
                        self.transition_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_at(&self, index: usize)
                        -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                        self.transition_timing_function.0[index].clone()
                    }
                        /// Set transition-property.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_property<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_property
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_property = longhands::transition_property::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-property from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_property_from(&mut self, other: &Self) {
                            self.transition_property = other.transition_property.clone();
                        }
                    /// Reset transition-property from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_property(&mut self, other: &Self) {
                        self.copy_transition_property_from(other)
                    }

                    /// Get the computed value for transition-property.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_property(&self) -> longhands::transition_property::computed_value::T {
                        self.transition_property.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_property_count(&self) -> usize {
                        self.transition_property.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_property_at(&self, index: usize)
                        -> longhands::transition_property::computed_value::SingleComputedValue {
                        self.transition_property.0[index].clone()
                    }
                        /// Set transition-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_delay<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::transition_delay
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.transition_delay = longhands::transition_delay::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set transition-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_delay_from(&mut self, other: &Self) {
                            self.transition_delay = other.transition_delay.clone();
                        }
                    /// Reset transition-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_delay(&mut self, other: &Self) {
                        self.copy_transition_delay_from(other)
                    }

                    /// Get the computed value for transition-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_delay(&self) -> longhands::transition_delay::computed_value::T {
                        self.transition_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_count(&self) -> usize {
                        self.transition_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_at(&self, index: usize)
                        -> longhands::transition_delay::computed_value::SingleComputedValue {
                        self.transition_delay.0[index].clone()
                    }
                        /// Set animation-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_name<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_name
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_name = longhands::animation_name::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_name_from(&mut self, other: &Self) {
                            self.animation_name = other.animation_name.clone();
                        }
                    /// Reset animation-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_name(&mut self, other: &Self) {
                        self.copy_animation_name_from(other)
                    }

                    /// Get the computed value for animation-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_name(&self) -> longhands::animation_name::computed_value::T {
                        self.animation_name.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_name_count(&self) -> usize {
                        self.animation_name.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_name_at(&self, index: usize)
                        -> longhands::animation_name::computed_value::SingleComputedValue {
                        self.animation_name.0[index].clone()
                    }
                        /// Set animation-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_duration<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_duration
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_duration = longhands::animation_duration::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_duration_from(&mut self, other: &Self) {
                            self.animation_duration = other.animation_duration.clone();
                        }
                    /// Reset animation-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_duration(&mut self, other: &Self) {
                        self.copy_animation_duration_from(other)
                    }

                    /// Get the computed value for animation-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_duration(&self) -> longhands::animation_duration::computed_value::T {
                        self.animation_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_count(&self) -> usize {
                        self.animation_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_at(&self, index: usize)
                        -> longhands::animation_duration::computed_value::SingleComputedValue {
                        self.animation_duration.0[index].clone()
                    }
                        /// Set animation-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_timing_function<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_timing_function
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_timing_function = longhands::animation_timing_function::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_timing_function_from(&mut self, other: &Self) {
                            self.animation_timing_function = other.animation_timing_function.clone();
                        }
                    /// Reset animation-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_timing_function(&mut self, other: &Self) {
                        self.copy_animation_timing_function_from(other)
                    }

                    /// Get the computed value for animation-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_timing_function(&self) -> longhands::animation_timing_function::computed_value::T {
                        self.animation_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_count(&self) -> usize {
                        self.animation_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_at(&self, index: usize)
                        -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                        self.animation_timing_function.0[index].clone()
                    }
                        /// Set animation-iteration-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_iteration_count<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_iteration_count
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_iteration_count = longhands::animation_iteration_count::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-iteration-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_iteration_count_from(&mut self, other: &Self) {
                            self.animation_iteration_count = other.animation_iteration_count.clone();
                        }
                    /// Reset animation-iteration-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_iteration_count(&mut self, other: &Self) {
                        self.copy_animation_iteration_count_from(other)
                    }

                    /// Get the computed value for animation-iteration-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_iteration_count(&self) -> longhands::animation_iteration_count::computed_value::T {
                        self.animation_iteration_count.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_count(&self) -> usize {
                        self.animation_iteration_count.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_at(&self, index: usize)
                        -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                        self.animation_iteration_count.0[index].clone()
                    }
                        /// Set animation-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_direction<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_direction
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_direction = longhands::animation_direction::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_direction_from(&mut self, other: &Self) {
                            self.animation_direction = other.animation_direction.clone();
                        }
                    /// Reset animation-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_direction(&mut self, other: &Self) {
                        self.copy_animation_direction_from(other)
                    }

                    /// Get the computed value for animation-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_direction(&self) -> longhands::animation_direction::computed_value::T {
                        self.animation_direction.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_count(&self) -> usize {
                        self.animation_direction.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_at(&self, index: usize)
                        -> longhands::animation_direction::computed_value::SingleComputedValue {
                        self.animation_direction.0[index].clone()
                    }
                        /// Set animation-play-state.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_play_state<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_play_state
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_play_state = longhands::animation_play_state::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-play-state from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_play_state_from(&mut self, other: &Self) {
                            self.animation_play_state = other.animation_play_state.clone();
                        }
                    /// Reset animation-play-state from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_play_state(&mut self, other: &Self) {
                        self.copy_animation_play_state_from(other)
                    }

                    /// Get the computed value for animation-play-state.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_play_state(&self) -> longhands::animation_play_state::computed_value::T {
                        self.animation_play_state.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_count(&self) -> usize {
                        self.animation_play_state.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_at(&self, index: usize)
                        -> longhands::animation_play_state::computed_value::SingleComputedValue {
                        self.animation_play_state.0[index].clone()
                    }
                        /// Set animation-fill-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_fill_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_fill_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_fill_mode = longhands::animation_fill_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-fill-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_fill_mode_from(&mut self, other: &Self) {
                            self.animation_fill_mode = other.animation_fill_mode.clone();
                        }
                    /// Reset animation-fill-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_fill_mode(&mut self, other: &Self) {
                        self.copy_animation_fill_mode_from(other)
                    }

                    /// Get the computed value for animation-fill-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_fill_mode(&self) -> longhands::animation_fill_mode::computed_value::T {
                        self.animation_fill_mode.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_count(&self) -> usize {
                        self.animation_fill_mode.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_at(&self, index: usize)
                        -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                        self.animation_fill_mode.0[index].clone()
                    }
                        /// Set animation-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_delay<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::animation_delay
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.animation_delay = longhands::animation_delay::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set animation-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_delay_from(&mut self, other: &Self) {
                            self.animation_delay = other.animation_delay.clone();
                        }
                    /// Reset animation-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_delay(&mut self, other: &Self) {
                        self.copy_animation_delay_from(other)
                    }

                    /// Get the computed value for animation-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_delay(&self) -> longhands::animation_delay::computed_value::T {
                        self.animation_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_count(&self) -> usize {
                        self.animation_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_at(&self, index: usize)
                        -> longhands::animation_delay::computed_value::SingleComputedValue {
                        self.animation_delay.0[index].clone()
                    }
                        /// Set scroll-snap-points-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_points_x(&mut self, v: longhands::scroll_snap_points_x::computed_value::T) {
                            self.scroll_snap_points_x = v;
                        }
                        /// Set scroll-snap-points-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_points_x_from(&mut self, other: &Self) {
                            self.scroll_snap_points_x = other.scroll_snap_points_x.clone();
                        }
                    /// Reset scroll-snap-points-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_points_x(&mut self, other: &Self) {
                        self.copy_scroll_snap_points_x_from(other)
                    }

                    /// Get the computed value for scroll-snap-points-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_points_x(&self) -> longhands::scroll_snap_points_x::computed_value::T {
                        self.scroll_snap_points_x.clone()
                    }
                        /// Set scroll-snap-points-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_points_y(&mut self, v: longhands::scroll_snap_points_y::computed_value::T) {
                            self.scroll_snap_points_y = v;
                        }
                        /// Set scroll-snap-points-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_points_y_from(&mut self, other: &Self) {
                            self.scroll_snap_points_y = other.scroll_snap_points_y.clone();
                        }
                    /// Reset scroll-snap-points-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_points_y(&mut self, other: &Self) {
                        self.copy_scroll_snap_points_y_from(other)
                    }

                    /// Get the computed value for scroll-snap-points-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_points_y(&self) -> longhands::scroll_snap_points_y::computed_value::T {
                        self.scroll_snap_points_y.clone()
                    }
                        /// Set scroll-snap-destination.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_destination(&mut self, v: longhands::scroll_snap_destination::computed_value::T) {
                            self.scroll_snap_destination = v;
                        }
                        /// Set scroll-snap-destination from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_destination_from(&mut self, other: &Self) {
                            self.scroll_snap_destination = other.scroll_snap_destination.clone();
                        }
                    /// Reset scroll-snap-destination from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_destination(&mut self, other: &Self) {
                        self.copy_scroll_snap_destination_from(other)
                    }

                    /// Get the computed value for scroll-snap-destination.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_destination(&self) -> longhands::scroll_snap_destination::computed_value::T {
                        self.scroll_snap_destination.clone()
                    }
                        /// Set scroll-snap-coordinate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_coordinate<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::scroll_snap_coordinate
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.scroll_snap_coordinate = longhands::scroll_snap_coordinate::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set scroll-snap-coordinate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_coordinate_from(&mut self, other: &Self) {
                            self.scroll_snap_coordinate = other.scroll_snap_coordinate.clone();
                        }
                    /// Reset scroll-snap-coordinate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_coordinate(&mut self, other: &Self) {
                        self.copy_scroll_snap_coordinate_from(other)
                    }

                    /// Get the computed value for scroll-snap-coordinate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_coordinate(&self) -> longhands::scroll_snap_coordinate::computed_value::T {
                        self.scroll_snap_coordinate.clone()
                    }
                        /// Set transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform(&mut self, v: longhands::transform::computed_value::T) {
                            self.transform = v;
                        }
                        /// Set transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_from(&mut self, other: &Self) {
                            self.transform = other.transform.clone();
                        }
                    /// Reset transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform(&mut self, other: &Self) {
                        self.copy_transform_from(other)
                    }

                    /// Get the computed value for transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform(&self) -> longhands::transform::computed_value::T {
                        self.transform.clone()
                    }
                        /// Set scroll-behavior.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_behavior(&mut self, v: longhands::scroll_behavior::computed_value::T) {
                            self.scroll_behavior = v;
                        }
                        /// Set scroll-behavior from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_behavior_from(&mut self, other: &Self) {
                            self.scroll_behavior = other.scroll_behavior.clone();
                        }
                    /// Reset scroll-behavior from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_behavior(&mut self, other: &Self) {
                        self.copy_scroll_behavior_from(other)
                    }

                    /// Get the computed value for scroll-behavior.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_behavior(&self) -> longhands::scroll_behavior::computed_value::T {
                        self.scroll_behavior.clone()
                    }
                        /// Set scroll-snap-type-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_type_x(&mut self, v: longhands::scroll_snap_type_x::computed_value::T) {
                            self.scroll_snap_type_x = v;
                        }
                        /// Set scroll-snap-type-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_type_x_from(&mut self, other: &Self) {
                            self.scroll_snap_type_x = other.scroll_snap_type_x.clone();
                        }
                    /// Reset scroll-snap-type-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_type_x(&mut self, other: &Self) {
                        self.copy_scroll_snap_type_x_from(other)
                    }

                    /// Get the computed value for scroll-snap-type-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_type_x(&self) -> longhands::scroll_snap_type_x::computed_value::T {
                        self.scroll_snap_type_x.clone()
                    }
                        /// Set scroll-snap-type-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_type_y(&mut self, v: longhands::scroll_snap_type_y::computed_value::T) {
                            self.scroll_snap_type_y = v;
                        }
                        /// Set scroll-snap-type-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_type_y_from(&mut self, other: &Self) {
                            self.scroll_snap_type_y = other.scroll_snap_type_y.clone();
                        }
                    /// Reset scroll-snap-type-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_type_y(&mut self, other: &Self) {
                        self.copy_scroll_snap_type_y_from(other)
                    }

                    /// Get the computed value for scroll-snap-type-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_type_y(&self) -> longhands::scroll_snap_type_y::computed_value::T {
                        self.scroll_snap_type_y.clone()
                    }
                        /// Set overscroll-behavior-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_x(&mut self, v: longhands::overscroll_behavior_x::computed_value::T) {
                            self.overscroll_behavior_x = v;
                        }
                        /// Set overscroll-behavior-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_x_from(&mut self, other: &Self) {
                            self.overscroll_behavior_x = other.overscroll_behavior_x.clone();
                        }
                    /// Reset overscroll-behavior-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_x(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_x_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_x(&self) -> longhands::overscroll_behavior_x::computed_value::T {
                        self.overscroll_behavior_x.clone()
                    }
                        /// Set overscroll-behavior-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_y(&mut self, v: longhands::overscroll_behavior_y::computed_value::T) {
                            self.overscroll_behavior_y = v;
                        }
                        /// Set overscroll-behavior-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_y_from(&mut self, other: &Self) {
                            self.overscroll_behavior_y = other.overscroll_behavior_y.clone();
                        }
                    /// Reset overscroll-behavior-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_y(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_y_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_y(&self) -> longhands::overscroll_behavior_y::computed_value::T {
                        self.overscroll_behavior_y.clone()
                    }
                        /// Set isolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_isolation(&mut self, v: longhands::isolation::computed_value::T) {
                            self.isolation = v;
                        }
                        /// Set isolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_isolation_from(&mut self, other: &Self) {
                            self.isolation = other.isolation.clone();
                        }
                    /// Reset isolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_isolation(&mut self, other: &Self) {
                        self.copy_isolation_from(other)
                    }

                    /// Get the computed value for isolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_isolation(&self) -> longhands::isolation::computed_value::T {
                        self.isolation.clone()
                    }
                        /// Set page-break-after.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_after(&mut self, v: longhands::page_break_after::computed_value::T) {
                            self.page_break_after = v;
                        }
                        /// Set page-break-after from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_after_from(&mut self, other: &Self) {
                            self.page_break_after = other.page_break_after.clone();
                        }
                    /// Reset page-break-after from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_after(&mut self, other: &Self) {
                        self.copy_page_break_after_from(other)
                    }

                    /// Get the computed value for page-break-after.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_after(&self) -> longhands::page_break_after::computed_value::T {
                        self.page_break_after.clone()
                    }
                        /// Set page-break-before.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_before(&mut self, v: longhands::page_break_before::computed_value::T) {
                            self.page_break_before = v;
                        }
                        /// Set page-break-before from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_before_from(&mut self, other: &Self) {
                            self.page_break_before = other.page_break_before.clone();
                        }
                    /// Reset page-break-before from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_before(&mut self, other: &Self) {
                        self.copy_page_break_before_from(other)
                    }

                    /// Get the computed value for page-break-before.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_before(&self) -> longhands::page_break_before::computed_value::T {
                        self.page_break_before.clone()
                    }
                        /// Set page-break-inside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_break_inside(&mut self, v: longhands::page_break_inside::computed_value::T) {
                            self.page_break_inside = v;
                        }
                        /// Set page-break-inside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_break_inside_from(&mut self, other: &Self) {
                            self.page_break_inside = other.page_break_inside.clone();
                        }
                    /// Reset page-break-inside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_break_inside(&mut self, other: &Self) {
                        self.copy_page_break_inside_from(other)
                    }

                    /// Get the computed value for page-break-inside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_break_inside(&self) -> longhands::page_break_inside::computed_value::T {
                        self.page_break_inside.clone()
                    }
                        /// Set resize.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_resize(&mut self, v: longhands::resize::computed_value::T) {
                            self.resize = v;
                        }
                        /// Set resize from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_resize_from(&mut self, other: &Self) {
                            self.resize = other.resize.clone();
                        }
                    /// Reset resize from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_resize(&mut self, other: &Self) {
                        self.copy_resize_from(other)
                    }

                    /// Get the computed value for resize.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_resize(&self) -> longhands::resize::computed_value::T {
                        self.resize.clone()
                    }
                        /// Set perspective.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective(&mut self, v: longhands::perspective::computed_value::T) {
                            self.perspective = v;
                        }
                        /// Set perspective from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_from(&mut self, other: &Self) {
                            self.perspective = other.perspective.clone();
                        }
                    /// Reset perspective from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective(&mut self, other: &Self) {
                        self.copy_perspective_from(other)
                    }

                    /// Get the computed value for perspective.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective(&self) -> longhands::perspective::computed_value::T {
                        self.perspective.clone()
                    }
                        /// Set perspective-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective_origin(&mut self, v: longhands::perspective_origin::computed_value::T) {
                            self.perspective_origin = v;
                        }
                        /// Set perspective-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_origin_from(&mut self, other: &Self) {
                            self.perspective_origin = other.perspective_origin.clone();
                        }
                    /// Reset perspective-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective_origin(&mut self, other: &Self) {
                        self.copy_perspective_origin_from(other)
                    }

                    /// Get the computed value for perspective-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective_origin(&self) -> longhands::perspective_origin::computed_value::T {
                        self.perspective_origin.clone()
                    }
                        /// Set backface-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_backface_visibility(&mut self, v: longhands::backface_visibility::computed_value::T) {
                            self.backface_visibility = v;
                        }
                        /// Set backface-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_backface_visibility_from(&mut self, other: &Self) {
                            self.backface_visibility = other.backface_visibility.clone();
                        }
                    /// Reset backface-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_backface_visibility(&mut self, other: &Self) {
                        self.copy_backface_visibility_from(other)
                    }

                    /// Get the computed value for backface-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_backface_visibility(&self) -> longhands::backface_visibility::computed_value::T {
                        self.backface_visibility.clone()
                    }
                        /// Set transform-box.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_box(&mut self, v: longhands::transform_box::computed_value::T) {
                            self.transform_box = v;
                        }
                        /// Set transform-box from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_box_from(&mut self, other: &Self) {
                            self.transform_box = other.transform_box.clone();
                        }
                    /// Reset transform-box from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_box(&mut self, other: &Self) {
                        self.copy_transform_box_from(other)
                    }

                    /// Get the computed value for transform-box.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_box(&self) -> longhands::transform_box::computed_value::T {
                        self.transform_box.clone()
                    }
                        /// Set transform-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_style(&mut self, v: longhands::transform_style::computed_value::T) {
                            self.transform_style = v;
                        }
                        /// Set transform-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_style_from(&mut self, other: &Self) {
                            self.transform_style = other.transform_style.clone();
                        }
                    /// Reset transform-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_style(&mut self, other: &Self) {
                        self.copy_transform_style_from(other)
                    }

                    /// Get the computed value for transform-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_style(&self) -> longhands::transform_style::computed_value::T {
                        self.transform_style.clone()
                    }
                        /// Set transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_origin(&mut self, v: longhands::transform_origin::computed_value::T) {
                            self.transform_origin = v;
                        }
                        /// Set transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_origin_from(&mut self, other: &Self) {
                            self.transform_origin = other.transform_origin.clone();
                        }
                    /// Reset transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_origin(&mut self, other: &Self) {
                        self.copy_transform_origin_from(other)
                    }

                    /// Get the computed value for transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_origin(&self) -> longhands::transform_origin::computed_value::T {
                        self.transform_origin.clone()
                    }
                        /// Set contain.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_contain(&mut self, v: longhands::contain::computed_value::T) {
                            self.contain = v;
                        }
                        /// Set contain from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_contain_from(&mut self, other: &Self) {
                            self.contain = other.contain.clone();
                        }
                    /// Reset contain from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_contain(&mut self, other: &Self) {
                        self.copy_contain_from(other)
                    }

                    /// Get the computed value for contain.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_contain(&self) -> longhands::contain::computed_value::T {
                        self.contain.clone()
                    }
                        /// Set -moz-appearance.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_appearance(&mut self, v: longhands::_moz_appearance::computed_value::T) {
                            self._moz_appearance = v;
                        }
                        /// Set -moz-appearance from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_appearance_from(&mut self, other: &Self) {
                            self._moz_appearance = other._moz_appearance.clone();
                        }
                    /// Reset -moz-appearance from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_appearance(&mut self, other: &Self) {
                        self.copy__moz_appearance_from(other)
                    }

                    /// Get the computed value for -moz-appearance.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_appearance(&self) -> longhands::_moz_appearance::computed_value::T {
                        self._moz_appearance.clone()
                    }
                        /// Set -moz-binding.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_binding(&mut self, v: longhands::_moz_binding::computed_value::T) {
                            self._moz_binding = v;
                        }
                        /// Set -moz-binding from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_binding_from(&mut self, other: &Self) {
                            self._moz_binding = other._moz_binding.clone();
                        }
                    /// Reset -moz-binding from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_binding(&mut self, other: &Self) {
                        self.copy__moz_binding_from(other)
                    }

                    /// Get the computed value for -moz-binding.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_binding(&self) -> longhands::_moz_binding::computed_value::T {
                        self._moz_binding.clone()
                    }
                        /// Set -moz-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_orient(&mut self, v: longhands::_moz_orient::computed_value::T) {
                            self._moz_orient = v;
                        }
                        /// Set -moz-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_orient_from(&mut self, other: &Self) {
                            self._moz_orient = other._moz_orient.clone();
                        }
                    /// Reset -moz-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_orient(&mut self, other: &Self) {
                        self.copy__moz_orient_from(other)
                    }

                    /// Get the computed value for -moz-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_orient(&self) -> longhands::_moz_orient::computed_value::T {
                        self._moz_orient.clone()
                    }
                        /// Set will-change.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_will_change(&mut self, v: longhands::will_change::computed_value::T) {
                            self.will_change = v;
                        }
                        /// Set will-change from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_will_change_from(&mut self, other: &Self) {
                            self.will_change = other.will_change.clone();
                        }
                    /// Reset will-change from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_will_change(&mut self, other: &Self) {
                        self.copy_will_change_from(other)
                    }

                    /// Get the computed value for will-change.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_will_change(&self) -> longhands::will_change::computed_value::T {
                        self.will_change.clone()
                    }
                        /// Set shape-image-threshold.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_image_threshold(&mut self, v: longhands::shape_image_threshold::computed_value::T) {
                            self.shape_image_threshold = v;
                        }
                        /// Set shape-image-threshold from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_image_threshold_from(&mut self, other: &Self) {
                            self.shape_image_threshold = other.shape_image_threshold.clone();
                        }
                    /// Reset shape-image-threshold from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_image_threshold(&mut self, other: &Self) {
                        self.copy_shape_image_threshold_from(other)
                    }

                    /// Get the computed value for shape-image-threshold.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_image_threshold(&self) -> longhands::shape_image_threshold::computed_value::T {
                        self.shape_image_threshold.clone()
                    }
                        /// Set shape-outside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_outside(&mut self, v: longhands::shape_outside::computed_value::T) {
                            self.shape_outside = v;
                        }
                        /// Set shape-outside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_outside_from(&mut self, other: &Self) {
                            self.shape_outside = other.shape_outside.clone();
                        }
                    /// Reset shape-outside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_outside(&mut self, other: &Self) {
                        self.copy_shape_outside_from(other)
                    }

                    /// Get the computed value for shape-outside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_outside(&self) -> longhands::shape_outside::computed_value::T {
                        self.shape_outside.clone()
                    }
                        /// Set touch-action.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_touch_action(&mut self, v: longhands::touch_action::computed_value::T) {
                            self.touch_action = v;
                        }
                        /// Set touch-action from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_touch_action_from(&mut self, other: &Self) {
                            self.touch_action = other.touch_action.clone();
                        }
                    /// Reset touch-action from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_touch_action(&mut self, other: &Self) {
                        self.copy_touch_action_from(other)
                    }

                    /// Get the computed value for touch-action.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_touch_action(&self) -> longhands::touch_action::computed_value::T {
                        self.touch_action.clone()
                    }
                /// Sets the display property, but without touching original_display,
                /// except when the adjustment comes from root or item display fixups.
                pub fn set_adjusted_display(
                    &mut self,
                    dpy: longhands::display::computed_value::T,
                    is_item_or_root: bool
                ) {
                    self.display = dpy;
                    if is_item_or_root {
                        self.original_display = dpy;
                    }
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Color style struct.
        pub struct Color {
                /// The color computed value.
                pub color: longhands::color::computed_value::T,
        }

        impl Color {
                        /// Set color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color(&mut self, v: longhands::color::computed_value::T) {
                            self.color = v;
                        }
                        /// Set color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_from(&mut self, other: &Self) {
                            self.color = other.color.clone();
                        }
                    /// Reset color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color(&mut self, other: &Self) {
                        self.copy_color_from(other)
                    }

                    /// Get the computed value for color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color(&self) -> longhands::color::computed_value::T {
                        self.color.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Column style struct.
        pub struct Column {
                /// The column-width computed value.
                pub column_width: longhands::column_width::computed_value::T,
                /// The column-count computed value.
                pub column_count: longhands::column_count::computed_value::T,
                /// The column-gap computed value.
                pub column_gap: longhands::column_gap::computed_value::T,
                /// The column-fill computed value.
                pub column_fill: longhands::column_fill::computed_value::T,
                /// The column-rule-width computed value.
                pub column_rule_width: longhands::column_rule_width::computed_value::T,
                /// The column-rule-color computed value.
                pub column_rule_color: longhands::column_rule_color::computed_value::T,
                /// The column-span computed value.
                pub column_span: longhands::column_span::computed_value::T,
                /// The column-rule-style computed value.
                pub column_rule_style: longhands::column_rule_style::computed_value::T,
        }

        impl Column {
                        /// Set column-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_width(&mut self, v: longhands::column_width::computed_value::T) {
                            self.column_width = v;
                        }
                        /// Set column-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_width_from(&mut self, other: &Self) {
                            self.column_width = other.column_width.clone();
                        }
                    /// Reset column-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_width(&mut self, other: &Self) {
                        self.copy_column_width_from(other)
                    }

                    /// Get the computed value for column-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_width(&self) -> longhands::column_width::computed_value::T {
                        self.column_width.clone()
                    }
                        /// Set column-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_count(&mut self, v: longhands::column_count::computed_value::T) {
                            self.column_count = v;
                        }
                        /// Set column-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_count_from(&mut self, other: &Self) {
                            self.column_count = other.column_count.clone();
                        }
                    /// Reset column-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_count(&mut self, other: &Self) {
                        self.copy_column_count_from(other)
                    }

                    /// Get the computed value for column-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_count(&self) -> longhands::column_count::computed_value::T {
                        self.column_count.clone()
                    }
                        /// Set column-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_gap(&mut self, v: longhands::column_gap::computed_value::T) {
                            self.column_gap = v;
                        }
                        /// Set column-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_gap_from(&mut self, other: &Self) {
                            self.column_gap = other.column_gap.clone();
                        }
                    /// Reset column-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_gap(&mut self, other: &Self) {
                        self.copy_column_gap_from(other)
                    }

                    /// Get the computed value for column-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_gap(&self) -> longhands::column_gap::computed_value::T {
                        self.column_gap.clone()
                    }
                        /// Set column-fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_fill(&mut self, v: longhands::column_fill::computed_value::T) {
                            self.column_fill = v;
                        }
                        /// Set column-fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_fill_from(&mut self, other: &Self) {
                            self.column_fill = other.column_fill.clone();
                        }
                    /// Reset column-fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_fill(&mut self, other: &Self) {
                        self.copy_column_fill_from(other)
                    }

                    /// Get the computed value for column-fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_fill(&self) -> longhands::column_fill::computed_value::T {
                        self.column_fill.clone()
                    }
                        /// Set column-rule-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_width(&mut self, v: longhands::column_rule_width::computed_value::T) {
                            self.column_rule_width = v;
                        }
                        /// Set column-rule-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_width_from(&mut self, other: &Self) {
                            self.column_rule_width = other.column_rule_width.clone();
                        }
                    /// Reset column-rule-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_width(&mut self, other: &Self) {
                        self.copy_column_rule_width_from(other)
                    }

                    /// Get the computed value for column-rule-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_width(&self) -> longhands::column_rule_width::computed_value::T {
                        self.column_rule_width.clone()
                    }
                        /// Set column-rule-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_color(&mut self, v: longhands::column_rule_color::computed_value::T) {
                            self.column_rule_color = v;
                        }
                        /// Set column-rule-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_color_from(&mut self, other: &Self) {
                            self.column_rule_color = other.column_rule_color.clone();
                        }
                    /// Reset column-rule-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_color(&mut self, other: &Self) {
                        self.copy_column_rule_color_from(other)
                    }

                    /// Get the computed value for column-rule-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_color(&self) -> longhands::column_rule_color::computed_value::T {
                        self.column_rule_color.clone()
                    }
                        /// Set column-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_span(&mut self, v: longhands::column_span::computed_value::T) {
                            self.column_span = v;
                        }
                        /// Set column-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_span_from(&mut self, other: &Self) {
                            self.column_span = other.column_span.clone();
                        }
                    /// Reset column-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_span(&mut self, other: &Self) {
                        self.copy_column_span_from(other)
                    }

                    /// Get the computed value for column-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_span(&self) -> longhands::column_span::computed_value::T {
                        self.column_span.clone()
                    }
                        /// Set column-rule-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_style(&mut self, v: longhands::column_rule_style::computed_value::T) {
                            self.column_rule_style = v;
                        }
                        /// Set column-rule-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_style_from(&mut self, other: &Self) {
                            self.column_rule_style = other.column_rule_style.clone();
                        }
                    /// Reset column-rule-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_style(&mut self, other: &Self) {
                        self.copy_column_rule_style_from(other)
                    }

                    /// Get the computed value for column-rule-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_style(&self) -> longhands::column_rule_style::computed_value::T {
                        self.column_rule_style.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Counters style struct.
        pub struct Counters {
                /// The content computed value.
                pub content: longhands::content::computed_value::T,
                /// The counter-increment computed value.
                pub counter_increment: longhands::counter_increment::computed_value::T,
                /// The counter-reset computed value.
                pub counter_reset: longhands::counter_reset::computed_value::T,
        }

        impl Counters {
                        /// Set content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_content(&mut self, v: longhands::content::computed_value::T) {
                            self.content = v;
                        }
                        /// Set content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_content_from(&mut self, other: &Self) {
                            self.content = other.content.clone();
                        }
                    /// Reset content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_content(&mut self, other: &Self) {
                        self.copy_content_from(other)
                    }

                    /// Get the computed value for content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_content(&self) -> longhands::content::computed_value::T {
                        self.content.clone()
                    }
                        /// Set counter-increment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_increment(&mut self, v: longhands::counter_increment::computed_value::T) {
                            self.counter_increment = v;
                        }
                        /// Set counter-increment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_increment_from(&mut self, other: &Self) {
                            self.counter_increment = other.counter_increment.clone();
                        }
                    /// Reset counter-increment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_increment(&mut self, other: &Self) {
                        self.copy_counter_increment_from(other)
                    }

                    /// Get the computed value for counter-increment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_increment(&self) -> longhands::counter_increment::computed_value::T {
                        self.counter_increment.clone()
                    }
                        /// Set counter-reset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_reset(&mut self, v: longhands::counter_reset::computed_value::T) {
                            self.counter_reset = v;
                        }
                        /// Set counter-reset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_reset_from(&mut self, other: &Self) {
                            self.counter_reset = other.counter_reset.clone();
                        }
                    /// Reset counter-reset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_reset(&mut self, other: &Self) {
                        self.copy_counter_reset_from(other)
                    }

                    /// Get the computed value for counter-reset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_reset(&self) -> longhands::counter_reset::computed_value::T {
                        self.counter_reset.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Effects style struct.
        pub struct Effects {
                /// The opacity computed value.
                pub opacity: longhands::opacity::computed_value::T,
                /// The box-shadow computed value.
                pub box_shadow: longhands::box_shadow::computed_value::T,
                /// The clip computed value.
                pub clip: longhands::clip::computed_value::T,
                /// The filter computed value.
                pub filter: longhands::filter::computed_value::T,
                /// The mix-blend-mode computed value.
                pub mix_blend_mode: longhands::mix_blend_mode::computed_value::T,
        }

        impl Effects {
                        /// Set opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_opacity(&mut self, v: longhands::opacity::computed_value::T) {
                            self.opacity = v;
                        }
                        /// Set opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_opacity_from(&mut self, other: &Self) {
                            self.opacity = other.opacity.clone();
                        }
                    /// Reset opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_opacity(&mut self, other: &Self) {
                        self.copy_opacity_from(other)
                    }

                    /// Get the computed value for opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_opacity(&self) -> longhands::opacity::computed_value::T {
                        self.opacity.clone()
                    }
                        /// Set box-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_shadow<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::box_shadow
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.box_shadow = longhands::box_shadow::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set box-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_shadow_from(&mut self, other: &Self) {
                            self.box_shadow = other.box_shadow.clone();
                        }
                    /// Reset box-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_shadow(&mut self, other: &Self) {
                        self.copy_box_shadow_from(other)
                    }

                    /// Get the computed value for box-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_shadow(&self) -> longhands::box_shadow::computed_value::T {
                        self.box_shadow.clone()
                    }
                        /// Set clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip(&mut self, v: longhands::clip::computed_value::T) {
                            self.clip = v;
                        }
                        /// Set clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_from(&mut self, other: &Self) {
                            self.clip = other.clip.clone();
                        }
                    /// Reset clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip(&mut self, other: &Self) {
                        self.copy_clip_from(other)
                    }

                    /// Get the computed value for clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip(&self) -> longhands::clip::computed_value::T {
                        self.clip.clone()
                    }
                        /// Set filter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_filter<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::filter
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.filter = longhands::filter::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set filter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_filter_from(&mut self, other: &Self) {
                            self.filter = other.filter.clone();
                        }
                    /// Reset filter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_filter(&mut self, other: &Self) {
                        self.copy_filter_from(other)
                    }

                    /// Get the computed value for filter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_filter(&self) -> longhands::filter::computed_value::T {
                        self.filter.clone()
                    }
                        /// Set mix-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mix_blend_mode(&mut self, v: longhands::mix_blend_mode::computed_value::T) {
                            self.mix_blend_mode = v;
                        }
                        /// Set mix-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mix_blend_mode_from(&mut self, other: &Self) {
                            self.mix_blend_mode = other.mix_blend_mode.clone();
                        }
                    /// Reset mix-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mix_blend_mode(&mut self, other: &Self) {
                        self.copy_mix_blend_mode_from(other)
                    }

                    /// Get the computed value for mix-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mix_blend_mode(&self) -> longhands::mix_blend_mode::computed_value::T {
                        self.mix_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf)]
        /// The Font style struct.
        pub struct Font {
                /// The font-family computed value.
                pub font_family: longhands::font_family::computed_value::T,
                /// The font-style computed value.
                pub font_style: longhands::font_style::computed_value::T,
                /// The font-variant-caps computed value.
                pub font_variant_caps: longhands::font_variant_caps::computed_value::T,
                /// The font-weight computed value.
                pub font_weight: longhands::font_weight::computed_value::T,
                /// The font-size computed value.
                pub font_size: longhands::font_size::computed_value::T,
                /// The font-size-adjust computed value.
                pub font_size_adjust: longhands::font_size_adjust::computed_value::T,
                /// The font-synthesis computed value.
                pub font_synthesis: longhands::font_synthesis::computed_value::T,
                /// The font-stretch computed value.
                pub font_stretch: longhands::font_stretch::computed_value::T,
                /// The font-kerning computed value.
                pub font_kerning: longhands::font_kerning::computed_value::T,
                /// The font-variant-alternates computed value.
                pub font_variant_alternates: longhands::font_variant_alternates::computed_value::T,
                /// The font-variant-east-asian computed value.
                pub font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T,
                /// The font-variant-ligatures computed value.
                pub font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T,
                /// The font-variant-numeric computed value.
                pub font_variant_numeric: longhands::font_variant_numeric::computed_value::T,
                /// The font-variant-position computed value.
                pub font_variant_position: longhands::font_variant_position::computed_value::T,
                /// The font-feature-settings computed value.
                pub font_feature_settings: longhands::font_feature_settings::computed_value::T,
                /// The font-variation-settings computed value.
                pub font_variation_settings: longhands::font_variation_settings::computed_value::T,
                /// The font-language-override computed value.
                pub font_language_override: longhands::font_language_override::computed_value::T,
                /// The -x-lang computed value.
                pub _x_lang: longhands::_x_lang::computed_value::T,
                /// The -moz-script-size-multiplier computed value.
                pub _moz_script_size_multiplier: longhands::_moz_script_size_multiplier::computed_value::T,
                /// The -moz-script-level computed value.
                pub _moz_script_level: longhands::_moz_script_level::computed_value::T,
                /// The -moz-math-display computed value.
                pub _moz_math_display: longhands::_moz_math_display::computed_value::T,
                /// The -moz-math-variant computed value.
                pub _moz_math_variant: longhands::_moz_math_variant::computed_value::T,
                /// The -moz-script-min-size computed value.
                pub _moz_script_min_size: longhands::_moz_script_min_size::computed_value::T,
                /// The -x-text-zoom computed value.
                pub _x_text_zoom: longhands::_x_text_zoom::computed_value::T,
                /// The -moz-osx-font-smoothing computed value.
                pub _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::computed_value::T,
                /// The -moz-font-smoothing-background-color computed value.
                pub _moz_font_smoothing_background_color: longhands::_moz_font_smoothing_background_color::computed_value::T,
                /// The -moz-min-font-size-ratio computed value.
                pub _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::computed_value::T,
                /// The font hash, used for font caching.
                pub hash: u64,
        }
        impl PartialEq for Font {
            fn eq(&self, other: &Font) -> bool {
                self.hash == other.hash
                    && self.font_family == other.font_family
                    && self.font_style == other.font_style
                    && self.font_variant_caps == other.font_variant_caps
                    && self.font_weight == other.font_weight
                    && self.font_size == other.font_size
                    && self.font_size_adjust == other.font_size_adjust
                    && self.font_synthesis == other.font_synthesis
                    && self.font_stretch == other.font_stretch
                    && self.font_kerning == other.font_kerning
                    && self.font_variant_alternates == other.font_variant_alternates
                    && self.font_variant_east_asian == other.font_variant_east_asian
                    && self.font_variant_ligatures == other.font_variant_ligatures
                    && self.font_variant_numeric == other.font_variant_numeric
                    && self.font_variant_position == other.font_variant_position
                    && self.font_feature_settings == other.font_feature_settings
                    && self.font_variation_settings == other.font_variation_settings
                    && self.font_language_override == other.font_language_override
                    && self._x_lang == other._x_lang
                    && self._moz_script_size_multiplier == other._moz_script_size_multiplier
                    && self._moz_script_level == other._moz_script_level
                    && self._moz_math_display == other._moz_math_display
                    && self._moz_math_variant == other._moz_math_variant
                    && self._moz_script_min_size == other._moz_script_min_size
                    && self._x_text_zoom == other._x_text_zoom
                    && self._moz_osx_font_smoothing == other._moz_osx_font_smoothing
                    && self._moz_font_smoothing_background_color == other._moz_font_smoothing_background_color
                    && self._moz_min_font_size_ratio == other._moz_min_font_size_ratio
            }
        }

        impl Font {
                        /// Set font-family.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_family(&mut self, v: longhands::font_family::computed_value::T) {
                            self.font_family = v;
                        }
                        /// Set font-family from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_family_from(&mut self, other: &Self) {
                            self.font_family = other.font_family.clone();
                        }
                    /// Reset font-family from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_family(&mut self, other: &Self) {
                        self.copy_font_family_from(other)
                    }

                    /// Get the computed value for font-family.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_family(&self) -> longhands::font_family::computed_value::T {
                        self.font_family.clone()
                    }
                        /// Set font-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_style(&mut self, v: longhands::font_style::computed_value::T) {
                            self.font_style = v;
                        }
                        /// Set font-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_style_from(&mut self, other: &Self) {
                            self.font_style = other.font_style.clone();
                        }
                    /// Reset font-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_style(&mut self, other: &Self) {
                        self.copy_font_style_from(other)
                    }

                    /// Get the computed value for font-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_style(&self) -> longhands::font_style::computed_value::T {
                        self.font_style.clone()
                    }
                        /// Set font-variant-caps.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_caps(&mut self, v: longhands::font_variant_caps::computed_value::T) {
                            self.font_variant_caps = v;
                        }
                        /// Set font-variant-caps from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_caps_from(&mut self, other: &Self) {
                            self.font_variant_caps = other.font_variant_caps.clone();
                        }
                    /// Reset font-variant-caps from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_caps(&mut self, other: &Self) {
                        self.copy_font_variant_caps_from(other)
                    }

                    /// Get the computed value for font-variant-caps.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_caps(&self) -> longhands::font_variant_caps::computed_value::T {
                        self.font_variant_caps.clone()
                    }
                        /// Set font-weight.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_weight(&mut self, v: longhands::font_weight::computed_value::T) {
                            self.font_weight = v;
                        }
                        /// Set font-weight from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_weight_from(&mut self, other: &Self) {
                            self.font_weight = other.font_weight.clone();
                        }
                    /// Reset font-weight from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_weight(&mut self, other: &Self) {
                        self.copy_font_weight_from(other)
                    }

                    /// Get the computed value for font-weight.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_weight(&self) -> longhands::font_weight::computed_value::T {
                        self.font_weight.clone()
                    }
                        /// Set font-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size(&mut self, v: longhands::font_size::computed_value::T) {
                            self.font_size = v;
                        }
                        /// Set font-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_from(&mut self, other: &Self) {
                            self.font_size = other.font_size.clone();
                        }
                    /// Reset font-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size(&mut self, other: &Self) {
                        self.copy_font_size_from(other)
                    }

                    /// Get the computed value for font-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size(&self) -> longhands::font_size::computed_value::T {
                        self.font_size.clone()
                    }
                        /// Set font-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size_adjust(&mut self, v: longhands::font_size_adjust::computed_value::T) {
                            self.font_size_adjust = v;
                        }
                        /// Set font-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_adjust_from(&mut self, other: &Self) {
                            self.font_size_adjust = other.font_size_adjust.clone();
                        }
                    /// Reset font-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size_adjust(&mut self, other: &Self) {
                        self.copy_font_size_adjust_from(other)
                    }

                    /// Get the computed value for font-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size_adjust(&self) -> longhands::font_size_adjust::computed_value::T {
                        self.font_size_adjust.clone()
                    }
                        /// Set font-synthesis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis(&mut self, v: longhands::font_synthesis::computed_value::T) {
                            self.font_synthesis = v;
                        }
                        /// Set font-synthesis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_from(&mut self, other: &Self) {
                            self.font_synthesis = other.font_synthesis.clone();
                        }
                    /// Reset font-synthesis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis(&mut self, other: &Self) {
                        self.copy_font_synthesis_from(other)
                    }

                    /// Get the computed value for font-synthesis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis(&self) -> longhands::font_synthesis::computed_value::T {
                        self.font_synthesis.clone()
                    }
                        /// Set font-stretch.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_stretch(&mut self, v: longhands::font_stretch::computed_value::T) {
                            self.font_stretch = v;
                        }
                        /// Set font-stretch from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_stretch_from(&mut self, other: &Self) {
                            self.font_stretch = other.font_stretch.clone();
                        }
                    /// Reset font-stretch from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_stretch(&mut self, other: &Self) {
                        self.copy_font_stretch_from(other)
                    }

                    /// Get the computed value for font-stretch.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_stretch(&self) -> longhands::font_stretch::computed_value::T {
                        self.font_stretch.clone()
                    }
                        /// Set font-kerning.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_kerning(&mut self, v: longhands::font_kerning::computed_value::T) {
                            self.font_kerning = v;
                        }
                        /// Set font-kerning from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_kerning_from(&mut self, other: &Self) {
                            self.font_kerning = other.font_kerning.clone();
                        }
                    /// Reset font-kerning from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_kerning(&mut self, other: &Self) {
                        self.copy_font_kerning_from(other)
                    }

                    /// Get the computed value for font-kerning.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_kerning(&self) -> longhands::font_kerning::computed_value::T {
                        self.font_kerning.clone()
                    }
                        /// Set font-variant-alternates.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_alternates(&mut self, v: longhands::font_variant_alternates::computed_value::T) {
                            self.font_variant_alternates = v;
                        }
                        /// Set font-variant-alternates from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_alternates_from(&mut self, other: &Self) {
                            self.font_variant_alternates = other.font_variant_alternates.clone();
                        }
                    /// Reset font-variant-alternates from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_alternates(&mut self, other: &Self) {
                        self.copy_font_variant_alternates_from(other)
                    }

                    /// Get the computed value for font-variant-alternates.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_alternates(&self) -> longhands::font_variant_alternates::computed_value::T {
                        self.font_variant_alternates.clone()
                    }
                        /// Set font-variant-east-asian.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_east_asian(&mut self, v: longhands::font_variant_east_asian::computed_value::T) {
                            self.font_variant_east_asian = v;
                        }
                        /// Set font-variant-east-asian from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_east_asian_from(&mut self, other: &Self) {
                            self.font_variant_east_asian = other.font_variant_east_asian.clone();
                        }
                    /// Reset font-variant-east-asian from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_east_asian(&mut self, other: &Self) {
                        self.copy_font_variant_east_asian_from(other)
                    }

                    /// Get the computed value for font-variant-east-asian.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_east_asian(&self) -> longhands::font_variant_east_asian::computed_value::T {
                        self.font_variant_east_asian.clone()
                    }
                        /// Set font-variant-ligatures.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_ligatures(&mut self, v: longhands::font_variant_ligatures::computed_value::T) {
                            self.font_variant_ligatures = v;
                        }
                        /// Set font-variant-ligatures from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_ligatures_from(&mut self, other: &Self) {
                            self.font_variant_ligatures = other.font_variant_ligatures.clone();
                        }
                    /// Reset font-variant-ligatures from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_ligatures(&mut self, other: &Self) {
                        self.copy_font_variant_ligatures_from(other)
                    }

                    /// Get the computed value for font-variant-ligatures.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_ligatures(&self) -> longhands::font_variant_ligatures::computed_value::T {
                        self.font_variant_ligatures.clone()
                    }
                        /// Set font-variant-numeric.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_numeric(&mut self, v: longhands::font_variant_numeric::computed_value::T) {
                            self.font_variant_numeric = v;
                        }
                        /// Set font-variant-numeric from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_numeric_from(&mut self, other: &Self) {
                            self.font_variant_numeric = other.font_variant_numeric.clone();
                        }
                    /// Reset font-variant-numeric from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_numeric(&mut self, other: &Self) {
                        self.copy_font_variant_numeric_from(other)
                    }

                    /// Get the computed value for font-variant-numeric.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_numeric(&self) -> longhands::font_variant_numeric::computed_value::T {
                        self.font_variant_numeric.clone()
                    }
                        /// Set font-variant-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_position(&mut self, v: longhands::font_variant_position::computed_value::T) {
                            self.font_variant_position = v;
                        }
                        /// Set font-variant-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_position_from(&mut self, other: &Self) {
                            self.font_variant_position = other.font_variant_position.clone();
                        }
                    /// Reset font-variant-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_position(&mut self, other: &Self) {
                        self.copy_font_variant_position_from(other)
                    }

                    /// Get the computed value for font-variant-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_position(&self) -> longhands::font_variant_position::computed_value::T {
                        self.font_variant_position.clone()
                    }
                        /// Set font-feature-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_feature_settings(&mut self, v: longhands::font_feature_settings::computed_value::T) {
                            self.font_feature_settings = v;
                        }
                        /// Set font-feature-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_feature_settings_from(&mut self, other: &Self) {
                            self.font_feature_settings = other.font_feature_settings.clone();
                        }
                    /// Reset font-feature-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_feature_settings(&mut self, other: &Self) {
                        self.copy_font_feature_settings_from(other)
                    }

                    /// Get the computed value for font-feature-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_feature_settings(&self) -> longhands::font_feature_settings::computed_value::T {
                        self.font_feature_settings.clone()
                    }
                        /// Set font-variation-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variation_settings(&mut self, v: longhands::font_variation_settings::computed_value::T) {
                            self.font_variation_settings = v;
                        }
                        /// Set font-variation-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variation_settings_from(&mut self, other: &Self) {
                            self.font_variation_settings = other.font_variation_settings.clone();
                        }
                    /// Reset font-variation-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variation_settings(&mut self, other: &Self) {
                        self.copy_font_variation_settings_from(other)
                    }

                    /// Get the computed value for font-variation-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variation_settings(&self) -> longhands::font_variation_settings::computed_value::T {
                        self.font_variation_settings.clone()
                    }
                        /// Set font-language-override.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_language_override(&mut self, v: longhands::font_language_override::computed_value::T) {
                            self.font_language_override = v;
                        }
                        /// Set font-language-override from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_language_override_from(&mut self, other: &Self) {
                            self.font_language_override = other.font_language_override.clone();
                        }
                    /// Reset font-language-override from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_language_override(&mut self, other: &Self) {
                        self.copy_font_language_override_from(other)
                    }

                    /// Get the computed value for font-language-override.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_language_override(&self) -> longhands::font_language_override::computed_value::T {
                        self.font_language_override.clone()
                    }
                        /// Set -x-lang.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_lang(&mut self, v: longhands::_x_lang::computed_value::T) {
                            self._x_lang = v;
                        }
                        /// Set -x-lang from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_lang_from(&mut self, other: &Self) {
                            self._x_lang = other._x_lang.clone();
                        }
                    /// Reset -x-lang from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_lang(&mut self, other: &Self) {
                        self.copy__x_lang_from(other)
                    }

                    /// Get the computed value for -x-lang.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_lang(&self) -> longhands::_x_lang::computed_value::T {
                        self._x_lang.clone()
                    }
                        /// Set -moz-script-size-multiplier.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_size_multiplier(&mut self, v: longhands::_moz_script_size_multiplier::computed_value::T) {
                            self._moz_script_size_multiplier = v;
                        }
                        /// Set -moz-script-size-multiplier from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_size_multiplier_from(&mut self, other: &Self) {
                            self._moz_script_size_multiplier = other._moz_script_size_multiplier.clone();
                        }
                    /// Reset -moz-script-size-multiplier from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_size_multiplier(&mut self, other: &Self) {
                        self.copy__moz_script_size_multiplier_from(other)
                    }

                    /// Get the computed value for -moz-script-size-multiplier.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_size_multiplier(&self) -> longhands::_moz_script_size_multiplier::computed_value::T {
                        self._moz_script_size_multiplier.clone()
                    }
                        /// Set -moz-script-level.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_level(&mut self, v: longhands::_moz_script_level::computed_value::T) {
                            self._moz_script_level = v;
                        }
                        /// Set -moz-script-level from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_level_from(&mut self, other: &Self) {
                            self._moz_script_level = other._moz_script_level.clone();
                        }
                    /// Reset -moz-script-level from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_level(&mut self, other: &Self) {
                        self.copy__moz_script_level_from(other)
                    }

                    /// Get the computed value for -moz-script-level.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_level(&self) -> longhands::_moz_script_level::computed_value::T {
                        self._moz_script_level.clone()
                    }
                        /// Set -moz-math-display.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_math_display(&mut self, v: longhands::_moz_math_display::computed_value::T) {
                            self._moz_math_display = v;
                        }
                        /// Set -moz-math-display from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_math_display_from(&mut self, other: &Self) {
                            self._moz_math_display = other._moz_math_display.clone();
                        }
                    /// Reset -moz-math-display from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_math_display(&mut self, other: &Self) {
                        self.copy__moz_math_display_from(other)
                    }

                    /// Get the computed value for -moz-math-display.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_math_display(&self) -> longhands::_moz_math_display::computed_value::T {
                        self._moz_math_display.clone()
                    }
                        /// Set -moz-math-variant.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_math_variant(&mut self, v: longhands::_moz_math_variant::computed_value::T) {
                            self._moz_math_variant = v;
                        }
                        /// Set -moz-math-variant from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_math_variant_from(&mut self, other: &Self) {
                            self._moz_math_variant = other._moz_math_variant.clone();
                        }
                    /// Reset -moz-math-variant from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_math_variant(&mut self, other: &Self) {
                        self.copy__moz_math_variant_from(other)
                    }

                    /// Get the computed value for -moz-math-variant.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_math_variant(&self) -> longhands::_moz_math_variant::computed_value::T {
                        self._moz_math_variant.clone()
                    }
                        /// Set -moz-script-min-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_script_min_size(&mut self, v: longhands::_moz_script_min_size::computed_value::T) {
                            self._moz_script_min_size = v;
                        }
                        /// Set -moz-script-min-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_script_min_size_from(&mut self, other: &Self) {
                            self._moz_script_min_size = other._moz_script_min_size.clone();
                        }
                    /// Reset -moz-script-min-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_script_min_size(&mut self, other: &Self) {
                        self.copy__moz_script_min_size_from(other)
                    }

                    /// Get the computed value for -moz-script-min-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_script_min_size(&self) -> longhands::_moz_script_min_size::computed_value::T {
                        self._moz_script_min_size.clone()
                    }
                        /// Set -x-text-zoom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_text_zoom(&mut self, v: longhands::_x_text_zoom::computed_value::T) {
                            self._x_text_zoom = v;
                        }
                        /// Set -x-text-zoom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_text_zoom_from(&mut self, other: &Self) {
                            self._x_text_zoom = other._x_text_zoom.clone();
                        }
                    /// Reset -x-text-zoom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_text_zoom(&mut self, other: &Self) {
                        self.copy__x_text_zoom_from(other)
                    }

                    /// Get the computed value for -x-text-zoom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_text_zoom(&self) -> longhands::_x_text_zoom::computed_value::T {
                        self._x_text_zoom.clone()
                    }
                        /// Set -moz-osx-font-smoothing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_osx_font_smoothing(&mut self, v: longhands::_moz_osx_font_smoothing::computed_value::T) {
                            self._moz_osx_font_smoothing = v;
                        }
                        /// Set -moz-osx-font-smoothing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_osx_font_smoothing_from(&mut self, other: &Self) {
                            self._moz_osx_font_smoothing = other._moz_osx_font_smoothing.clone();
                        }
                    /// Reset -moz-osx-font-smoothing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_osx_font_smoothing(&mut self, other: &Self) {
                        self.copy__moz_osx_font_smoothing_from(other)
                    }

                    /// Get the computed value for -moz-osx-font-smoothing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_osx_font_smoothing(&self) -> longhands::_moz_osx_font_smoothing::computed_value::T {
                        self._moz_osx_font_smoothing.clone()
                    }
                        /// Set -moz-font-smoothing-background-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_font_smoothing_background_color(&mut self, v: longhands::_moz_font_smoothing_background_color::computed_value::T) {
                            self._moz_font_smoothing_background_color = v;
                        }
                        /// Set -moz-font-smoothing-background-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_font_smoothing_background_color_from(&mut self, other: &Self) {
                            self._moz_font_smoothing_background_color = other._moz_font_smoothing_background_color.clone();
                        }
                    /// Reset -moz-font-smoothing-background-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_font_smoothing_background_color(&mut self, other: &Self) {
                        self.copy__moz_font_smoothing_background_color_from(other)
                    }

                    /// Get the computed value for -moz-font-smoothing-background-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_font_smoothing_background_color(&self) -> longhands::_moz_font_smoothing_background_color::computed_value::T {
                        self._moz_font_smoothing_background_color.clone()
                    }
                        /// Set -moz-min-font-size-ratio.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_min_font_size_ratio(&mut self, v: longhands::_moz_min_font_size_ratio::computed_value::T) {
                            self._moz_min_font_size_ratio = v;
                        }
                        /// Set -moz-min-font-size-ratio from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_min_font_size_ratio_from(&mut self, other: &Self) {
                            self._moz_min_font_size_ratio = other._moz_min_font_size_ratio.clone();
                        }
                    /// Reset -moz-min-font-size-ratio from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_min_font_size_ratio(&mut self, other: &Self) {
                        self.copy__moz_min_font_size_ratio_from(other)
                    }

                    /// Get the computed value for -moz-min-font-size-ratio.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_min_font_size_ratio(&self) -> longhands::_moz_min_font_size_ratio::computed_value::T {
                        self._moz_min_font_size_ratio.clone()
                    }
                /// Computes a font hash in order to be able to cache fonts
                /// effectively in GFX and layout.
                pub fn compute_font_hash(&mut self) {
                    // Corresponds to the fields in
                    // `gfx::font_template::FontTemplateDescriptor`.
                    let mut hasher: FnvHasher = Default::default();
                    hasher.write_u16(self.font_weight.0);
                    self.font_stretch.hash(&mut hasher);
                    self.font_family.hash(&mut hasher);
                    self.hash = hasher.finish()
                }

                /// (Servo does not handle MathML, so this just calls copy_font_size_from)
                pub fn inherit_font_size_from(&mut self, parent: &Self,
                                              _: Option<NonNegativeLength>,
                                              _: &Device) {
                    self.copy_font_size_from(parent);
                }
                /// (Servo does not handle MathML, so this just calls set_font_size)
                pub fn apply_font_size(&mut self,
                                       v: longhands::font_size::computed_value::T,
                                       _: &Self,
                                       _: &Device) -> Option<NonNegativeLength> {
                    self.set_font_size(v);
                    None
                }
                /// (Servo does not handle MathML, so this does nothing)
                pub fn apply_unconstrained_font_size(&mut self, _: NonNegativeLength) {
                }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedBox style struct.
        pub struct InheritedBox {
                /// The visibility computed value.
                pub visibility: longhands::visibility::computed_value::T,
                /// The writing-mode computed value.
                pub writing_mode: longhands::writing_mode::computed_value::T,
                /// The direction computed value.
                pub direction: longhands::direction::computed_value::T,
                /// The text-orientation computed value.
                pub text_orientation: longhands::text_orientation::computed_value::T,
                /// The color-adjust computed value.
                pub color_adjust: longhands::color_adjust::computed_value::T,
                /// The image-rendering computed value.
                pub image_rendering: longhands::image_rendering::computed_value::T,
                /// The image-orientation computed value.
                pub image_orientation: longhands::image_orientation::computed_value::T,
        }

        impl InheritedBox {
                        /// Set visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_visibility(&mut self, v: longhands::visibility::computed_value::T) {
                            self.visibility = v;
                        }
                        /// Set visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_visibility_from(&mut self, other: &Self) {
                            self.visibility = other.visibility.clone();
                        }
                    /// Reset visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_visibility(&mut self, other: &Self) {
                        self.copy_visibility_from(other)
                    }

                    /// Get the computed value for visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_visibility(&self) -> longhands::visibility::computed_value::T {
                        self.visibility.clone()
                    }
                        /// Set writing-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_writing_mode(&mut self, v: longhands::writing_mode::computed_value::T) {
                            self.writing_mode = v;
                        }
                        /// Set writing-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_writing_mode_from(&mut self, other: &Self) {
                            self.writing_mode = other.writing_mode.clone();
                        }
                    /// Reset writing-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_writing_mode(&mut self, other: &Self) {
                        self.copy_writing_mode_from(other)
                    }

                    /// Get the computed value for writing-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_writing_mode(&self) -> longhands::writing_mode::computed_value::T {
                        self.writing_mode.clone()
                    }
                        /// Set direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_direction(&mut self, v: longhands::direction::computed_value::T) {
                            self.direction = v;
                        }
                        /// Set direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_direction_from(&mut self, other: &Self) {
                            self.direction = other.direction.clone();
                        }
                    /// Reset direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_direction(&mut self, other: &Self) {
                        self.copy_direction_from(other)
                    }

                    /// Get the computed value for direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_direction(&self) -> longhands::direction::computed_value::T {
                        self.direction.clone()
                    }
                        /// Set text-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_orientation(&mut self, v: longhands::text_orientation::computed_value::T) {
                            self.text_orientation = v;
                        }
                        /// Set text-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_orientation_from(&mut self, other: &Self) {
                            self.text_orientation = other.text_orientation.clone();
                        }
                    /// Reset text-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_orientation(&mut self, other: &Self) {
                        self.copy_text_orientation_from(other)
                    }

                    /// Get the computed value for text-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_orientation(&self) -> longhands::text_orientation::computed_value::T {
                        self.text_orientation.clone()
                    }
                        /// Set color-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_adjust(&mut self, v: longhands::color_adjust::computed_value::T) {
                            self.color_adjust = v;
                        }
                        /// Set color-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_adjust_from(&mut self, other: &Self) {
                            self.color_adjust = other.color_adjust.clone();
                        }
                    /// Reset color-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_adjust(&mut self, other: &Self) {
                        self.copy_color_adjust_from(other)
                    }

                    /// Get the computed value for color-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_adjust(&self) -> longhands::color_adjust::computed_value::T {
                        self.color_adjust.clone()
                    }
                        /// Set image-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_rendering(&mut self, v: longhands::image_rendering::computed_value::T) {
                            self.image_rendering = v;
                        }
                        /// Set image-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_rendering_from(&mut self, other: &Self) {
                            self.image_rendering = other.image_rendering.clone();
                        }
                    /// Reset image-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_rendering(&mut self, other: &Self) {
                        self.copy_image_rendering_from(other)
                    }

                    /// Get the computed value for image-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_rendering(&self) -> longhands::image_rendering::computed_value::T {
                        self.image_rendering.clone()
                    }
                        /// Set image-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_orientation(&mut self, v: longhands::image_orientation::computed_value::T) {
                            self.image_orientation = v;
                        }
                        /// Set image-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_orientation_from(&mut self, other: &Self) {
                            self.image_orientation = other.image_orientation.clone();
                        }
                    /// Reset image-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_orientation(&mut self, other: &Self) {
                        self.copy_image_orientation_from(other)
                    }

                    /// Get the computed value for image-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_orientation(&self) -> longhands::image_orientation::computed_value::T {
                        self.image_orientation.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedTable style struct.
        pub struct InheritedTable {
                /// The border-collapse computed value.
                pub border_collapse: longhands::border_collapse::computed_value::T,
                /// The empty-cells computed value.
                pub empty_cells: longhands::empty_cells::computed_value::T,
                /// The caption-side computed value.
                pub caption_side: longhands::caption_side::computed_value::T,
                /// The border-spacing computed value.
                pub border_spacing: longhands::border_spacing::computed_value::T,
        }

        impl InheritedTable {
                        /// Set border-collapse.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_collapse(&mut self, v: longhands::border_collapse::computed_value::T) {
                            self.border_collapse = v;
                        }
                        /// Set border-collapse from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_collapse_from(&mut self, other: &Self) {
                            self.border_collapse = other.border_collapse.clone();
                        }
                    /// Reset border-collapse from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_collapse(&mut self, other: &Self) {
                        self.copy_border_collapse_from(other)
                    }

                    /// Get the computed value for border-collapse.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_collapse(&self) -> longhands::border_collapse::computed_value::T {
                        self.border_collapse.clone()
                    }
                        /// Set empty-cells.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_empty_cells(&mut self, v: longhands::empty_cells::computed_value::T) {
                            self.empty_cells = v;
                        }
                        /// Set empty-cells from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_empty_cells_from(&mut self, other: &Self) {
                            self.empty_cells = other.empty_cells.clone();
                        }
                    /// Reset empty-cells from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_empty_cells(&mut self, other: &Self) {
                        self.copy_empty_cells_from(other)
                    }

                    /// Get the computed value for empty-cells.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_empty_cells(&self) -> longhands::empty_cells::computed_value::T {
                        self.empty_cells.clone()
                    }
                        /// Set caption-side.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caption_side(&mut self, v: longhands::caption_side::computed_value::T) {
                            self.caption_side = v;
                        }
                        /// Set caption-side from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caption_side_from(&mut self, other: &Self) {
                            self.caption_side = other.caption_side.clone();
                        }
                    /// Reset caption-side from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caption_side(&mut self, other: &Self) {
                        self.copy_caption_side_from(other)
                    }

                    /// Get the computed value for caption-side.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caption_side(&self) -> longhands::caption_side::computed_value::T {
                        self.caption_side.clone()
                    }
                        /// Set border-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_spacing(&mut self, v: longhands::border_spacing::computed_value::T) {
                            self.border_spacing = v;
                        }
                        /// Set border-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_spacing_from(&mut self, other: &Self) {
                            self.border_spacing = other.border_spacing.clone();
                        }
                    /// Reset border-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_spacing(&mut self, other: &Self) {
                        self.copy_border_spacing_from(other)
                    }

                    /// Get the computed value for border-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_spacing(&self) -> longhands::border_spacing::computed_value::T {
                        self.border_spacing.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedText style struct.
        pub struct InheritedText {
                /// The line-height computed value.
                pub line_height: longhands::line_height::computed_value::T,
                /// The text-transform computed value.
                pub text_transform: longhands::text_transform::computed_value::T,
                /// The hyphens computed value.
                pub hyphens: longhands::hyphens::computed_value::T,
                /// The -moz-text-size-adjust computed value.
                pub _moz_text_size_adjust: longhands::_moz_text_size_adjust::computed_value::T,
                /// The text-indent computed value.
                pub text_indent: longhands::text_indent::computed_value::T,
                /// The overflow-wrap computed value.
                pub overflow_wrap: longhands::overflow_wrap::computed_value::T,
                /// The word-break computed value.
                pub word_break: longhands::word_break::computed_value::T,
                /// The text-justify computed value.
                pub text_justify: longhands::text_justify::computed_value::T,
                /// The text-align-last computed value.
                pub text_align_last: longhands::text_align_last::computed_value::T,
                /// The text-align computed value.
                pub text_align: longhands::text_align::computed_value::T,
                /// The letter-spacing computed value.
                pub letter_spacing: longhands::letter_spacing::computed_value::T,
                /// The word-spacing computed value.
                pub word_spacing: longhands::word_spacing::computed_value::T,
                /// The white-space computed value.
                pub white_space: longhands::white_space::computed_value::T,
                /// The text-shadow computed value.
                pub text_shadow: longhands::text_shadow::computed_value::T,
                /// The text-emphasis-style computed value.
                pub text_emphasis_style: longhands::text_emphasis_style::computed_value::T,
                /// The text-emphasis-position computed value.
                pub text_emphasis_position: longhands::text_emphasis_position::computed_value::T,
                /// The text-emphasis-color computed value.
                pub text_emphasis_color: longhands::text_emphasis_color::computed_value::T,
                /// The -moz-tab-size computed value.
                pub _moz_tab_size: longhands::_moz_tab_size::computed_value::T,
                /// The -webkit-text-fill-color computed value.
                pub _webkit_text_fill_color: longhands::_webkit_text_fill_color::computed_value::T,
                /// The -webkit-text-stroke-color computed value.
                pub _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::computed_value::T,
                /// The -webkit-text-stroke-width computed value.
                pub _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::computed_value::T,
                /// The ruby-align computed value.
                pub ruby_align: longhands::ruby_align::computed_value::T,
                /// The ruby-position computed value.
                pub ruby_position: longhands::ruby_position::computed_value::T,
                /// The text-combine-upright computed value.
                pub text_combine_upright: longhands::text_combine_upright::computed_value::T,
                /// The text-rendering computed value.
                pub text_rendering: longhands::text_rendering::computed_value::T,
                /// The -moz-control-character-visibility computed value.
                pub _moz_control_character_visibility: longhands::_moz_control_character_visibility::computed_value::T,
                /// The "used" text-decorations that apply to this box.
                ///
                /// FIXME(emilio): This is technically a box-tree concept, and
                /// would be nice to move away from style.
                pub text_decorations_in_effect: ::values::computed::text::TextDecorationsInEffect,
        }

        impl InheritedText {
                        /// Set line-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_line_height(&mut self, v: longhands::line_height::computed_value::T) {
                            self.line_height = v;
                        }
                        /// Set line-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_line_height_from(&mut self, other: &Self) {
                            self.line_height = other.line_height.clone();
                        }
                    /// Reset line-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_line_height(&mut self, other: &Self) {
                        self.copy_line_height_from(other)
                    }

                    /// Get the computed value for line-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_line_height(&self) -> longhands::line_height::computed_value::T {
                        self.line_height.clone()
                    }
                        /// Set text-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_transform(&mut self, v: longhands::text_transform::computed_value::T) {
                            self.text_transform = v;
                        }
                        /// Set text-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_transform_from(&mut self, other: &Self) {
                            self.text_transform = other.text_transform.clone();
                        }
                    /// Reset text-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_transform(&mut self, other: &Self) {
                        self.copy_text_transform_from(other)
                    }

                    /// Get the computed value for text-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_transform(&self) -> longhands::text_transform::computed_value::T {
                        self.text_transform.clone()
                    }
                        /// Set hyphens.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_hyphens(&mut self, v: longhands::hyphens::computed_value::T) {
                            self.hyphens = v;
                        }
                        /// Set hyphens from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_hyphens_from(&mut self, other: &Self) {
                            self.hyphens = other.hyphens.clone();
                        }
                    /// Reset hyphens from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_hyphens(&mut self, other: &Self) {
                        self.copy_hyphens_from(other)
                    }

                    /// Get the computed value for hyphens.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_hyphens(&self) -> longhands::hyphens::computed_value::T {
                        self.hyphens.clone()
                    }
                        /// Set -moz-text-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_text_size_adjust(&mut self, v: longhands::_moz_text_size_adjust::computed_value::T) {
                            self._moz_text_size_adjust = v;
                        }
                        /// Set -moz-text-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_text_size_adjust_from(&mut self, other: &Self) {
                            self._moz_text_size_adjust = other._moz_text_size_adjust.clone();
                        }
                    /// Reset -moz-text-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_text_size_adjust(&mut self, other: &Self) {
                        self.copy__moz_text_size_adjust_from(other)
                    }

                    /// Get the computed value for -moz-text-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_text_size_adjust(&self) -> longhands::_moz_text_size_adjust::computed_value::T {
                        self._moz_text_size_adjust.clone()
                    }
                        /// Set text-indent.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_indent(&mut self, v: longhands::text_indent::computed_value::T) {
                            self.text_indent = v;
                        }
                        /// Set text-indent from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_indent_from(&mut self, other: &Self) {
                            self.text_indent = other.text_indent.clone();
                        }
                    /// Reset text-indent from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_indent(&mut self, other: &Self) {
                        self.copy_text_indent_from(other)
                    }

                    /// Get the computed value for text-indent.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_indent(&self) -> longhands::text_indent::computed_value::T {
                        self.text_indent.clone()
                    }
                        /// Set overflow-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_wrap(&mut self, v: longhands::overflow_wrap::computed_value::T) {
                            self.overflow_wrap = v;
                        }
                        /// Set overflow-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_wrap_from(&mut self, other: &Self) {
                            self.overflow_wrap = other.overflow_wrap.clone();
                        }
                    /// Reset overflow-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_wrap(&mut self, other: &Self) {
                        self.copy_overflow_wrap_from(other)
                    }

                    /// Get the computed value for overflow-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_wrap(&self) -> longhands::overflow_wrap::computed_value::T {
                        self.overflow_wrap.clone()
                    }
                        /// Set word-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_break(&mut self, v: longhands::word_break::computed_value::T) {
                            self.word_break = v;
                        }
                        /// Set word-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_break_from(&mut self, other: &Self) {
                            self.word_break = other.word_break.clone();
                        }
                    /// Reset word-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_break(&mut self, other: &Self) {
                        self.copy_word_break_from(other)
                    }

                    /// Get the computed value for word-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_break(&self) -> longhands::word_break::computed_value::T {
                        self.word_break.clone()
                    }
                        /// Set text-justify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_justify(&mut self, v: longhands::text_justify::computed_value::T) {
                            self.text_justify = v;
                        }
                        /// Set text-justify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_justify_from(&mut self, other: &Self) {
                            self.text_justify = other.text_justify.clone();
                        }
                    /// Reset text-justify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_justify(&mut self, other: &Self) {
                        self.copy_text_justify_from(other)
                    }

                    /// Get the computed value for text-justify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_justify(&self) -> longhands::text_justify::computed_value::T {
                        self.text_justify.clone()
                    }
                        /// Set text-align-last.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align_last(&mut self, v: longhands::text_align_last::computed_value::T) {
                            self.text_align_last = v;
                        }
                        /// Set text-align-last from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_last_from(&mut self, other: &Self) {
                            self.text_align_last = other.text_align_last.clone();
                        }
                    /// Reset text-align-last from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align_last(&mut self, other: &Self) {
                        self.copy_text_align_last_from(other)
                    }

                    /// Get the computed value for text-align-last.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align_last(&self) -> longhands::text_align_last::computed_value::T {
                        self.text_align_last.clone()
                    }
                        /// Set text-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align(&mut self, v: longhands::text_align::computed_value::T) {
                            self.text_align = v;
                        }
                        /// Set text-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_from(&mut self, other: &Self) {
                            self.text_align = other.text_align.clone();
                        }
                    /// Reset text-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align(&mut self, other: &Self) {
                        self.copy_text_align_from(other)
                    }

                    /// Get the computed value for text-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align(&self) -> longhands::text_align::computed_value::T {
                        self.text_align.clone()
                    }
                        /// Set letter-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_letter_spacing(&mut self, v: longhands::letter_spacing::computed_value::T) {
                            self.letter_spacing = v;
                        }
                        /// Set letter-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_letter_spacing_from(&mut self, other: &Self) {
                            self.letter_spacing = other.letter_spacing.clone();
                        }
                    /// Reset letter-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_letter_spacing(&mut self, other: &Self) {
                        self.copy_letter_spacing_from(other)
                    }

                    /// Get the computed value for letter-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_letter_spacing(&self) -> longhands::letter_spacing::computed_value::T {
                        self.letter_spacing.clone()
                    }
                        /// Set word-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_spacing(&mut self, v: longhands::word_spacing::computed_value::T) {
                            self.word_spacing = v;
                        }
                        /// Set word-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_spacing_from(&mut self, other: &Self) {
                            self.word_spacing = other.word_spacing.clone();
                        }
                    /// Reset word-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_spacing(&mut self, other: &Self) {
                        self.copy_word_spacing_from(other)
                    }

                    /// Get the computed value for word-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_spacing(&self) -> longhands::word_spacing::computed_value::T {
                        self.word_spacing.clone()
                    }
                        /// Set white-space.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_white_space(&mut self, v: longhands::white_space::computed_value::T) {
                            self.white_space = v;
                        }
                        /// Set white-space from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_white_space_from(&mut self, other: &Self) {
                            self.white_space = other.white_space.clone();
                        }
                    /// Reset white-space from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_white_space(&mut self, other: &Self) {
                        self.copy_white_space_from(other)
                    }

                    /// Get the computed value for white-space.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_white_space(&self) -> longhands::white_space::computed_value::T {
                        self.white_space.clone()
                    }
                        /// Set text-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_shadow<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::text_shadow
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.text_shadow = longhands::text_shadow::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set text-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_shadow_from(&mut self, other: &Self) {
                            self.text_shadow = other.text_shadow.clone();
                        }
                    /// Reset text-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_shadow(&mut self, other: &Self) {
                        self.copy_text_shadow_from(other)
                    }

                    /// Get the computed value for text-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_shadow(&self) -> longhands::text_shadow::computed_value::T {
                        self.text_shadow.clone()
                    }
                        /// Set text-emphasis-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_style(&mut self, v: longhands::text_emphasis_style::computed_value::T) {
                            self.text_emphasis_style = v;
                        }
                        /// Set text-emphasis-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_style_from(&mut self, other: &Self) {
                            self.text_emphasis_style = other.text_emphasis_style.clone();
                        }
                    /// Reset text-emphasis-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_style(&mut self, other: &Self) {
                        self.copy_text_emphasis_style_from(other)
                    }

                    /// Get the computed value for text-emphasis-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_style(&self) -> longhands::text_emphasis_style::computed_value::T {
                        self.text_emphasis_style.clone()
                    }
                        /// Set text-emphasis-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_position(&mut self, v: longhands::text_emphasis_position::computed_value::T) {
                            self.text_emphasis_position = v;
                        }
                        /// Set text-emphasis-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_position_from(&mut self, other: &Self) {
                            self.text_emphasis_position = other.text_emphasis_position.clone();
                        }
                    /// Reset text-emphasis-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_position(&mut self, other: &Self) {
                        self.copy_text_emphasis_position_from(other)
                    }

                    /// Get the computed value for text-emphasis-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_position(&self) -> longhands::text_emphasis_position::computed_value::T {
                        self.text_emphasis_position.clone()
                    }
                        /// Set text-emphasis-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_color(&mut self, v: longhands::text_emphasis_color::computed_value::T) {
                            self.text_emphasis_color = v;
                        }
                        /// Set text-emphasis-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_color_from(&mut self, other: &Self) {
                            self.text_emphasis_color = other.text_emphasis_color.clone();
                        }
                    /// Reset text-emphasis-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_color(&mut self, other: &Self) {
                        self.copy_text_emphasis_color_from(other)
                    }

                    /// Get the computed value for text-emphasis-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_color(&self) -> longhands::text_emphasis_color::computed_value::T {
                        self.text_emphasis_color.clone()
                    }
                        /// Set -moz-tab-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_tab_size(&mut self, v: longhands::_moz_tab_size::computed_value::T) {
                            self._moz_tab_size = v;
                        }
                        /// Set -moz-tab-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_tab_size_from(&mut self, other: &Self) {
                            self._moz_tab_size = other._moz_tab_size.clone();
                        }
                    /// Reset -moz-tab-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_tab_size(&mut self, other: &Self) {
                        self.copy__moz_tab_size_from(other)
                    }

                    /// Get the computed value for -moz-tab-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_tab_size(&self) -> longhands::_moz_tab_size::computed_value::T {
                        self._moz_tab_size.clone()
                    }
                        /// Set -webkit-text-fill-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_fill_color(&mut self, v: longhands::_webkit_text_fill_color::computed_value::T) {
                            self._webkit_text_fill_color = v;
                        }
                        /// Set -webkit-text-fill-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_fill_color_from(&mut self, other: &Self) {
                            self._webkit_text_fill_color = other._webkit_text_fill_color.clone();
                        }
                    /// Reset -webkit-text-fill-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_fill_color(&mut self, other: &Self) {
                        self.copy__webkit_text_fill_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-fill-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_fill_color(&self) -> longhands::_webkit_text_fill_color::computed_value::T {
                        self._webkit_text_fill_color.clone()
                    }
                        /// Set -webkit-text-stroke-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_color(&mut self, v: longhands::_webkit_text_stroke_color::computed_value::T) {
                            self._webkit_text_stroke_color = v;
                        }
                        /// Set -webkit-text-stroke-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_color_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_color = other._webkit_text_stroke_color.clone();
                        }
                    /// Reset -webkit-text-stroke-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_color(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_color(&self) -> longhands::_webkit_text_stroke_color::computed_value::T {
                        self._webkit_text_stroke_color.clone()
                    }
                        /// Set -webkit-text-stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_width(&mut self, v: longhands::_webkit_text_stroke_width::computed_value::T) {
                            self._webkit_text_stroke_width = v;
                        }
                        /// Set -webkit-text-stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_width_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_width = other._webkit_text_stroke_width.clone();
                        }
                    /// Reset -webkit-text-stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_width(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_width_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_width(&self) -> longhands::_webkit_text_stroke_width::computed_value::T {
                        self._webkit_text_stroke_width.clone()
                    }
                        /// Set ruby-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_align(&mut self, v: longhands::ruby_align::computed_value::T) {
                            self.ruby_align = v;
                        }
                        /// Set ruby-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_align_from(&mut self, other: &Self) {
                            self.ruby_align = other.ruby_align.clone();
                        }
                    /// Reset ruby-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_align(&mut self, other: &Self) {
                        self.copy_ruby_align_from(other)
                    }

                    /// Get the computed value for ruby-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_align(&self) -> longhands::ruby_align::computed_value::T {
                        self.ruby_align.clone()
                    }
                        /// Set ruby-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_position(&mut self, v: longhands::ruby_position::computed_value::T) {
                            self.ruby_position = v;
                        }
                        /// Set ruby-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_position_from(&mut self, other: &Self) {
                            self.ruby_position = other.ruby_position.clone();
                        }
                    /// Reset ruby-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_position(&mut self, other: &Self) {
                        self.copy_ruby_position_from(other)
                    }

                    /// Get the computed value for ruby-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_position(&self) -> longhands::ruby_position::computed_value::T {
                        self.ruby_position.clone()
                    }
                        /// Set text-combine-upright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_combine_upright(&mut self, v: longhands::text_combine_upright::computed_value::T) {
                            self.text_combine_upright = v;
                        }
                        /// Set text-combine-upright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_combine_upright_from(&mut self, other: &Self) {
                            self.text_combine_upright = other.text_combine_upright.clone();
                        }
                    /// Reset text-combine-upright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_combine_upright(&mut self, other: &Self) {
                        self.copy_text_combine_upright_from(other)
                    }

                    /// Get the computed value for text-combine-upright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_combine_upright(&self) -> longhands::text_combine_upright::computed_value::T {
                        self.text_combine_upright.clone()
                    }
                        /// Set text-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_rendering(&mut self, v: longhands::text_rendering::computed_value::T) {
                            self.text_rendering = v;
                        }
                        /// Set text-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_rendering_from(&mut self, other: &Self) {
                            self.text_rendering = other.text_rendering.clone();
                        }
                    /// Reset text-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_rendering(&mut self, other: &Self) {
                        self.copy_text_rendering_from(other)
                    }

                    /// Get the computed value for text-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_rendering(&self) -> longhands::text_rendering::computed_value::T {
                        self.text_rendering.clone()
                    }
                        /// Set -moz-control-character-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_control_character_visibility(&mut self, v: longhands::_moz_control_character_visibility::computed_value::T) {
                            self._moz_control_character_visibility = v;
                        }
                        /// Set -moz-control-character-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_control_character_visibility_from(&mut self, other: &Self) {
                            self._moz_control_character_visibility = other._moz_control_character_visibility.clone();
                        }
                    /// Reset -moz-control-character-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_control_character_visibility(&mut self, other: &Self) {
                        self.copy__moz_control_character_visibility_from(other)
                    }

                    /// Get the computed value for -moz-control-character-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_control_character_visibility(&self) -> longhands::_moz_control_character_visibility::computed_value::T {
                        self._moz_control_character_visibility.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The List style struct.
        pub struct List {
                /// The list-style-position computed value.
                pub list_style_position: longhands::list_style_position::computed_value::T,
                /// The list-style-type computed value.
                pub list_style_type: longhands::list_style_type::computed_value::T,
                /// The list-style-image computed value.
                pub list_style_image: longhands::list_style_image::computed_value::T,
                /// The quotes computed value.
                pub quotes: longhands::quotes::computed_value::T,
                /// The -moz-image-region computed value.
                pub _moz_image_region: longhands::_moz_image_region::computed_value::T,
        }

        impl List {
                        /// Set list-style-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_position(&mut self, v: longhands::list_style_position::computed_value::T) {
                            self.list_style_position = v;
                        }
                        /// Set list-style-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_position_from(&mut self, other: &Self) {
                            self.list_style_position = other.list_style_position.clone();
                        }
                    /// Reset list-style-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_position(&mut self, other: &Self) {
                        self.copy_list_style_position_from(other)
                    }

                    /// Get the computed value for list-style-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_position(&self) -> longhands::list_style_position::computed_value::T {
                        self.list_style_position.clone()
                    }
                        /// Set list-style-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_type(&mut self, v: longhands::list_style_type::computed_value::T) {
                            self.list_style_type = v;
                        }
                        /// Set list-style-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_type_from(&mut self, other: &Self) {
                            self.list_style_type = other.list_style_type.clone();
                        }
                    /// Reset list-style-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_type(&mut self, other: &Self) {
                        self.copy_list_style_type_from(other)
                    }

                    /// Get the computed value for list-style-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_type(&self) -> longhands::list_style_type::computed_value::T {
                        self.list_style_type.clone()
                    }
                        /// Set list-style-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_image(&mut self, v: longhands::list_style_image::computed_value::T) {
                            self.list_style_image = v;
                        }
                        /// Set list-style-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_image_from(&mut self, other: &Self) {
                            self.list_style_image = other.list_style_image.clone();
                        }
                    /// Reset list-style-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_image(&mut self, other: &Self) {
                        self.copy_list_style_image_from(other)
                    }

                    /// Get the computed value for list-style-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_image(&self) -> longhands::list_style_image::computed_value::T {
                        self.list_style_image.clone()
                    }
                        /// Set quotes.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_quotes(&mut self, v: longhands::quotes::computed_value::T) {
                            self.quotes = v;
                        }
                        /// Set quotes from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_quotes_from(&mut self, other: &Self) {
                            self.quotes = other.quotes.clone();
                        }
                    /// Reset quotes from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_quotes(&mut self, other: &Self) {
                        self.copy_quotes_from(other)
                    }

                    /// Get the computed value for quotes.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_quotes(&self) -> longhands::quotes::computed_value::T {
                        self.quotes.clone()
                    }
                        /// Set -moz-image-region.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_image_region(&mut self, v: longhands::_moz_image_region::computed_value::T) {
                            self._moz_image_region = v;
                        }
                        /// Set -moz-image-region from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_image_region_from(&mut self, other: &Self) {
                            self._moz_image_region = other._moz_image_region.clone();
                        }
                    /// Reset -moz-image-region from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_image_region(&mut self, other: &Self) {
                        self.copy__moz_image_region_from(other)
                    }

                    /// Get the computed value for -moz-image-region.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_image_region(&self) -> longhands::_moz_image_region::computed_value::T {
                        self._moz_image_region.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Margin style struct.
        pub struct Margin {
                /// The margin-top computed value.
                pub margin_top: longhands::margin_top::computed_value::T,
                /// The margin-left computed value.
                pub margin_left: longhands::margin_left::computed_value::T,
                /// The margin-bottom computed value.
                pub margin_bottom: longhands::margin_bottom::computed_value::T,
                /// The margin-right computed value.
                pub margin_right: longhands::margin_right::computed_value::T,
                /// The margin-block-start computed value.
                pub margin_block_start: longhands::margin_block_start::computed_value::T,
                /// The margin-block-end computed value.
                pub margin_block_end: longhands::margin_block_end::computed_value::T,
                /// The margin-inline-start computed value.
                pub margin_inline_start: longhands::margin_inline_start::computed_value::T,
                /// The margin-inline-end computed value.
                pub margin_inline_end: longhands::margin_inline_end::computed_value::T,
        }

        impl Margin {
                        /// Set margin-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_top(&mut self, v: longhands::margin_top::computed_value::T) {
                            self.margin_top = v;
                        }
                        /// Set margin-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_top_from(&mut self, other: &Self) {
                            self.margin_top = other.margin_top.clone();
                        }
                    /// Reset margin-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_top(&mut self, other: &Self) {
                        self.copy_margin_top_from(other)
                    }

                    /// Get the computed value for margin-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_top(&self) -> longhands::margin_top::computed_value::T {
                        self.margin_top.clone()
                    }
                        /// Set margin-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_left(&mut self, v: longhands::margin_left::computed_value::T) {
                            self.margin_left = v;
                        }
                        /// Set margin-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_left_from(&mut self, other: &Self) {
                            self.margin_left = other.margin_left.clone();
                        }
                    /// Reset margin-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_left(&mut self, other: &Self) {
                        self.copy_margin_left_from(other)
                    }

                    /// Get the computed value for margin-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_left(&self) -> longhands::margin_left::computed_value::T {
                        self.margin_left.clone()
                    }
                        /// Set margin-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_bottom(&mut self, v: longhands::margin_bottom::computed_value::T) {
                            self.margin_bottom = v;
                        }
                        /// Set margin-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_bottom_from(&mut self, other: &Self) {
                            self.margin_bottom = other.margin_bottom.clone();
                        }
                    /// Reset margin-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_bottom(&mut self, other: &Self) {
                        self.copy_margin_bottom_from(other)
                    }

                    /// Get the computed value for margin-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_bottom(&self) -> longhands::margin_bottom::computed_value::T {
                        self.margin_bottom.clone()
                    }
                        /// Set margin-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_right(&mut self, v: longhands::margin_right::computed_value::T) {
                            self.margin_right = v;
                        }
                        /// Set margin-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_right_from(&mut self, other: &Self) {
                            self.margin_right = other.margin_right.clone();
                        }
                    /// Reset margin-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_right(&mut self, other: &Self) {
                        self.copy_margin_right_from(other)
                    }

                    /// Get the computed value for margin-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_right(&self) -> longhands::margin_right::computed_value::T {
                        self.margin_right.clone()
                    }
                    
    /// Set the appropriate physical property for margin-block-start given a writing mode.
    pub fn set_margin_block_start(&mut self,
                                      v: longhands::margin_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-start
    /// given a writing mode.
    pub fn copy_margin_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-start
    /// given a writing mode.
    pub fn reset_margin_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-block-start given a writing mode.
    pub fn clone_margin_block_start(&self, wm: WritingMode)
        -> longhands::margin_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-block-end given a writing mode.
    pub fn set_margin_block_end(&mut self,
                                      v: longhands::margin_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-end
    /// given a writing mode.
    pub fn copy_margin_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-block-end
    /// given a writing mode.
    pub fn reset_margin_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-block-end given a writing mode.
    pub fn clone_margin_block_end(&self, wm: WritingMode)
        -> longhands::margin_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-inline-start given a writing mode.
    pub fn set_margin_inline_start(&mut self,
                                      v: longhands::margin_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-start
    /// given a writing mode.
    pub fn copy_margin_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-start
    /// given a writing mode.
    pub fn reset_margin_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-inline-start given a writing mode.
    pub fn clone_margin_inline_start(&self, wm: WritingMode)
        -> longhands::margin_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for margin-inline-end given a writing mode.
    pub fn set_margin_inline_end(&mut self,
                                      v: longhands::margin_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_margin_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_margin_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_margin_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_margin_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-end
    /// given a writing mode.
    pub fn copy_margin_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_margin_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_margin_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_margin_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_margin_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for margin-inline-end
    /// given a writing mode.
    pub fn reset_margin_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_margin_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// margin-inline-end given a writing mode.
    pub fn clone_margin_inline_end(&self, wm: WritingMode)
        -> longhands::margin_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_margin_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_margin_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_margin_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_margin_right()
        
                }
        }

    }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Outline style struct.
        pub struct Outline {
                /// The outline-color computed value.
                pub outline_color: longhands::outline_color::computed_value::T,
                /// The outline-style computed value.
                pub outline_style: longhands::outline_style::computed_value::T,
                /// The outline-width computed value.
                pub outline_width: longhands::outline_width::computed_value::T,
                /// The -moz-outline-radius-topleft computed value.
                pub _moz_outline_radius_topleft: longhands::_moz_outline_radius_topleft::computed_value::T,
                /// The -moz-outline-radius-topright computed value.
                pub _moz_outline_radius_topright: longhands::_moz_outline_radius_topright::computed_value::T,
                /// The -moz-outline-radius-bottomright computed value.
                pub _moz_outline_radius_bottomright: longhands::_moz_outline_radius_bottomright::computed_value::T,
                /// The -moz-outline-radius-bottomleft computed value.
                pub _moz_outline_radius_bottomleft: longhands::_moz_outline_radius_bottomleft::computed_value::T,
                /// The outline-offset computed value.
                pub outline_offset: longhands::outline_offset::computed_value::T,
        }

        impl Outline {
                        /// Set outline-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_color(&mut self, v: longhands::outline_color::computed_value::T) {
                            self.outline_color = v;
                        }
                        /// Set outline-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_color_from(&mut self, other: &Self) {
                            self.outline_color = other.outline_color.clone();
                        }
                    /// Reset outline-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_color(&mut self, other: &Self) {
                        self.copy_outline_color_from(other)
                    }

                    /// Get the computed value for outline-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_color(&self) -> longhands::outline_color::computed_value::T {
                        self.outline_color.clone()
                    }
                        /// Set outline-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_style(&mut self, v: longhands::outline_style::computed_value::T) {
                            self.outline_style = v;
                        }
                        /// Set outline-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_style_from(&mut self, other: &Self) {
                            self.outline_style = other.outline_style.clone();
                        }
                    /// Reset outline-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_style(&mut self, other: &Self) {
                        self.copy_outline_style_from(other)
                    }

                    /// Get the computed value for outline-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_style(&self) -> longhands::outline_style::computed_value::T {
                        self.outline_style.clone()
                    }
                        /// Set outline-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_width(&mut self, v: longhands::outline_width::computed_value::T) {
                            self.outline_width = v;
                        }
                        /// Set outline-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_width_from(&mut self, other: &Self) {
                            self.outline_width = other.outline_width.clone();
                        }
                    /// Reset outline-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_width(&mut self, other: &Self) {
                        self.copy_outline_width_from(other)
                    }

                    /// Get the computed value for outline-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_width(&self) -> longhands::outline_width::computed_value::T {
                        self.outline_width.clone()
                    }
                        /// Set -moz-outline-radius-topleft.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_topleft(&mut self, v: longhands::_moz_outline_radius_topleft::computed_value::T) {
                            self._moz_outline_radius_topleft = v;
                        }
                        /// Set -moz-outline-radius-topleft from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_topleft_from(&mut self, other: &Self) {
                            self._moz_outline_radius_topleft = other._moz_outline_radius_topleft.clone();
                        }
                    /// Reset -moz-outline-radius-topleft from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_topleft(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_topleft_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-topleft.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_topleft(&self) -> longhands::_moz_outline_radius_topleft::computed_value::T {
                        self._moz_outline_radius_topleft.clone()
                    }
                        /// Set -moz-outline-radius-topright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_topright(&mut self, v: longhands::_moz_outline_radius_topright::computed_value::T) {
                            self._moz_outline_radius_topright = v;
                        }
                        /// Set -moz-outline-radius-topright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_topright_from(&mut self, other: &Self) {
                            self._moz_outline_radius_topright = other._moz_outline_radius_topright.clone();
                        }
                    /// Reset -moz-outline-radius-topright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_topright(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_topright_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-topright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_topright(&self) -> longhands::_moz_outline_radius_topright::computed_value::T {
                        self._moz_outline_radius_topright.clone()
                    }
                        /// Set -moz-outline-radius-bottomright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_bottomright(&mut self, v: longhands::_moz_outline_radius_bottomright::computed_value::T) {
                            self._moz_outline_radius_bottomright = v;
                        }
                        /// Set -moz-outline-radius-bottomright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_bottomright_from(&mut self, other: &Self) {
                            self._moz_outline_radius_bottomright = other._moz_outline_radius_bottomright.clone();
                        }
                    /// Reset -moz-outline-radius-bottomright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_bottomright(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_bottomright_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-bottomright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_bottomright(&self) -> longhands::_moz_outline_radius_bottomright::computed_value::T {
                        self._moz_outline_radius_bottomright.clone()
                    }
                        /// Set -moz-outline-radius-bottomleft.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_outline_radius_bottomleft(&mut self, v: longhands::_moz_outline_radius_bottomleft::computed_value::T) {
                            self._moz_outline_radius_bottomleft = v;
                        }
                        /// Set -moz-outline-radius-bottomleft from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_outline_radius_bottomleft_from(&mut self, other: &Self) {
                            self._moz_outline_radius_bottomleft = other._moz_outline_radius_bottomleft.clone();
                        }
                    /// Reset -moz-outline-radius-bottomleft from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_outline_radius_bottomleft(&mut self, other: &Self) {
                        self.copy__moz_outline_radius_bottomleft_from(other)
                    }

                    /// Get the computed value for -moz-outline-radius-bottomleft.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_outline_radius_bottomleft(&self) -> longhands::_moz_outline_radius_bottomleft::computed_value::T {
                        self._moz_outline_radius_bottomleft.clone()
                    }
                        /// Set outline-offset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_offset(&mut self, v: longhands::outline_offset::computed_value::T) {
                            self.outline_offset = v;
                        }
                        /// Set outline-offset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_offset_from(&mut self, other: &Self) {
                            self.outline_offset = other.outline_offset.clone();
                        }
                    /// Reset outline-offset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_offset(&mut self, other: &Self) {
                        self.copy_outline_offset_from(other)
                    }

                    /// Get the computed value for outline-offset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_offset(&self) -> longhands::outline_offset::computed_value::T {
                        self.outline_offset.clone()
                    }
                /// Whether the outline-width property is non-zero.
                #[inline]
                pub fn outline_has_nonzero_width(&self) -> bool {
                    self.outline_width != NonNegativeLength::zero()
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Padding style struct.
        pub struct Padding {
                /// The padding-top computed value.
                pub padding_top: longhands::padding_top::computed_value::T,
                /// The padding-left computed value.
                pub padding_left: longhands::padding_left::computed_value::T,
                /// The padding-bottom computed value.
                pub padding_bottom: longhands::padding_bottom::computed_value::T,
                /// The padding-right computed value.
                pub padding_right: longhands::padding_right::computed_value::T,
                /// The padding-block-start computed value.
                pub padding_block_start: longhands::padding_block_start::computed_value::T,
                /// The padding-block-end computed value.
                pub padding_block_end: longhands::padding_block_end::computed_value::T,
                /// The padding-inline-start computed value.
                pub padding_inline_start: longhands::padding_inline_start::computed_value::T,
                /// The padding-inline-end computed value.
                pub padding_inline_end: longhands::padding_inline_end::computed_value::T,
        }

        impl Padding {
                        /// Set padding-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_top(&mut self, v: longhands::padding_top::computed_value::T) {
                            self.padding_top = v;
                        }
                        /// Set padding-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_top_from(&mut self, other: &Self) {
                            self.padding_top = other.padding_top.clone();
                        }
                    /// Reset padding-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_top(&mut self, other: &Self) {
                        self.copy_padding_top_from(other)
                    }

                    /// Get the computed value for padding-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_top(&self) -> longhands::padding_top::computed_value::T {
                        self.padding_top.clone()
                    }
                        /// Set padding-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_left(&mut self, v: longhands::padding_left::computed_value::T) {
                            self.padding_left = v;
                        }
                        /// Set padding-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_left_from(&mut self, other: &Self) {
                            self.padding_left = other.padding_left.clone();
                        }
                    /// Reset padding-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_left(&mut self, other: &Self) {
                        self.copy_padding_left_from(other)
                    }

                    /// Get the computed value for padding-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_left(&self) -> longhands::padding_left::computed_value::T {
                        self.padding_left.clone()
                    }
                        /// Set padding-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_bottom(&mut self, v: longhands::padding_bottom::computed_value::T) {
                            self.padding_bottom = v;
                        }
                        /// Set padding-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_bottom_from(&mut self, other: &Self) {
                            self.padding_bottom = other.padding_bottom.clone();
                        }
                    /// Reset padding-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_bottom(&mut self, other: &Self) {
                        self.copy_padding_bottom_from(other)
                    }

                    /// Get the computed value for padding-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_bottom(&self) -> longhands::padding_bottom::computed_value::T {
                        self.padding_bottom.clone()
                    }
                        /// Set padding-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_right(&mut self, v: longhands::padding_right::computed_value::T) {
                            self.padding_right = v;
                        }
                        /// Set padding-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_right_from(&mut self, other: &Self) {
                            self.padding_right = other.padding_right.clone();
                        }
                    /// Reset padding-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_right(&mut self, other: &Self) {
                        self.copy_padding_right_from(other)
                    }

                    /// Get the computed value for padding-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_right(&self) -> longhands::padding_right::computed_value::T {
                        self.padding_right.clone()
                    }
                    
    /// Set the appropriate physical property for padding-block-start given a writing mode.
    pub fn set_padding_block_start(&mut self,
                                      v: longhands::padding_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-start
    /// given a writing mode.
    pub fn copy_padding_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-start
    /// given a writing mode.
    pub fn reset_padding_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-block-start given a writing mode.
    pub fn clone_padding_block_start(&self, wm: WritingMode)
        -> longhands::padding_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-block-end given a writing mode.
    pub fn set_padding_block_end(&mut self,
                                      v: longhands::padding_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-end
    /// given a writing mode.
    pub fn copy_padding_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-block-end
    /// given a writing mode.
    pub fn reset_padding_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-block-end given a writing mode.
    pub fn clone_padding_block_end(&self, wm: WritingMode)
        -> longhands::padding_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-inline-start given a writing mode.
    pub fn set_padding_inline_start(&mut self,
                                      v: longhands::padding_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-start
    /// given a writing mode.
    pub fn copy_padding_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-start
    /// given a writing mode.
    pub fn reset_padding_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-inline-start given a writing mode.
    pub fn clone_padding_inline_start(&self, wm: WritingMode)
        -> longhands::padding_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for padding-inline-end given a writing mode.
    pub fn set_padding_inline_end(&mut self,
                                      v: longhands::padding_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_padding_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_padding_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_padding_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_padding_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-end
    /// given a writing mode.
    pub fn copy_padding_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_padding_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_padding_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_padding_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_padding_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for padding-inline-end
    /// given a writing mode.
    pub fn reset_padding_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_padding_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// padding-inline-end given a writing mode.
    pub fn clone_padding_inline_end(&self, wm: WritingMode)
        -> longhands::padding_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_padding_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_padding_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_padding_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_padding_right()
        
                }
        }

    }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Pointing style struct.
        pub struct Pointing {
                /// The cursor computed value.
                pub cursor: longhands::cursor::computed_value::T,
                /// The pointer-events computed value.
                pub pointer_events: longhands::pointer_events::computed_value::T,
                /// The -moz-user-input computed value.
                pub _moz_user_input: longhands::_moz_user_input::computed_value::T,
                /// The -moz-user-modify computed value.
                pub _moz_user_modify: longhands::_moz_user_modify::computed_value::T,
                /// The -moz-user-focus computed value.
                pub _moz_user_focus: longhands::_moz_user_focus::computed_value::T,
                /// The caret-color computed value.
                pub caret_color: longhands::caret_color::computed_value::T,
        }

        impl Pointing {
                        /// Set cursor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_cursor(&mut self, v: longhands::cursor::computed_value::T) {
                            self.cursor = v;
                        }
                        /// Set cursor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_cursor_from(&mut self, other: &Self) {
                            self.cursor = other.cursor.clone();
                        }
                    /// Reset cursor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_cursor(&mut self, other: &Self) {
                        self.copy_cursor_from(other)
                    }

                    /// Get the computed value for cursor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_cursor(&self) -> longhands::cursor::computed_value::T {
                        self.cursor.clone()
                    }
                        /// Set pointer-events.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_pointer_events(&mut self, v: longhands::pointer_events::computed_value::T) {
                            self.pointer_events = v;
                        }
                        /// Set pointer-events from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_pointer_events_from(&mut self, other: &Self) {
                            self.pointer_events = other.pointer_events.clone();
                        }
                    /// Reset pointer-events from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_pointer_events(&mut self, other: &Self) {
                        self.copy_pointer_events_from(other)
                    }

                    /// Get the computed value for pointer-events.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_pointer_events(&self) -> longhands::pointer_events::computed_value::T {
                        self.pointer_events.clone()
                    }
                        /// Set -moz-user-input.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_input(&mut self, v: longhands::_moz_user_input::computed_value::T) {
                            self._moz_user_input = v;
                        }
                        /// Set -moz-user-input from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_input_from(&mut self, other: &Self) {
                            self._moz_user_input = other._moz_user_input.clone();
                        }
                    /// Reset -moz-user-input from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_input(&mut self, other: &Self) {
                        self.copy__moz_user_input_from(other)
                    }

                    /// Get the computed value for -moz-user-input.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_input(&self) -> longhands::_moz_user_input::computed_value::T {
                        self._moz_user_input.clone()
                    }
                        /// Set -moz-user-modify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_modify(&mut self, v: longhands::_moz_user_modify::computed_value::T) {
                            self._moz_user_modify = v;
                        }
                        /// Set -moz-user-modify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_modify_from(&mut self, other: &Self) {
                            self._moz_user_modify = other._moz_user_modify.clone();
                        }
                    /// Reset -moz-user-modify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_modify(&mut self, other: &Self) {
                        self.copy__moz_user_modify_from(other)
                    }

                    /// Get the computed value for -moz-user-modify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_modify(&self) -> longhands::_moz_user_modify::computed_value::T {
                        self._moz_user_modify.clone()
                    }
                        /// Set -moz-user-focus.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_focus(&mut self, v: longhands::_moz_user_focus::computed_value::T) {
                            self._moz_user_focus = v;
                        }
                        /// Set -moz-user-focus from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_focus_from(&mut self, other: &Self) {
                            self._moz_user_focus = other._moz_user_focus.clone();
                        }
                    /// Reset -moz-user-focus from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_focus(&mut self, other: &Self) {
                        self.copy__moz_user_focus_from(other)
                    }

                    /// Get the computed value for -moz-user-focus.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_focus(&self) -> longhands::_moz_user_focus::computed_value::T {
                        self._moz_user_focus.clone()
                    }
                        /// Set caret-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caret_color(&mut self, v: longhands::caret_color::computed_value::T) {
                            self.caret_color = v;
                        }
                        /// Set caret-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caret_color_from(&mut self, other: &Self) {
                            self.caret_color = other.caret_color.clone();
                        }
                    /// Reset caret-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caret_color(&mut self, other: &Self) {
                        self.copy_caret_color_from(other)
                    }

                    /// Get the computed value for caret-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caret_color(&self) -> longhands::caret_color::computed_value::T {
                        self.caret_color.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Position style struct.
        pub struct Position {
                /// The top computed value.
                pub top: longhands::top::computed_value::T,
                /// The left computed value.
                pub left: longhands::left::computed_value::T,
                /// The bottom computed value.
                pub bottom: longhands::bottom::computed_value::T,
                /// The right computed value.
                pub right: longhands::right::computed_value::T,
                /// The offset-block-start computed value.
                pub offset_block_start: longhands::offset_block_start::computed_value::T,
                /// The offset-block-end computed value.
                pub offset_block_end: longhands::offset_block_end::computed_value::T,
                /// The offset-inline-start computed value.
                pub offset_inline_start: longhands::offset_inline_start::computed_value::T,
                /// The offset-inline-end computed value.
                pub offset_inline_end: longhands::offset_inline_end::computed_value::T,
                /// The z-index computed value.
                pub z_index: longhands::z_index::computed_value::T,
                /// The flex-direction computed value.
                pub flex_direction: longhands::flex_direction::computed_value::T,
                /// The flex-wrap computed value.
                pub flex_wrap: longhands::flex_wrap::computed_value::T,
                /// The justify-content computed value.
                pub justify_content: longhands::justify_content::computed_value::T,
                /// The align-content computed value.
                pub align_content: longhands::align_content::computed_value::T,
                /// The align-items computed value.
                pub align_items: longhands::align_items::computed_value::T,
                /// The justify-items computed value.
                pub justify_items: longhands::justify_items::computed_value::T,
                /// The flex-grow computed value.
                pub flex_grow: longhands::flex_grow::computed_value::T,
                /// The flex-shrink computed value.
                pub flex_shrink: longhands::flex_shrink::computed_value::T,
                /// The align-self computed value.
                pub align_self: longhands::align_self::computed_value::T,
                /// The justify-self computed value.
                pub justify_self: longhands::justify_self::computed_value::T,
                /// The order computed value.
                pub order: longhands::order::computed_value::T,
                /// The flex-basis computed value.
                pub flex_basis: longhands::flex_basis::computed_value::T,
                /// The width computed value.
                pub width: longhands::width::computed_value::T,
                /// The min-width computed value.
                pub min_width: longhands::min_width::computed_value::T,
                /// The max-width computed value.
                pub max_width: longhands::max_width::computed_value::T,
                /// The height computed value.
                pub height: longhands::height::computed_value::T,
                /// The min-height computed value.
                pub min_height: longhands::min_height::computed_value::T,
                /// The max-height computed value.
                pub max_height: longhands::max_height::computed_value::T,
                /// The block-size computed value.
                pub block_size: longhands::block_size::computed_value::T,
                /// The min-block-size computed value.
                pub min_block_size: longhands::min_block_size::computed_value::T,
                /// The max-block-size computed value.
                pub max_block_size: longhands::max_block_size::computed_value::T,
                /// The inline-size computed value.
                pub inline_size: longhands::inline_size::computed_value::T,
                /// The min-inline-size computed value.
                pub min_inline_size: longhands::min_inline_size::computed_value::T,
                /// The max-inline-size computed value.
                pub max_inline_size: longhands::max_inline_size::computed_value::T,
                /// The box-sizing computed value.
                pub box_sizing: longhands::box_sizing::computed_value::T,
                /// The object-fit computed value.
                pub object_fit: longhands::object_fit::computed_value::T,
                /// The object-position computed value.
                pub object_position: longhands::object_position::computed_value::T,
                /// The grid-row-gap computed value.
                pub grid_row_gap: longhands::grid_row_gap::computed_value::T,
                /// The grid-row-start computed value.
                pub grid_row_start: longhands::grid_row_start::computed_value::T,
                /// The grid-row-end computed value.
                pub grid_row_end: longhands::grid_row_end::computed_value::T,
                /// The grid-auto-rows computed value.
                pub grid_auto_rows: longhands::grid_auto_rows::computed_value::T,
                /// The grid-template-rows computed value.
                pub grid_template_rows: longhands::grid_template_rows::computed_value::T,
                /// The grid-column-gap computed value.
                pub grid_column_gap: longhands::grid_column_gap::computed_value::T,
                /// The grid-column-start computed value.
                pub grid_column_start: longhands::grid_column_start::computed_value::T,
                /// The grid-column-end computed value.
                pub grid_column_end: longhands::grid_column_end::computed_value::T,
                /// The grid-auto-columns computed value.
                pub grid_auto_columns: longhands::grid_auto_columns::computed_value::T,
                /// The grid-template-columns computed value.
                pub grid_template_columns: longhands::grid_template_columns::computed_value::T,
                /// The grid-auto-flow computed value.
                pub grid_auto_flow: longhands::grid_auto_flow::computed_value::T,
                /// The grid-template-areas computed value.
                pub grid_template_areas: longhands::grid_template_areas::computed_value::T,
        }

        impl Position {
                        /// Set top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_top(&mut self, v: longhands::top::computed_value::T) {
                            self.top = v;
                        }
                        /// Set top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_top_from(&mut self, other: &Self) {
                            self.top = other.top.clone();
                        }
                    /// Reset top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_top(&mut self, other: &Self) {
                        self.copy_top_from(other)
                    }

                    /// Get the computed value for top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_top(&self) -> longhands::top::computed_value::T {
                        self.top.clone()
                    }
                        /// Set left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_left(&mut self, v: longhands::left::computed_value::T) {
                            self.left = v;
                        }
                        /// Set left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_left_from(&mut self, other: &Self) {
                            self.left = other.left.clone();
                        }
                    /// Reset left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_left(&mut self, other: &Self) {
                        self.copy_left_from(other)
                    }

                    /// Get the computed value for left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_left(&self) -> longhands::left::computed_value::T {
                        self.left.clone()
                    }
                        /// Set bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_bottom(&mut self, v: longhands::bottom::computed_value::T) {
                            self.bottom = v;
                        }
                        /// Set bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_bottom_from(&mut self, other: &Self) {
                            self.bottom = other.bottom.clone();
                        }
                    /// Reset bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_bottom(&mut self, other: &Self) {
                        self.copy_bottom_from(other)
                    }

                    /// Get the computed value for bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_bottom(&self) -> longhands::bottom::computed_value::T {
                        self.bottom.clone()
                    }
                        /// Set right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_right(&mut self, v: longhands::right::computed_value::T) {
                            self.right = v;
                        }
                        /// Set right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_right_from(&mut self, other: &Self) {
                            self.right = other.right.clone();
                        }
                    /// Reset right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_right(&mut self, other: &Self) {
                        self.copy_right_from(other)
                    }

                    /// Get the computed value for right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_right(&self) -> longhands::right::computed_value::T {
                        self.right.clone()
                    }
                    
    /// Set the appropriate physical property for offset-block-start given a writing mode.
    pub fn set_offset_block_start(&mut self,
                                      v: longhands::offset_block_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-start
    /// given a writing mode.
    pub fn copy_offset_block_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-start
    /// given a writing mode.
    pub fn reset_offset_block_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_block_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-block-start given a writing mode.
    pub fn clone_offset_block_start(&self, wm: WritingMode)
        -> longhands::offset_block_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-block-end given a writing mode.
    pub fn set_offset_block_end(&mut self,
                                      v: longhands::offset_block_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-end
    /// given a writing mode.
    pub fn copy_offset_block_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-block-end
    /// given a writing mode.
    pub fn reset_offset_block_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_block_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-block-end given a writing mode.
    pub fn clone_offset_block_end(&self, wm: WritingMode)
        -> longhands::offset_block_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.block_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-inline-start given a writing mode.
    pub fn set_offset_inline_start(&mut self,
                                      v: longhands::offset_inline_start::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-start
    /// given a writing mode.
    pub fn copy_offset_inline_start_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-start
    /// given a writing mode.
    pub fn reset_offset_inline_start(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_inline_start_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-inline-start given a writing mode.
    pub fn clone_offset_inline_start(&self, wm: WritingMode)
        -> longhands::offset_inline_start::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_start_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                    
    /// Set the appropriate physical property for offset-inline-end given a writing mode.
    pub fn set_offset_inline_end(&mut self,
                                      v: longhands::offset_inline_end::computed_value::T,
                                      wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.set_top(v)
            
                }
                PhysicalSide::Left => {
                    
                self.set_left(v)
            
                }
                PhysicalSide::Bottom => {
                    
                self.set_bottom(v)
            
                }
                PhysicalSide::Right => {
                    
                self.set_right(v)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-end
    /// given a writing mode.
    pub fn copy_offset_inline_end_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
                self.copy_top_from(other)
            
                }
                PhysicalSide::Left => {
                    
                self.copy_left_from(other)
            
                }
                PhysicalSide::Bottom => {
                    
                self.copy_bottom_from(other)
            
                }
                PhysicalSide::Right => {
                    
                self.copy_right_from(other)
            
                }
        }

    }

    /// Copy the appropriate physical property from another struct for offset-inline-end
    /// given a writing mode.
    pub fn reset_offset_inline_end(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_offset_inline_end_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// offset-inline-end given a writing mode.
    pub fn clone_offset_inline_end(&self, wm: WritingMode)
        -> longhands::offset_inline_end::computed_value::T {
    
    
        use logical_geometry::PhysicalSide;
        match wm.inline_end_physical_side() {
                PhysicalSide::Top => {
                    
            self.clone_top()
        
                }
                PhysicalSide::Left => {
                    
            self.clone_left()
        
                }
                PhysicalSide::Bottom => {
                    
            self.clone_bottom()
        
                }
                PhysicalSide::Right => {
                    
            self.clone_right()
        
                }
        }

    }

                        /// Set z-index.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_z_index(&mut self, v: longhands::z_index::computed_value::T) {
                            self.z_index = v;
                        }
                        /// Set z-index from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_z_index_from(&mut self, other: &Self) {
                            self.z_index = other.z_index.clone();
                        }
                    /// Reset z-index from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_z_index(&mut self, other: &Self) {
                        self.copy_z_index_from(other)
                    }

                    /// Get the computed value for z-index.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_z_index(&self) -> longhands::z_index::computed_value::T {
                        self.z_index.clone()
                    }
                        /// Set flex-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_direction(&mut self, v: longhands::flex_direction::computed_value::T) {
                            self.flex_direction = v;
                        }
                        /// Set flex-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_direction_from(&mut self, other: &Self) {
                            self.flex_direction = other.flex_direction.clone();
                        }
                    /// Reset flex-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_direction(&mut self, other: &Self) {
                        self.copy_flex_direction_from(other)
                    }

                    /// Get the computed value for flex-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_direction(&self) -> longhands::flex_direction::computed_value::T {
                        self.flex_direction.clone()
                    }
                        /// Set flex-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_wrap(&mut self, v: longhands::flex_wrap::computed_value::T) {
                            self.flex_wrap = v;
                        }
                        /// Set flex-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_wrap_from(&mut self, other: &Self) {
                            self.flex_wrap = other.flex_wrap.clone();
                        }
                    /// Reset flex-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_wrap(&mut self, other: &Self) {
                        self.copy_flex_wrap_from(other)
                    }

                    /// Get the computed value for flex-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_wrap(&self) -> longhands::flex_wrap::computed_value::T {
                        self.flex_wrap.clone()
                    }
                        /// Set justify-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_content(&mut self, v: longhands::justify_content::computed_value::T) {
                            self.justify_content = v;
                        }
                        /// Set justify-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_content_from(&mut self, other: &Self) {
                            self.justify_content = other.justify_content.clone();
                        }
                    /// Reset justify-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_content(&mut self, other: &Self) {
                        self.copy_justify_content_from(other)
                    }

                    /// Get the computed value for justify-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_content(&self) -> longhands::justify_content::computed_value::T {
                        self.justify_content.clone()
                    }
                        /// Set align-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_content(&mut self, v: longhands::align_content::computed_value::T) {
                            self.align_content = v;
                        }
                        /// Set align-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_content_from(&mut self, other: &Self) {
                            self.align_content = other.align_content.clone();
                        }
                    /// Reset align-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_content(&mut self, other: &Self) {
                        self.copy_align_content_from(other)
                    }

                    /// Get the computed value for align-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_content(&self) -> longhands::align_content::computed_value::T {
                        self.align_content.clone()
                    }
                        /// Set align-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_items(&mut self, v: longhands::align_items::computed_value::T) {
                            self.align_items = v;
                        }
                        /// Set align-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_items_from(&mut self, other: &Self) {
                            self.align_items = other.align_items.clone();
                        }
                    /// Reset align-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_items(&mut self, other: &Self) {
                        self.copy_align_items_from(other)
                    }

                    /// Get the computed value for align-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_items(&self) -> longhands::align_items::computed_value::T {
                        self.align_items.clone()
                    }
                        /// Set justify-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_items(&mut self, v: longhands::justify_items::computed_value::T) {
                            self.justify_items = v;
                        }
                        /// Set justify-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_items_from(&mut self, other: &Self) {
                            self.justify_items = other.justify_items.clone();
                        }
                    /// Reset justify-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_items(&mut self, other: &Self) {
                        self.copy_justify_items_from(other)
                    }

                    /// Get the computed value for justify-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_items(&self) -> longhands::justify_items::computed_value::T {
                        self.justify_items.clone()
                    }
                        /// Set flex-grow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_grow(&mut self, v: longhands::flex_grow::computed_value::T) {
                            self.flex_grow = v;
                        }
                        /// Set flex-grow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_grow_from(&mut self, other: &Self) {
                            self.flex_grow = other.flex_grow.clone();
                        }
                    /// Reset flex-grow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_grow(&mut self, other: &Self) {
                        self.copy_flex_grow_from(other)
                    }

                    /// Get the computed value for flex-grow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_grow(&self) -> longhands::flex_grow::computed_value::T {
                        self.flex_grow.clone()
                    }
                        /// Set flex-shrink.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_shrink(&mut self, v: longhands::flex_shrink::computed_value::T) {
                            self.flex_shrink = v;
                        }
                        /// Set flex-shrink from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_shrink_from(&mut self, other: &Self) {
                            self.flex_shrink = other.flex_shrink.clone();
                        }
                    /// Reset flex-shrink from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_shrink(&mut self, other: &Self) {
                        self.copy_flex_shrink_from(other)
                    }

                    /// Get the computed value for flex-shrink.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_shrink(&self) -> longhands::flex_shrink::computed_value::T {
                        self.flex_shrink.clone()
                    }
                        /// Set align-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_self(&mut self, v: longhands::align_self::computed_value::T) {
                            self.align_self = v;
                        }
                        /// Set align-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_self_from(&mut self, other: &Self) {
                            self.align_self = other.align_self.clone();
                        }
                    /// Reset align-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_self(&mut self, other: &Self) {
                        self.copy_align_self_from(other)
                    }

                    /// Get the computed value for align-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_self(&self) -> longhands::align_self::computed_value::T {
                        self.align_self.clone()
                    }
                        /// Set justify-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_self(&mut self, v: longhands::justify_self::computed_value::T) {
                            self.justify_self = v;
                        }
                        /// Set justify-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_self_from(&mut self, other: &Self) {
                            self.justify_self = other.justify_self.clone();
                        }
                    /// Reset justify-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_self(&mut self, other: &Self) {
                        self.copy_justify_self_from(other)
                    }

                    /// Get the computed value for justify-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_self(&self) -> longhands::justify_self::computed_value::T {
                        self.justify_self.clone()
                    }
                        /// Set order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_order(&mut self, v: longhands::order::computed_value::T) {
                            self.order = v;
                        }
                        /// Set order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_order_from(&mut self, other: &Self) {
                            self.order = other.order.clone();
                        }
                    /// Reset order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_order(&mut self, other: &Self) {
                        self.copy_order_from(other)
                    }

                    /// Get the computed value for order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_order(&self) -> longhands::order::computed_value::T {
                        self.order.clone()
                    }
                        /// Set flex-basis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_basis(&mut self, v: longhands::flex_basis::computed_value::T) {
                            self.flex_basis = v;
                        }
                        /// Set flex-basis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_basis_from(&mut self, other: &Self) {
                            self.flex_basis = other.flex_basis.clone();
                        }
                    /// Reset flex-basis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_basis(&mut self, other: &Self) {
                        self.copy_flex_basis_from(other)
                    }

                    /// Get the computed value for flex-basis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_basis(&self) -> longhands::flex_basis::computed_value::T {
                        self.flex_basis.clone()
                    }
                        /// Set width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_width(&mut self, v: longhands::width::computed_value::T) {
                            self.width = v;
                        }
                        /// Set width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_width_from(&mut self, other: &Self) {
                            self.width = other.width.clone();
                        }
                    /// Reset width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_width(&mut self, other: &Self) {
                        self.copy_width_from(other)
                    }

                    /// Get the computed value for width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_width(&self) -> longhands::width::computed_value::T {
                        self.width.clone()
                    }
                        /// Set min-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_width(&mut self, v: longhands::min_width::computed_value::T) {
                            self.min_width = v;
                        }
                        /// Set min-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_width_from(&mut self, other: &Self) {
                            self.min_width = other.min_width.clone();
                        }
                    /// Reset min-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_width(&mut self, other: &Self) {
                        self.copy_min_width_from(other)
                    }

                    /// Get the computed value for min-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_width(&self) -> longhands::min_width::computed_value::T {
                        self.min_width.clone()
                    }
                        /// Set max-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_width(&mut self, v: longhands::max_width::computed_value::T) {
                            self.max_width = v;
                        }
                        /// Set max-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_width_from(&mut self, other: &Self) {
                            self.max_width = other.max_width.clone();
                        }
                    /// Reset max-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_width(&mut self, other: &Self) {
                        self.copy_max_width_from(other)
                    }

                    /// Get the computed value for max-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_width(&self) -> longhands::max_width::computed_value::T {
                        self.max_width.clone()
                    }
                        /// Set height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_height(&mut self, v: longhands::height::computed_value::T) {
                            self.height = v;
                        }
                        /// Set height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_height_from(&mut self, other: &Self) {
                            self.height = other.height.clone();
                        }
                    /// Reset height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_height(&mut self, other: &Self) {
                        self.copy_height_from(other)
                    }

                    /// Get the computed value for height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_height(&self) -> longhands::height::computed_value::T {
                        self.height.clone()
                    }
                        /// Set min-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_height(&mut self, v: longhands::min_height::computed_value::T) {
                            self.min_height = v;
                        }
                        /// Set min-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_height_from(&mut self, other: &Self) {
                            self.min_height = other.min_height.clone();
                        }
                    /// Reset min-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_height(&mut self, other: &Self) {
                        self.copy_min_height_from(other)
                    }

                    /// Get the computed value for min-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_height(&self) -> longhands::min_height::computed_value::T {
                        self.min_height.clone()
                    }
                        /// Set max-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_height(&mut self, v: longhands::max_height::computed_value::T) {
                            self.max_height = v;
                        }
                        /// Set max-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_height_from(&mut self, other: &Self) {
                            self.max_height = other.max_height.clone();
                        }
                    /// Reset max-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_height(&mut self, other: &Self) {
                        self.copy_max_height_from(other)
                    }

                    /// Get the computed value for max-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_height(&self) -> longhands::max_height::computed_value::T {
                        self.max_height.clone()
                    }
                    
    /// Set the appropriate physical property for block-size given a writing mode.
    pub fn set_block_size(&mut self,
                                      v: longhands::block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_width(v)
            
        } else {
            
                self.set_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for block-size
    /// given a writing mode.
    pub fn copy_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_width_from(other)
            
        } else {
            
                self.copy_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for block-size
    /// given a writing mode.
    pub fn reset_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// block-size given a writing mode.
    pub fn clone_block_size(&self, wm: WritingMode)
        -> longhands::block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_width()
        
        } else {
            
            self.clone_height()
        
        }

    }

                    
    /// Set the appropriate physical property for min-block-size given a writing mode.
    pub fn set_min_block_size(&mut self,
                                      v: longhands::min_block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_min_width(v)
            
        } else {
            
                self.set_min_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-block-size
    /// given a writing mode.
    pub fn copy_min_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_min_width_from(other)
            
        } else {
            
                self.copy_min_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-block-size
    /// given a writing mode.
    pub fn reset_min_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_min_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// min-block-size given a writing mode.
    pub fn clone_min_block_size(&self, wm: WritingMode)
        -> longhands::min_block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_min_width()
        
        } else {
            
            self.clone_min_height()
        
        }

    }

                    
    /// Set the appropriate physical property for max-block-size given a writing mode.
    pub fn set_max_block_size(&mut self,
                                      v: longhands::max_block_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_max_width(v)
            
        } else {
            
                self.set_max_height(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-block-size
    /// given a writing mode.
    pub fn copy_max_block_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_max_width_from(other)
            
        } else {
            
                self.copy_max_height_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-block-size
    /// given a writing mode.
    pub fn reset_max_block_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_max_block_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// max-block-size given a writing mode.
    pub fn clone_max_block_size(&self, wm: WritingMode)
        -> longhands::max_block_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_max_width()
        
        } else {
            
            self.clone_max_height()
        
        }

    }

                    
    /// Set the appropriate physical property for inline-size given a writing mode.
    pub fn set_inline_size(&mut self,
                                      v: longhands::inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_height(v)
            
        } else {
            
                self.set_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for inline-size
    /// given a writing mode.
    pub fn copy_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_height_from(other)
            
        } else {
            
                self.copy_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for inline-size
    /// given a writing mode.
    pub fn reset_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// inline-size given a writing mode.
    pub fn clone_inline_size(&self, wm: WritingMode)
        -> longhands::inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_height()
        
        } else {
            
            self.clone_width()
        
        }

    }

                    
    /// Set the appropriate physical property for min-inline-size given a writing mode.
    pub fn set_min_inline_size(&mut self,
                                      v: longhands::min_inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_min_height(v)
            
        } else {
            
                self.set_min_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-inline-size
    /// given a writing mode.
    pub fn copy_min_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_min_height_from(other)
            
        } else {
            
                self.copy_min_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for min-inline-size
    /// given a writing mode.
    pub fn reset_min_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_min_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// min-inline-size given a writing mode.
    pub fn clone_min_inline_size(&self, wm: WritingMode)
        -> longhands::min_inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_min_height()
        
        } else {
            
            self.clone_min_width()
        
        }

    }

                    
    /// Set the appropriate physical property for max-inline-size given a writing mode.
    pub fn set_max_inline_size(&mut self,
                                      v: longhands::max_inline_size::computed_value::T,
                                      wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.set_max_height(v)
            
        } else {
            
                self.set_max_width(v)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-inline-size
    /// given a writing mode.
    pub fn copy_max_inline_size_from(&mut self,
                                            other: &Self,
                                            wm: WritingMode) {
        
    
        
        if wm.is_vertical() {
            
                self.copy_max_height_from(other)
            
        } else {
            
                self.copy_max_width_from(other)
            
        }

    }

    /// Copy the appropriate physical property from another struct for max-inline-size
    /// given a writing mode.
    pub fn reset_max_inline_size(&mut self,
                                        other: &Self,
                                        wm: WritingMode) {
        self.copy_max_inline_size_from(other, wm)
    }

    /// Get the computed value for the appropriate physical property for
    /// max-inline-size given a writing mode.
    pub fn clone_max_inline_size(&self, wm: WritingMode)
        -> longhands::max_inline_size::computed_value::T {
    
    
        
        if wm.is_vertical() {
            
            self.clone_max_height()
        
        } else {
            
            self.clone_max_width()
        
        }

    }

                        /// Set box-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_sizing(&mut self, v: longhands::box_sizing::computed_value::T) {
                            self.box_sizing = v;
                        }
                        /// Set box-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_sizing_from(&mut self, other: &Self) {
                            self.box_sizing = other.box_sizing.clone();
                        }
                    /// Reset box-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_sizing(&mut self, other: &Self) {
                        self.copy_box_sizing_from(other)
                    }

                    /// Get the computed value for box-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_sizing(&self) -> longhands::box_sizing::computed_value::T {
                        self.box_sizing.clone()
                    }
                        /// Set object-fit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_fit(&mut self, v: longhands::object_fit::computed_value::T) {
                            self.object_fit = v;
                        }
                        /// Set object-fit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_fit_from(&mut self, other: &Self) {
                            self.object_fit = other.object_fit.clone();
                        }
                    /// Reset object-fit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_fit(&mut self, other: &Self) {
                        self.copy_object_fit_from(other)
                    }

                    /// Get the computed value for object-fit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_fit(&self) -> longhands::object_fit::computed_value::T {
                        self.object_fit.clone()
                    }
                        /// Set object-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_position(&mut self, v: longhands::object_position::computed_value::T) {
                            self.object_position = v;
                        }
                        /// Set object-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_position_from(&mut self, other: &Self) {
                            self.object_position = other.object_position.clone();
                        }
                    /// Reset object-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_position(&mut self, other: &Self) {
                        self.copy_object_position_from(other)
                    }

                    /// Get the computed value for object-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_position(&self) -> longhands::object_position::computed_value::T {
                        self.object_position.clone()
                    }
                        /// Set grid-row-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_gap(&mut self, v: longhands::grid_row_gap::computed_value::T) {
                            self.grid_row_gap = v;
                        }
                        /// Set grid-row-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_gap_from(&mut self, other: &Self) {
                            self.grid_row_gap = other.grid_row_gap.clone();
                        }
                    /// Reset grid-row-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_gap(&mut self, other: &Self) {
                        self.copy_grid_row_gap_from(other)
                    }

                    /// Get the computed value for grid-row-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_gap(&self) -> longhands::grid_row_gap::computed_value::T {
                        self.grid_row_gap.clone()
                    }
                        /// Set grid-row-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_start(&mut self, v: longhands::grid_row_start::computed_value::T) {
                            self.grid_row_start = v;
                        }
                        /// Set grid-row-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_start_from(&mut self, other: &Self) {
                            self.grid_row_start = other.grid_row_start.clone();
                        }
                    /// Reset grid-row-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_start(&mut self, other: &Self) {
                        self.copy_grid_row_start_from(other)
                    }

                    /// Get the computed value for grid-row-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_start(&self) -> longhands::grid_row_start::computed_value::T {
                        self.grid_row_start.clone()
                    }
                        /// Set grid-row-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_end(&mut self, v: longhands::grid_row_end::computed_value::T) {
                            self.grid_row_end = v;
                        }
                        /// Set grid-row-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_end_from(&mut self, other: &Self) {
                            self.grid_row_end = other.grid_row_end.clone();
                        }
                    /// Reset grid-row-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_end(&mut self, other: &Self) {
                        self.copy_grid_row_end_from(other)
                    }

                    /// Get the computed value for grid-row-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_end(&self) -> longhands::grid_row_end::computed_value::T {
                        self.grid_row_end.clone()
                    }
                        /// Set grid-auto-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_rows(&mut self, v: longhands::grid_auto_rows::computed_value::T) {
                            self.grid_auto_rows = v;
                        }
                        /// Set grid-auto-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_rows_from(&mut self, other: &Self) {
                            self.grid_auto_rows = other.grid_auto_rows.clone();
                        }
                    /// Reset grid-auto-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_rows(&mut self, other: &Self) {
                        self.copy_grid_auto_rows_from(other)
                    }

                    /// Get the computed value for grid-auto-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_rows(&self) -> longhands::grid_auto_rows::computed_value::T {
                        self.grid_auto_rows.clone()
                    }
                        /// Set grid-template-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_rows(&mut self, v: longhands::grid_template_rows::computed_value::T) {
                            self.grid_template_rows = v;
                        }
                        /// Set grid-template-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_rows_from(&mut self, other: &Self) {
                            self.grid_template_rows = other.grid_template_rows.clone();
                        }
                    /// Reset grid-template-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_rows(&mut self, other: &Self) {
                        self.copy_grid_template_rows_from(other)
                    }

                    /// Get the computed value for grid-template-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_rows(&self) -> longhands::grid_template_rows::computed_value::T {
                        self.grid_template_rows.clone()
                    }
                        /// Set grid-column-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_gap(&mut self, v: longhands::grid_column_gap::computed_value::T) {
                            self.grid_column_gap = v;
                        }
                        /// Set grid-column-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_gap_from(&mut self, other: &Self) {
                            self.grid_column_gap = other.grid_column_gap.clone();
                        }
                    /// Reset grid-column-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_gap(&mut self, other: &Self) {
                        self.copy_grid_column_gap_from(other)
                    }

                    /// Get the computed value for grid-column-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_gap(&self) -> longhands::grid_column_gap::computed_value::T {
                        self.grid_column_gap.clone()
                    }
                        /// Set grid-column-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_start(&mut self, v: longhands::grid_column_start::computed_value::T) {
                            self.grid_column_start = v;
                        }
                        /// Set grid-column-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_start_from(&mut self, other: &Self) {
                            self.grid_column_start = other.grid_column_start.clone();
                        }
                    /// Reset grid-column-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_start(&mut self, other: &Self) {
                        self.copy_grid_column_start_from(other)
                    }

                    /// Get the computed value for grid-column-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_start(&self) -> longhands::grid_column_start::computed_value::T {
                        self.grid_column_start.clone()
                    }
                        /// Set grid-column-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_end(&mut self, v: longhands::grid_column_end::computed_value::T) {
                            self.grid_column_end = v;
                        }
                        /// Set grid-column-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_end_from(&mut self, other: &Self) {
                            self.grid_column_end = other.grid_column_end.clone();
                        }
                    /// Reset grid-column-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_end(&mut self, other: &Self) {
                        self.copy_grid_column_end_from(other)
                    }

                    /// Get the computed value for grid-column-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_end(&self) -> longhands::grid_column_end::computed_value::T {
                        self.grid_column_end.clone()
                    }
                        /// Set grid-auto-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_columns(&mut self, v: longhands::grid_auto_columns::computed_value::T) {
                            self.grid_auto_columns = v;
                        }
                        /// Set grid-auto-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_columns_from(&mut self, other: &Self) {
                            self.grid_auto_columns = other.grid_auto_columns.clone();
                        }
                    /// Reset grid-auto-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_columns(&mut self, other: &Self) {
                        self.copy_grid_auto_columns_from(other)
                    }

                    /// Get the computed value for grid-auto-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_columns(&self) -> longhands::grid_auto_columns::computed_value::T {
                        self.grid_auto_columns.clone()
                    }
                        /// Set grid-template-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_columns(&mut self, v: longhands::grid_template_columns::computed_value::T) {
                            self.grid_template_columns = v;
                        }
                        /// Set grid-template-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_columns_from(&mut self, other: &Self) {
                            self.grid_template_columns = other.grid_template_columns.clone();
                        }
                    /// Reset grid-template-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_columns(&mut self, other: &Self) {
                        self.copy_grid_template_columns_from(other)
                    }

                    /// Get the computed value for grid-template-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_columns(&self) -> longhands::grid_template_columns::computed_value::T {
                        self.grid_template_columns.clone()
                    }
                        /// Set grid-auto-flow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_flow(&mut self, v: longhands::grid_auto_flow::computed_value::T) {
                            self.grid_auto_flow = v;
                        }
                        /// Set grid-auto-flow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_flow_from(&mut self, other: &Self) {
                            self.grid_auto_flow = other.grid_auto_flow.clone();
                        }
                    /// Reset grid-auto-flow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_flow(&mut self, other: &Self) {
                        self.copy_grid_auto_flow_from(other)
                    }

                    /// Get the computed value for grid-auto-flow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_flow(&self) -> longhands::grid_auto_flow::computed_value::T {
                        self.grid_auto_flow.clone()
                    }
                        /// Set grid-template-areas.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_areas(&mut self, v: longhands::grid_template_areas::computed_value::T) {
                            self.grid_template_areas = v;
                        }
                        /// Set grid-template-areas from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_areas_from(&mut self, other: &Self) {
                            self.grid_template_areas = other.grid_template_areas.clone();
                        }
                    /// Reset grid-template-areas from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_areas(&mut self, other: &Self) {
                        self.copy_grid_template_areas_from(other)
                    }

                    /// Get the computed value for grid-template-areas.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_areas(&self) -> longhands::grid_template_areas::computed_value::T {
                        self.grid_template_areas.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Table style struct.
        pub struct Table {
                /// The table-layout computed value.
                pub table_layout: longhands::table_layout::computed_value::T,
                /// The -x-span computed value.
                pub _x_span: longhands::_x_span::computed_value::T,
        }

        impl Table {
                        /// Set table-layout.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_table_layout(&mut self, v: longhands::table_layout::computed_value::T) {
                            self.table_layout = v;
                        }
                        /// Set table-layout from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_table_layout_from(&mut self, other: &Self) {
                            self.table_layout = other.table_layout.clone();
                        }
                    /// Reset table-layout from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_table_layout(&mut self, other: &Self) {
                        self.copy_table_layout_from(other)
                    }

                    /// Get the computed value for table-layout.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_table_layout(&self) -> longhands::table_layout::computed_value::T {
                        self.table_layout.clone()
                    }
                        /// Set -x-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_span(&mut self, v: longhands::_x_span::computed_value::T) {
                            self._x_span = v;
                        }
                        /// Set -x-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_span_from(&mut self, other: &Self) {
                            self._x_span = other._x_span.clone();
                        }
                    /// Reset -x-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_span(&mut self, other: &Self) {
                        self.copy__x_span_from(other)
                    }

                    /// Get the computed value for -x-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_span(&self) -> longhands::_x_span::computed_value::T {
                        self._x_span.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Text style struct.
        pub struct Text {
                /// The text-overflow computed value.
                pub text_overflow: longhands::text_overflow::computed_value::T,
                /// The unicode-bidi computed value.
                pub unicode_bidi: longhands::unicode_bidi::computed_value::T,
                /// The text-decoration-line computed value.
                pub text_decoration_line: longhands::text_decoration_line::computed_value::T,
                /// The text-decoration-style computed value.
                pub text_decoration_style: longhands::text_decoration_style::computed_value::T,
                /// The text-decoration-color computed value.
                pub text_decoration_color: longhands::text_decoration_color::computed_value::T,
                /// The initial-letter computed value.
                pub initial_letter: longhands::initial_letter::computed_value::T,
        }

        impl Text {
                        /// Set text-overflow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_overflow(&mut self, v: longhands::text_overflow::computed_value::T) {
                            self.text_overflow = v;
                        }
                        /// Set text-overflow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_overflow_from(&mut self, other: &Self) {
                            self.text_overflow = other.text_overflow.clone();
                        }
                    /// Reset text-overflow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_overflow(&mut self, other: &Self) {
                        self.copy_text_overflow_from(other)
                    }

                    /// Get the computed value for text-overflow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_overflow(&self) -> longhands::text_overflow::computed_value::T {
                        self.text_overflow.clone()
                    }
                        /// Set unicode-bidi.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_unicode_bidi(&mut self, v: longhands::unicode_bidi::computed_value::T) {
                            self.unicode_bidi = v;
                        }
                        /// Set unicode-bidi from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_unicode_bidi_from(&mut self, other: &Self) {
                            self.unicode_bidi = other.unicode_bidi.clone();
                        }
                    /// Reset unicode-bidi from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_unicode_bidi(&mut self, other: &Self) {
                        self.copy_unicode_bidi_from(other)
                    }

                    /// Get the computed value for unicode-bidi.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_unicode_bidi(&self) -> longhands::unicode_bidi::computed_value::T {
                        self.unicode_bidi.clone()
                    }
                        /// Set text-decoration-line.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_line(&mut self, v: longhands::text_decoration_line::computed_value::T) {
                            self.text_decoration_line = v;
                        }
                        /// Set text-decoration-line from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_line_from(&mut self, other: &Self) {
                            self.text_decoration_line = other.text_decoration_line.clone();
                        }
                    /// Reset text-decoration-line from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_line(&mut self, other: &Self) {
                        self.copy_text_decoration_line_from(other)
                    }

                    /// Get the computed value for text-decoration-line.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_line(&self) -> longhands::text_decoration_line::computed_value::T {
                        self.text_decoration_line.clone()
                    }
                        /// Set text-decoration-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_style(&mut self, v: longhands::text_decoration_style::computed_value::T) {
                            self.text_decoration_style = v;
                        }
                        /// Set text-decoration-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_style_from(&mut self, other: &Self) {
                            self.text_decoration_style = other.text_decoration_style.clone();
                        }
                    /// Reset text-decoration-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_style(&mut self, other: &Self) {
                        self.copy_text_decoration_style_from(other)
                    }

                    /// Get the computed value for text-decoration-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_style(&self) -> longhands::text_decoration_style::computed_value::T {
                        self.text_decoration_style.clone()
                    }
                        /// Set text-decoration-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_color(&mut self, v: longhands::text_decoration_color::computed_value::T) {
                            self.text_decoration_color = v;
                        }
                        /// Set text-decoration-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_color_from(&mut self, other: &Self) {
                            self.text_decoration_color = other.text_decoration_color.clone();
                        }
                    /// Reset text-decoration-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_color(&mut self, other: &Self) {
                        self.copy_text_decoration_color_from(other)
                    }

                    /// Get the computed value for text-decoration-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_color(&self) -> longhands::text_decoration_color::computed_value::T {
                        self.text_decoration_color.clone()
                    }
                        /// Set initial-letter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_initial_letter(&mut self, v: longhands::initial_letter::computed_value::T) {
                            self.initial_letter = v;
                        }
                        /// Set initial-letter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_initial_letter_from(&mut self, other: &Self) {
                            self.initial_letter = other.initial_letter.clone();
                        }
                    /// Reset initial-letter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_initial_letter(&mut self, other: &Self) {
                        self.copy_initial_letter_from(other)
                    }

                    /// Get the computed value for initial-letter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_initial_letter(&self) -> longhands::initial_letter::computed_value::T {
                        self.initial_letter.clone()
                    }
                /// Whether the text decoration has an underline.
                #[inline]
                pub fn has_underline(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::UNDERLINE)
                }

                /// Whether the text decoration has an overline.
                #[inline]
                pub fn has_overline(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::OVERLINE)
                }

                /// Whether the text decoration has a line through.
                #[inline]
                pub fn has_line_through(&self) -> bool {
                    self.text_decoration_line.contains(longhands::text_decoration_line::SpecifiedValue::LINE_THROUGH)
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The UI style struct.
        pub struct UI {
                /// The ime-mode computed value.
                pub ime_mode: longhands::ime_mode::computed_value::T,
                /// The -moz-user-select computed value.
                pub _moz_user_select: longhands::_moz_user_select::computed_value::T,
                /// The -moz-window-dragging computed value.
                pub _moz_window_dragging: longhands::_moz_window_dragging::computed_value::T,
                /// The -moz-window-shadow computed value.
                pub _moz_window_shadow: longhands::_moz_window_shadow::computed_value::T,
                /// The -moz-window-opacity computed value.
                pub _moz_window_opacity: longhands::_moz_window_opacity::computed_value::T,
                /// The -moz-window-transform computed value.
                pub _moz_window_transform: longhands::_moz_window_transform::computed_value::T,
                /// The -moz-window-transform-origin computed value.
                pub _moz_window_transform_origin: longhands::_moz_window_transform_origin::computed_value::T,
                /// The -moz-force-broken-image-icon computed value.
                pub _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::computed_value::T,
        }

        impl UI {
                        /// Set ime-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ime_mode(&mut self, v: longhands::ime_mode::computed_value::T) {
                            self.ime_mode = v;
                        }
                        /// Set ime-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ime_mode_from(&mut self, other: &Self) {
                            self.ime_mode = other.ime_mode.clone();
                        }
                    /// Reset ime-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ime_mode(&mut self, other: &Self) {
                        self.copy_ime_mode_from(other)
                    }

                    /// Get the computed value for ime-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ime_mode(&self) -> longhands::ime_mode::computed_value::T {
                        self.ime_mode.clone()
                    }
                        /// Set -moz-user-select.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_select(&mut self, v: longhands::_moz_user_select::computed_value::T) {
                            self._moz_user_select = v;
                        }
                        /// Set -moz-user-select from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_select_from(&mut self, other: &Self) {
                            self._moz_user_select = other._moz_user_select.clone();
                        }
                    /// Reset -moz-user-select from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_select(&mut self, other: &Self) {
                        self.copy__moz_user_select_from(other)
                    }

                    /// Get the computed value for -moz-user-select.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_select(&self) -> longhands::_moz_user_select::computed_value::T {
                        self._moz_user_select.clone()
                    }
                        /// Set -moz-window-dragging.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_dragging(&mut self, v: longhands::_moz_window_dragging::computed_value::T) {
                            self._moz_window_dragging = v;
                        }
                        /// Set -moz-window-dragging from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_dragging_from(&mut self, other: &Self) {
                            self._moz_window_dragging = other._moz_window_dragging.clone();
                        }
                    /// Reset -moz-window-dragging from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_dragging(&mut self, other: &Self) {
                        self.copy__moz_window_dragging_from(other)
                    }

                    /// Get the computed value for -moz-window-dragging.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_dragging(&self) -> longhands::_moz_window_dragging::computed_value::T {
                        self._moz_window_dragging.clone()
                    }
                        /// Set -moz-window-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_shadow(&mut self, v: longhands::_moz_window_shadow::computed_value::T) {
                            self._moz_window_shadow = v;
                        }
                        /// Set -moz-window-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_shadow_from(&mut self, other: &Self) {
                            self._moz_window_shadow = other._moz_window_shadow.clone();
                        }
                    /// Reset -moz-window-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_shadow(&mut self, other: &Self) {
                        self.copy__moz_window_shadow_from(other)
                    }

                    /// Get the computed value for -moz-window-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_shadow(&self) -> longhands::_moz_window_shadow::computed_value::T {
                        self._moz_window_shadow.clone()
                    }
                        /// Set -moz-window-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_opacity(&mut self, v: longhands::_moz_window_opacity::computed_value::T) {
                            self._moz_window_opacity = v;
                        }
                        /// Set -moz-window-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_opacity_from(&mut self, other: &Self) {
                            self._moz_window_opacity = other._moz_window_opacity.clone();
                        }
                    /// Reset -moz-window-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_opacity(&mut self, other: &Self) {
                        self.copy__moz_window_opacity_from(other)
                    }

                    /// Get the computed value for -moz-window-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_opacity(&self) -> longhands::_moz_window_opacity::computed_value::T {
                        self._moz_window_opacity.clone()
                    }
                        /// Set -moz-window-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform(&mut self, v: longhands::_moz_window_transform::computed_value::T) {
                            self._moz_window_transform = v;
                        }
                        /// Set -moz-window-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_from(&mut self, other: &Self) {
                            self._moz_window_transform = other._moz_window_transform.clone();
                        }
                    /// Reset -moz-window-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform(&mut self, other: &Self) {
                        self.copy__moz_window_transform_from(other)
                    }

                    /// Get the computed value for -moz-window-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform(&self) -> longhands::_moz_window_transform::computed_value::T {
                        self._moz_window_transform.clone()
                    }
                        /// Set -moz-window-transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform_origin(&mut self, v: longhands::_moz_window_transform_origin::computed_value::T) {
                            self._moz_window_transform_origin = v;
                        }
                        /// Set -moz-window-transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_origin_from(&mut self, other: &Self) {
                            self._moz_window_transform_origin = other._moz_window_transform_origin.clone();
                        }
                    /// Reset -moz-window-transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform_origin(&mut self, other: &Self) {
                        self.copy__moz_window_transform_origin_from(other)
                    }

                    /// Get the computed value for -moz-window-transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform_origin(&self) -> longhands::_moz_window_transform_origin::computed_value::T {
                        self._moz_window_transform_origin.clone()
                    }
                        /// Set -moz-force-broken-image-icon.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_force_broken_image_icon(&mut self, v: longhands::_moz_force_broken_image_icon::computed_value::T) {
                            self._moz_force_broken_image_icon = v;
                        }
                        /// Set -moz-force-broken-image-icon from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_force_broken_image_icon_from(&mut self, other: &Self) {
                            self._moz_force_broken_image_icon = other._moz_force_broken_image_icon.clone();
                        }
                    /// Reset -moz-force-broken-image-icon from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_force_broken_image_icon(&mut self, other: &Self) {
                        self.copy__moz_force_broken_image_icon_from(other)
                    }

                    /// Get the computed value for -moz-force-broken-image-icon.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_force_broken_image_icon(&self) -> longhands::_moz_force_broken_image_icon::computed_value::T {
                        self._moz_force_broken_image_icon.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedSVG style struct.
        pub struct InheritedSVG {
                /// The text-anchor computed value.
                pub text_anchor: longhands::text_anchor::computed_value::T,
                /// The color-interpolation computed value.
                pub color_interpolation: longhands::color_interpolation::computed_value::T,
                /// The color-interpolation-filters computed value.
                pub color_interpolation_filters: longhands::color_interpolation_filters::computed_value::T,
                /// The fill computed value.
                pub fill: longhands::fill::computed_value::T,
                /// The fill-opacity computed value.
                pub fill_opacity: longhands::fill_opacity::computed_value::T,
                /// The fill-rule computed value.
                pub fill_rule: longhands::fill_rule::computed_value::T,
                /// The shape-rendering computed value.
                pub shape_rendering: longhands::shape_rendering::computed_value::T,
                /// The stroke computed value.
                pub stroke: longhands::stroke::computed_value::T,
                /// The stroke-width computed value.
                pub stroke_width: longhands::stroke_width::computed_value::T,
                /// The stroke-linecap computed value.
                pub stroke_linecap: longhands::stroke_linecap::computed_value::T,
                /// The stroke-linejoin computed value.
                pub stroke_linejoin: longhands::stroke_linejoin::computed_value::T,
                /// The stroke-miterlimit computed value.
                pub stroke_miterlimit: longhands::stroke_miterlimit::computed_value::T,
                /// The stroke-opacity computed value.
                pub stroke_opacity: longhands::stroke_opacity::computed_value::T,
                /// The stroke-dasharray computed value.
                pub stroke_dasharray: longhands::stroke_dasharray::computed_value::T,
                /// The stroke-dashoffset computed value.
                pub stroke_dashoffset: longhands::stroke_dashoffset::computed_value::T,
                /// The clip-rule computed value.
                pub clip_rule: longhands::clip_rule::computed_value::T,
                /// The marker-start computed value.
                pub marker_start: longhands::marker_start::computed_value::T,
                /// The marker-mid computed value.
                pub marker_mid: longhands::marker_mid::computed_value::T,
                /// The marker-end computed value.
                pub marker_end: longhands::marker_end::computed_value::T,
                /// The paint-order computed value.
                pub paint_order: longhands::paint_order::computed_value::T,
                /// The -moz-context-properties computed value.
                pub _moz_context_properties: longhands::_moz_context_properties::computed_value::T,
        }

        impl InheritedSVG {
                        /// Set text-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_anchor(&mut self, v: longhands::text_anchor::computed_value::T) {
                            self.text_anchor = v;
                        }
                        /// Set text-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_anchor_from(&mut self, other: &Self) {
                            self.text_anchor = other.text_anchor.clone();
                        }
                    /// Reset text-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_anchor(&mut self, other: &Self) {
                        self.copy_text_anchor_from(other)
                    }

                    /// Get the computed value for text-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_anchor(&self) -> longhands::text_anchor::computed_value::T {
                        self.text_anchor.clone()
                    }
                        /// Set color-interpolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation(&mut self, v: longhands::color_interpolation::computed_value::T) {
                            self.color_interpolation = v;
                        }
                        /// Set color-interpolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_from(&mut self, other: &Self) {
                            self.color_interpolation = other.color_interpolation.clone();
                        }
                    /// Reset color-interpolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation(&mut self, other: &Self) {
                        self.copy_color_interpolation_from(other)
                    }

                    /// Get the computed value for color-interpolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation(&self) -> longhands::color_interpolation::computed_value::T {
                        self.color_interpolation.clone()
                    }
                        /// Set color-interpolation-filters.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation_filters(&mut self, v: longhands::color_interpolation_filters::computed_value::T) {
                            self.color_interpolation_filters = v;
                        }
                        /// Set color-interpolation-filters from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_filters_from(&mut self, other: &Self) {
                            self.color_interpolation_filters = other.color_interpolation_filters.clone();
                        }
                    /// Reset color-interpolation-filters from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation_filters(&mut self, other: &Self) {
                        self.copy_color_interpolation_filters_from(other)
                    }

                    /// Get the computed value for color-interpolation-filters.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation_filters(&self) -> longhands::color_interpolation_filters::computed_value::T {
                        self.color_interpolation_filters.clone()
                    }
                        /// Set fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill(&mut self, v: longhands::fill::computed_value::T) {
                            self.fill = v;
                        }
                        /// Set fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_from(&mut self, other: &Self) {
                            self.fill = other.fill.clone();
                        }
                    /// Reset fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill(&mut self, other: &Self) {
                        self.copy_fill_from(other)
                    }

                    /// Get the computed value for fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill(&self) -> longhands::fill::computed_value::T {
                        self.fill.clone()
                    }
                        /// Set fill-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_opacity(&mut self, v: longhands::fill_opacity::computed_value::T) {
                            self.fill_opacity = v;
                        }
                        /// Set fill-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_opacity_from(&mut self, other: &Self) {
                            self.fill_opacity = other.fill_opacity.clone();
                        }
                    /// Reset fill-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_opacity(&mut self, other: &Self) {
                        self.copy_fill_opacity_from(other)
                    }

                    /// Get the computed value for fill-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_opacity(&self) -> longhands::fill_opacity::computed_value::T {
                        self.fill_opacity.clone()
                    }
                        /// Set fill-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_rule(&mut self, v: longhands::fill_rule::computed_value::T) {
                            self.fill_rule = v;
                        }
                        /// Set fill-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_rule_from(&mut self, other: &Self) {
                            self.fill_rule = other.fill_rule.clone();
                        }
                    /// Reset fill-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_rule(&mut self, other: &Self) {
                        self.copy_fill_rule_from(other)
                    }

                    /// Get the computed value for fill-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_rule(&self) -> longhands::fill_rule::computed_value::T {
                        self.fill_rule.clone()
                    }
                        /// Set shape-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_rendering(&mut self, v: longhands::shape_rendering::computed_value::T) {
                            self.shape_rendering = v;
                        }
                        /// Set shape-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_rendering_from(&mut self, other: &Self) {
                            self.shape_rendering = other.shape_rendering.clone();
                        }
                    /// Reset shape-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_rendering(&mut self, other: &Self) {
                        self.copy_shape_rendering_from(other)
                    }

                    /// Get the computed value for shape-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_rendering(&self) -> longhands::shape_rendering::computed_value::T {
                        self.shape_rendering.clone()
                    }
                        /// Set stroke.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke(&mut self, v: longhands::stroke::computed_value::T) {
                            self.stroke = v;
                        }
                        /// Set stroke from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_from(&mut self, other: &Self) {
                            self.stroke = other.stroke.clone();
                        }
                    /// Reset stroke from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke(&mut self, other: &Self) {
                        self.copy_stroke_from(other)
                    }

                    /// Get the computed value for stroke.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke(&self) -> longhands::stroke::computed_value::T {
                        self.stroke.clone()
                    }
                        /// Set stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_width(&mut self, v: longhands::stroke_width::computed_value::T) {
                            self.stroke_width = v;
                        }
                        /// Set stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_width_from(&mut self, other: &Self) {
                            self.stroke_width = other.stroke_width.clone();
                        }
                    /// Reset stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_width(&mut self, other: &Self) {
                        self.copy_stroke_width_from(other)
                    }

                    /// Get the computed value for stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_width(&self) -> longhands::stroke_width::computed_value::T {
                        self.stroke_width.clone()
                    }
                        /// Set stroke-linecap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linecap(&mut self, v: longhands::stroke_linecap::computed_value::T) {
                            self.stroke_linecap = v;
                        }
                        /// Set stroke-linecap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linecap_from(&mut self, other: &Self) {
                            self.stroke_linecap = other.stroke_linecap.clone();
                        }
                    /// Reset stroke-linecap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linecap(&mut self, other: &Self) {
                        self.copy_stroke_linecap_from(other)
                    }

                    /// Get the computed value for stroke-linecap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linecap(&self) -> longhands::stroke_linecap::computed_value::T {
                        self.stroke_linecap.clone()
                    }
                        /// Set stroke-linejoin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linejoin(&mut self, v: longhands::stroke_linejoin::computed_value::T) {
                            self.stroke_linejoin = v;
                        }
                        /// Set stroke-linejoin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linejoin_from(&mut self, other: &Self) {
                            self.stroke_linejoin = other.stroke_linejoin.clone();
                        }
                    /// Reset stroke-linejoin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linejoin(&mut self, other: &Self) {
                        self.copy_stroke_linejoin_from(other)
                    }

                    /// Get the computed value for stroke-linejoin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linejoin(&self) -> longhands::stroke_linejoin::computed_value::T {
                        self.stroke_linejoin.clone()
                    }
                        /// Set stroke-miterlimit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_miterlimit(&mut self, v: longhands::stroke_miterlimit::computed_value::T) {
                            self.stroke_miterlimit = v;
                        }
                        /// Set stroke-miterlimit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_miterlimit_from(&mut self, other: &Self) {
                            self.stroke_miterlimit = other.stroke_miterlimit.clone();
                        }
                    /// Reset stroke-miterlimit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_miterlimit(&mut self, other: &Self) {
                        self.copy_stroke_miterlimit_from(other)
                    }

                    /// Get the computed value for stroke-miterlimit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_miterlimit(&self) -> longhands::stroke_miterlimit::computed_value::T {
                        self.stroke_miterlimit.clone()
                    }
                        /// Set stroke-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_opacity(&mut self, v: longhands::stroke_opacity::computed_value::T) {
                            self.stroke_opacity = v;
                        }
                        /// Set stroke-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_opacity_from(&mut self, other: &Self) {
                            self.stroke_opacity = other.stroke_opacity.clone();
                        }
                    /// Reset stroke-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_opacity(&mut self, other: &Self) {
                        self.copy_stroke_opacity_from(other)
                    }

                    /// Get the computed value for stroke-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_opacity(&self) -> longhands::stroke_opacity::computed_value::T {
                        self.stroke_opacity.clone()
                    }
                        /// Set stroke-dasharray.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dasharray(&mut self, v: longhands::stroke_dasharray::computed_value::T) {
                            self.stroke_dasharray = v;
                        }
                        /// Set stroke-dasharray from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dasharray_from(&mut self, other: &Self) {
                            self.stroke_dasharray = other.stroke_dasharray.clone();
                        }
                    /// Reset stroke-dasharray from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dasharray(&mut self, other: &Self) {
                        self.copy_stroke_dasharray_from(other)
                    }

                    /// Get the computed value for stroke-dasharray.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dasharray(&self) -> longhands::stroke_dasharray::computed_value::T {
                        self.stroke_dasharray.clone()
                    }
                        /// Set stroke-dashoffset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dashoffset(&mut self, v: longhands::stroke_dashoffset::computed_value::T) {
                            self.stroke_dashoffset = v;
                        }
                        /// Set stroke-dashoffset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dashoffset_from(&mut self, other: &Self) {
                            self.stroke_dashoffset = other.stroke_dashoffset.clone();
                        }
                    /// Reset stroke-dashoffset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dashoffset(&mut self, other: &Self) {
                        self.copy_stroke_dashoffset_from(other)
                    }

                    /// Get the computed value for stroke-dashoffset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dashoffset(&self) -> longhands::stroke_dashoffset::computed_value::T {
                        self.stroke_dashoffset.clone()
                    }
                        /// Set clip-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_rule(&mut self, v: longhands::clip_rule::computed_value::T) {
                            self.clip_rule = v;
                        }
                        /// Set clip-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_rule_from(&mut self, other: &Self) {
                            self.clip_rule = other.clip_rule.clone();
                        }
                    /// Reset clip-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_rule(&mut self, other: &Self) {
                        self.copy_clip_rule_from(other)
                    }

                    /// Get the computed value for clip-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_rule(&self) -> longhands::clip_rule::computed_value::T {
                        self.clip_rule.clone()
                    }
                        /// Set marker-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_start(&mut self, v: longhands::marker_start::computed_value::T) {
                            self.marker_start = v;
                        }
                        /// Set marker-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_start_from(&mut self, other: &Self) {
                            self.marker_start = other.marker_start.clone();
                        }
                    /// Reset marker-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_start(&mut self, other: &Self) {
                        self.copy_marker_start_from(other)
                    }

                    /// Get the computed value for marker-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_start(&self) -> longhands::marker_start::computed_value::T {
                        self.marker_start.clone()
                    }
                        /// Set marker-mid.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_mid(&mut self, v: longhands::marker_mid::computed_value::T) {
                            self.marker_mid = v;
                        }
                        /// Set marker-mid from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_mid_from(&mut self, other: &Self) {
                            self.marker_mid = other.marker_mid.clone();
                        }
                    /// Reset marker-mid from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_mid(&mut self, other: &Self) {
                        self.copy_marker_mid_from(other)
                    }

                    /// Get the computed value for marker-mid.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_mid(&self) -> longhands::marker_mid::computed_value::T {
                        self.marker_mid.clone()
                    }
                        /// Set marker-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_end(&mut self, v: longhands::marker_end::computed_value::T) {
                            self.marker_end = v;
                        }
                        /// Set marker-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_end_from(&mut self, other: &Self) {
                            self.marker_end = other.marker_end.clone();
                        }
                    /// Reset marker-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_end(&mut self, other: &Self) {
                        self.copy_marker_end_from(other)
                    }

                    /// Get the computed value for marker-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_end(&self) -> longhands::marker_end::computed_value::T {
                        self.marker_end.clone()
                    }
                        /// Set paint-order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_paint_order(&mut self, v: longhands::paint_order::computed_value::T) {
                            self.paint_order = v;
                        }
                        /// Set paint-order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_paint_order_from(&mut self, other: &Self) {
                            self.paint_order = other.paint_order.clone();
                        }
                    /// Reset paint-order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_paint_order(&mut self, other: &Self) {
                        self.copy_paint_order_from(other)
                    }

                    /// Get the computed value for paint-order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_paint_order(&self) -> longhands::paint_order::computed_value::T {
                        self.paint_order.clone()
                    }
                        /// Set -moz-context-properties.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_context_properties<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::_moz_context_properties
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self._moz_context_properties = longhands::_moz_context_properties::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set -moz-context-properties from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_context_properties_from(&mut self, other: &Self) {
                            self._moz_context_properties = other._moz_context_properties.clone();
                        }
                    /// Reset -moz-context-properties from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_context_properties(&mut self, other: &Self) {
                        self.copy__moz_context_properties_from(other)
                    }

                    /// Get the computed value for -moz-context-properties.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_context_properties(&self) -> longhands::_moz_context_properties::computed_value::T {
                        self._moz_context_properties.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The SVG style struct.
        pub struct SVG {
                /// The dominant-baseline computed value.
                pub dominant_baseline: longhands::dominant_baseline::computed_value::T,
                /// The vector-effect computed value.
                pub vector_effect: longhands::vector_effect::computed_value::T,
                /// The stop-color computed value.
                pub stop_color: longhands::stop_color::computed_value::T,
                /// The stop-opacity computed value.
                pub stop_opacity: longhands::stop_opacity::computed_value::T,
                /// The flood-color computed value.
                pub flood_color: longhands::flood_color::computed_value::T,
                /// The flood-opacity computed value.
                pub flood_opacity: longhands::flood_opacity::computed_value::T,
                /// The lighting-color computed value.
                pub lighting_color: longhands::lighting_color::computed_value::T,
                /// The mask-type computed value.
                pub mask_type: longhands::mask_type::computed_value::T,
                /// The clip-path computed value.
                pub clip_path: longhands::clip_path::computed_value::T,
                /// The mask-mode computed value.
                pub mask_mode: longhands::mask_mode::computed_value::T,
                /// The mask-repeat computed value.
                pub mask_repeat: longhands::mask_repeat::computed_value::T,
                /// The mask-position-x computed value.
                pub mask_position_x: longhands::mask_position_x::computed_value::T,
                /// The mask-position-y computed value.
                pub mask_position_y: longhands::mask_position_y::computed_value::T,
                /// The mask-clip computed value.
                pub mask_clip: longhands::mask_clip::computed_value::T,
                /// The mask-origin computed value.
                pub mask_origin: longhands::mask_origin::computed_value::T,
                /// The mask-size computed value.
                pub mask_size: longhands::mask_size::computed_value::T,
                /// The mask-composite computed value.
                pub mask_composite: longhands::mask_composite::computed_value::T,
                /// The mask-image computed value.
                pub mask_image: longhands::mask_image::computed_value::T,
        }

        impl SVG {
                        /// Set dominant-baseline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_dominant_baseline(&mut self, v: longhands::dominant_baseline::computed_value::T) {
                            self.dominant_baseline = v;
                        }
                        /// Set dominant-baseline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_dominant_baseline_from(&mut self, other: &Self) {
                            self.dominant_baseline = other.dominant_baseline.clone();
                        }
                    /// Reset dominant-baseline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_dominant_baseline(&mut self, other: &Self) {
                        self.copy_dominant_baseline_from(other)
                    }

                    /// Get the computed value for dominant-baseline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_dominant_baseline(&self) -> longhands::dominant_baseline::computed_value::T {
                        self.dominant_baseline.clone()
                    }
                        /// Set vector-effect.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vector_effect(&mut self, v: longhands::vector_effect::computed_value::T) {
                            self.vector_effect = v;
                        }
                        /// Set vector-effect from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vector_effect_from(&mut self, other: &Self) {
                            self.vector_effect = other.vector_effect.clone();
                        }
                    /// Reset vector-effect from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vector_effect(&mut self, other: &Self) {
                        self.copy_vector_effect_from(other)
                    }

                    /// Get the computed value for vector-effect.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vector_effect(&self) -> longhands::vector_effect::computed_value::T {
                        self.vector_effect.clone()
                    }
                        /// Set stop-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_color(&mut self, v: longhands::stop_color::computed_value::T) {
                            self.stop_color = v;
                        }
                        /// Set stop-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_color_from(&mut self, other: &Self) {
                            self.stop_color = other.stop_color.clone();
                        }
                    /// Reset stop-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_color(&mut self, other: &Self) {
                        self.copy_stop_color_from(other)
                    }

                    /// Get the computed value for stop-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_color(&self) -> longhands::stop_color::computed_value::T {
                        self.stop_color.clone()
                    }
                        /// Set stop-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_opacity(&mut self, v: longhands::stop_opacity::computed_value::T) {
                            self.stop_opacity = v;
                        }
                        /// Set stop-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_opacity_from(&mut self, other: &Self) {
                            self.stop_opacity = other.stop_opacity.clone();
                        }
                    /// Reset stop-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_opacity(&mut self, other: &Self) {
                        self.copy_stop_opacity_from(other)
                    }

                    /// Get the computed value for stop-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_opacity(&self) -> longhands::stop_opacity::computed_value::T {
                        self.stop_opacity.clone()
                    }
                        /// Set flood-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_color(&mut self, v: longhands::flood_color::computed_value::T) {
                            self.flood_color = v;
                        }
                        /// Set flood-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_color_from(&mut self, other: &Self) {
                            self.flood_color = other.flood_color.clone();
                        }
                    /// Reset flood-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_color(&mut self, other: &Self) {
                        self.copy_flood_color_from(other)
                    }

                    /// Get the computed value for flood-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_color(&self) -> longhands::flood_color::computed_value::T {
                        self.flood_color.clone()
                    }
                        /// Set flood-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_opacity(&mut self, v: longhands::flood_opacity::computed_value::T) {
                            self.flood_opacity = v;
                        }
                        /// Set flood-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_opacity_from(&mut self, other: &Self) {
                            self.flood_opacity = other.flood_opacity.clone();
                        }
                    /// Reset flood-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_opacity(&mut self, other: &Self) {
                        self.copy_flood_opacity_from(other)
                    }

                    /// Get the computed value for flood-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_opacity(&self) -> longhands::flood_opacity::computed_value::T {
                        self.flood_opacity.clone()
                    }
                        /// Set lighting-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_lighting_color(&mut self, v: longhands::lighting_color::computed_value::T) {
                            self.lighting_color = v;
                        }
                        /// Set lighting-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_lighting_color_from(&mut self, other: &Self) {
                            self.lighting_color = other.lighting_color.clone();
                        }
                    /// Reset lighting-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_lighting_color(&mut self, other: &Self) {
                        self.copy_lighting_color_from(other)
                    }

                    /// Get the computed value for lighting-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_lighting_color(&self) -> longhands::lighting_color::computed_value::T {
                        self.lighting_color.clone()
                    }
                        /// Set mask-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_type(&mut self, v: longhands::mask_type::computed_value::T) {
                            self.mask_type = v;
                        }
                        /// Set mask-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_type_from(&mut self, other: &Self) {
                            self.mask_type = other.mask_type.clone();
                        }
                    /// Reset mask-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_type(&mut self, other: &Self) {
                        self.copy_mask_type_from(other)
                    }

                    /// Get the computed value for mask-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_type(&self) -> longhands::mask_type::computed_value::T {
                        self.mask_type.clone()
                    }
                        /// Set clip-path.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_path(&mut self, v: longhands::clip_path::computed_value::T) {
                            self.clip_path = v;
                        }
                        /// Set clip-path from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_path_from(&mut self, other: &Self) {
                            self.clip_path = other.clip_path.clone();
                        }
                    /// Reset clip-path from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_path(&mut self, other: &Self) {
                        self.copy_clip_path_from(other)
                    }

                    /// Get the computed value for clip-path.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_path(&self) -> longhands::clip_path::computed_value::T {
                        self.clip_path.clone()
                    }
                        /// Set mask-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_mode<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_mode
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_mode = longhands::mask_mode::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_mode_from(&mut self, other: &Self) {
                            self.mask_mode = other.mask_mode.clone();
                        }
                    /// Reset mask-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_mode(&mut self, other: &Self) {
                        self.copy_mask_mode_from(other)
                    }

                    /// Get the computed value for mask-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_mode(&self) -> longhands::mask_mode::computed_value::T {
                        self.mask_mode.clone()
                    }
                        /// Set mask-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_repeat<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_repeat
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_repeat = longhands::mask_repeat::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_repeat_from(&mut self, other: &Self) {
                            self.mask_repeat = other.mask_repeat.clone();
                        }
                    /// Reset mask-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_repeat(&mut self, other: &Self) {
                        self.copy_mask_repeat_from(other)
                    }

                    /// Get the computed value for mask-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_repeat(&self) -> longhands::mask_repeat::computed_value::T {
                        self.mask_repeat.clone()
                    }
                        /// Set mask-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_x<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_position_x
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_position_x = longhands::mask_position_x::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_x_from(&mut self, other: &Self) {
                            self.mask_position_x = other.mask_position_x.clone();
                        }
                    /// Reset mask-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_x(&mut self, other: &Self) {
                        self.copy_mask_position_x_from(other)
                    }

                    /// Get the computed value for mask-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_x(&self) -> longhands::mask_position_x::computed_value::T {
                        self.mask_position_x.clone()
                    }
                        /// Set mask-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_y<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_position_y
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_position_y = longhands::mask_position_y::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_y_from(&mut self, other: &Self) {
                            self.mask_position_y = other.mask_position_y.clone();
                        }
                    /// Reset mask-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_y(&mut self, other: &Self) {
                        self.copy_mask_position_y_from(other)
                    }

                    /// Get the computed value for mask-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_y(&self) -> longhands::mask_position_y::computed_value::T {
                        self.mask_position_y.clone()
                    }
                        /// Set mask-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_clip<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_clip
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_clip = longhands::mask_clip::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_clip_from(&mut self, other: &Self) {
                            self.mask_clip = other.mask_clip.clone();
                        }
                    /// Reset mask-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_clip(&mut self, other: &Self) {
                        self.copy_mask_clip_from(other)
                    }

                    /// Get the computed value for mask-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_clip(&self) -> longhands::mask_clip::computed_value::T {
                        self.mask_clip.clone()
                    }
                        /// Set mask-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_origin<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_origin
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_origin = longhands::mask_origin::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_origin_from(&mut self, other: &Self) {
                            self.mask_origin = other.mask_origin.clone();
                        }
                    /// Reset mask-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_origin(&mut self, other: &Self) {
                        self.copy_mask_origin_from(other)
                    }

                    /// Get the computed value for mask-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_origin(&self) -> longhands::mask_origin::computed_value::T {
                        self.mask_origin.clone()
                    }
                        /// Set mask-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_size(&mut self, v: longhands::mask_size::computed_value::T) {
                            self.mask_size = v;
                        }
                        /// Set mask-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_size_from(&mut self, other: &Self) {
                            self.mask_size = other.mask_size.clone();
                        }
                    /// Reset mask-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_size(&mut self, other: &Self) {
                        self.copy_mask_size_from(other)
                    }

                    /// Get the computed value for mask-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_size(&self) -> longhands::mask_size::computed_value::T {
                        self.mask_size.clone()
                    }
                        /// Set mask-composite.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_composite<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_composite
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_composite = longhands::mask_composite::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-composite from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_composite_from(&mut self, other: &Self) {
                            self.mask_composite = other.mask_composite.clone();
                        }
                    /// Reset mask-composite from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_composite(&mut self, other: &Self) {
                        self.copy_mask_composite_from(other)
                    }

                    /// Get the computed value for mask-composite.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_composite(&self) -> longhands::mask_composite::computed_value::T {
                        self.mask_composite.clone()
                    }
                        /// Set mask-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_image<I>(&mut self, v: I)
                            where I: IntoIterator<Item = longhands::mask_image
                                                                  ::computed_value::single_value::T>,
                                  I::IntoIter: ExactSizeIterator
                        {
                            self.mask_image = longhands::mask_image::computed_value
                                                              ::T(v.into_iter().collect());
                        }
                        /// Set mask-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_image_from(&mut self, other: &Self) {
                            self.mask_image = other.mask_image.clone();
                        }
                    /// Reset mask-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_image(&mut self, other: &Self) {
                        self.copy_mask_image_from(other)
                    }

                    /// Get the computed value for mask-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_image(&self) -> longhands::mask_image::computed_value::T {
                        self.mask_image.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The XUL style struct.
        pub struct XUL {
                /// The -moz-box-align computed value.
                pub _moz_box_align: longhands::_moz_box_align::computed_value::T,
                /// The -moz-box-direction computed value.
                pub _moz_box_direction: longhands::_moz_box_direction::computed_value::T,
                /// The -moz-box-flex computed value.
                pub _moz_box_flex: longhands::_moz_box_flex::computed_value::T,
                /// The -moz-box-orient computed value.
                pub _moz_box_orient: longhands::_moz_box_orient::computed_value::T,
                /// The -moz-box-pack computed value.
                pub _moz_box_pack: longhands::_moz_box_pack::computed_value::T,
                /// The -moz-stack-sizing computed value.
                pub _moz_stack_sizing: longhands::_moz_stack_sizing::computed_value::T,
                /// The -moz-box-ordinal-group computed value.
                pub _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::computed_value::T,
        }

        impl XUL {
                        /// Set -moz-box-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_align(&mut self, v: longhands::_moz_box_align::computed_value::T) {
                            self._moz_box_align = v;
                        }
                        /// Set -moz-box-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_align_from(&mut self, other: &Self) {
                            self._moz_box_align = other._moz_box_align.clone();
                        }
                    /// Reset -moz-box-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_align(&mut self, other: &Self) {
                        self.copy__moz_box_align_from(other)
                    }

                    /// Get the computed value for -moz-box-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_align(&self) -> longhands::_moz_box_align::computed_value::T {
                        self._moz_box_align.clone()
                    }
                        /// Set -moz-box-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_direction(&mut self, v: longhands::_moz_box_direction::computed_value::T) {
                            self._moz_box_direction = v;
                        }
                        /// Set -moz-box-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_direction_from(&mut self, other: &Self) {
                            self._moz_box_direction = other._moz_box_direction.clone();
                        }
                    /// Reset -moz-box-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_direction(&mut self, other: &Self) {
                        self.copy__moz_box_direction_from(other)
                    }

                    /// Get the computed value for -moz-box-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_direction(&self) -> longhands::_moz_box_direction::computed_value::T {
                        self._moz_box_direction.clone()
                    }
                        /// Set -moz-box-flex.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_flex(&mut self, v: longhands::_moz_box_flex::computed_value::T) {
                            self._moz_box_flex = v;
                        }
                        /// Set -moz-box-flex from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_flex_from(&mut self, other: &Self) {
                            self._moz_box_flex = other._moz_box_flex.clone();
                        }
                    /// Reset -moz-box-flex from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_flex(&mut self, other: &Self) {
                        self.copy__moz_box_flex_from(other)
                    }

                    /// Get the computed value for -moz-box-flex.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_flex(&self) -> longhands::_moz_box_flex::computed_value::T {
                        self._moz_box_flex.clone()
                    }
                        /// Set -moz-box-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_orient(&mut self, v: longhands::_moz_box_orient::computed_value::T) {
                            self._moz_box_orient = v;
                        }
                        /// Set -moz-box-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_orient_from(&mut self, other: &Self) {
                            self._moz_box_orient = other._moz_box_orient.clone();
                        }
                    /// Reset -moz-box-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_orient(&mut self, other: &Self) {
                        self.copy__moz_box_orient_from(other)
                    }

                    /// Get the computed value for -moz-box-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_orient(&self) -> longhands::_moz_box_orient::computed_value::T {
                        self._moz_box_orient.clone()
                    }
                        /// Set -moz-box-pack.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_pack(&mut self, v: longhands::_moz_box_pack::computed_value::T) {
                            self._moz_box_pack = v;
                        }
                        /// Set -moz-box-pack from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_pack_from(&mut self, other: &Self) {
                            self._moz_box_pack = other._moz_box_pack.clone();
                        }
                    /// Reset -moz-box-pack from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_pack(&mut self, other: &Self) {
                        self.copy__moz_box_pack_from(other)
                    }

                    /// Get the computed value for -moz-box-pack.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_pack(&self) -> longhands::_moz_box_pack::computed_value::T {
                        self._moz_box_pack.clone()
                    }
                        /// Set -moz-stack-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_stack_sizing(&mut self, v: longhands::_moz_stack_sizing::computed_value::T) {
                            self._moz_stack_sizing = v;
                        }
                        /// Set -moz-stack-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_stack_sizing_from(&mut self, other: &Self) {
                            self._moz_stack_sizing = other._moz_stack_sizing.clone();
                        }
                    /// Reset -moz-stack-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_stack_sizing(&mut self, other: &Self) {
                        self.copy__moz_stack_sizing_from(other)
                    }

                    /// Get the computed value for -moz-stack-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_stack_sizing(&self) -> longhands::_moz_stack_sizing::computed_value::T {
                        self._moz_stack_sizing.clone()
                    }
                        /// Set -moz-box-ordinal-group.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_ordinal_group(&mut self, v: longhands::_moz_box_ordinal_group::computed_value::T) {
                            self._moz_box_ordinal_group = v;
                        }
                        /// Set -moz-box-ordinal-group from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_ordinal_group_from(&mut self, other: &Self) {
                            self._moz_box_ordinal_group = other._moz_box_ordinal_group.clone();
                        }
                    /// Reset -moz-box-ordinal-group from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_ordinal_group(&mut self, other: &Self) {
                        self.copy__moz_box_ordinal_group_from(other)
                    }

                    /// Get the computed value for -moz-box-ordinal-group.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_ordinal_group(&self) -> longhands::_moz_box_ordinal_group::computed_value::T {
                        self._moz_box_ordinal_group.clone()
                    }
        }

}

    impl style_structs::Background {

    }

    impl style_structs::Border {

    }

    impl style_structs::Box {
                /// Iterate over the values of transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_iter(&self) -> TransitionDurationIter {
                    TransitionDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_mod(&self, index: usize)
                    -> longhands::transition_duration::computed_value::SingleComputedValue {
                    self.transition_duration_at(index % self.transition_duration_count())
                }
                /// Iterate over the values of transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_iter(&self) -> TransitionTimingFunctionIter {
                    TransitionTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_mod(&self, index: usize)
                    -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                    self.transition_timing_function_at(index % self.transition_timing_function_count())
                }
                /// Iterate over the values of transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_iter(&self) -> TransitionPropertyIter {
                    TransitionPropertyIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_property_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_mod(&self, index: usize)
                    -> longhands::transition_property::computed_value::SingleComputedValue {
                    self.transition_property_at(index % self.transition_property_count())
                }
                /// Iterate over the values of transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_iter(&self) -> TransitionDelayIter {
                    TransitionDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_mod(&self, index: usize)
                    -> longhands::transition_delay::computed_value::SingleComputedValue {
                    self.transition_delay_at(index % self.transition_delay_count())
                }
                /// Iterate over the values of animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_iter(&self) -> AnimationNameIter {
                    AnimationNameIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_name_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_mod(&self, index: usize)
                    -> longhands::animation_name::computed_value::SingleComputedValue {
                    self.animation_name_at(index % self.animation_name_count())
                }
                /// Iterate over the values of animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_iter(&self) -> AnimationDurationIter {
                    AnimationDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_mod(&self, index: usize)
                    -> longhands::animation_duration::computed_value::SingleComputedValue {
                    self.animation_duration_at(index % self.animation_duration_count())
                }
                /// Iterate over the values of animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_iter(&self) -> AnimationTimingFunctionIter {
                    AnimationTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_mod(&self, index: usize)
                    -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                    self.animation_timing_function_at(index % self.animation_timing_function_count())
                }
                /// Iterate over the values of animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_iter(&self) -> AnimationIterationCountIter {
                    AnimationIterationCountIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_iteration_count_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_mod(&self, index: usize)
                    -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                    self.animation_iteration_count_at(index % self.animation_iteration_count_count())
                }
                /// Iterate over the values of animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_iter(&self) -> AnimationDirectionIter {
                    AnimationDirectionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_direction_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_mod(&self, index: usize)
                    -> longhands::animation_direction::computed_value::SingleComputedValue {
                    self.animation_direction_at(index % self.animation_direction_count())
                }
                /// Iterate over the values of animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_iter(&self) -> AnimationPlayStateIter {
                    AnimationPlayStateIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_play_state_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_mod(&self, index: usize)
                    -> longhands::animation_play_state::computed_value::SingleComputedValue {
                    self.animation_play_state_at(index % self.animation_play_state_count())
                }
                /// Iterate over the values of animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_iter(&self) -> AnimationFillModeIter {
                    AnimationFillModeIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_fill_mode_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_mod(&self, index: usize)
                    -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                    self.animation_fill_mode_at(index % self.animation_fill_mode_count())
                }
                /// Iterate over the values of animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_iter(&self) -> AnimationDelayIter {
                    AnimationDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_mod(&self, index: usize)
                    -> longhands::animation_delay::computed_value::SingleComputedValue {
                    self.animation_delay_at(index % self.animation_delay_count())
                }

            /// Returns whether there is any animation specified with
            /// animation-name other than `none`.
            pub fn specifies_animations(&self) -> bool {
                self.animation_name_iter().any(|name| name.0.is_some())
            }

            /// Returns whether there are any transitions specified.
            #[cfg(feature = "servo")]
            pub fn specifies_transitions(&self) -> bool {
                self.transition_duration_iter()
                    .take(self.transition_property_count())
                    .any(|t| t.seconds() > 0.)
            }
    }

            /// An iterator over the values of the transition-duration properties.
            pub struct TransitionDurationIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDurationIter<'a> {
                type Item = longhands::transition_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-timing-function properties.
            pub struct TransitionTimingFunctionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionTimingFunctionIter<'a> {
                type Item = longhands::transition_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-property properties.
            pub struct TransitionPropertyIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionPropertyIter<'a> {
                type Item = longhands::transition_property::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_property_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-delay properties.
            pub struct TransitionDelayIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDelayIter<'a> {
                type Item = longhands::transition_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-name properties.
            pub struct AnimationNameIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationNameIter<'a> {
                type Item = longhands::animation_name::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_name_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-duration properties.
            pub struct AnimationDurationIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDurationIter<'a> {
                type Item = longhands::animation_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-timing-function properties.
            pub struct AnimationTimingFunctionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationTimingFunctionIter<'a> {
                type Item = longhands::animation_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-iteration-count properties.
            pub struct AnimationIterationCountIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationIterationCountIter<'a> {
                type Item = longhands::animation_iteration_count::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_iteration_count_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-direction properties.
            pub struct AnimationDirectionIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDirectionIter<'a> {
                type Item = longhands::animation_direction::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_direction_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-play-state properties.
            pub struct AnimationPlayStateIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationPlayStateIter<'a> {
                type Item = longhands::animation_play_state::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_play_state_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-fill-mode properties.
            pub struct AnimationFillModeIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationFillModeIter<'a> {
                type Item = longhands::animation_fill_mode::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_fill_mode_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-delay properties.
            pub struct AnimationDelayIter<'a> {
                style_struct: &'a style_structs::Box,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDelayIter<'a> {
                type Item = longhands::animation_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
    impl style_structs::Color {

    }

    impl style_structs::Column {

            /// Whether this is a multicol style.
            #[cfg(feature = "servo")]
            pub fn is_multicol(&self) -> bool {
                match self.column_width {
                    Either::First(_width) => true,
                    Either::Second(_auto) => match self.column_count {
                        Either::First(_n) => true,
                        Either::Second(_auto) => false,
                    }
                }
            }
    }

    impl style_structs::Counters {

    }

    impl style_structs::Effects {

    }

    impl style_structs::Font {

    }

    impl style_structs::InheritedBox {

    }

    impl style_structs::InheritedTable {

    }

    impl style_structs::InheritedText {

    }

    impl style_structs::List {

    }

    impl style_structs::Margin {

    }

    impl style_structs::Outline {

    }

    impl style_structs::Padding {

    }

    impl style_structs::Pointing {

    }

    impl style_structs::Position {

    }

    impl style_structs::Table {

    }

    impl style_structs::Text {

    }

    impl style_structs::UI {

    }

    impl style_structs::InheritedSVG {

    }

    impl style_structs::SVG {

    }

    impl style_structs::XUL {

    }



#[cfg(feature = "gecko")]
pub use gecko_properties::{ComputedValues, ComputedValuesInner};

#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
/// Actual data of ComputedValues, to match up with Gecko
pub struct ComputedValuesInner {
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        color: Arc<style_structs::Color>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inheritedbox: Arc<style_structs::InheritedBox>,
        inheritedtable: Arc<style_structs::InheritedTable>,
        inheritedtext: Arc<style_structs::InheritedText>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        pointing: Arc<style_structs::Pointing>,
        position: Arc<style_structs::Position>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        inheritedsvg: Arc<style_structs::InheritedSVG>,
        svg: Arc<style_structs::SVG>,
        xul: Arc<style_structs::XUL>,
    custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
    /// The writing mode of this computed values struct.
    pub writing_mode: WritingMode,

    /// A set of flags we use to store misc information regarding this style.
    pub flags: ComputedValueFlags,

    /// The rule node representing the ordered list of rules matched for this
    /// node.  Can be None for default values and text nodes.  This is
    /// essentially an optimization to avoid referencing the root rule node.
    pub rules: Option<StrongRuleNode>,

    /// The element's computed values if visited, only computed if there's a
    /// relevant link for this element. A element's "relevant link" is the
    /// element being matched if it is a link or the nearest ancestor link.
    visited_style: Option<Arc<ComputedValues>>,
}

/// The struct that Servo uses to represent computed values.
///
/// This struct contains an immutable atomically-reference-counted pointer to
/// every kind of style struct.
///
/// When needed, the structs may be copied in order to get mutated.
#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
pub struct ComputedValues {
    /// The actual computed values
    ///
    /// In Gecko the outer ComputedValues is actually a style context,
    /// whereas ComputedValuesInner is the core set of computed values.
    ///
    /// We maintain this distinction in servo to reduce the amount of special casing.
    inner: ComputedValuesInner,
}

impl ComputedValues {
    /// Whether we're a visited style.
    pub fn is_style_if_visited(&self) -> bool {
        self.flags.contains(ComputedValueFlags::IS_STYLE_IF_VISITED)
    }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    /// Returns the visited style, if any.
    pub fn visited_style(&self) -> Option<&ComputedValues> {
        self.visited_style.as_ref().map(|s| &**s)
    }

    /// Returns the visited rules, if applicable.
    pub fn visited_rules(&self) -> Option<&StrongRuleNode> {
        self.visited_style.as_ref().and_then(|s| s.rules.as_ref())
    }

    /// Returns whether we're in a display: none subtree.
    pub fn is_in_display_none_subtree(&self) -> bool {
        use properties::computed_value_flags::ComputedValueFlags;

        self.flags.contains(ComputedValueFlags::IS_IN_DISPLAY_NONE_SUBTREE)
    }

    /// Gets a reference to the custom properties map (if one exists).
    pub fn custom_properties(&self) -> Option<&Arc<::custom_properties::CustomPropertiesMap>> {
        self.custom_properties.as_ref()
    }
}

#[cfg(feature = "servo")]
impl ComputedValues {
    /// Create a new refcounted `ComputedValues`
    pub fn new(
        _: &Device,
        _: Option<&ComputedValues>,
        _: Option<&PseudoElement>,
        custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
        writing_mode: WritingMode,
        flags: ComputedValueFlags,
        rules: Option<StrongRuleNode>,
        visited_style: Option<Arc<ComputedValues>>,
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        color: Arc<style_structs::Color>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inheritedbox: Arc<style_structs::InheritedBox>,
        inheritedtable: Arc<style_structs::InheritedTable>,
        inheritedtext: Arc<style_structs::InheritedText>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        pointing: Arc<style_structs::Pointing>,
        position: Arc<style_structs::Position>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        inheritedsvg: Arc<style_structs::InheritedSVG>,
        svg: Arc<style_structs::SVG>,
        xul: Arc<style_structs::XUL>,
    ) -> Arc<Self> {
        Arc::new(Self {
            inner: ComputedValuesInner {
                custom_properties,
                writing_mode,
                rules,
                visited_style,
                flags,
                background,
                border,
                box_,
                color,
                column,
                counters,
                effects,
                font,
                inheritedbox,
                inheritedtable,
                inheritedtext,
                list,
                margin,
                outline,
                padding,
                pointing,
                position,
                table,
                text,
                ui,
                inheritedsvg,
                svg,
                xul,
            }
        })
    }

    /// Get the initial computed values.
    pub fn initial_values() -> &'static Self { &*INITIAL_SERVO_VALUES }
}

#[cfg(feature = "servo")]
impl ops::Deref for ComputedValues {
    type Target = ComputedValuesInner;
    fn deref(&self) -> &ComputedValuesInner {
        &self.inner
    }
}

#[cfg(feature = "servo")]
impl ops::DerefMut for ComputedValues {
    fn deref_mut(&mut self) -> &mut ComputedValuesInner {
        &mut self.inner
    }
}

#[cfg(feature = "servo")]
impl ComputedValuesInner {
        /// Clone the Background struct.
        #[inline]
        pub fn clone_background(&self) -> Arc<style_structs::Background> {
            self.background.clone()
        }

        /// Get a immutable reference to the Background struct.
        #[inline]
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Background`.
        pub fn background_arc(&self) -> &Arc<style_structs::Background> {
            &self.background
        }

        /// Get a mutable reference to the Background struct.
        #[inline]
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            Arc::make_mut(&mut self.background)
        }
        /// Clone the Border struct.
        #[inline]
        pub fn clone_border(&self) -> Arc<style_structs::Border> {
            self.border.clone()
        }

        /// Get a immutable reference to the Border struct.
        #[inline]
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Border`.
        pub fn border_arc(&self) -> &Arc<style_structs::Border> {
            &self.border
        }

        /// Get a mutable reference to the Border struct.
        #[inline]
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            Arc::make_mut(&mut self.border)
        }
        /// Clone the Box struct.
        #[inline]
        pub fn clone_box(&self) -> Arc<style_structs::Box> {
            self.box_.clone()
        }

        /// Get a immutable reference to the Box struct.
        #[inline]
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Box`.
        pub fn box_arc(&self) -> &Arc<style_structs::Box> {
            &self.box_
        }

        /// Get a mutable reference to the Box struct.
        #[inline]
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            Arc::make_mut(&mut self.box_)
        }
        /// Clone the Color struct.
        #[inline]
        pub fn clone_color(&self) -> Arc<style_structs::Color> {
            self.color.clone()
        }

        /// Get a immutable reference to the Color struct.
        #[inline]
        pub fn get_color(&self) -> &style_structs::Color {
            &self.color
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Color`.
        pub fn color_arc(&self) -> &Arc<style_structs::Color> {
            &self.color
        }

        /// Get a mutable reference to the Color struct.
        #[inline]
        pub fn mutate_color(&mut self) -> &mut style_structs::Color {
            Arc::make_mut(&mut self.color)
        }
        /// Clone the Column struct.
        #[inline]
        pub fn clone_column(&self) -> Arc<style_structs::Column> {
            self.column.clone()
        }

        /// Get a immutable reference to the Column struct.
        #[inline]
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Column`.
        pub fn column_arc(&self) -> &Arc<style_structs::Column> {
            &self.column
        }

        /// Get a mutable reference to the Column struct.
        #[inline]
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            Arc::make_mut(&mut self.column)
        }
        /// Clone the Counters struct.
        #[inline]
        pub fn clone_counters(&self) -> Arc<style_structs::Counters> {
            self.counters.clone()
        }

        /// Get a immutable reference to the Counters struct.
        #[inline]
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Counters`.
        pub fn counters_arc(&self) -> &Arc<style_structs::Counters> {
            &self.counters
        }

        /// Get a mutable reference to the Counters struct.
        #[inline]
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            Arc::make_mut(&mut self.counters)
        }
        /// Clone the Effects struct.
        #[inline]
        pub fn clone_effects(&self) -> Arc<style_structs::Effects> {
            self.effects.clone()
        }

        /// Get a immutable reference to the Effects struct.
        #[inline]
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Effects`.
        pub fn effects_arc(&self) -> &Arc<style_structs::Effects> {
            &self.effects
        }

        /// Get a mutable reference to the Effects struct.
        #[inline]
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            Arc::make_mut(&mut self.effects)
        }
        /// Clone the Font struct.
        #[inline]
        pub fn clone_font(&self) -> Arc<style_structs::Font> {
            self.font.clone()
        }

        /// Get a immutable reference to the Font struct.
        #[inline]
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Font`.
        pub fn font_arc(&self) -> &Arc<style_structs::Font> {
            &self.font
        }

        /// Get a mutable reference to the Font struct.
        #[inline]
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            Arc::make_mut(&mut self.font)
        }
        /// Clone the InheritedBox struct.
        #[inline]
        pub fn clone_inheritedbox(&self) -> Arc<style_structs::InheritedBox> {
            self.inheritedbox.clone()
        }

        /// Get a immutable reference to the InheritedBox struct.
        #[inline]
        pub fn get_inheritedbox(&self) -> &style_structs::InheritedBox {
            &self.inheritedbox
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedBox`.
        pub fn inheritedbox_arc(&self) -> &Arc<style_structs::InheritedBox> {
            &self.inheritedbox
        }

        /// Get a mutable reference to the InheritedBox struct.
        #[inline]
        pub fn mutate_inheritedbox(&mut self) -> &mut style_structs::InheritedBox {
            Arc::make_mut(&mut self.inheritedbox)
        }
        /// Clone the InheritedTable struct.
        #[inline]
        pub fn clone_inheritedtable(&self) -> Arc<style_structs::InheritedTable> {
            self.inheritedtable.clone()
        }

        /// Get a immutable reference to the InheritedTable struct.
        #[inline]
        pub fn get_inheritedtable(&self) -> &style_structs::InheritedTable {
            &self.inheritedtable
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedTable`.
        pub fn inheritedtable_arc(&self) -> &Arc<style_structs::InheritedTable> {
            &self.inheritedtable
        }

        /// Get a mutable reference to the InheritedTable struct.
        #[inline]
        pub fn mutate_inheritedtable(&mut self) -> &mut style_structs::InheritedTable {
            Arc::make_mut(&mut self.inheritedtable)
        }
        /// Clone the InheritedText struct.
        #[inline]
        pub fn clone_inheritedtext(&self) -> Arc<style_structs::InheritedText> {
            self.inheritedtext.clone()
        }

        /// Get a immutable reference to the InheritedText struct.
        #[inline]
        pub fn get_inheritedtext(&self) -> &style_structs::InheritedText {
            &self.inheritedtext
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedText`.
        pub fn inheritedtext_arc(&self) -> &Arc<style_structs::InheritedText> {
            &self.inheritedtext
        }

        /// Get a mutable reference to the InheritedText struct.
        #[inline]
        pub fn mutate_inheritedtext(&mut self) -> &mut style_structs::InheritedText {
            Arc::make_mut(&mut self.inheritedtext)
        }
        /// Clone the List struct.
        #[inline]
        pub fn clone_list(&self) -> Arc<style_structs::List> {
            self.list.clone()
        }

        /// Get a immutable reference to the List struct.
        #[inline]
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `List`.
        pub fn list_arc(&self) -> &Arc<style_structs::List> {
            &self.list
        }

        /// Get a mutable reference to the List struct.
        #[inline]
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            Arc::make_mut(&mut self.list)
        }
        /// Clone the Margin struct.
        #[inline]
        pub fn clone_margin(&self) -> Arc<style_structs::Margin> {
            self.margin.clone()
        }

        /// Get a immutable reference to the Margin struct.
        #[inline]
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Margin`.
        pub fn margin_arc(&self) -> &Arc<style_structs::Margin> {
            &self.margin
        }

        /// Get a mutable reference to the Margin struct.
        #[inline]
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            Arc::make_mut(&mut self.margin)
        }
        /// Clone the Outline struct.
        #[inline]
        pub fn clone_outline(&self) -> Arc<style_structs::Outline> {
            self.outline.clone()
        }

        /// Get a immutable reference to the Outline struct.
        #[inline]
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Outline`.
        pub fn outline_arc(&self) -> &Arc<style_structs::Outline> {
            &self.outline
        }

        /// Get a mutable reference to the Outline struct.
        #[inline]
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            Arc::make_mut(&mut self.outline)
        }
        /// Clone the Padding struct.
        #[inline]
        pub fn clone_padding(&self) -> Arc<style_structs::Padding> {
            self.padding.clone()
        }

        /// Get a immutable reference to the Padding struct.
        #[inline]
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Padding`.
        pub fn padding_arc(&self) -> &Arc<style_structs::Padding> {
            &self.padding
        }

        /// Get a mutable reference to the Padding struct.
        #[inline]
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            Arc::make_mut(&mut self.padding)
        }
        /// Clone the Pointing struct.
        #[inline]
        pub fn clone_pointing(&self) -> Arc<style_structs::Pointing> {
            self.pointing.clone()
        }

        /// Get a immutable reference to the Pointing struct.
        #[inline]
        pub fn get_pointing(&self) -> &style_structs::Pointing {
            &self.pointing
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Pointing`.
        pub fn pointing_arc(&self) -> &Arc<style_structs::Pointing> {
            &self.pointing
        }

        /// Get a mutable reference to the Pointing struct.
        #[inline]
        pub fn mutate_pointing(&mut self) -> &mut style_structs::Pointing {
            Arc::make_mut(&mut self.pointing)
        }
        /// Clone the Position struct.
        #[inline]
        pub fn clone_position(&self) -> Arc<style_structs::Position> {
            self.position.clone()
        }

        /// Get a immutable reference to the Position struct.
        #[inline]
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Position`.
        pub fn position_arc(&self) -> &Arc<style_structs::Position> {
            &self.position
        }

        /// Get a mutable reference to the Position struct.
        #[inline]
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            Arc::make_mut(&mut self.position)
        }
        /// Clone the Table struct.
        #[inline]
        pub fn clone_table(&self) -> Arc<style_structs::Table> {
            self.table.clone()
        }

        /// Get a immutable reference to the Table struct.
        #[inline]
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Table`.
        pub fn table_arc(&self) -> &Arc<style_structs::Table> {
            &self.table
        }

        /// Get a mutable reference to the Table struct.
        #[inline]
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            Arc::make_mut(&mut self.table)
        }
        /// Clone the Text struct.
        #[inline]
        pub fn clone_text(&self) -> Arc<style_structs::Text> {
            self.text.clone()
        }

        /// Get a immutable reference to the Text struct.
        #[inline]
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `Text`.
        pub fn text_arc(&self) -> &Arc<style_structs::Text> {
            &self.text
        }

        /// Get a mutable reference to the Text struct.
        #[inline]
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            Arc::make_mut(&mut self.text)
        }
        /// Clone the UI struct.
        #[inline]
        pub fn clone_ui(&self) -> Arc<style_structs::UI> {
            self.ui.clone()
        }

        /// Get a immutable reference to the UI struct.
        #[inline]
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `UI`.
        pub fn ui_arc(&self) -> &Arc<style_structs::UI> {
            &self.ui
        }

        /// Get a mutable reference to the UI struct.
        #[inline]
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            Arc::make_mut(&mut self.ui)
        }
        /// Clone the InheritedSVG struct.
        #[inline]
        pub fn clone_inheritedsvg(&self) -> Arc<style_structs::InheritedSVG> {
            self.inheritedsvg.clone()
        }

        /// Get a immutable reference to the InheritedSVG struct.
        #[inline]
        pub fn get_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            &self.inheritedsvg
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `InheritedSVG`.
        pub fn inheritedsvg_arc(&self) -> &Arc<style_structs::InheritedSVG> {
            &self.inheritedsvg
        }

        /// Get a mutable reference to the InheritedSVG struct.
        #[inline]
        pub fn mutate_inheritedsvg(&mut self) -> &mut style_structs::InheritedSVG {
            Arc::make_mut(&mut self.inheritedsvg)
        }
        /// Clone the SVG struct.
        #[inline]
        pub fn clone_svg(&self) -> Arc<style_structs::SVG> {
            self.svg.clone()
        }

        /// Get a immutable reference to the SVG struct.
        #[inline]
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `SVG`.
        pub fn svg_arc(&self) -> &Arc<style_structs::SVG> {
            &self.svg
        }

        /// Get a mutable reference to the SVG struct.
        #[inline]
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            Arc::make_mut(&mut self.svg)
        }
        /// Clone the XUL struct.
        #[inline]
        pub fn clone_xul(&self) -> Arc<style_structs::XUL> {
            self.xul.clone()
        }

        /// Get a immutable reference to the XUL struct.
        #[inline]
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Gets an immutable reference to the refcounted value that wraps
        /// `XUL`.
        pub fn xul_arc(&self) -> &Arc<style_structs::XUL> {
            &self.xul
        }

        /// Get a mutable reference to the XUL struct.
        #[inline]
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            Arc::make_mut(&mut self.xul)
        }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    /// Whether this style has a -moz-binding value. This is always false for
    /// Servo for obvious reasons.
    pub fn has_moz_binding(&self) -> bool { false }

    /// Clone the visited style.  Used for inheriting parent styles in
    /// StyleBuilder::for_derived_style.
    pub fn clone_visited_style(&self) -> Option<Arc<ComputedValues>> {
        self.visited_style.clone()
    }

    /// Returns whether this style's display value is equal to contents.
    ///
    /// Since this isn't supported in Servo, this is always false for Servo.
    pub fn is_display_contents(&self) -> bool { false }

    #[inline]
    /// Returns whether the "content" property for the given style is completely
    /// ineffective, and would yield an empty `::before` or `::after`
    /// pseudo-element.
    pub fn ineffective_content_property(&self) -> bool {
        use properties::longhands::content::computed_value::T;
        match self.get_counters().content {
            T::Normal | T::None => true,
            T::Items(ref items) => items.is_empty(),
        }
    }

    /// Whether the current style or any of its ancestors is multicolumn.
    #[inline]
    pub fn can_be_fragmented(&self) -> bool {
        self.flags.contains(ComputedValueFlags::CAN_BE_FRAGMENTED)
    }

    /// Whether the current style is multicolumn.
    #[inline]
    pub fn is_multicol(&self) -> bool {
        self.get_column().is_multicol()
    }

    /// Resolves the currentColor keyword.
    ///
    /// Any color value from computed values (except for the 'color' property
    /// itself) should go through this method.
    ///
    /// Usage example:
    /// let top_color = style.resolve_color(style.Border.border_top_color);
    #[inline]
    pub fn resolve_color(&self, color: computed::Color) -> RGBA {
        color.to_rgba(self.get_color().color)
    }

    /// Get the logical computed inline size.
    #[inline]
    pub fn content_inline_size(&self) -> computed::LengthOrPercentageOrAuto {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() {
            position_style.height
        } else {
            position_style.width
        }
    }

    /// Get the logical computed block size.
    #[inline]
    pub fn content_block_size(&self) -> computed::LengthOrPercentageOrAuto {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.width } else { position_style.height }
    }

    /// Get the logical computed min inline size.
    #[inline]
    pub fn min_inline_size(&self) -> computed::LengthOrPercentage {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.min_height } else { position_style.min_width }
    }

    /// Get the logical computed min block size.
    #[inline]
    pub fn min_block_size(&self) -> computed::LengthOrPercentage {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.min_width } else { position_style.min_height }
    }

    /// Get the logical computed max inline size.
    #[inline]
    pub fn max_inline_size(&self) -> computed::LengthOrPercentageOrNone {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.max_height } else { position_style.max_width }
    }

    /// Get the logical computed max block size.
    #[inline]
    pub fn max_block_size(&self) -> computed::LengthOrPercentageOrNone {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { position_style.max_width } else { position_style.max_height }
    }

    /// Get the logical computed padding for this writing mode.
    #[inline]
    pub fn logical_padding(&self) -> LogicalMargin<computed::LengthOrPercentage> {
        let padding_style = self.get_padding();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            padding_style.padding_top.0,
            padding_style.padding_right.0,
            padding_style.padding_bottom.0,
            padding_style.padding_left.0,
        ))
    }

    /// Get the logical border width
    #[inline]
    pub fn border_width_for_writing_mode(&self, writing_mode: WritingMode) -> LogicalMargin<Au> {
        let border_style = self.get_border();
        LogicalMargin::from_physical(writing_mode, SideOffsets2D::new(
            Au::from(border_style.border_top_width),
            Au::from(border_style.border_right_width),
            Au::from(border_style.border_bottom_width),
            Au::from(border_style.border_left_width),
        ))
    }

    /// Gets the logical computed border widths for this style.
    #[inline]
    pub fn logical_border_width(&self) -> LogicalMargin<Au> {
        self.border_width_for_writing_mode(self.writing_mode)
    }

    /// Gets the logical computed margin from this style.
    #[inline]
    pub fn logical_margin(&self) -> LogicalMargin<computed::LengthOrPercentageOrAuto> {
        let margin_style = self.get_margin();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            margin_style.margin_top,
            margin_style.margin_right,
            margin_style.margin_bottom,
            margin_style.margin_left,
        ))
    }

    /// Gets the logical position from this style.
    #[inline]
    pub fn logical_position(&self) -> LogicalMargin<computed::LengthOrPercentageOrAuto> {
        // FIXME(SimonSapin): should be the writing mode of the containing block, maybe?
        let position_style = self.get_position();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            position_style.top,
            position_style.right,
            position_style.bottom,
            position_style.left,
        ))
    }

    /// Return true if the effects force the transform style to be Flat
    pub fn overrides_transform_style(&self) -> bool {
        use computed_values::mix_blend_mode::T as MixBlendMode;

        let effects = self.get_effects();
        // TODO(gw): Add clip-path, isolation, mask-image, mask-border-source when supported.
        effects.opacity < 1.0 ||
           !effects.filter.0.is_empty() ||
           !effects.clip.is_auto() ||
           effects.mix_blend_mode != MixBlendMode::Normal
    }

    /// <https://drafts.csswg.org/css-transforms/#grouping-property-values>
    pub fn get_used_transform_style(&self) -> computed_values::transform_style::T {
        use computed_values::transform_style::T as TransformStyle;

        let box_ = self.get_box();

        if self.overrides_transform_style() {
            TransformStyle::Flat
        } else {
            // Return the computed value if not overridden by the above exceptions
            box_.transform_style
        }
    }

    /// Whether given this transform value, the compositor would require a
    /// layer.
    pub fn transform_requires_layer(&self) -> bool {
        use values::generics::transform::TransformOperation;
        // Check if the transform matrix is 2D or 3D
        for transform in &self.get_box().transform.0 {
            match *transform {
                TransformOperation::Perspective(..) => {
                    return true;
                }
                TransformOperation::Matrix3D(m) => {
                    // See http://dev.w3.org/csswg/css-transforms/#2d-matrix
                    if m.m31 != 0.0 || m.m32 != 0.0 ||
                       m.m13 != 0.0 || m.m23 != 0.0 ||
                       m.m43 != 0.0 || m.m14 != 0.0 ||
                       m.m24 != 0.0 || m.m34 != 0.0 ||
                       m.m33 != 1.0 || m.m44 != 1.0 {
                        return true;
                    }
                }
                TransformOperation::Translate3D(_, _, z) |
                TransformOperation::TranslateZ(z) => {
                    if z.px() != 0. {
                        return true;
                    }
                }
                _ => {}
            }
        }

        // Neither perspective nor transform present
        false
    }

    /// Serializes the computed value of this property as a string.
    pub fn computed_value_to_string(&self, property: PropertyDeclarationId) -> String {
        match property {
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundColor) => {
                        self.background.background_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundImage) => {
                        self.background.background_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundPositionX) => {
                        self.background.background_position_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundPositionY) => {
                        self.background.background_position_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundRepeat) => {
                        self.background.background_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundAttachment) => {
                        self.background.background_attachment.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundClip) => {
                        self.background.background_clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundOrigin) => {
                        self.background.background_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundSize) => {
                        self.background.background_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackgroundBlendMode) => {
                        self.background.background_blend_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopColor) => {
                        self.border.border_top_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopStyle) => {
                        self.border.border_top_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopWidth) => {
                        self.border.border_top_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftColor) => {
                        self.border.border_left_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftStyle) => {
                        self.border.border_left_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderLeftWidth) => {
                        self.border.border_left_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomColor) => {
                        self.border.border_bottom_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomStyle) => {
                        self.border.border_bottom_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomWidth) => {
                        self.border.border_bottom_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightColor) => {
                        self.border.border_right_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightStyle) => {
                        self.border.border_right_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderRightWidth) => {
                        self.border.border_right_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartColor) => {
                        self.border.border_block_start_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartStyle) => {
                        self.border.border_block_start_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockStartWidth) => {
                        self.border.border_block_start_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndColor) => {
                        self.border.border_block_end_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndStyle) => {
                        self.border.border_block_end_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBlockEndWidth) => {
                        self.border.border_block_end_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartColor) => {
                        self.border.border_inline_start_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartStyle) => {
                        self.border.border_inline_start_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineStartWidth) => {
                        self.border.border_inline_start_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndColor) => {
                        self.border.border_inline_end_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndStyle) => {
                        self.border.border_inline_end_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderInlineEndWidth) => {
                        self.border.border_inline_end_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopLeftRadius) => {
                        self.border.border_top_left_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderTopRightRadius) => {
                        self.border.border_top_right_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomRightRadius) => {
                        self.border.border_bottom_right_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderBottomLeftRadius) => {
                        self.border.border_bottom_left_radius.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBorderTopColors) => {
                        self.border._moz_border_top_colors.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBorderLeftColors) => {
                        self.border._moz_border_left_colors.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBorderBottomColors) => {
                        self.border._moz_border_bottom_colors.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBorderRightColors) => {
                        self.border._moz_border_right_colors.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxDecorationBreak) => {
                        self.border.box_decoration_break.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozFloatEdge) => {
                        self.border._moz_float_edge.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageSource) => {
                        self.border.border_image_source.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageOutset) => {
                        self.border.border_image_outset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageRepeat) => {
                        self.border.border_image_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageWidth) => {
                        self.border.border_image_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderImageSlice) => {
                        self.border.border_image_slice.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Display) => {
                        self.box_.display.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTopLayer) => {
                        self.box_._moz_top_layer.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Position) => {
                        self.box_.position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Float) => {
                        self.box_.float.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Clear) => {
                        self.box_.clear.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::VerticalAlign) => {
                        self.box_.vertical_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowClipBoxInline) => {
                        self.box_.overflow_clip_box_inline.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowClipBoxBlock) => {
                        self.box_.overflow_clip_box_block.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowX) => {
                        self.box_.overflow_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowY) => {
                        self.box_.overflow_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionDuration) => {
                        self.box_.transition_duration.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionTimingFunction) => {
                        self.box_.transition_timing_function.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionProperty) => {
                        self.box_.transition_property.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransitionDelay) => {
                        self.box_.transition_delay.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationName) => {
                        self.box_.animation_name.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDuration) => {
                        self.box_.animation_duration.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationTimingFunction) => {
                        self.box_.animation_timing_function.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationIterationCount) => {
                        self.box_.animation_iteration_count.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDirection) => {
                        self.box_.animation_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationPlayState) => {
                        self.box_.animation_play_state.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationFillMode) => {
                        self.box_.animation_fill_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AnimationDelay) => {
                        self.box_.animation_delay.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapPointsX) => {
                        self.box_.scroll_snap_points_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapPointsY) => {
                        self.box_.scroll_snap_points_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapDestination) => {
                        self.box_.scroll_snap_destination.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapCoordinate) => {
                        self.box_.scroll_snap_coordinate.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Transform) => {
                        self.box_.transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollBehavior) => {
                        self.box_.scroll_behavior.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapTypeX) => {
                        self.box_.scroll_snap_type_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ScrollSnapTypeY) => {
                        self.box_.scroll_snap_type_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverscrollBehaviorX) => {
                        self.box_.overscroll_behavior_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverscrollBehaviorY) => {
                        self.box_.overscroll_behavior_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Isolation) => {
                        self.box_.isolation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakAfter) => {
                        self.box_.page_break_after.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakBefore) => {
                        self.box_.page_break_before.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PageBreakInside) => {
                        self.box_.page_break_inside.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Resize) => {
                        self.box_.resize.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Perspective) => {
                        self.box_.perspective.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PerspectiveOrigin) => {
                        self.box_.perspective_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BackfaceVisibility) => {
                        self.box_.backface_visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformBox) => {
                        self.box_.transform_box.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformStyle) => {
                        self.box_.transform_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TransformOrigin) => {
                        self.box_.transform_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Contain) => {
                        self.box_.contain.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozAppearance) => {
                        self.box_._moz_appearance.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBinding) => {
                        self.box_._moz_binding.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOrient) => {
                        self.box_._moz_orient.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WillChange) => {
                        self.box_.will_change.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeImageThreshold) => {
                        self.box_.shape_image_threshold.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeOutside) => {
                        self.box_.shape_outside.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TouchAction) => {
                        self.box_.touch_action.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Color) => {
                        self.color.color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnWidth) => {
                        self.column.column_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnCount) => {
                        self.column.column_count.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnGap) => {
                        self.column.column_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnFill) => {
                        self.column.column_fill.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleWidth) => {
                        self.column.column_rule_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleColor) => {
                        self.column.column_rule_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnSpan) => {
                        self.column.column_span.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColumnRuleStyle) => {
                        self.column.column_rule_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Content) => {
                        self.counters.content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CounterIncrement) => {
                        self.counters.counter_increment.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CounterReset) => {
                        self.counters.counter_reset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Opacity) => {
                        self.effects.opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxShadow) => {
                        self.effects.box_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Clip) => {
                        self.effects.clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Filter) => {
                        self.effects.filter.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MixBlendMode) => {
                        self.effects.mix_blend_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontFamily) => {
                        self.font.font_family.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontStyle) => {
                        self.font.font_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantCaps) => {
                        self.font.font_variant_caps.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontWeight) => {
                        self.font.font_weight.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSize) => {
                        self.font.font_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSizeAdjust) => {
                        self.font.font_size_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontSynthesis) => {
                        self.font.font_synthesis.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontStretch) => {
                        self.font.font_stretch.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontKerning) => {
                        self.font.font_kerning.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantAlternates) => {
                        self.font.font_variant_alternates.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantEastAsian) => {
                        self.font.font_variant_east_asian.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantLigatures) => {
                        self.font.font_variant_ligatures.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantNumeric) => {
                        self.font.font_variant_numeric.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariantPosition) => {
                        self.font.font_variant_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontFeatureSettings) => {
                        self.font.font_feature_settings.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontVariationSettings) => {
                        self.font.font_variation_settings.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FontLanguageOverride) => {
                        self.font.font_language_override.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XLang) => {
                        self.font._x_lang.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptSizeMultiplier) => {
                        self.font._moz_script_size_multiplier.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptLevel) => {
                        self.font._moz_script_level.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMathDisplay) => {
                        self.font._moz_math_display.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMathVariant) => {
                        self.font._moz_math_variant.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozScriptMinSize) => {
                        self.font._moz_script_min_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XTextZoom) => {
                        self.font._x_text_zoom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOsxFontSmoothing) => {
                        self.font._moz_osx_font_smoothing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozFontSmoothingBackgroundColor) => {
                        self.font._moz_font_smoothing_background_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozMinFontSizeRatio) => {
                        self.font._moz_min_font_size_ratio.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Visibility) => {
                        self.inheritedbox.visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WritingMode) => {
                        self.inheritedbox.writing_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Direction) => {
                        self.inheritedbox.direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextOrientation) => {
                        self.inheritedbox.text_orientation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorAdjust) => {
                        self.inheritedbox.color_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImageRendering) => {
                        self.inheritedbox.image_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImageOrientation) => {
                        self.inheritedbox.image_orientation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderCollapse) => {
                        self.inheritedtable.border_collapse.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::EmptyCells) => {
                        self.inheritedtable.empty_cells.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CaptionSide) => {
                        self.inheritedtable.caption_side.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BorderSpacing) => {
                        self.inheritedtable.border_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LineHeight) => {
                        self.inheritedtext.line_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextTransform) => {
                        self.inheritedtext.text_transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Hyphens) => {
                        self.inheritedtext.hyphens.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTextSizeAdjust) => {
                        self.inheritedtext._moz_text_size_adjust.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextIndent) => {
                        self.inheritedtext.text_indent.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OverflowWrap) => {
                        self.inheritedtext.overflow_wrap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WordBreak) => {
                        self.inheritedtext.word_break.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextJustify) => {
                        self.inheritedtext.text_justify.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAlignLast) => {
                        self.inheritedtext.text_align_last.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAlign) => {
                        self.inheritedtext.text_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LetterSpacing) => {
                        self.inheritedtext.letter_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WordSpacing) => {
                        self.inheritedtext.word_spacing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WhiteSpace) => {
                        self.inheritedtext.white_space.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextShadow) => {
                        self.inheritedtext.text_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisStyle) => {
                        self.inheritedtext.text_emphasis_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisPosition) => {
                        self.inheritedtext.text_emphasis_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextEmphasisColor) => {
                        self.inheritedtext.text_emphasis_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozTabSize) => {
                        self.inheritedtext._moz_tab_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextFillColor) => {
                        self.inheritedtext._webkit_text_fill_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextStrokeColor) => {
                        self.inheritedtext._webkit_text_stroke_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::WebkitTextStrokeWidth) => {
                        self.inheritedtext._webkit_text_stroke_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::RubyAlign) => {
                        self.inheritedtext.ruby_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::RubyPosition) => {
                        self.inheritedtext.ruby_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextCombineUpright) => {
                        self.inheritedtext.text_combine_upright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextRendering) => {
                        self.inheritedtext.text_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozControlCharacterVisibility) => {
                        self.inheritedtext._moz_control_character_visibility.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStylePosition) => {
                        self.list.list_style_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStyleType) => {
                        self.list.list_style_type.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ListStyleImage) => {
                        self.list.list_style_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Quotes) => {
                        self.list.quotes.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozImageRegion) => {
                        self.list._moz_image_region.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginTop) => {
                        self.margin.margin_top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginLeft) => {
                        self.margin.margin_left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBottom) => {
                        self.margin.margin_bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginRight) => {
                        self.margin.margin_right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBlockStart) => {
                        self.margin.margin_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginBlockEnd) => {
                        self.margin.margin_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginInlineStart) => {
                        self.margin.margin_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarginInlineEnd) => {
                        self.margin.margin_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineColor) => {
                        self.outline.outline_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineStyle) => {
                        self.outline.outline_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineWidth) => {
                        self.outline.outline_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusTopleft) => {
                        self.outline._moz_outline_radius_topleft.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusTopright) => {
                        self.outline._moz_outline_radius_topright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusBottomright) => {
                        self.outline._moz_outline_radius_bottomright.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozOutlineRadiusBottomleft) => {
                        self.outline._moz_outline_radius_bottomleft.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OutlineOffset) => {
                        self.outline.outline_offset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingTop) => {
                        self.padding.padding_top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingLeft) => {
                        self.padding.padding_left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBottom) => {
                        self.padding.padding_bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingRight) => {
                        self.padding.padding_right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBlockStart) => {
                        self.padding.padding_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingBlockEnd) => {
                        self.padding.padding_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingInlineStart) => {
                        self.padding.padding_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaddingInlineEnd) => {
                        self.padding.padding_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Cursor) => {
                        self.pointing.cursor.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PointerEvents) => {
                        self.pointing.pointer_events.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserInput) => {
                        self.pointing._moz_user_input.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserModify) => {
                        self.pointing._moz_user_modify.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserFocus) => {
                        self.pointing._moz_user_focus.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::CaretColor) => {
                        self.pointing.caret_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Top) => {
                        self.position.top.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Left) => {
                        self.position.left.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Bottom) => {
                        self.position.bottom.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Right) => {
                        self.position.right.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetBlockStart) => {
                        self.position.offset_block_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetBlockEnd) => {
                        self.position.offset_block_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetInlineStart) => {
                        self.position.offset_inline_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::OffsetInlineEnd) => {
                        self.position.offset_inline_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ZIndex) => {
                        self.position.z_index.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexDirection) => {
                        self.position.flex_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexWrap) => {
                        self.position.flex_wrap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifyContent) => {
                        self.position.justify_content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignContent) => {
                        self.position.align_content.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignItems) => {
                        self.position.align_items.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifyItems) => {
                        self.position.justify_items.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexGrow) => {
                        self.position.flex_grow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexShrink) => {
                        self.position.flex_shrink.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::AlignSelf) => {
                        self.position.align_self.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::JustifySelf) => {
                        self.position.justify_self.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Order) => {
                        self.position.order.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FlexBasis) => {
                        self.position.flex_basis.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Width) => {
                        self.position.width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinWidth) => {
                        self.position.min_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxWidth) => {
                        self.position.max_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Height) => {
                        self.position.height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinHeight) => {
                        self.position.min_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxHeight) => {
                        self.position.max_height.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BlockSize) => {
                        self.position.block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinBlockSize) => {
                        self.position.min_block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxBlockSize) => {
                        self.position.max_block_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::InlineSize) => {
                        self.position.inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MinInlineSize) => {
                        self.position.min_inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaxInlineSize) => {
                        self.position.max_inline_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::BoxSizing) => {
                        self.position.box_sizing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ObjectFit) => {
                        self.position.object_fit.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ObjectPosition) => {
                        self.position.object_position.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowGap) => {
                        self.position.grid_row_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowStart) => {
                        self.position.grid_row_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridRowEnd) => {
                        self.position.grid_row_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoRows) => {
                        self.position.grid_auto_rows.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateRows) => {
                        self.position.grid_template_rows.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnGap) => {
                        self.position.grid_column_gap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnStart) => {
                        self.position.grid_column_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridColumnEnd) => {
                        self.position.grid_column_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoColumns) => {
                        self.position.grid_auto_columns.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateColumns) => {
                        self.position.grid_template_columns.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridAutoFlow) => {
                        self.position.grid_auto_flow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::GridTemplateAreas) => {
                        self.position.grid_template_areas.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TableLayout) => {
                        self.table.table_layout.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::XSpan) => {
                        self.table._x_span.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextOverflow) => {
                        self.text.text_overflow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::UnicodeBidi) => {
                        self.text.unicode_bidi.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationLine) => {
                        self.text.text_decoration_line.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationStyle) => {
                        self.text.text_decoration_style.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextDecorationColor) => {
                        self.text.text_decoration_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::InitialLetter) => {
                        self.text.initial_letter.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ImeMode) => {
                        self.ui.ime_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozUserSelect) => {
                        self.ui._moz_user_select.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowDragging) => {
                        self.ui._moz_window_dragging.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowShadow) => {
                        self.ui._moz_window_shadow.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowOpacity) => {
                        self.ui._moz_window_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowTransform) => {
                        self.ui._moz_window_transform.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozWindowTransformOrigin) => {
                        self.ui._moz_window_transform_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozForceBrokenImageIcon) => {
                        self.ui._moz_force_broken_image_icon.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::TextAnchor) => {
                        self.inheritedsvg.text_anchor.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorInterpolation) => {
                        self.inheritedsvg.color_interpolation.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ColorInterpolationFilters) => {
                        self.inheritedsvg.color_interpolation_filters.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Fill) => {
                        self.inheritedsvg.fill.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FillOpacity) => {
                        self.inheritedsvg.fill_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FillRule) => {
                        self.inheritedsvg.fill_rule.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ShapeRendering) => {
                        self.inheritedsvg.shape_rendering.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::Stroke) => {
                        self.inheritedsvg.stroke.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeWidth) => {
                        self.inheritedsvg.stroke_width.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeLinecap) => {
                        self.inheritedsvg.stroke_linecap.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeLinejoin) => {
                        self.inheritedsvg.stroke_linejoin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeMiterlimit) => {
                        self.inheritedsvg.stroke_miterlimit.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeOpacity) => {
                        self.inheritedsvg.stroke_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeDasharray) => {
                        self.inheritedsvg.stroke_dasharray.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StrokeDashoffset) => {
                        self.inheritedsvg.stroke_dashoffset.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ClipRule) => {
                        self.inheritedsvg.clip_rule.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerStart) => {
                        self.inheritedsvg.marker_start.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerMid) => {
                        self.inheritedsvg.marker_mid.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MarkerEnd) => {
                        self.inheritedsvg.marker_end.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::PaintOrder) => {
                        self.inheritedsvg.paint_order.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozContextProperties) => {
                        self.inheritedsvg._moz_context_properties.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::DominantBaseline) => {
                        self.svg.dominant_baseline.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::VectorEffect) => {
                        self.svg.vector_effect.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StopColor) => {
                        self.svg.stop_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::StopOpacity) => {
                        self.svg.stop_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FloodColor) => {
                        self.svg.flood_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::FloodOpacity) => {
                        self.svg.flood_opacity.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::LightingColor) => {
                        self.svg.lighting_color.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskType) => {
                        self.svg.mask_type.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::ClipPath) => {
                        self.svg.clip_path.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskMode) => {
                        self.svg.mask_mode.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskRepeat) => {
                        self.svg.mask_repeat.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskPositionX) => {
                        self.svg.mask_position_x.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskPositionY) => {
                        self.svg.mask_position_y.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskClip) => {
                        self.svg.mask_clip.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskOrigin) => {
                        self.svg.mask_origin.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskSize) => {
                        self.svg.mask_size.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskComposite) => {
                        self.svg.mask_composite.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MaskImage) => {
                        self.svg.mask_image.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxAlign) => {
                        self.xul._moz_box_align.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxDirection) => {
                        self.xul._moz_box_direction.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxFlex) => {
                        self.xul._moz_box_flex.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxOrient) => {
                        self.xul._moz_box_orient.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxPack) => {
                        self.xul._moz_box_pack.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozStackSizing) => {
                        self.xul._moz_stack_sizing.to_css_string()
                    }
                    PropertyDeclarationId::Longhand(LonghandId::MozBoxOrdinalGroup) => {
                        self.xul._moz_box_ordinal_group.to_css_string()
                    }
            PropertyDeclarationId::Custom(name) => {
                self.custom_properties
                    .as_ref()
                    .and_then(|map| map.get(name))
                    .map(|value| value.to_css_string())
                    .unwrap_or(String::new())
            }
        }
    }
}

    pub use ::servo_arc::RawOffsetArc as BuilderArc;
    /// Clone an arc, returning a regular arc
    fn clone_arc<T: 'static>(x: &BuilderArc<T>) -> Arc<T> {
        Arc::from_raw_offset(x.clone())
    }

/// A reference to a style struct of the parent, or our own style struct.
pub enum StyleStructRef<'a, T: 'static> {
    /// A borrowed struct from the parent, for example, for inheriting style.
    Borrowed(&'a BuilderArc<T>),
    /// An owned struct, that we've already mutated.
    Owned(UniqueArc<T>),
    /// Temporarily vacated, will panic if accessed
    Vacated,
}

impl<'a, T: 'a> StyleStructRef<'a, T>
    where T: Clone,
{
    /// Ensure a mutable reference of this value exists, either cloning the
    /// borrowed value, or returning the owned one.
    pub fn mutate(&mut self) -> &mut T {
        if let StyleStructRef::Borrowed(v) = *self {
            *self = StyleStructRef::Owned(UniqueArc::new((**v).clone()));
        }

        match *self {
            StyleStructRef::Owned(ref mut v) => v,
            StyleStructRef::Borrowed(..) => unreachable!(),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Extract a unique Arc from this struct, vacating it.
    ///
    /// The vacated state is a transient one, please put the Arc back
    /// when done via `put()`. This function is to be used to separate
    /// the struct being mutated from the computed context
    pub fn take(&mut self) -> UniqueArc<T> {
        use std::mem::replace;
        let inner = replace(self, StyleStructRef::Vacated);

        match inner {
            StyleStructRef::Owned(arc) => arc,
            StyleStructRef::Borrowed(arc) => UniqueArc::new((**arc).clone()),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct"),
        }
    }

    /// Replace vacated ref with an arc
    pub fn put(&mut self, arc: UniqueArc<T>) {
        debug_assert!(matches!(*self, StyleStructRef::Vacated));
        *self = StyleStructRef::Owned(arc);
    }

    /// Get a mutable reference to the owned struct, or `None` if the struct
    /// hasn't been mutated.
    pub fn get_if_mutated(&mut self) -> Option<&mut T> {
        match *self {
            StyleStructRef::Owned(ref mut v) => Some(v),
            StyleStructRef::Borrowed(..) => None,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Returns an `Arc` to the internal struct, constructing one if
    /// appropriate.
    pub fn build(self) -> Arc<T> {
        match self {
            StyleStructRef::Owned(v) => v.shareable(),
            StyleStructRef::Borrowed(v) => clone_arc(v),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

impl<'a, T: 'a> ops::Deref for StyleStructRef<'a, T> {
    type Target = T;

    fn deref(&self) -> &T {
        match *self {
            StyleStructRef::Owned(ref v) => &**v,
            StyleStructRef::Borrowed(v) => &**v,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

/// A type used to compute a struct with minimal overhead.
///
/// This allows holding references to the parent/default computed values without
/// actually cloning them, until we either build the style, or mutate the
/// inherited value.
pub struct StyleBuilder<'a> {
    /// The device we're using to compute style.
    ///
    /// This provides access to viewport unit ratios, etc.
    pub device: &'a Device,

    /// The style we're inheriting from.
    ///
    /// This is effectively
    /// `parent_style.unwrap_or(device.default_computed_values())`.
    inherited_style: &'a ComputedValues,

    /// The style we're inheriting from for properties that don't inherit from
    /// ::first-line.  This is the same as inherited_style, unless
    /// inherited_style is a ::first-line style.
    inherited_style_ignoring_first_line: &'a ComputedValues,

    /// The style we're getting reset structs from.
    reset_style: &'a ComputedValues,

    /// The style we're inheriting from explicitly, or none if we're the root of
    /// a subtree.
    parent_style: Option<&'a ComputedValues>,

    /// The rule node representing the ordered list of rules matched for this
    /// node.
    pub rules: Option<StrongRuleNode>,

    custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,

    /// The pseudo-element this style will represent.
    pub pseudo: Option<&'a PseudoElement>,

    /// Whether we have mutated any reset structs since the the last time
    /// `clear_modified_reset` was called.  This is used to tell whether the
    /// `StyleAdjuster` did any work.
    modified_reset: bool,

    /// The writing mode flags.
    ///
    /// TODO(emilio): Make private.
    pub writing_mode: WritingMode,
    /// Flags for the computed value.
    pub flags: ComputedValueFlags,
    /// The element's style if visited, only computed if there's a relevant link
    /// for this element.  A element's "relevant link" is the element being
    /// matched if it is a link or the nearest ancestor link.
    visited_style: Option<Arc<ComputedValues>>,
        background: StyleStructRef<'a, style_structs::Background>,
        border: StyleStructRef<'a, style_structs::Border>,
        box_: StyleStructRef<'a, style_structs::Box>,
        color: StyleStructRef<'a, style_structs::Color>,
        column: StyleStructRef<'a, style_structs::Column>,
        counters: StyleStructRef<'a, style_structs::Counters>,
        effects: StyleStructRef<'a, style_structs::Effects>,
        font: StyleStructRef<'a, style_structs::Font>,
        inheritedbox: StyleStructRef<'a, style_structs::InheritedBox>,
        inheritedtable: StyleStructRef<'a, style_structs::InheritedTable>,
        inheritedtext: StyleStructRef<'a, style_structs::InheritedText>,
        list: StyleStructRef<'a, style_structs::List>,
        margin: StyleStructRef<'a, style_structs::Margin>,
        outline: StyleStructRef<'a, style_structs::Outline>,
        padding: StyleStructRef<'a, style_structs::Padding>,
        pointing: StyleStructRef<'a, style_structs::Pointing>,
        position: StyleStructRef<'a, style_structs::Position>,
        table: StyleStructRef<'a, style_structs::Table>,
        text: StyleStructRef<'a, style_structs::Text>,
        ui: StyleStructRef<'a, style_structs::UI>,
        inheritedsvg: StyleStructRef<'a, style_structs::InheritedSVG>,
        svg: StyleStructRef<'a, style_structs::SVG>,
        xul: StyleStructRef<'a, style_structs::XUL>,
}

impl<'a> StyleBuilder<'a> {
    /// Trivially construct a `StyleBuilder`.
    fn new(
        device: &'a Device,
        parent_style: Option<&'a ComputedValues>,
        parent_style_ignoring_first_line: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
        cascade_flags: CascadeFlags,
        rules: Option<StrongRuleNode>,
        custom_properties: Option<Arc<::custom_properties::CustomPropertiesMap>>,
        writing_mode: WritingMode,
        mut flags: ComputedValueFlags,
        visited_style: Option<Arc<ComputedValues>>,
    ) -> Self {
        debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
        #[cfg(feature = "gecko")]
        debug_assert!(parent_style.is_none() ||
                      ::std::ptr::eq(parent_style.unwrap(),
                                     parent_style_ignoring_first_line.unwrap()) ||
                      parent_style.unwrap().pseudo() == Some(PseudoElement::FirstLine));
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);
        let inherited_style_ignoring_first_line = parent_style_ignoring_first_line.unwrap_or(reset_style);
        // FIXME(bz): INHERIT_ALL seems like a fundamentally broken idea.  I'm
        // 99% sure it should give incorrect behavior for table anonymous box
        // backgrounds, for example.  This code doesn't attempt to make it play
        // nice with inherited_style_ignoring_first_line.
        let reset_style = if cascade_flags.contains(CascadeFlags::INHERIT_ALL) {
            inherited_style
        } else {
            reset_style
        };

        if cascade_flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) {
            flags.insert(ComputedValueFlags::IS_STYLE_IF_VISITED);
        }

        StyleBuilder {
            device,
            parent_style,
            inherited_style,
            inherited_style_ignoring_first_line,
            reset_style,
            pseudo,
            rules,
            modified_reset: false,
            custom_properties,
            writing_mode,
            flags,
            visited_style,
            background: StyleStructRef::Borrowed(reset_style.background_arc()),
            border: StyleStructRef::Borrowed(reset_style.border_arc()),
            box_: StyleStructRef::Borrowed(reset_style.box_arc()),
            color: StyleStructRef::Borrowed(inherited_style.color_arc()),
            column: StyleStructRef::Borrowed(reset_style.column_arc()),
            counters: StyleStructRef::Borrowed(reset_style.counters_arc()),
            effects: StyleStructRef::Borrowed(reset_style.effects_arc()),
            font: StyleStructRef::Borrowed(inherited_style.font_arc()),
            inheritedbox: StyleStructRef::Borrowed(inherited_style.inheritedbox_arc()),
            inheritedtable: StyleStructRef::Borrowed(inherited_style.inheritedtable_arc()),
            inheritedtext: StyleStructRef::Borrowed(inherited_style.inheritedtext_arc()),
            list: StyleStructRef::Borrowed(inherited_style.list_arc()),
            margin: StyleStructRef::Borrowed(reset_style.margin_arc()),
            outline: StyleStructRef::Borrowed(reset_style.outline_arc()),
            padding: StyleStructRef::Borrowed(reset_style.padding_arc()),
            pointing: StyleStructRef::Borrowed(inherited_style.pointing_arc()),
            position: StyleStructRef::Borrowed(reset_style.position_arc()),
            table: StyleStructRef::Borrowed(reset_style.table_arc()),
            text: StyleStructRef::Borrowed(reset_style.text_arc()),
            ui: StyleStructRef::Borrowed(reset_style.ui_arc()),
            inheritedsvg: StyleStructRef::Borrowed(inherited_style.inheritedsvg_arc()),
            svg: StyleStructRef::Borrowed(reset_style.svg_arc()),
            xul: StyleStructRef::Borrowed(reset_style.xul_arc()),
        }
    }

    /// Whether we're a visited style.
    pub fn is_style_if_visited(&self) -> bool {
        self.flags.contains(ComputedValueFlags::IS_STYLE_IF_VISITED)
    }

    /// Creates a StyleBuilder holding only references to the structs of `s`, in
    /// order to create a derived style.
    pub fn for_derived_style(
        device: &'a Device,
        style_to_derive_from: &'a ComputedValues,
        parent_style: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
    ) -> Self {
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);
        #[cfg(feature = "gecko")]
        debug_assert!(parent_style.is_none() ||
                      parent_style.unwrap().pseudo() != Some(PseudoElement::FirstLine));
        StyleBuilder {
            device,
            parent_style,
            inherited_style,
            // None of our callers pass in ::first-line parent styles.
            inherited_style_ignoring_first_line: inherited_style,
            reset_style,
            pseudo,
            modified_reset: false,
            rules: None, // FIXME(emilio): Dubious...
            custom_properties: style_to_derive_from.custom_properties().cloned(),
            writing_mode: style_to_derive_from.writing_mode,
            flags: style_to_derive_from.flags,
            visited_style: style_to_derive_from.clone_visited_style(),
            background: StyleStructRef::Borrowed(
                style_to_derive_from.background_arc()
            ),
            border: StyleStructRef::Borrowed(
                style_to_derive_from.border_arc()
            ),
            box_: StyleStructRef::Borrowed(
                style_to_derive_from.box_arc()
            ),
            color: StyleStructRef::Borrowed(
                style_to_derive_from.color_arc()
            ),
            column: StyleStructRef::Borrowed(
                style_to_derive_from.column_arc()
            ),
            counters: StyleStructRef::Borrowed(
                style_to_derive_from.counters_arc()
            ),
            effects: StyleStructRef::Borrowed(
                style_to_derive_from.effects_arc()
            ),
            font: StyleStructRef::Borrowed(
                style_to_derive_from.font_arc()
            ),
            inheritedbox: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedbox_arc()
            ),
            inheritedtable: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedtable_arc()
            ),
            inheritedtext: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedtext_arc()
            ),
            list: StyleStructRef::Borrowed(
                style_to_derive_from.list_arc()
            ),
            margin: StyleStructRef::Borrowed(
                style_to_derive_from.margin_arc()
            ),
            outline: StyleStructRef::Borrowed(
                style_to_derive_from.outline_arc()
            ),
            padding: StyleStructRef::Borrowed(
                style_to_derive_from.padding_arc()
            ),
            pointing: StyleStructRef::Borrowed(
                style_to_derive_from.pointing_arc()
            ),
            position: StyleStructRef::Borrowed(
                style_to_derive_from.position_arc()
            ),
            table: StyleStructRef::Borrowed(
                style_to_derive_from.table_arc()
            ),
            text: StyleStructRef::Borrowed(
                style_to_derive_from.text_arc()
            ),
            ui: StyleStructRef::Borrowed(
                style_to_derive_from.ui_arc()
            ),
            inheritedsvg: StyleStructRef::Borrowed(
                style_to_derive_from.inheritedsvg_arc()
            ),
            svg: StyleStructRef::Borrowed(
                style_to_derive_from.svg_arc()
            ),
            xul: StyleStructRef::Borrowed(
                style_to_derive_from.xul_arc()
            ),
        }
    }

    /// Copy the reset properties from `style`.
    pub fn copy_reset_from(&mut self, style: &'a ComputedValues) {
        self.background =
            StyleStructRef::Borrowed(style.background_arc());
        self.border =
            StyleStructRef::Borrowed(style.border_arc());
        self.box_ =
            StyleStructRef::Borrowed(style.box_arc());
        self.column =
            StyleStructRef::Borrowed(style.column_arc());
        self.counters =
            StyleStructRef::Borrowed(style.counters_arc());
        self.effects =
            StyleStructRef::Borrowed(style.effects_arc());
        self.margin =
            StyleStructRef::Borrowed(style.margin_arc());
        self.outline =
            StyleStructRef::Borrowed(style.outline_arc());
        self.padding =
            StyleStructRef::Borrowed(style.padding_arc());
        self.position =
            StyleStructRef::Borrowed(style.position_arc());
        self.table =
            StyleStructRef::Borrowed(style.table_arc());
        self.text =
            StyleStructRef::Borrowed(style.text_arc());
        self.ui =
            StyleStructRef::Borrowed(style.ui_arc());
        self.svg =
            StyleStructRef::Borrowed(style.svg_arc());
        self.xul =
            StyleStructRef::Borrowed(style.xul_arc());
    }

    /// Inherit `background_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_color_from(
                inherited_struct,
            );
    }

    /// Reset `background_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_color(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_color(
                reset_struct,
            );
    }

    /// Set the `background_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_background_color(
        &mut self,
        value: longhands::background_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.background.mutate()
            .set_background_color(
                value,
            );
    }
    /// Inherit `background_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_image(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_image_from(
                inherited_struct,
            );
    }

    /// Reset `background_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_image(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_image(
                reset_struct,
            );
    }

    /// Inherit `background_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_position_x_from(
                inherited_struct,
            );
    }

    /// Reset `background_position_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_position_x(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_position_x(
                reset_struct,
            );
    }

    /// Inherit `background_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_position_y_from(
                inherited_struct,
            );
    }

    /// Reset `background_position_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_position_y(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_position_y(
                reset_struct,
            );
    }

    /// Inherit `background_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `background_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_repeat(
                reset_struct,
            );
    }

    /// Inherit `background_attachment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_attachment(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_attachment_from(
                inherited_struct,
            );
    }

    /// Reset `background_attachment` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_attachment(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_attachment(
                reset_struct,
            );
    }

    /// Inherit `background_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_clip_from(
                inherited_struct,
            );
    }

    /// Reset `background_clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_clip(
                reset_struct,
            );
    }

    /// Inherit `background_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_origin_from(
                inherited_struct,
            );
    }

    /// Reset `background_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_origin(
                reset_struct,
            );
    }

    /// Inherit `background_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_size_from(
                inherited_struct,
            );
    }

    /// Reset `background_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_size(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_size(
                reset_struct,
            );
    }

    /// Inherit `background_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_background();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.background.mutate()
            .copy_background_blend_mode_from(
                inherited_struct,
            );
    }

    /// Reset `background_blend_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_background_blend_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_background();

        self.modified_reset = true;

        self.background.mutate()
            .reset_background_blend_mode(
                reset_struct,
            );
    }

    /// Inherit `border_top_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_color(
                reset_struct,
            );
    }

    /// Set the `border_top_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_color(
        &mut self,
        value: longhands::border_top_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_color(
                value,
            );
    }
    /// Inherit `border_top_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_style(
                reset_struct,
            );
    }

    /// Set the `border_top_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_style(
        &mut self,
        value: longhands::border_top_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_style(
                value,
            );
    }
    /// Inherit `border_top_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_width(
                reset_struct,
            );
    }

    /// Set the `border_top_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_width(
        &mut self,
        value: longhands::border_top_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_width(
                value,
            );
    }
    /// Inherit `border_left_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_color(
                reset_struct,
            );
    }

    /// Set the `border_left_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_color(
        &mut self,
        value: longhands::border_left_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_color(
                value,
            );
    }
    /// Inherit `border_left_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_style(
                reset_struct,
            );
    }

    /// Set the `border_left_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_style(
        &mut self,
        value: longhands::border_left_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_style(
                value,
            );
    }
    /// Inherit `border_left_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_left_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_left_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_left_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_left_width(
                reset_struct,
            );
    }

    /// Set the `border_left_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_width(
        &mut self,
        value: longhands::border_left_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_left_width(
                value,
            );
    }
    /// Inherit `border_bottom_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_color(
                reset_struct,
            );
    }

    /// Set the `border_bottom_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_color(
        &mut self,
        value: longhands::border_bottom_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_color(
                value,
            );
    }
    /// Inherit `border_bottom_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_style(
                reset_struct,
            );
    }

    /// Set the `border_bottom_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_style(
        &mut self,
        value: longhands::border_bottom_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_style(
                value,
            );
    }
    /// Inherit `border_bottom_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_width(
                reset_struct,
            );
    }

    /// Set the `border_bottom_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_width(
        &mut self,
        value: longhands::border_bottom_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_width(
                value,
            );
    }
    /// Inherit `border_right_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_color_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_color(
                reset_struct,
            );
    }

    /// Set the `border_right_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_color(
        &mut self,
        value: longhands::border_right_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_color(
                value,
            );
    }
    /// Inherit `border_right_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_style_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_style(
                reset_struct,
            );
    }

    /// Set the `border_right_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_style(
        &mut self,
        value: longhands::border_right_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_style(
                value,
            );
    }
    /// Inherit `border_right_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_right_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_right_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_right_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_right_width(
                reset_struct,
            );
    }

    /// Set the `border_right_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_width(
        &mut self,
        value: longhands::border_right_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_right_width(
                value,
            );
    }
    /// Inherit `border_block_start_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_color(
        &mut self,
        value: longhands::border_block_start_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_start_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_style(
        &mut self,
        value: longhands::border_block_start_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_start_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_start_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_start_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_start_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_start_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_start_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_start_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_start_width(
        &mut self,
        value: longhands::border_block_start_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_start_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_end_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_color(
        &mut self,
        value: longhands::border_block_end_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_end_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_style(
        &mut self,
        value: longhands::border_block_end_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_block_end_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_block_end_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_block_end_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_block_end_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_block_end_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_block_end_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_block_end_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_block_end_width(
        &mut self,
        value: longhands::border_block_end_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_block_end_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_color(
        &mut self,
        value: longhands::border_inline_start_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_style(
        &mut self,
        value: longhands::border_inline_start_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_start_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_start_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_start_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_start_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_start_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_start_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_start_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_start_width(
        &mut self,
        value: longhands::border_inline_start_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_start_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_end_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_color_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_color(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_color(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_color(
        &mut self,
        value: longhands::border_inline_end_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_color(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_end_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_style_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_style(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_style(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_style(
        &mut self,
        value: longhands::border_inline_end_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_style(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_inline_end_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_inline_end_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_inline_end_width_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `border_inline_end_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_inline_end_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_inline_end_width(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `border_inline_end_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_inline_end_width(
        &mut self,
        value: longhands::border_inline_end_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_inline_end_width(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `border_top_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_left_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_left_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_left_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_left_radius(
                reset_struct,
            );
    }

    /// Set the `border_top_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_left_radius(
        &mut self,
        value: longhands::border_top_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_left_radius(
                value,
            );
    }
    /// Inherit `border_top_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_top_right_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_top_right_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_top_right_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_top_right_radius(
                reset_struct,
            );
    }

    /// Set the `border_top_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_right_radius(
        &mut self,
        value: longhands::border_top_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_top_right_radius(
                value,
            );
    }
    /// Inherit `border_bottom_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_right_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_right_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_right_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_right_radius(
                reset_struct,
            );
    }

    /// Set the `border_bottom_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_right_radius(
        &mut self,
        value: longhands::border_bottom_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_right_radius(
                value,
            );
    }
    /// Inherit `border_bottom_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_bottom_left_radius_from(
                inherited_struct,
            );
    }

    /// Reset `border_bottom_left_radius` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_bottom_left_radius(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_bottom_left_radius(
                reset_struct,
            );
    }

    /// Set the `border_bottom_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_left_radius(
        &mut self,
        value: longhands::border_bottom_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_bottom_left_radius(
                value,
            );
    }
    /// Inherit `_moz_border_top_colors` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_border_top_colors(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_border_top_colors_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_border_top_colors` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_border_top_colors(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_border_top_colors(
                reset_struct,
            );
    }

    /// Set the `_moz_border_top_colors` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_border_top_colors(
        &mut self,
        value: longhands::_moz_border_top_colors::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_border_top_colors(
                value,
            );
    }
    /// Inherit `_moz_border_left_colors` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_border_left_colors(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_border_left_colors_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_border_left_colors` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_border_left_colors(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_border_left_colors(
                reset_struct,
            );
    }

    /// Set the `_moz_border_left_colors` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_border_left_colors(
        &mut self,
        value: longhands::_moz_border_left_colors::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_border_left_colors(
                value,
            );
    }
    /// Inherit `_moz_border_bottom_colors` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_border_bottom_colors(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_border_bottom_colors_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_border_bottom_colors` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_border_bottom_colors(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_border_bottom_colors(
                reset_struct,
            );
    }

    /// Set the `_moz_border_bottom_colors` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_border_bottom_colors(
        &mut self,
        value: longhands::_moz_border_bottom_colors::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_border_bottom_colors(
                value,
            );
    }
    /// Inherit `_moz_border_right_colors` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_border_right_colors(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_border_right_colors_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_border_right_colors` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_border_right_colors(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_border_right_colors(
                reset_struct,
            );
    }

    /// Set the `_moz_border_right_colors` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_border_right_colors(
        &mut self,
        value: longhands::_moz_border_right_colors::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_border_right_colors(
                value,
            );
    }
    /// Inherit `box_decoration_break` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_decoration_break(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_box_decoration_break_from(
                inherited_struct,
            );
    }

    /// Reset `box_decoration_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_decoration_break(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_box_decoration_break(
                reset_struct,
            );
    }

    /// Set the `box_decoration_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_decoration_break(
        &mut self,
        value: longhands::box_decoration_break::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_box_decoration_break(
                value,
            );
    }
    /// Inherit `_moz_float_edge` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_float_edge(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy__moz_float_edge_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_float_edge` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_float_edge(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset__moz_float_edge(
                reset_struct,
            );
    }

    /// Set the `_moz_float_edge` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_float_edge(
        &mut self,
        value: longhands::_moz_float_edge::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set__moz_float_edge(
                value,
            );
    }
    /// Inherit `border_image_source` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_source(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_source_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_source` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_source(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_source(
                reset_struct,
            );
    }

    /// Set the `border_image_source` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_source(
        &mut self,
        value: longhands::border_image_source::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_source(
                value,
            );
    }
    /// Inherit `border_image_outset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_outset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_outset_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_outset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_outset(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_outset(
                reset_struct,
            );
    }

    /// Set the `border_image_outset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_outset(
        &mut self,
        value: longhands::border_image_outset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_outset(
                value,
            );
    }
    /// Inherit `border_image_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_repeat(
                reset_struct,
            );
    }

    /// Set the `border_image_repeat` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_repeat(
        &mut self,
        value: longhands::border_image_repeat::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_repeat(
                value,
            );
    }
    /// Inherit `border_image_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_width_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_width(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_width(
                reset_struct,
            );
    }

    /// Set the `border_image_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_width(
        &mut self,
        value: longhands::border_image_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_width(
                value,
            );
    }
    /// Inherit `border_image_slice` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_slice(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_border();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.border.mutate()
            .copy_border_image_slice_from(
                inherited_struct,
            );
    }

    /// Reset `border_image_slice` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_image_slice(&mut self) {
        let reset_struct =
            self.reset_style.get_border();

        self.modified_reset = true;

        self.border.mutate()
            .reset_border_image_slice(
                reset_struct,
            );
    }

    /// Set the `border_image_slice` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_slice(
        &mut self,
        value: longhands::border_image_slice::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.border.mutate()
            .set_border_image_slice(
                value,
            );
    }
    /// Inherit `display` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_display(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;


        self.flags.insert(ComputedValueFlags::INHERITS_DISPLAY);

        self.box_.mutate()
            .copy_display_from(
                inherited_struct,
            );
    }

    /// Reset `display` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_display(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_display(
                reset_struct,
            );
    }

    /// Set the `display` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_display(
        &mut self,
        value: longhands::display::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_display(
                value,
            );
    }
    /// Inherit `_moz_top_layer` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_top_layer(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_top_layer_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_top_layer` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_top_layer(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_top_layer(
                reset_struct,
            );
    }

    /// Set the `_moz_top_layer` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_top_layer(
        &mut self,
        value: longhands::_moz_top_layer::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_top_layer(
                value,
            );
    }
    /// Inherit `position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_position_from(
                inherited_struct,
            );
    }

    /// Reset `position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_position(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_position(
                reset_struct,
            );
    }

    /// Set the `position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position(
        &mut self,
        value: longhands::position::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_position(
                value,
            );
    }
    /// Inherit `float` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_float(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_float_from(
                inherited_struct,
            );
    }

    /// Reset `float` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_float(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_float(
                reset_struct,
            );
    }

    /// Set the `float` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_float(
        &mut self,
        value: longhands::float::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_float(
                value,
            );
    }
    /// Inherit `clear` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clear(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_clear_from(
                inherited_struct,
            );
    }

    /// Reset `clear` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clear(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_clear(
                reset_struct,
            );
    }

    /// Set the `clear` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clear(
        &mut self,
        value: longhands::clear::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_clear(
                value,
            );
    }
    /// Inherit `vertical_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vertical_align(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_vertical_align_from(
                inherited_struct,
            );
    }

    /// Reset `vertical_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_vertical_align(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_vertical_align(
                reset_struct,
            );
    }

    /// Set the `vertical_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vertical_align(
        &mut self,
        value: longhands::vertical_align::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_vertical_align(
                value,
            );
    }
    /// Inherit `overflow_clip_box_inline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_inline(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_clip_box_inline_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_clip_box_inline` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_inline(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_clip_box_inline(
                reset_struct,
            );
    }

    /// Set the `overflow_clip_box_inline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_inline(
        &mut self,
        value: longhands::overflow_clip_box_inline::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_clip_box_inline(
                value,
            );
    }
    /// Inherit `overflow_clip_box_block` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_block(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_clip_box_block_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_clip_box_block` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_block(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_clip_box_block(
                reset_struct,
            );
    }

    /// Set the `overflow_clip_box_block` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_block(
        &mut self,
        value: longhands::overflow_clip_box_block::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_clip_box_block(
                value,
            );
    }
    /// Inherit `overflow_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_x_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_x(
                reset_struct,
            );
    }

    /// Set the `overflow_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_x(
        &mut self,
        value: longhands::overflow_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_x(
                value,
            );
    }
    /// Inherit `overflow_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overflow_y_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overflow_y(
                reset_struct,
            );
    }

    /// Set the `overflow_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_y(
        &mut self,
        value: longhands::overflow_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overflow_y(
                value,
            );
    }
    /// Inherit `transition_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_duration(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_duration_from(
                inherited_struct,
            );
    }

    /// Reset `transition_duration` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_duration(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_duration(
                reset_struct,
            );
    }

    /// Inherit `transition_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_timing_function_from(
                inherited_struct,
            );
    }

    /// Reset `transition_timing_function` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_timing_function(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_timing_function(
                reset_struct,
            );
    }

    /// Inherit `transition_property` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_property(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_property_from(
                inherited_struct,
            );
    }

    /// Reset `transition_property` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_property(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_property(
                reset_struct,
            );
    }

    /// Inherit `transition_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_delay(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transition_delay_from(
                inherited_struct,
            );
    }

    /// Reset `transition_delay` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transition_delay(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transition_delay(
                reset_struct,
            );
    }

    /// Inherit `animation_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_name(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_name_from(
                inherited_struct,
            );
    }

    /// Reset `animation_name` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_name(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_name(
                reset_struct,
            );
    }

    /// Inherit `animation_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_duration(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_duration_from(
                inherited_struct,
            );
    }

    /// Reset `animation_duration` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_duration(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_duration(
                reset_struct,
            );
    }

    /// Inherit `animation_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_timing_function_from(
                inherited_struct,
            );
    }

    /// Reset `animation_timing_function` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_timing_function(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_timing_function(
                reset_struct,
            );
    }

    /// Inherit `animation_iteration_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_iteration_count(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_iteration_count_from(
                inherited_struct,
            );
    }

    /// Reset `animation_iteration_count` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_iteration_count(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_iteration_count(
                reset_struct,
            );
    }

    /// Inherit `animation_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_direction_from(
                inherited_struct,
            );
    }

    /// Reset `animation_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_direction(
                reset_struct,
            );
    }

    /// Inherit `animation_play_state` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_play_state(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_play_state_from(
                inherited_struct,
            );
    }

    /// Reset `animation_play_state` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_play_state(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_play_state(
                reset_struct,
            );
    }

    /// Inherit `animation_fill_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_fill_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_fill_mode_from(
                inherited_struct,
            );
    }

    /// Reset `animation_fill_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_fill_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_fill_mode(
                reset_struct,
            );
    }

    /// Inherit `animation_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_delay(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_animation_delay_from(
                inherited_struct,
            );
    }

    /// Reset `animation_delay` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_animation_delay(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_animation_delay(
                reset_struct,
            );
    }

    /// Inherit `scroll_snap_points_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_points_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_points_x_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_points_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_points_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_points_x(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_points_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_points_x(
        &mut self,
        value: longhands::scroll_snap_points_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_points_x(
                value,
            );
    }
    /// Inherit `scroll_snap_points_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_points_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_points_y_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_points_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_points_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_points_y(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_points_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_points_y(
        &mut self,
        value: longhands::scroll_snap_points_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_points_y(
                value,
            );
    }
    /// Inherit `scroll_snap_destination` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_destination(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_destination_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_destination` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_destination(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_destination(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_destination` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_destination(
        &mut self,
        value: longhands::scroll_snap_destination::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_destination(
                value,
            );
    }
    /// Inherit `scroll_snap_coordinate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_coordinate(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_coordinate_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_coordinate` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_coordinate(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_coordinate(
                reset_struct,
            );
    }

    /// Inherit `transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_from(
                inherited_struct,
            );
    }

    /// Reset `transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform(
                reset_struct,
            );
    }

    /// Set the `transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform(
        &mut self,
        value: longhands::transform::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform(
                value,
            );
    }
    /// Inherit `scroll_behavior` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_behavior(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_behavior_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_behavior` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_behavior(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_behavior(
                reset_struct,
            );
    }

    /// Set the `scroll_behavior` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_behavior(
        &mut self,
        value: longhands::scroll_behavior::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_behavior(
                value,
            );
    }
    /// Inherit `scroll_snap_type_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_type_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_type_x_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_type_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_type_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_type_x(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_type_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type_x(
        &mut self,
        value: longhands::scroll_snap_type_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_type_x(
                value,
            );
    }
    /// Inherit `scroll_snap_type_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_type_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_scroll_snap_type_y_from(
                inherited_struct,
            );
    }

    /// Reset `scroll_snap_type_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_type_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_scroll_snap_type_y(
                reset_struct,
            );
    }

    /// Set the `scroll_snap_type_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type_y(
        &mut self,
        value: longhands::scroll_snap_type_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_scroll_snap_type_y(
                value,
            );
    }
    /// Inherit `overscroll_behavior_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overscroll_behavior_x_from(
                inherited_struct,
            );
    }

    /// Reset `overscroll_behavior_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_x(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overscroll_behavior_x(
                reset_struct,
            );
    }

    /// Set the `overscroll_behavior_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_x(
        &mut self,
        value: longhands::overscroll_behavior_x::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overscroll_behavior_x(
                value,
            );
    }
    /// Inherit `overscroll_behavior_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_overscroll_behavior_y_from(
                inherited_struct,
            );
    }

    /// Reset `overscroll_behavior_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_y(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_overscroll_behavior_y(
                reset_struct,
            );
    }

    /// Set the `overscroll_behavior_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_y(
        &mut self,
        value: longhands::overscroll_behavior_y::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_overscroll_behavior_y(
                value,
            );
    }
    /// Inherit `isolation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_isolation(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_isolation_from(
                inherited_struct,
            );
    }

    /// Reset `isolation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_isolation(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_isolation(
                reset_struct,
            );
    }

    /// Set the `isolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_isolation(
        &mut self,
        value: longhands::isolation::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_isolation(
                value,
            );
    }
    /// Inherit `page_break_after` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_after(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_after_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_after` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_after(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_after(
                reset_struct,
            );
    }

    /// Set the `page_break_after` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_after(
        &mut self,
        value: longhands::page_break_after::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_after(
                value,
            );
    }
    /// Inherit `page_break_before` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_before(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_before_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_before` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_before(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_before(
                reset_struct,
            );
    }

    /// Set the `page_break_before` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_before(
        &mut self,
        value: longhands::page_break_before::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_before(
                value,
            );
    }
    /// Inherit `page_break_inside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_break_inside(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_page_break_inside_from(
                inherited_struct,
            );
    }

    /// Reset `page_break_inside` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_page_break_inside(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_page_break_inside(
                reset_struct,
            );
    }

    /// Set the `page_break_inside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_break_inside(
        &mut self,
        value: longhands::page_break_inside::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_page_break_inside(
                value,
            );
    }
    /// Inherit `resize` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_resize(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_resize_from(
                inherited_struct,
            );
    }

    /// Reset `resize` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_resize(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_resize(
                reset_struct,
            );
    }

    /// Set the `resize` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_resize(
        &mut self,
        value: longhands::resize::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_resize(
                value,
            );
    }
    /// Inherit `perspective` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_perspective_from(
                inherited_struct,
            );
    }

    /// Reset `perspective` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_perspective(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_perspective(
                reset_struct,
            );
    }

    /// Set the `perspective` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective(
        &mut self,
        value: longhands::perspective::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_perspective(
                value,
            );
    }
    /// Inherit `perspective_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_perspective_origin_from(
                inherited_struct,
            );
    }

    /// Reset `perspective_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_perspective_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_perspective_origin(
                reset_struct,
            );
    }

    /// Set the `perspective_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective_origin(
        &mut self,
        value: longhands::perspective_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_perspective_origin(
                value,
            );
    }
    /// Inherit `backface_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_backface_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_backface_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `backface_visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_backface_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_backface_visibility(
                reset_struct,
            );
    }

    /// Set the `backface_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_backface_visibility(
        &mut self,
        value: longhands::backface_visibility::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_backface_visibility(
                value,
            );
    }
    /// Inherit `transform_box` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_box(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_box_from(
                inherited_struct,
            );
    }

    /// Reset `transform_box` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_box(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_box(
                reset_struct,
            );
    }

    /// Set the `transform_box` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_box(
        &mut self,
        value: longhands::transform_box::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_box(
                value,
            );
    }
    /// Inherit `transform_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_style_from(
                inherited_struct,
            );
    }

    /// Reset `transform_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_style(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_style(
                reset_struct,
            );
    }

    /// Set the `transform_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_style(
        &mut self,
        value: longhands::transform_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_style(
                value,
            );
    }
    /// Inherit `transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_transform_origin_from(
                inherited_struct,
            );
    }

    /// Reset `transform_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_transform_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_transform_origin(
                reset_struct,
            );
    }

    /// Set the `transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_origin(
        &mut self,
        value: longhands::transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_transform_origin(
                value,
            );
    }
    /// Inherit `contain` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_contain(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_contain_from(
                inherited_struct,
            );
    }

    /// Reset `contain` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_contain(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_contain(
                reset_struct,
            );
    }

    /// Set the `contain` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_contain(
        &mut self,
        value: longhands::contain::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_contain(
                value,
            );
    }
    /// Inherit `_moz_appearance` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_appearance(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_appearance_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_appearance` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_appearance(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_appearance(
                reset_struct,
            );
    }

    /// Set the `_moz_appearance` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_appearance(
        &mut self,
        value: longhands::_moz_appearance::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_appearance(
                value,
            );
    }
    /// Inherit `_moz_binding` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_binding(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_binding_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_binding` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_binding(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_binding(
                reset_struct,
            );
    }

    /// Set the `_moz_binding` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_binding(
        &mut self,
        value: longhands::_moz_binding::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_binding(
                value,
            );
    }
    /// Inherit `_moz_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_orient(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy__moz_orient_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_orient` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_orient(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset__moz_orient(
                reset_struct,
            );
    }

    /// Set the `_moz_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_orient(
        &mut self,
        value: longhands::_moz_orient::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set__moz_orient(
                value,
            );
    }
    /// Inherit `will_change` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_will_change(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_will_change_from(
                inherited_struct,
            );
    }

    /// Reset `will_change` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_will_change(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_will_change(
                reset_struct,
            );
    }

    /// Set the `will_change` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_will_change(
        &mut self,
        value: longhands::will_change::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_will_change(
                value,
            );
    }
    /// Inherit `shape_image_threshold` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_image_threshold(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_shape_image_threshold_from(
                inherited_struct,
            );
    }

    /// Reset `shape_image_threshold` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_image_threshold(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_shape_image_threshold(
                reset_struct,
            );
    }

    /// Set the `shape_image_threshold` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_image_threshold(
        &mut self,
        value: longhands::shape_image_threshold::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_shape_image_threshold(
                value,
            );
    }
    /// Inherit `shape_outside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_outside(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_shape_outside_from(
                inherited_struct,
            );
    }

    /// Reset `shape_outside` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_outside(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_shape_outside(
                reset_struct,
            );
    }

    /// Set the `shape_outside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_outside(
        &mut self,
        value: longhands::shape_outside::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_shape_outside(
                value,
            );
    }
    /// Inherit `touch_action` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_touch_action(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_box();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.box_.mutate()
            .copy_touch_action_from(
                inherited_struct,
            );
    }

    /// Reset `touch_action` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_touch_action(&mut self) {
        let reset_struct =
            self.reset_style.get_box();

        self.modified_reset = true;

        self.box_.mutate()
            .reset_touch_action(
                reset_struct,
            );
    }

    /// Set the `touch_action` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_touch_action(
        &mut self,
        value: longhands::touch_action::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.box_.mutate()
            .set_touch_action(
                value,
            );
    }
    /// Inherit `color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_color();




        self.color.mutate()
            .copy_color_from(
                inherited_struct,
            );
    }

    /// Reset `color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color(&mut self) {
        let reset_struct =
            self.reset_style.get_color();


        self.color.mutate()
            .reset_color(
                reset_struct,
            );
    }

    /// Set the `color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color(
        &mut self,
        value: longhands::color::computed_value::T
    ) {

        
        self.color.mutate()
            .set_color(
                value,
            );
    }
    /// Inherit `column_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_width_from(
                inherited_struct,
            );
    }

    /// Reset `column_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_width(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_width(
                reset_struct,
            );
    }

    /// Set the `column_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_width(
        &mut self,
        value: longhands::column_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_width(
                value,
            );
    }
    /// Inherit `column_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_count(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_count_from(
                inherited_struct,
            );
    }

    /// Reset `column_count` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_count(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_count(
                reset_struct,
            );
    }

    /// Set the `column_count` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_count(
        &mut self,
        value: longhands::column_count::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_count(
                value,
            );
    }
    /// Inherit `column_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_gap_from(
                inherited_struct,
            );
    }

    /// Reset `column_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_gap(
                reset_struct,
            );
    }

    /// Set the `column_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_gap(
        &mut self,
        value: longhands::column_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_gap(
                value,
            );
    }
    /// Inherit `column_fill` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_fill(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_fill_from(
                inherited_struct,
            );
    }

    /// Reset `column_fill` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_fill(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_fill(
                reset_struct,
            );
    }

    /// Set the `column_fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_fill(
        &mut self,
        value: longhands::column_fill::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_fill(
                value,
            );
    }
    /// Inherit `column_rule_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_width_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_width(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_width(
                reset_struct,
            );
    }

    /// Set the `column_rule_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_width(
        &mut self,
        value: longhands::column_rule_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_width(
                value,
            );
    }
    /// Inherit `column_rule_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_color_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_color(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_color(
                reset_struct,
            );
    }

    /// Set the `column_rule_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_color(
        &mut self,
        value: longhands::column_rule_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_color(
                value,
            );
    }
    /// Inherit `column_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_span(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_span_from(
                inherited_struct,
            );
    }

    /// Reset `column_span` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_span(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_span(
                reset_struct,
            );
    }

    /// Set the `column_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_span(
        &mut self,
        value: longhands::column_span::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_span(
                value,
            );
    }
    /// Inherit `column_rule_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_column();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.column.mutate()
            .copy_column_rule_style_from(
                inherited_struct,
            );
    }

    /// Reset `column_rule_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_column_rule_style(&mut self) {
        let reset_struct =
            self.reset_style.get_column();

        self.modified_reset = true;

        self.column.mutate()
            .reset_column_rule_style(
                reset_struct,
            );
    }

    /// Set the `column_rule_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_style(
        &mut self,
        value: longhands::column_rule_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.column.mutate()
            .set_column_rule_style(
                value,
            );
    }
    /// Inherit `content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;

        self.flags.insert(ComputedValueFlags::INHERITS_CONTENT);


        self.counters.mutate()
            .copy_content_from(
                inherited_struct,
            );
    }

    /// Reset `content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_content(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_content(
                reset_struct,
            );
    }

    /// Set the `content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_content(
        &mut self,
        value: longhands::content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_content(
                value,
                self.device,
            );
    }
    /// Inherit `counter_increment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_increment(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.counters.mutate()
            .copy_counter_increment_from(
                inherited_struct,
            );
    }

    /// Reset `counter_increment` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_counter_increment(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_counter_increment(
                reset_struct,
            );
    }

    /// Set the `counter_increment` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_increment(
        &mut self,
        value: longhands::counter_increment::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_counter_increment(
                value,
            );
    }
    /// Inherit `counter_reset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_reset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_counters();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.counters.mutate()
            .copy_counter_reset_from(
                inherited_struct,
            );
    }

    /// Reset `counter_reset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_counter_reset(&mut self) {
        let reset_struct =
            self.reset_style.get_counters();

        self.modified_reset = true;

        self.counters.mutate()
            .reset_counter_reset(
                reset_struct,
            );
    }

    /// Set the `counter_reset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_reset(
        &mut self,
        value: longhands::counter_reset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.counters.mutate()
            .set_counter_reset(
                value,
            );
    }
    /// Inherit `opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_opacity(
                reset_struct,
            );
    }

    /// Set the `opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_opacity(
        &mut self,
        value: longhands::opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_opacity(
                value,
            );
    }
    /// Inherit `box_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_box_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `box_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_box_shadow(
                reset_struct,
            );
    }

    /// Inherit `clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_clip_from(
                inherited_struct,
            );
    }

    /// Reset `clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_clip(
                reset_struct,
            );
    }

    /// Set the `clip` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip(
        &mut self,
        value: longhands::clip::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_clip(
                value,
            );
    }
    /// Inherit `filter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_filter(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_filter_from(
                inherited_struct,
            );
    }

    /// Reset `filter` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_filter(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_filter(
                reset_struct,
            );
    }

    /// Inherit `mix_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mix_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_effects();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.effects.mutate()
            .copy_mix_blend_mode_from(
                inherited_struct,
            );
    }

    /// Reset `mix_blend_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mix_blend_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_effects();

        self.modified_reset = true;

        self.effects.mutate()
            .reset_mix_blend_mode(
                reset_struct,
            );
    }

    /// Set the `mix_blend_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mix_blend_mode(
        &mut self,
        value: longhands::mix_blend_mode::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.effects.mutate()
            .set_mix_blend_mode(
                value,
            );
    }
    /// Inherit `font_family` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_family(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_family_from(
                inherited_struct,
            );
    }

    /// Reset `font_family` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_family(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_family(
                reset_struct,
            );
    }

    /// Set the `font_family` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_family(
        &mut self,
        value: longhands::font_family::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_family(
                value,
            );
    }
    /// Inherit `font_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_style_from(
                inherited_struct,
            );
    }

    /// Reset `font_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_style(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_style(
                reset_struct,
            );
    }

    /// Set the `font_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_style(
        &mut self,
        value: longhands::font_style::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_style(
                value,
            );
    }
    /// Inherit `font_variant_caps` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_caps(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_caps_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_caps` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_caps(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_caps(
                reset_struct,
            );
    }

    /// Set the `font_variant_caps` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_caps(
        &mut self,
        value: longhands::font_variant_caps::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_caps(
                value,
            );
    }
    /// Inherit `font_weight` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_weight(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_weight_from(
                inherited_struct,
            );
    }

    /// Reset `font_weight` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_weight(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_weight(
                reset_struct,
            );
    }

    /// Set the `font_weight` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_weight(
        &mut self,
        value: longhands::font_weight::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_weight(
                value,
            );
    }
    /// Inherit `font_size_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_size_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_size_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `font_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_size_adjust(
                reset_struct,
            );
    }

    /// Set the `font_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_size_adjust(
        &mut self,
        value: longhands::font_size_adjust::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_size_adjust(
                value,
            );
    }
    /// Inherit `font_synthesis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_synthesis(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_synthesis_from(
                inherited_struct,
            );
    }

    /// Reset `font_synthesis` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_synthesis(
                reset_struct,
            );
    }

    /// Set the `font_synthesis` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis(
        &mut self,
        value: longhands::font_synthesis::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_synthesis(
                value,
            );
    }
    /// Inherit `font_stretch` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_stretch(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_stretch_from(
                inherited_struct,
            );
    }

    /// Reset `font_stretch` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_stretch(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_stretch(
                reset_struct,
            );
    }

    /// Set the `font_stretch` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_stretch(
        &mut self,
        value: longhands::font_stretch::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_stretch(
                value,
            );
    }
    /// Inherit `font_kerning` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_kerning(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_kerning_from(
                inherited_struct,
            );
    }

    /// Reset `font_kerning` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_kerning(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_kerning(
                reset_struct,
            );
    }

    /// Set the `font_kerning` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_kerning(
        &mut self,
        value: longhands::font_kerning::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_kerning(
                value,
            );
    }
    /// Inherit `font_variant_alternates` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_alternates(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_alternates_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_alternates` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_alternates(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_alternates(
                reset_struct,
            );
    }

    /// Set the `font_variant_alternates` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_alternates(
        &mut self,
        value: longhands::font_variant_alternates::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_alternates(
                value,
                self.device,
            );
    }
    /// Inherit `font_variant_east_asian` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_east_asian(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_east_asian_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_east_asian` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_east_asian(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_east_asian(
                reset_struct,
            );
    }

    /// Set the `font_variant_east_asian` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_east_asian(
        &mut self,
        value: longhands::font_variant_east_asian::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_east_asian(
                value,
            );
    }
    /// Inherit `font_variant_ligatures` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_ligatures(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_ligatures_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_ligatures` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_ligatures(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_ligatures(
                reset_struct,
            );
    }

    /// Set the `font_variant_ligatures` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_ligatures(
        &mut self,
        value: longhands::font_variant_ligatures::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_ligatures(
                value,
            );
    }
    /// Inherit `font_variant_numeric` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_numeric(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_numeric_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_numeric` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_numeric(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_numeric(
                reset_struct,
            );
    }

    /// Set the `font_variant_numeric` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_numeric(
        &mut self,
        value: longhands::font_variant_numeric::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_numeric(
                value,
            );
    }
    /// Inherit `font_variant_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variant_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variant_position_from(
                inherited_struct,
            );
    }

    /// Reset `font_variant_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_position(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variant_position(
                reset_struct,
            );
    }

    /// Set the `font_variant_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_position(
        &mut self,
        value: longhands::font_variant_position::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variant_position(
                value,
            );
    }
    /// Inherit `font_feature_settings` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_feature_settings(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_feature_settings_from(
                inherited_struct,
            );
    }

    /// Reset `font_feature_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_feature_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_feature_settings(
                reset_struct,
            );
    }

    /// Set the `font_feature_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_feature_settings(
        &mut self,
        value: longhands::font_feature_settings::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_feature_settings(
                value,
            );
    }
    /// Inherit `font_variation_settings` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_variation_settings(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_variation_settings_from(
                inherited_struct,
            );
    }

    /// Reset `font_variation_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variation_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_variation_settings(
                reset_struct,
            );
    }

    /// Set the `font_variation_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variation_settings(
        &mut self,
        value: longhands::font_variation_settings::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_variation_settings(
                value,
            );
    }
    /// Inherit `font_language_override` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_font_language_override(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy_font_language_override_from(
                inherited_struct,
            );
    }

    /// Reset `font_language_override` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_language_override(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset_font_language_override(
                reset_struct,
            );
    }

    /// Set the `font_language_override` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_language_override(
        &mut self,
        value: longhands::font_language_override::computed_value::T
    ) {

        
        self.font.mutate()
            .set_font_language_override(
                value,
            );
    }
    /// Inherit `_x_lang` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_lang(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__x_lang_from(
                inherited_struct,
            );
    }

    /// Reset `_x_lang` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_lang(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__x_lang(
                reset_struct,
            );
    }

    /// Set the `_x_lang` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_lang(
        &mut self,
        value: longhands::_x_lang::computed_value::T
    ) {

        
        self.font.mutate()
            .set__x_lang(
                value,
            );
    }
    /// Inherit `_moz_script_size_multiplier` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_size_multiplier(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_size_multiplier_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_size_multiplier` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_size_multiplier(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_size_multiplier(
                reset_struct,
            );
    }

    /// Set the `_moz_script_size_multiplier` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_size_multiplier(
        &mut self,
        value: longhands::_moz_script_size_multiplier::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_size_multiplier(
                value,
            );
    }
    /// Inherit `_moz_script_level` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_level(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_level_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_level` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_level(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_level(
                reset_struct,
            );
    }

    /// Set the `_moz_script_level` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_level(
        &mut self,
        value: longhands::_moz_script_level::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_level(
                value,
            );
    }
    /// Inherit `_moz_math_display` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_math_display(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_math_display_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_math_display` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_math_display(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_math_display(
                reset_struct,
            );
    }

    /// Set the `_moz_math_display` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_math_display(
        &mut self,
        value: longhands::_moz_math_display::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_math_display(
                value,
            );
    }
    /// Inherit `_moz_math_variant` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_math_variant(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_math_variant_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_math_variant` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_math_variant(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_math_variant(
                reset_struct,
            );
    }

    /// Set the `_moz_math_variant` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_math_variant(
        &mut self,
        value: longhands::_moz_math_variant::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_math_variant(
                value,
            );
    }
    /// Inherit `_moz_script_min_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_script_min_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_script_min_size_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_script_min_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_script_min_size(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_script_min_size(
                reset_struct,
            );
    }

    /// Set the `_moz_script_min_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_script_min_size(
        &mut self,
        value: longhands::_moz_script_min_size::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_script_min_size(
                value,
            );
    }
    /// Inherit `_x_text_zoom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_text_zoom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__x_text_zoom_from(
                inherited_struct,
            );
    }

    /// Reset `_x_text_zoom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_text_zoom(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__x_text_zoom(
                reset_struct,
            );
    }

    /// Set the `_x_text_zoom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_text_zoom(
        &mut self,
        value: longhands::_x_text_zoom::computed_value::T
    ) {

        
        self.font.mutate()
            .set__x_text_zoom(
                value,
            );
    }
    /// Inherit `_moz_osx_font_smoothing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_osx_font_smoothing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_osx_font_smoothing_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_osx_font_smoothing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_osx_font_smoothing(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_osx_font_smoothing(
                reset_struct,
            );
    }

    /// Set the `_moz_osx_font_smoothing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_osx_font_smoothing(
        &mut self,
        value: longhands::_moz_osx_font_smoothing::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_osx_font_smoothing(
                value,
            );
    }
    /// Inherit `_moz_font_smoothing_background_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_font_smoothing_background_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_font_smoothing_background_color_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_font_smoothing_background_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_font_smoothing_background_color(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_font_smoothing_background_color(
                reset_struct,
            );
    }

    /// Set the `_moz_font_smoothing_background_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_font_smoothing_background_color(
        &mut self,
        value: longhands::_moz_font_smoothing_background_color::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_font_smoothing_background_color(
                value,
            );
    }
    /// Inherit `_moz_min_font_size_ratio` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_min_font_size_ratio(&mut self) {
        let inherited_struct =
            self.inherited_style.get_font();




        self.font.mutate()
            .copy__moz_min_font_size_ratio_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_min_font_size_ratio` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_min_font_size_ratio(&mut self) {
        let reset_struct =
            self.reset_style.get_font();


        self.font.mutate()
            .reset__moz_min_font_size_ratio(
                reset_struct,
            );
    }

    /// Set the `_moz_min_font_size_ratio` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_min_font_size_ratio(
        &mut self,
        value: longhands::_moz_min_font_size_ratio::computed_value::T
    ) {

        
        self.font.mutate()
            .set__moz_min_font_size_ratio(
                value,
            );
    }
    /// Inherit `visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_visibility(
                reset_struct,
            );
    }

    /// Set the `visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_visibility(
        &mut self,
        value: longhands::visibility::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_visibility(
                value,
            );
    }
    /// Inherit `writing_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_writing_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_writing_mode_from(
                inherited_struct,
            );
    }

    /// Reset `writing_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_writing_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_writing_mode(
                reset_struct,
            );
    }

    /// Set the `writing_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_writing_mode(
        &mut self,
        value: longhands::writing_mode::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_writing_mode(
                value,
            );
    }
    /// Inherit `direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_direction(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_direction_from(
                inherited_struct,
            );
    }

    /// Reset `direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_direction(
                reset_struct,
            );
    }

    /// Set the `direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_direction(
        &mut self,
        value: longhands::direction::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_direction(
                value,
            );
    }
    /// Inherit `text_orientation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_orientation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_text_orientation_from(
                inherited_struct,
            );
    }

    /// Reset `text_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_text_orientation(
                reset_struct,
            );
    }

    /// Set the `text_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_orientation(
        &mut self,
        value: longhands::text_orientation::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_text_orientation(
                value,
            );
    }
    /// Inherit `color_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_color_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `color_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_color_adjust(
                reset_struct,
            );
    }

    /// Set the `color_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_adjust(
        &mut self,
        value: longhands::color_adjust::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_color_adjust(
                value,
            );
    }
    /// Inherit `image_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_image_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_image_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `image_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_image_rendering(
                reset_struct,
            );
    }

    /// Set the `image_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_rendering(
        &mut self,
        value: longhands::image_rendering::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_image_rendering(
                value,
            );
    }
    /// Inherit `image_orientation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_image_orientation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedbox();




        self.inheritedbox.mutate()
            .copy_image_orientation_from(
                inherited_struct,
            );
    }

    /// Reset `image_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedbox();


        self.inheritedbox.mutate()
            .reset_image_orientation(
                reset_struct,
            );
    }

    /// Set the `image_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_orientation(
        &mut self,
        value: longhands::image_orientation::computed_value::T
    ) {

        
        self.inheritedbox.mutate()
            .set_image_orientation(
                value,
            );
    }
    /// Inherit `border_collapse` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_collapse(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_border_collapse_from(
                inherited_struct,
            );
    }

    /// Reset `border_collapse` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_collapse(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_border_collapse(
                reset_struct,
            );
    }

    /// Set the `border_collapse` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_collapse(
        &mut self,
        value: longhands::border_collapse::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_border_collapse(
                value,
            );
    }
    /// Inherit `empty_cells` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_empty_cells(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_empty_cells_from(
                inherited_struct,
            );
    }

    /// Reset `empty_cells` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_empty_cells(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_empty_cells(
                reset_struct,
            );
    }

    /// Set the `empty_cells` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_empty_cells(
        &mut self,
        value: longhands::empty_cells::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_empty_cells(
                value,
            );
    }
    /// Inherit `caption_side` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_caption_side(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_caption_side_from(
                inherited_struct,
            );
    }

    /// Reset `caption_side` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caption_side(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_caption_side(
                reset_struct,
            );
    }

    /// Set the `caption_side` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caption_side(
        &mut self,
        value: longhands::caption_side::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_caption_side(
                value,
            );
    }
    /// Inherit `border_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtable();




        self.inheritedtable.mutate()
            .copy_border_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `border_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtable();


        self.inheritedtable.mutate()
            .reset_border_spacing(
                reset_struct,
            );
    }

    /// Set the `border_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_spacing(
        &mut self,
        value: longhands::border_spacing::computed_value::T
    ) {

        
        self.inheritedtable.mutate()
            .set_border_spacing(
                value,
            );
    }
    /// Inherit `line_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_line_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_line_height_from(
                inherited_struct,
            );
    }

    /// Reset `line_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_line_height(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_line_height(
                reset_struct,
            );
    }

    /// Set the `line_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_line_height(
        &mut self,
        value: longhands::line_height::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_line_height(
                value,
            );
    }
    /// Inherit `text_transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_transform(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_transform_from(
                inherited_struct,
            );
    }

    /// Reset `text_transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_transform(
                reset_struct,
            );
    }

    /// Set the `text_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_transform(
        &mut self,
        value: longhands::text_transform::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_transform(
                value,
            );
    }
    /// Inherit `hyphens` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_hyphens(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_hyphens_from(
                inherited_struct,
            );
    }

    /// Reset `hyphens` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_hyphens(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_hyphens(
                reset_struct,
            );
    }

    /// Set the `hyphens` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_hyphens(
        &mut self,
        value: longhands::hyphens::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_hyphens(
                value,
            );
    }
    /// Inherit `_moz_text_size_adjust` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_text_size_adjust(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_text_size_adjust_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_text_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_text_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_text_size_adjust(
                reset_struct,
            );
    }

    /// Set the `_moz_text_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_text_size_adjust(
        &mut self,
        value: longhands::_moz_text_size_adjust::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_text_size_adjust(
                value,
            );
    }
    /// Inherit `text_indent` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_indent(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_indent_from(
                inherited_struct,
            );
    }

    /// Reset `text_indent` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_indent(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_indent(
                reset_struct,
            );
    }

    /// Set the `text_indent` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_indent(
        &mut self,
        value: longhands::text_indent::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_indent(
                value,
            );
    }
    /// Inherit `overflow_wrap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_wrap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_overflow_wrap_from(
                inherited_struct,
            );
    }

    /// Reset `overflow_wrap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_wrap(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_overflow_wrap(
                reset_struct,
            );
    }

    /// Set the `overflow_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_wrap(
        &mut self,
        value: longhands::overflow_wrap::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_overflow_wrap(
                value,
            );
    }
    /// Inherit `word_break` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_word_break(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_word_break_from(
                inherited_struct,
            );
    }

    /// Reset `word_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_break(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_word_break(
                reset_struct,
            );
    }

    /// Set the `word_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_break(
        &mut self,
        value: longhands::word_break::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_word_break(
                value,
            );
    }
    /// Inherit `text_justify` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_justify(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_justify_from(
                inherited_struct,
            );
    }

    /// Reset `text_justify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_justify(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_justify(
                reset_struct,
            );
    }

    /// Set the `text_justify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_justify(
        &mut self,
        value: longhands::text_justify::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_justify(
                value,
            );
    }
    /// Inherit `text_align_last` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_align_last(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_align_last_from(
                inherited_struct,
            );
    }

    /// Reset `text_align_last` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align_last(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_align_last(
                reset_struct,
            );
    }

    /// Set the `text_align_last` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align_last(
        &mut self,
        value: longhands::text_align_last::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_align_last(
                value,
            );
    }
    /// Inherit `text_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_align_from(
                inherited_struct,
            );
    }

    /// Reset `text_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_align(
                reset_struct,
            );
    }

    /// Set the `text_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align(
        &mut self,
        value: longhands::text_align::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_align(
                value,
            );
    }
    /// Inherit `letter_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_letter_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_letter_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `letter_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_letter_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_letter_spacing(
                reset_struct,
            );
    }

    /// Set the `letter_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_letter_spacing(
        &mut self,
        value: longhands::letter_spacing::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_letter_spacing(
                value,
            );
    }
    /// Inherit `word_spacing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_word_spacing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_word_spacing_from(
                inherited_struct,
            );
    }

    /// Reset `word_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_word_spacing(
                reset_struct,
            );
    }

    /// Set the `word_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_spacing(
        &mut self,
        value: longhands::word_spacing::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_word_spacing(
                value,
            );
    }
    /// Inherit `white_space` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_white_space(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_white_space_from(
                inherited_struct,
            );
    }

    /// Reset `white_space` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_white_space(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_white_space(
                reset_struct,
            );
    }

    /// Set the `white_space` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_white_space(
        &mut self,
        value: longhands::white_space::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_white_space(
                value,
            );
    }
    /// Inherit `text_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `text_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_shadow(
                reset_struct,
            );
    }

    /// Inherit `text_emphasis_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_style_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_style(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_style(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_style(
        &mut self,
        value: longhands::text_emphasis_style::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_style(
                value,
            );
    }
    /// Inherit `text_emphasis_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_position_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_position(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_position(
        &mut self,
        value: longhands::text_emphasis_position::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_position(
                value,
            );
    }
    /// Inherit `text_emphasis_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_emphasis_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_emphasis_color_from(
                inherited_struct,
            );
    }

    /// Reset `text_emphasis_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_emphasis_color(
                reset_struct,
            );
    }

    /// Set the `text_emphasis_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_color(
        &mut self,
        value: longhands::text_emphasis_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_emphasis_color(
                value,
            );
    }
    /// Inherit `_moz_tab_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_tab_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_tab_size_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_tab_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_tab_size(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_tab_size(
                reset_struct,
            );
    }

    /// Set the `_moz_tab_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_tab_size(
        &mut self,
        value: longhands::_moz_tab_size::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_tab_size(
                value,
            );
    }
    /// Inherit `_webkit_text_fill_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_fill_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_fill_color_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_fill_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_fill_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_fill_color(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_fill_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_fill_color(
        &mut self,
        value: longhands::_webkit_text_fill_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_fill_color(
                value,
            );
    }
    /// Inherit `_webkit_text_stroke_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_stroke_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_stroke_color_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_stroke_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_stroke_color(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_stroke_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_color(
        &mut self,
        value: longhands::_webkit_text_stroke_color::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_stroke_color(
                value,
            );
    }
    /// Inherit `_webkit_text_stroke_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_text_stroke_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__webkit_text_stroke_width_from(
                inherited_struct,
            );
    }

    /// Reset `_webkit_text_stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__webkit_text_stroke_width(
                reset_struct,
            );
    }

    /// Set the `_webkit_text_stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_width(
        &mut self,
        value: longhands::_webkit_text_stroke_width::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__webkit_text_stroke_width(
                value,
            );
    }
    /// Inherit `ruby_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ruby_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_ruby_align_from(
                inherited_struct,
            );
    }

    /// Reset `ruby_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_ruby_align(
                reset_struct,
            );
    }

    /// Set the `ruby_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_align(
        &mut self,
        value: longhands::ruby_align::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_ruby_align(
                value,
            );
    }
    /// Inherit `ruby_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ruby_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_ruby_position_from(
                inherited_struct,
            );
    }

    /// Reset `ruby_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_ruby_position(
                reset_struct,
            );
    }

    /// Set the `ruby_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_position(
        &mut self,
        value: longhands::ruby_position::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_ruby_position(
                value,
            );
    }
    /// Inherit `text_combine_upright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_combine_upright(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_combine_upright_from(
                inherited_struct,
            );
    }

    /// Reset `text_combine_upright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_combine_upright(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_combine_upright(
                reset_struct,
            );
    }

    /// Set the `text_combine_upright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_combine_upright(
        &mut self,
        value: longhands::text_combine_upright::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_combine_upright(
                value,
            );
    }
    /// Inherit `text_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy_text_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `text_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset_text_rendering(
                reset_struct,
            );
    }

    /// Set the `text_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_rendering(
        &mut self,
        value: longhands::text_rendering::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set_text_rendering(
                value,
            );
    }
    /// Inherit `_moz_control_character_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_control_character_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedtext();




        self.inheritedtext.mutate()
            .copy__moz_control_character_visibility_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_control_character_visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_control_character_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedtext();


        self.inheritedtext.mutate()
            .reset__moz_control_character_visibility(
                reset_struct,
            );
    }

    /// Set the `_moz_control_character_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_control_character_visibility(
        &mut self,
        value: longhands::_moz_control_character_visibility::computed_value::T
    ) {

        
        self.inheritedtext.mutate()
            .set__moz_control_character_visibility(
                value,
            );
    }
    /// Inherit `list_style_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_position_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_position(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_position(
                reset_struct,
            );
    }

    /// Set the `list_style_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_position(
        &mut self,
        value: longhands::list_style_position::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_position(
                value,
            );
    }
    /// Inherit `list_style_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_type(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_type_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_type` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_type(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_type(
                reset_struct,
            );
    }

    /// Set the `list_style_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_type(
        &mut self,
        value: longhands::list_style_type::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_type(
                value,
                self.device,
            );
    }
    /// Inherit `list_style_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_list_style_image(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_list_style_image_from(
                inherited_struct,
            );
    }

    /// Reset `list_style_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_image(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_list_style_image(
                reset_struct,
            );
    }

    /// Set the `list_style_image` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_image(
        &mut self,
        value: longhands::list_style_image::computed_value::T
    ) {

        
        self.list.mutate()
            .set_list_style_image(
                value,
            );
    }
    /// Inherit `quotes` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_quotes(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy_quotes_from(
                inherited_struct,
            );
    }

    /// Reset `quotes` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_quotes(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset_quotes(
                reset_struct,
            );
    }

    /// Set the `quotes` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_quotes(
        &mut self,
        value: longhands::quotes::computed_value::T
    ) {

        
        self.list.mutate()
            .set_quotes(
                value,
            );
    }
    /// Inherit `_moz_image_region` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_image_region(&mut self) {
        let inherited_struct =
            self.inherited_style.get_list();




        self.list.mutate()
            .copy__moz_image_region_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_image_region` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_image_region(&mut self) {
        let reset_struct =
            self.reset_style.get_list();


        self.list.mutate()
            .reset__moz_image_region(
                reset_struct,
            );
    }

    /// Set the `_moz_image_region` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_image_region(
        &mut self,
        value: longhands::_moz_image_region::computed_value::T
    ) {

        
        self.list.mutate()
            .set__moz_image_region(
                value,
            );
    }
    /// Inherit `margin_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_top_from(
                inherited_struct,
            );
    }

    /// Reset `margin_top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_top(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_top(
                reset_struct,
            );
    }

    /// Set the `margin_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_top(
        &mut self,
        value: longhands::margin_top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_top(
                value,
            );
    }
    /// Inherit `margin_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_left_from(
                inherited_struct,
            );
    }

    /// Reset `margin_left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_left(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_left(
                reset_struct,
            );
    }

    /// Set the `margin_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_left(
        &mut self,
        value: longhands::margin_left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_left(
                value,
            );
    }
    /// Inherit `margin_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `margin_bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_bottom(
                reset_struct,
            );
    }

    /// Set the `margin_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_bottom(
        &mut self,
        value: longhands::margin_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_bottom(
                value,
            );
    }
    /// Inherit `margin_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_right_from(
                inherited_struct,
            );
    }

    /// Reset `margin_right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_right(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_right(
                reset_struct,
            );
    }

    /// Set the `margin_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_right(
        &mut self,
        value: longhands::margin_right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_right(
                value,
            );
    }
    /// Inherit `margin_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_block_start(
        &mut self,
        value: longhands::margin_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_block_end(
        &mut self,
        value: longhands::margin_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_inline_start(
        &mut self,
        value: longhands::margin_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `margin_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_margin();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.margin.mutate()
            .copy_margin_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `margin_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_margin_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_margin();

        self.modified_reset = true;

        self.margin.mutate()
            .reset_margin_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `margin_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_inline_end(
        &mut self,
        value: longhands::margin_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.margin.mutate()
            .set_margin_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `outline_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_color_from(
                inherited_struct,
            );
    }

    /// Reset `outline_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_color(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_color(
                reset_struct,
            );
    }

    /// Set the `outline_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_color(
        &mut self,
        value: longhands::outline_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_color(
                value,
            );
    }
    /// Inherit `outline_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_style_from(
                inherited_struct,
            );
    }

    /// Reset `outline_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_style(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_style(
                reset_struct,
            );
    }

    /// Set the `outline_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_style(
        &mut self,
        value: longhands::outline_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_style(
                value,
            );
    }
    /// Inherit `outline_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_width_from(
                inherited_struct,
            );
    }

    /// Reset `outline_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_width(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_width(
                reset_struct,
            );
    }

    /// Set the `outline_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_width(
        &mut self,
        value: longhands::outline_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_width(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_topleft` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_topleft(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_topleft_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_topleft` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_topleft(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_topleft(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_topleft` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_topleft(
        &mut self,
        value: longhands::_moz_outline_radius_topleft::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_topleft(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_topright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_topright(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_topright_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_topright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_topright(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_topright(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_topright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_topright(
        &mut self,
        value: longhands::_moz_outline_radius_topright::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_topright(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_bottomright` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_bottomright(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_bottomright_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_bottomright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_bottomright(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_bottomright(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_bottomright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_bottomright(
        &mut self,
        value: longhands::_moz_outline_radius_bottomright::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_bottomright(
                value,
            );
    }
    /// Inherit `_moz_outline_radius_bottomleft` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_outline_radius_bottomleft(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy__moz_outline_radius_bottomleft_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_outline_radius_bottomleft` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_outline_radius_bottomleft(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset__moz_outline_radius_bottomleft(
                reset_struct,
            );
    }

    /// Set the `_moz_outline_radius_bottomleft` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_outline_radius_bottomleft(
        &mut self,
        value: longhands::_moz_outline_radius_bottomleft::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set__moz_outline_radius_bottomleft(
                value,
            );
    }
    /// Inherit `outline_offset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_offset(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_outline();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.outline.mutate()
            .copy_outline_offset_from(
                inherited_struct,
            );
    }

    /// Reset `outline_offset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_outline_offset(&mut self) {
        let reset_struct =
            self.reset_style.get_outline();

        self.modified_reset = true;

        self.outline.mutate()
            .reset_outline_offset(
                reset_struct,
            );
    }

    /// Set the `outline_offset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_offset(
        &mut self,
        value: longhands::outline_offset::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.outline.mutate()
            .set_outline_offset(
                value,
            );
    }
    /// Inherit `padding_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_top_from(
                inherited_struct,
            );
    }

    /// Reset `padding_top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_top(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_top(
                reset_struct,
            );
    }

    /// Set the `padding_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_top(
        &mut self,
        value: longhands::padding_top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_top(
                value,
            );
    }
    /// Inherit `padding_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_left_from(
                inherited_struct,
            );
    }

    /// Reset `padding_left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_left(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_left(
                reset_struct,
            );
    }

    /// Set the `padding_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_left(
        &mut self,
        value: longhands::padding_left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_left(
                value,
            );
    }
    /// Inherit `padding_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `padding_bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_bottom(
                reset_struct,
            );
    }

    /// Set the `padding_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_bottom(
        &mut self,
        value: longhands::padding_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_bottom(
                value,
            );
    }
    /// Inherit `padding_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_right_from(
                inherited_struct,
            );
    }

    /// Reset `padding_right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_right(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_right(
                reset_struct,
            );
    }

    /// Set the `padding_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_right(
        &mut self,
        value: longhands::padding_right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_right(
                value,
            );
    }
    /// Inherit `padding_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_block_start(
        &mut self,
        value: longhands::padding_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_block_end(
        &mut self,
        value: longhands::padding_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_inline_start(
        &mut self,
        value: longhands::padding_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `padding_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_padding();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.padding.mutate()
            .copy_padding_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `padding_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_padding_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_padding();

        self.modified_reset = true;

        self.padding.mutate()
            .reset_padding_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `padding_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_inline_end(
        &mut self,
        value: longhands::padding_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.padding.mutate()
            .set_padding_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `cursor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_cursor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_cursor_from(
                inherited_struct,
            );
    }

    /// Reset `cursor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_cursor(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_cursor(
                reset_struct,
            );
    }

    /// Set the `cursor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_cursor(
        &mut self,
        value: longhands::cursor::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_cursor(
                value,
            );
    }
    /// Inherit `pointer_events` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_pointer_events(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_pointer_events_from(
                inherited_struct,
            );
    }

    /// Reset `pointer_events` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_pointer_events(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_pointer_events(
                reset_struct,
            );
    }

    /// Set the `pointer_events` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_pointer_events(
        &mut self,
        value: longhands::pointer_events::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_pointer_events(
                value,
            );
    }
    /// Inherit `_moz_user_input` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_input(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_input_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_input` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_input(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_input(
                reset_struct,
            );
    }

    /// Set the `_moz_user_input` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_input(
        &mut self,
        value: longhands::_moz_user_input::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_input(
                value,
            );
    }
    /// Inherit `_moz_user_modify` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_modify(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_modify_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_modify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_modify(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_modify(
                reset_struct,
            );
    }

    /// Set the `_moz_user_modify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_modify(
        &mut self,
        value: longhands::_moz_user_modify::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_modify(
                value,
            );
    }
    /// Inherit `_moz_user_focus` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_focus(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy__moz_user_focus_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_focus` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_focus(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset__moz_user_focus(
                reset_struct,
            );
    }

    /// Set the `_moz_user_focus` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_focus(
        &mut self,
        value: longhands::_moz_user_focus::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set__moz_user_focus(
                value,
            );
    }
    /// Inherit `caret_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_caret_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_pointing();




        self.pointing.mutate()
            .copy_caret_color_from(
                inherited_struct,
            );
    }

    /// Reset `caret_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caret_color(&mut self) {
        let reset_struct =
            self.reset_style.get_pointing();


        self.pointing.mutate()
            .reset_caret_color(
                reset_struct,
            );
    }

    /// Set the `caret_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caret_color(
        &mut self,
        value: longhands::caret_color::computed_value::T
    ) {

        
        self.pointing.mutate()
            .set_caret_color(
                value,
            );
    }
    /// Inherit `top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_top(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_top_from(
                inherited_struct,
            );
    }

    /// Reset `top` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_top(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_top(
                reset_struct,
            );
    }

    /// Set the `top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_top(
        &mut self,
        value: longhands::top::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_top(
                value,
            );
    }
    /// Inherit `left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_left(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_left_from(
                inherited_struct,
            );
    }

    /// Reset `left` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_left(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_left(
                reset_struct,
            );
    }

    /// Set the `left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_left(
        &mut self,
        value: longhands::left::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_left(
                value,
            );
    }
    /// Inherit `bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_bottom_from(
                inherited_struct,
            );
    }

    /// Reset `bottom` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_bottom(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_bottom(
                reset_struct,
            );
    }

    /// Set the `bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_bottom(
        &mut self,
        value: longhands::bottom::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_bottom(
                value,
            );
    }
    /// Inherit `right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_right(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_right_from(
                inherited_struct,
            );
    }

    /// Reset `right` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_right(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_right(
                reset_struct,
            );
    }

    /// Set the `right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_right(
        &mut self,
        value: longhands::right::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_right(
                value,
            );
    }
    /// Inherit `offset_block_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_block_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_block_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_block_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_block_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_block_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_block_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_block_start(
        &mut self,
        value: longhands::offset_block_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_block_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_block_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_block_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_block_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_block_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_block_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_block_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_block_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_block_end(
        &mut self,
        value: longhands::offset_block_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_block_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_inline_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_inline_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_inline_start_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_inline_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_inline_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_inline_start(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_inline_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_inline_start(
        &mut self,
        value: longhands::offset_inline_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_inline_start(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `offset_inline_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_inline_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_offset_inline_end_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `offset_inline_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_offset_inline_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_offset_inline_end(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `offset_inline_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_inline_end(
        &mut self,
        value: longhands::offset_inline_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_offset_inline_end(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `z_index` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_z_index(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_z_index_from(
                inherited_struct,
            );
    }

    /// Reset `z_index` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_z_index(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_z_index(
                reset_struct,
            );
    }

    /// Set the `z_index` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_z_index(
        &mut self,
        value: longhands::z_index::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_z_index(
                value,
            );
    }
    /// Inherit `flex_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_direction_from(
                inherited_struct,
            );
    }

    /// Reset `flex_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_direction(
                reset_struct,
            );
    }

    /// Set the `flex_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_direction(
        &mut self,
        value: longhands::flex_direction::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_direction(
                value,
            );
    }
    /// Inherit `flex_wrap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_wrap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_wrap_from(
                inherited_struct,
            );
    }

    /// Reset `flex_wrap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_wrap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_wrap(
                reset_struct,
            );
    }

    /// Set the `flex_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_wrap(
        &mut self,
        value: longhands::flex_wrap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_wrap(
                value,
            );
    }
    /// Inherit `justify_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_content_from(
                inherited_struct,
            );
    }

    /// Reset `justify_content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_content(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_content(
                reset_struct,
            );
    }

    /// Set the `justify_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_content(
        &mut self,
        value: longhands::justify_content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_content(
                value,
            );
    }
    /// Inherit `align_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_content(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_content_from(
                inherited_struct,
            );
    }

    /// Reset `align_content` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_content(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_content(
                reset_struct,
            );
    }

    /// Set the `align_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_content(
        &mut self,
        value: longhands::align_content::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_content(
                value,
            );
    }
    /// Inherit `align_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_items(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_items_from(
                inherited_struct,
            );
    }

    /// Reset `align_items` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_items(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_items(
                reset_struct,
            );
    }

    /// Set the `align_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_items(
        &mut self,
        value: longhands::align_items::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_items(
                value,
            );
    }
    /// Inherit `justify_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_items(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_items_from(
                inherited_struct,
            );
    }

    /// Reset `justify_items` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_items(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_items(
                reset_struct,
            );
    }

    /// Set the `justify_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_items(
        &mut self,
        value: longhands::justify_items::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_items(
                value,
            );
    }
    /// Inherit `flex_grow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_grow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_grow_from(
                inherited_struct,
            );
    }

    /// Reset `flex_grow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_grow(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_grow(
                reset_struct,
            );
    }

    /// Set the `flex_grow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_grow(
        &mut self,
        value: longhands::flex_grow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_grow(
                value,
            );
    }
    /// Inherit `flex_shrink` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_shrink(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_shrink_from(
                inherited_struct,
            );
    }

    /// Reset `flex_shrink` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_shrink(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_shrink(
                reset_struct,
            );
    }

    /// Set the `flex_shrink` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_shrink(
        &mut self,
        value: longhands::flex_shrink::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_shrink(
                value,
            );
    }
    /// Inherit `align_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_self(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_align_self_from(
                inherited_struct,
            );
    }

    /// Reset `align_self` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_align_self(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_align_self(
                reset_struct,
            );
    }

    /// Set the `align_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_self(
        &mut self,
        value: longhands::align_self::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_align_self(
                value,
            );
    }
    /// Inherit `justify_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_self(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_justify_self_from(
                inherited_struct,
            );
    }

    /// Reset `justify_self` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_justify_self(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_justify_self(
                reset_struct,
            );
    }

    /// Set the `justify_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_self(
        &mut self,
        value: longhands::justify_self::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_justify_self(
                value,
            );
    }
    /// Inherit `order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_order(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_order_from(
                inherited_struct,
            );
    }

    /// Reset `order` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_order(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_order(
                reset_struct,
            );
    }

    /// Set the `order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_order(
        &mut self,
        value: longhands::order::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_order(
                value,
            );
    }
    /// Inherit `flex_basis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_basis(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_flex_basis_from(
                inherited_struct,
            );
    }

    /// Reset `flex_basis` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flex_basis(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_flex_basis(
                reset_struct,
            );
    }

    /// Set the `flex_basis` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_basis(
        &mut self,
        value: longhands::flex_basis::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_flex_basis(
                value,
            );
    }
    /// Inherit `width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_width_from(
                inherited_struct,
            );
    }

    /// Reset `width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_width(
                reset_struct,
            );
    }

    /// Set the `width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_width(
        &mut self,
        value: longhands::width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_width(
                value,
            );
    }
    /// Inherit `min_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_width_from(
                inherited_struct,
            );
    }

    /// Reset `min_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_width(
                reset_struct,
            );
    }

    /// Set the `min_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_width(
        &mut self,
        value: longhands::min_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_width(
                value,
            );
    }
    /// Inherit `max_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_width(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_width_from(
                inherited_struct,
            );
    }

    /// Reset `max_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_width(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_width(
                reset_struct,
            );
    }

    /// Set the `max_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_width(
        &mut self,
        value: longhands::max_width::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_width(
                value,
            );
    }
    /// Inherit `height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_height_from(
                inherited_struct,
            );
    }

    /// Reset `height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_height(
                reset_struct,
            );
    }

    /// Set the `height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_height(
        &mut self,
        value: longhands::height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_height(
                value,
            );
    }
    /// Inherit `min_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_height_from(
                inherited_struct,
            );
    }

    /// Reset `min_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_height(
                reset_struct,
            );
    }

    /// Set the `min_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_height(
        &mut self,
        value: longhands::min_height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_height(
                value,
            );
    }
    /// Inherit `max_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_height(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_height_from(
                inherited_struct,
            );
    }

    /// Reset `max_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_height(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_height(
                reset_struct,
            );
    }

    /// Set the `max_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_height(
        &mut self,
        value: longhands::max_height::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_height(
                value,
            );
    }
    /// Inherit `block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_block_size(
        &mut self,
        value: longhands::block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `min_block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `min_block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `min_block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_block_size(
        &mut self,
        value: longhands::min_block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `max_block_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_block_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_block_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `max_block_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_block_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_block_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `max_block_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_block_size(
        &mut self,
        value: longhands::max_block_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_block_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_inline_size(
        &mut self,
        value: longhands::inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `min_inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_min_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `min_inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_min_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_min_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `min_inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_inline_size(
        &mut self,
        value: longhands::min_inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_min_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `max_inline_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_inline_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_max_inline_size_from(
                inherited_struct,
                self.writing_mode,
            );
    }

    /// Reset `max_inline_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_max_inline_size(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_max_inline_size(
                reset_struct,
                self.writing_mode,
            );
    }

    /// Set the `max_inline_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_inline_size(
        &mut self,
        value: longhands::max_inline_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_max_inline_size(
                value,
                self.writing_mode,
            );
    }
    /// Inherit `box_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_box_sizing_from(
                inherited_struct,
            );
    }

    /// Reset `box_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_box_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_box_sizing(
                reset_struct,
            );
    }

    /// Set the `box_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_sizing(
        &mut self,
        value: longhands::box_sizing::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_box_sizing(
                value,
            );
    }
    /// Inherit `object_fit` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_fit(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_object_fit_from(
                inherited_struct,
            );
    }

    /// Reset `object_fit` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_object_fit(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_object_fit(
                reset_struct,
            );
    }

    /// Set the `object_fit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_fit(
        &mut self,
        value: longhands::object_fit::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_object_fit(
                value,
            );
    }
    /// Inherit `object_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_position(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_object_position_from(
                inherited_struct,
            );
    }

    /// Reset `object_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_object_position(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_object_position(
                reset_struct,
            );
    }

    /// Set the `object_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_position(
        &mut self,
        value: longhands::object_position::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_object_position(
                value,
            );
    }
    /// Inherit `grid_row_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_gap_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_gap(
                reset_struct,
            );
    }

    /// Set the `grid_row_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_gap(
        &mut self,
        value: longhands::grid_row_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_gap(
                value,
            );
    }
    /// Inherit `grid_row_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_start_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_start(
                reset_struct,
            );
    }

    /// Set the `grid_row_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_start(
        &mut self,
        value: longhands::grid_row_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_start(
                value,
            );
    }
    /// Inherit `grid_row_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_row_end_from(
                inherited_struct,
            );
    }

    /// Reset `grid_row_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_row_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_row_end(
                reset_struct,
            );
    }

    /// Set the `grid_row_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_end(
        &mut self,
        value: longhands::grid_row_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_row_end(
                value,
            );
    }
    /// Inherit `grid_auto_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_rows(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_rows_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_rows` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_rows(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_rows(
                reset_struct,
            );
    }

    /// Set the `grid_auto_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_rows(
        &mut self,
        value: longhands::grid_auto_rows::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_rows(
                value,
            );
    }
    /// Inherit `grid_template_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_rows(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_rows_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_rows` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_rows(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_rows(
                reset_struct,
            );
    }

    /// Set the `grid_template_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_rows(
        &mut self,
        value: longhands::grid_template_rows::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_rows(
                value,
            );
    }
    /// Inherit `grid_column_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_gap(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_gap_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_gap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_gap(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_gap(
                reset_struct,
            );
    }

    /// Set the `grid_column_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_gap(
        &mut self,
        value: longhands::grid_column_gap::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_gap(
                value,
            );
    }
    /// Inherit `grid_column_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_start(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_start_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_start(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_start(
                reset_struct,
            );
    }

    /// Set the `grid_column_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_start(
        &mut self,
        value: longhands::grid_column_start::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_start(
                value,
            );
    }
    /// Inherit `grid_column_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_end(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_column_end_from(
                inherited_struct,
            );
    }

    /// Reset `grid_column_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_column_end(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_column_end(
                reset_struct,
            );
    }

    /// Set the `grid_column_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_end(
        &mut self,
        value: longhands::grid_column_end::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_column_end(
                value,
            );
    }
    /// Inherit `grid_auto_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_columns(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_columns_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_columns` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_columns(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_columns(
                reset_struct,
            );
    }

    /// Set the `grid_auto_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_columns(
        &mut self,
        value: longhands::grid_auto_columns::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_columns(
                value,
            );
    }
    /// Inherit `grid_template_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_columns(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_columns_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_columns` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_columns(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_columns(
                reset_struct,
            );
    }

    /// Set the `grid_template_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_columns(
        &mut self,
        value: longhands::grid_template_columns::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_columns(
                value,
            );
    }
    /// Inherit `grid_auto_flow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_flow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_auto_flow_from(
                inherited_struct,
            );
    }

    /// Reset `grid_auto_flow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_auto_flow(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_auto_flow(
                reset_struct,
            );
    }

    /// Set the `grid_auto_flow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_flow(
        &mut self,
        value: longhands::grid_auto_flow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_auto_flow(
                value,
            );
    }
    /// Inherit `grid_template_areas` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_areas(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_position();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.position.mutate()
            .copy_grid_template_areas_from(
                inherited_struct,
            );
    }

    /// Reset `grid_template_areas` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_grid_template_areas(&mut self) {
        let reset_struct =
            self.reset_style.get_position();

        self.modified_reset = true;

        self.position.mutate()
            .reset_grid_template_areas(
                reset_struct,
            );
    }

    /// Set the `grid_template_areas` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_areas(
        &mut self,
        value: longhands::grid_template_areas::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.position.mutate()
            .set_grid_template_areas(
                value,
            );
    }
    /// Inherit `table_layout` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_table_layout(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_table();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.table.mutate()
            .copy_table_layout_from(
                inherited_struct,
            );
    }

    /// Reset `table_layout` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_table_layout(&mut self) {
        let reset_struct =
            self.reset_style.get_table();

        self.modified_reset = true;

        self.table.mutate()
            .reset_table_layout(
                reset_struct,
            );
    }

    /// Set the `table_layout` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_table_layout(
        &mut self,
        value: longhands::table_layout::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.table.mutate()
            .set_table_layout(
                value,
            );
    }
    /// Inherit `_x_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_span(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_table();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.table.mutate()
            .copy__x_span_from(
                inherited_struct,
            );
    }

    /// Reset `_x_span` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_span(&mut self) {
        let reset_struct =
            self.reset_style.get_table();

        self.modified_reset = true;

        self.table.mutate()
            .reset__x_span(
                reset_struct,
            );
    }

    /// Set the `_x_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_span(
        &mut self,
        value: longhands::_x_span::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.table.mutate()
            .set__x_span(
                value,
            );
    }
    /// Inherit `text_overflow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_overflow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_overflow_from(
                inherited_struct,
            );
    }

    /// Reset `text_overflow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_overflow(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_overflow(
                reset_struct,
            );
    }

    /// Set the `text_overflow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_overflow(
        &mut self,
        value: longhands::text_overflow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_overflow(
                value,
            );
    }
    /// Inherit `unicode_bidi` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_unicode_bidi(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_unicode_bidi_from(
                inherited_struct,
            );
    }

    /// Reset `unicode_bidi` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_unicode_bidi(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_unicode_bidi(
                reset_struct,
            );
    }

    /// Set the `unicode_bidi` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_unicode_bidi(
        &mut self,
        value: longhands::unicode_bidi::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_unicode_bidi(
                value,
            );
    }
    /// Inherit `text_decoration_line` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_line(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_line_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_line` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_line(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_line(
                reset_struct,
            );
    }

    /// Set the `text_decoration_line` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_line(
        &mut self,
        value: longhands::text_decoration_line::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_line(
                value,
            );
    }
    /// Inherit `text_decoration_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_style(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_style_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_style(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_style(
                reset_struct,
            );
    }

    /// Set the `text_decoration_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_style(
        &mut self,
        value: longhands::text_decoration_style::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_style(
                value,
            );
    }
    /// Inherit `text_decoration_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_text_decoration_color_from(
                inherited_struct,
            );
    }

    /// Reset `text_decoration_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_color(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_text_decoration_color(
                reset_struct,
            );
    }

    /// Set the `text_decoration_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_color(
        &mut self,
        value: longhands::text_decoration_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_text_decoration_color(
                value,
            );
    }
    /// Inherit `initial_letter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_initial_letter(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_text();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.text.mutate()
            .copy_initial_letter_from(
                inherited_struct,
            );
    }

    /// Reset `initial_letter` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_initial_letter(&mut self) {
        let reset_struct =
            self.reset_style.get_text();

        self.modified_reset = true;

        self.text.mutate()
            .reset_initial_letter(
                reset_struct,
            );
    }

    /// Set the `initial_letter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_initial_letter(
        &mut self,
        value: longhands::initial_letter::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.text.mutate()
            .set_initial_letter(
                value,
            );
    }
    /// Inherit `ime_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ime_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy_ime_mode_from(
                inherited_struct,
            );
    }

    /// Reset `ime_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ime_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset_ime_mode(
                reset_struct,
            );
    }

    /// Set the `ime_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ime_mode(
        &mut self,
        value: longhands::ime_mode::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set_ime_mode(
                value,
            );
    }
    /// Inherit `_moz_user_select` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_user_select(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_user_select_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_user_select` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_select(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_user_select(
                reset_struct,
            );
    }

    /// Set the `_moz_user_select` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_select(
        &mut self,
        value: longhands::_moz_user_select::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_user_select(
                value,
            );
    }
    /// Inherit `_moz_window_dragging` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_dragging(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_dragging_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_dragging` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_dragging(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_dragging(
                reset_struct,
            );
    }

    /// Set the `_moz_window_dragging` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_dragging(
        &mut self,
        value: longhands::_moz_window_dragging::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_dragging(
                value,
            );
    }
    /// Inherit `_moz_window_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_shadow_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_shadow(
                reset_struct,
            );
    }

    /// Set the `_moz_window_shadow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_shadow(
        &mut self,
        value: longhands::_moz_window_shadow::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_shadow(
                value,
            );
    }
    /// Inherit `_moz_window_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_opacity(
                reset_struct,
            );
    }

    /// Set the `_moz_window_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_opacity(
        &mut self,
        value: longhands::_moz_window_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_opacity(
                value,
            );
    }
    /// Inherit `_moz_window_transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_transform_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_transform(
                reset_struct,
            );
    }

    /// Set the `_moz_window_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform(
        &mut self,
        value: longhands::_moz_window_transform::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_transform(
                value,
            );
    }
    /// Inherit `_moz_window_transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_window_transform_origin_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_window_transform_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_window_transform_origin(
                reset_struct,
            );
    }

    /// Set the `_moz_window_transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform_origin(
        &mut self,
        value: longhands::_moz_window_transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_window_transform_origin(
                value,
            );
    }
    /// Inherit `_moz_force_broken_image_icon` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_force_broken_image_icon(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_ui();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.ui.mutate()
            .copy__moz_force_broken_image_icon_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_force_broken_image_icon` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_force_broken_image_icon(&mut self) {
        let reset_struct =
            self.reset_style.get_ui();

        self.modified_reset = true;

        self.ui.mutate()
            .reset__moz_force_broken_image_icon(
                reset_struct,
            );
    }

    /// Set the `_moz_force_broken_image_icon` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_force_broken_image_icon(
        &mut self,
        value: longhands::_moz_force_broken_image_icon::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.ui.mutate()
            .set__moz_force_broken_image_icon(
                value,
            );
    }
    /// Inherit `text_anchor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_anchor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_text_anchor_from(
                inherited_struct,
            );
    }

    /// Reset `text_anchor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_anchor(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_text_anchor(
                reset_struct,
            );
    }

    /// Set the `text_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_anchor(
        &mut self,
        value: longhands::text_anchor::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_text_anchor(
                value,
            );
    }
    /// Inherit `color_interpolation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_interpolation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_color_interpolation_from(
                inherited_struct,
            );
    }

    /// Reset `color_interpolation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_color_interpolation(
                reset_struct,
            );
    }

    /// Set the `color_interpolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation(
        &mut self,
        value: longhands::color_interpolation::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_color_interpolation(
                value,
            );
    }
    /// Inherit `color_interpolation_filters` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_color_interpolation_filters(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_color_interpolation_filters_from(
                inherited_struct,
            );
    }

    /// Reset `color_interpolation_filters` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation_filters(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_color_interpolation_filters(
                reset_struct,
            );
    }

    /// Set the `color_interpolation_filters` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation_filters(
        &mut self,
        value: longhands::color_interpolation_filters::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_color_interpolation_filters(
                value,
            );
    }
    /// Inherit `fill` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_from(
                inherited_struct,
            );
    }

    /// Reset `fill` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill(
                reset_struct,
            );
    }

    /// Set the `fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill(
        &mut self,
        value: longhands::fill::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill(
                value,
            );
    }
    /// Inherit `fill_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `fill_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill_opacity(
                reset_struct,
            );
    }

    /// Set the `fill_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_opacity(
        &mut self,
        value: longhands::fill_opacity::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill_opacity(
                value,
            );
    }
    /// Inherit `fill_rule` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_fill_rule(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_fill_rule_from(
                inherited_struct,
            );
    }

    /// Reset `fill_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_fill_rule(
                reset_struct,
            );
    }

    /// Set the `fill_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_rule(
        &mut self,
        value: longhands::fill_rule::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_fill_rule(
                value,
            );
    }
    /// Inherit `shape_rendering` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_rendering(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_shape_rendering_from(
                inherited_struct,
            );
    }

    /// Reset `shape_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_shape_rendering(
                reset_struct,
            );
    }

    /// Set the `shape_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_rendering(
        &mut self,
        value: longhands::shape_rendering::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_shape_rendering(
                value,
            );
    }
    /// Inherit `stroke` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_from(
                inherited_struct,
            );
    }

    /// Reset `stroke` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke(
                reset_struct,
            );
    }

    /// Set the `stroke` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke(
        &mut self,
        value: longhands::stroke::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke(
                value,
            );
    }
    /// Inherit `stroke_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_width_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_width(
                reset_struct,
            );
    }

    /// Set the `stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_width(
        &mut self,
        value: longhands::stroke_width::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_width(
                value,
            );
    }
    /// Inherit `stroke_linecap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_linecap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_linecap_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_linecap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linecap(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_linecap(
                reset_struct,
            );
    }

    /// Set the `stroke_linecap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linecap(
        &mut self,
        value: longhands::stroke_linecap::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_linecap(
                value,
            );
    }
    /// Inherit `stroke_linejoin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_linejoin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_linejoin_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_linejoin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linejoin(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_linejoin(
                reset_struct,
            );
    }

    /// Set the `stroke_linejoin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linejoin(
        &mut self,
        value: longhands::stroke_linejoin::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_linejoin(
                value,
            );
    }
    /// Inherit `stroke_miterlimit` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_miterlimit(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_miterlimit_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_miterlimit` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_miterlimit(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_miterlimit(
                reset_struct,
            );
    }

    /// Set the `stroke_miterlimit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_miterlimit(
        &mut self,
        value: longhands::stroke_miterlimit::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_miterlimit(
                value,
            );
    }
    /// Inherit `stroke_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_opacity(
                reset_struct,
            );
    }

    /// Set the `stroke_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_opacity(
        &mut self,
        value: longhands::stroke_opacity::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_opacity(
                value,
            );
    }
    /// Inherit `stroke_dasharray` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_dasharray(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_dasharray_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_dasharray` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dasharray(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_dasharray(
                reset_struct,
            );
    }

    /// Set the `stroke_dasharray` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dasharray(
        &mut self,
        value: longhands::stroke_dasharray::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_dasharray(
                value,
            );
    }
    /// Inherit `stroke_dashoffset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stroke_dashoffset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_stroke_dashoffset_from(
                inherited_struct,
            );
    }

    /// Reset `stroke_dashoffset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dashoffset(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_stroke_dashoffset(
                reset_struct,
            );
    }

    /// Set the `stroke_dashoffset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dashoffset(
        &mut self,
        value: longhands::stroke_dashoffset::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_stroke_dashoffset(
                value,
            );
    }
    /// Inherit `clip_rule` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip_rule(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_clip_rule_from(
                inherited_struct,
            );
    }

    /// Reset `clip_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_clip_rule(
                reset_struct,
            );
    }

    /// Set the `clip_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_rule(
        &mut self,
        value: longhands::clip_rule::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_clip_rule(
                value,
            );
    }
    /// Inherit `marker_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_start(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_start_from(
                inherited_struct,
            );
    }

    /// Reset `marker_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_start(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_start(
                reset_struct,
            );
    }

    /// Set the `marker_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_start(
        &mut self,
        value: longhands::marker_start::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_start(
                value,
            );
    }
    /// Inherit `marker_mid` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_mid(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_mid_from(
                inherited_struct,
            );
    }

    /// Reset `marker_mid` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_mid(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_mid(
                reset_struct,
            );
    }

    /// Set the `marker_mid` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_mid(
        &mut self,
        value: longhands::marker_mid::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_mid(
                value,
            );
    }
    /// Inherit `marker_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_marker_end(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_marker_end_from(
                inherited_struct,
            );
    }

    /// Reset `marker_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_end(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_marker_end(
                reset_struct,
            );
    }

    /// Set the `marker_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_end(
        &mut self,
        value: longhands::marker_end::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_marker_end(
                value,
            );
    }
    /// Inherit `paint_order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_paint_order(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy_paint_order_from(
                inherited_struct,
            );
    }

    /// Reset `paint_order` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_paint_order(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset_paint_order(
                reset_struct,
            );
    }

    /// Set the `paint_order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_paint_order(
        &mut self,
        value: longhands::paint_order::computed_value::T
    ) {

        
        self.inheritedsvg.mutate()
            .set_paint_order(
                value,
            );
    }
    /// Inherit `_moz_context_properties` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_context_properties(&mut self) {
        let inherited_struct =
            self.inherited_style.get_inheritedsvg();




        self.inheritedsvg.mutate()
            .copy__moz_context_properties_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_context_properties` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_context_properties(&mut self) {
        let reset_struct =
            self.reset_style.get_inheritedsvg();


        self.inheritedsvg.mutate()
            .reset__moz_context_properties(
                reset_struct,
            );
    }

    /// Inherit `dominant_baseline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_dominant_baseline(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_dominant_baseline_from(
                inherited_struct,
            );
    }

    /// Reset `dominant_baseline` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_dominant_baseline(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_dominant_baseline(
                reset_struct,
            );
    }

    /// Set the `dominant_baseline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_dominant_baseline(
        &mut self,
        value: longhands::dominant_baseline::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_dominant_baseline(
                value,
            );
    }
    /// Inherit `vector_effect` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vector_effect(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_vector_effect_from(
                inherited_struct,
            );
    }

    /// Reset `vector_effect` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_vector_effect(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_vector_effect(
                reset_struct,
            );
    }

    /// Set the `vector_effect` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vector_effect(
        &mut self,
        value: longhands::vector_effect::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_vector_effect(
                value,
            );
    }
    /// Inherit `stop_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_stop_color_from(
                inherited_struct,
            );
    }

    /// Reset `stop_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stop_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_stop_color(
                reset_struct,
            );
    }

    /// Set the `stop_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_color(
        &mut self,
        value: longhands::stop_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_stop_color(
                value,
            );
    }
    /// Inherit `stop_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_stop_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `stop_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stop_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_stop_opacity(
                reset_struct,
            );
    }

    /// Set the `stop_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_opacity(
        &mut self,
        value: longhands::stop_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_stop_opacity(
                value,
            );
    }
    /// Inherit `flood_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_flood_color_from(
                inherited_struct,
            );
    }

    /// Reset `flood_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flood_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_flood_color(
                reset_struct,
            );
    }

    /// Set the `flood_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_color(
        &mut self,
        value: longhands::flood_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_flood_color(
                value,
            );
    }
    /// Inherit `flood_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_flood_opacity_from(
                inherited_struct,
            );
    }

    /// Reset `flood_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_flood_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_flood_opacity(
                reset_struct,
            );
    }

    /// Set the `flood_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_opacity(
        &mut self,
        value: longhands::flood_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_flood_opacity(
                value,
            );
    }
    /// Inherit `lighting_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_lighting_color(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_lighting_color_from(
                inherited_struct,
            );
    }

    /// Reset `lighting_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_lighting_color(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_lighting_color(
                reset_struct,
            );
    }

    /// Set the `lighting_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_lighting_color(
        &mut self,
        value: longhands::lighting_color::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_lighting_color(
                value,
            );
    }
    /// Inherit `mask_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_type(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_type_from(
                inherited_struct,
            );
    }

    /// Reset `mask_type` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_type(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_type(
                reset_struct,
            );
    }

    /// Set the `mask_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mask_type(
        &mut self,
        value: longhands::mask_type::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_mask_type(
                value,
            );
    }
    /// Inherit `clip_path` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip_path(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_clip_path_from(
                inherited_struct,
            );
    }

    /// Reset `clip_path` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip_path(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_clip_path(
                reset_struct,
            );
    }

    /// Set the `clip_path` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_path(
        &mut self,
        value: longhands::clip_path::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_clip_path(
                value,
            );
    }
    /// Inherit `mask_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_mode(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_mode_from(
                inherited_struct,
            );
    }

    /// Reset `mask_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_mode(
                reset_struct,
            );
    }

    /// Inherit `mask_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_repeat_from(
                inherited_struct,
            );
    }

    /// Reset `mask_repeat` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_repeat(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_repeat(
                reset_struct,
            );
    }

    /// Inherit `mask_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_position_x_from(
                inherited_struct,
            );
    }

    /// Reset `mask_position_x` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_position_x(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_position_x(
                reset_struct,
            );
    }

    /// Inherit `mask_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_position_y_from(
                inherited_struct,
            );
    }

    /// Reset `mask_position_y` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_position_y(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_position_y(
                reset_struct,
            );
    }

    /// Inherit `mask_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_clip(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_clip_from(
                inherited_struct,
            );
    }

    /// Reset `mask_clip` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_clip(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_clip(
                reset_struct,
            );
    }

    /// Inherit `mask_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_origin(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_origin_from(
                inherited_struct,
            );
    }

    /// Reset `mask_origin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_origin(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_origin(
                reset_struct,
            );
    }

    /// Inherit `mask_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_size(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_size_from(
                inherited_struct,
            );
    }

    /// Reset `mask_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_size(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_size(
                reset_struct,
            );
    }

    /// Set the `mask_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mask_size(
        &mut self,
        value: longhands::mask_size::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.svg.mutate()
            .set_mask_size(
                value,
            );
    }
    /// Inherit `mask_composite` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_composite(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_composite_from(
                inherited_struct,
            );
    }

    /// Reset `mask_composite` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_composite(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_composite(
                reset_struct,
            );
    }

    /// Inherit `mask_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_image(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_svg();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.svg.mutate()
            .copy_mask_image_from(
                inherited_struct,
            );
    }

    /// Reset `mask_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_mask_image(&mut self) {
        let reset_struct =
            self.reset_style.get_svg();

        self.modified_reset = true;

        self.svg.mutate()
            .reset_mask_image(
                reset_struct,
            );
    }

    /// Inherit `_moz_box_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_align(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_align_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_align(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_align(
                reset_struct,
            );
    }

    /// Set the `_moz_box_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_align(
        &mut self,
        value: longhands::_moz_box_align::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_align(
                value,
            );
    }
    /// Inherit `_moz_box_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_direction(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_direction_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_direction(
                reset_struct,
            );
    }

    /// Set the `_moz_box_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_direction(
        &mut self,
        value: longhands::_moz_box_direction::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_direction(
                value,
            );
    }
    /// Inherit `_moz_box_flex` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_flex(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_flex_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_flex` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_flex(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_flex(
                reset_struct,
            );
    }

    /// Set the `_moz_box_flex` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_flex(
        &mut self,
        value: longhands::_moz_box_flex::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_flex(
                value,
            );
    }
    /// Inherit `_moz_box_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_orient(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_orient_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_orient` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_orient(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_orient(
                reset_struct,
            );
    }

    /// Set the `_moz_box_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_orient(
        &mut self,
        value: longhands::_moz_box_orient::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_orient(
                value,
            );
    }
    /// Inherit `_moz_box_pack` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_pack(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_pack_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_pack` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_pack(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_pack(
                reset_struct,
            );
    }

    /// Set the `_moz_box_pack` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_pack(
        &mut self,
        value: longhands::_moz_box_pack::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_pack(
                value,
            );
    }
    /// Inherit `_moz_stack_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_stack_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_stack_sizing_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_stack_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_stack_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_stack_sizing(
                reset_struct,
            );
    }

    /// Set the `_moz_stack_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_stack_sizing(
        &mut self,
        value: longhands::_moz_stack_sizing::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_stack_sizing(
                value,
            );
    }
    /// Inherit `_moz_box_ordinal_group` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_ordinal_group(&mut self) {
        let inherited_struct =
            self.inherited_style_ignoring_first_line
                .get_xul();

        self.flags.insert(ComputedValueFlags::INHERITS_RESET_STYLE);
        self.modified_reset = true;



        self.xul.mutate()
            .copy__moz_box_ordinal_group_from(
                inherited_struct,
            );
    }

    /// Reset `_moz_box_ordinal_group` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_ordinal_group(&mut self) {
        let reset_struct =
            self.reset_style.get_xul();

        self.modified_reset = true;

        self.xul.mutate()
            .reset__moz_box_ordinal_group(
                reset_struct,
            );
    }

    /// Set the `_moz_box_ordinal_group` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_ordinal_group(
        &mut self,
        value: longhands::_moz_box_ordinal_group::computed_value::T
    ) {
        self.modified_reset = true;

        
        self.xul.mutate()
            .set__moz_box_ordinal_group(
                value,
            );
    }

    /// Inherits style from the parent element, accounting for the default
    /// computed values that need to be provided as well.
    pub fn for_inheritance(
        device: &'a Device,
        parent: &'a ComputedValues,
        pseudo: Option<&'a PseudoElement>,
    ) -> Self {
        // Rebuild the visited style from the parent, ensuring that it will also
        // not have rules.  This matches the unvisited style that will be
        // produced by this builder.  This assumes that the caller doesn't need
        // to adjust or process visited style, so we can just build visited
        // style here for simplicity.
        let visited_style = parent.visited_style().map(|style| {
            Self::for_inheritance(
                device,
                style,
                pseudo,
            ).build()
        });
        // FIXME(emilio): This Some(parent) here is inconsistent with what we
        // usually do if `parent` is the default computed values, but that's
        // fine, and we want to eventually get rid of it.
        Self::new(
            device,
            Some(parent),
            Some(parent),
            pseudo,
            CascadeFlags::empty(),
            /* rules = */ None,
            parent.custom_properties().cloned(),
            parent.writing_mode,
            parent.flags.inherited(),
            visited_style,
        )
    }

    /// Returns whether we have a visited style.
    pub fn has_visited_style(&self) -> bool {
        self.visited_style.is_some()
    }

    /// Returns whether we're a pseudo-elements style.
    pub fn is_pseudo_element(&self) -> bool {
        self.pseudo.map_or(false, |p| !p.is_anon_box())
    }

    /// Returns the style we're getting reset properties from.
    pub fn default_style(&self) -> &'a ComputedValues {
        self.reset_style
    }

        /// Gets an immutable view of the current `Background` style.
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            self.modified_reset = true;
            self.background.mutate()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn take_background(&mut self) -> UniqueArc<style_structs::Background> {
            self.modified_reset = true;
            self.background.take()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn put_background(&mut self, s: UniqueArc<style_structs::Background>) {
            self.background.put(s)
        }

        /// Gets a mutable view of the current `Background` style,
        /// only if it's been mutated before.
        pub fn get_background_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Background> {
            self.background.get_if_mutated()
        }

        /// Reset the current `Background` style to its default value.
        pub fn reset_background_struct(&mut self) {
            self.background =
                StyleStructRef::Borrowed(self.reset_style.background_arc());
        }
        /// Gets an immutable view of the current `Border` style.
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            self.modified_reset = true;
            self.border.mutate()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn take_border(&mut self) -> UniqueArc<style_structs::Border> {
            self.modified_reset = true;
            self.border.take()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn put_border(&mut self, s: UniqueArc<style_structs::Border>) {
            self.border.put(s)
        }

        /// Gets a mutable view of the current `Border` style,
        /// only if it's been mutated before.
        pub fn get_border_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Border> {
            self.border.get_if_mutated()
        }

        /// Reset the current `Border` style to its default value.
        pub fn reset_border_struct(&mut self) {
            self.border =
                StyleStructRef::Borrowed(self.reset_style.border_arc());
        }
        /// Gets an immutable view of the current `Box` style.
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            self.modified_reset = true;
            self.box_.mutate()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn take_box(&mut self) -> UniqueArc<style_structs::Box> {
            self.modified_reset = true;
            self.box_.take()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn put_box(&mut self, s: UniqueArc<style_structs::Box>) {
            self.box_.put(s)
        }

        /// Gets a mutable view of the current `Box` style,
        /// only if it's been mutated before.
        pub fn get_box_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Box> {
            self.box_.get_if_mutated()
        }

        /// Reset the current `Box` style to its default value.
        pub fn reset_box_struct(&mut self) {
            self.box_ =
                StyleStructRef::Borrowed(self.reset_style.box_arc());
        }
        /// Gets an immutable view of the current `Color` style.
        pub fn get_color(&self) -> &style_structs::Color {
            &self.color
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn mutate_color(&mut self) -> &mut style_structs::Color {
            self.modified_reset = true;
            self.color.mutate()
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn take_color(&mut self) -> UniqueArc<style_structs::Color> {
            self.modified_reset = true;
            self.color.take()
        }

        /// Gets a mutable view of the current `Color` style.
        pub fn put_color(&mut self, s: UniqueArc<style_structs::Color>) {
            self.color.put(s)
        }

        /// Gets a mutable view of the current `Color` style,
        /// only if it's been mutated before.
        pub fn get_color_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Color> {
            self.color.get_if_mutated()
        }

        /// Reset the current `Color` style to its default value.
        pub fn reset_color_struct(&mut self) {
            self.color =
                StyleStructRef::Borrowed(self.reset_style.color_arc());
        }
        /// Gets an immutable view of the current `Column` style.
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            self.modified_reset = true;
            self.column.mutate()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn take_column(&mut self) -> UniqueArc<style_structs::Column> {
            self.modified_reset = true;
            self.column.take()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn put_column(&mut self, s: UniqueArc<style_structs::Column>) {
            self.column.put(s)
        }

        /// Gets a mutable view of the current `Column` style,
        /// only if it's been mutated before.
        pub fn get_column_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Column> {
            self.column.get_if_mutated()
        }

        /// Reset the current `Column` style to its default value.
        pub fn reset_column_struct(&mut self) {
            self.column =
                StyleStructRef::Borrowed(self.reset_style.column_arc());
        }
        /// Gets an immutable view of the current `Counters` style.
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            self.modified_reset = true;
            self.counters.mutate()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn take_counters(&mut self) -> UniqueArc<style_structs::Counters> {
            self.modified_reset = true;
            self.counters.take()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn put_counters(&mut self, s: UniqueArc<style_structs::Counters>) {
            self.counters.put(s)
        }

        /// Gets a mutable view of the current `Counters` style,
        /// only if it's been mutated before.
        pub fn get_counters_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Counters> {
            self.counters.get_if_mutated()
        }

        /// Reset the current `Counters` style to its default value.
        pub fn reset_counters_struct(&mut self) {
            self.counters =
                StyleStructRef::Borrowed(self.reset_style.counters_arc());
        }
        /// Gets an immutable view of the current `Effects` style.
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            self.modified_reset = true;
            self.effects.mutate()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn take_effects(&mut self) -> UniqueArc<style_structs::Effects> {
            self.modified_reset = true;
            self.effects.take()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn put_effects(&mut self, s: UniqueArc<style_structs::Effects>) {
            self.effects.put(s)
        }

        /// Gets a mutable view of the current `Effects` style,
        /// only if it's been mutated before.
        pub fn get_effects_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Effects> {
            self.effects.get_if_mutated()
        }

        /// Reset the current `Effects` style to its default value.
        pub fn reset_effects_struct(&mut self) {
            self.effects =
                StyleStructRef::Borrowed(self.reset_style.effects_arc());
        }
        /// Gets an immutable view of the current `Font` style.
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            self.modified_reset = true;
            self.font.mutate()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn take_font(&mut self) -> UniqueArc<style_structs::Font> {
            self.modified_reset = true;
            self.font.take()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn put_font(&mut self, s: UniqueArc<style_structs::Font>) {
            self.font.put(s)
        }

        /// Gets a mutable view of the current `Font` style,
        /// only if it's been mutated before.
        pub fn get_font_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Font> {
            self.font.get_if_mutated()
        }

        /// Reset the current `Font` style to its default value.
        pub fn reset_font_struct(&mut self) {
            self.font =
                StyleStructRef::Borrowed(self.reset_style.font_arc());
        }
        /// Gets an immutable view of the current `InheritedBox` style.
        pub fn get_inheritedbox(&self) -> &style_structs::InheritedBox {
            &self.inheritedbox
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn mutate_inheritedbox(&mut self) -> &mut style_structs::InheritedBox {
            self.modified_reset = true;
            self.inheritedbox.mutate()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn take_inheritedbox(&mut self) -> UniqueArc<style_structs::InheritedBox> {
            self.modified_reset = true;
            self.inheritedbox.take()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn put_inheritedbox(&mut self, s: UniqueArc<style_structs::InheritedBox>) {
            self.inheritedbox.put(s)
        }

        /// Gets a mutable view of the current `InheritedBox` style,
        /// only if it's been mutated before.
        pub fn get_inheritedbox_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedBox> {
            self.inheritedbox.get_if_mutated()
        }

        /// Reset the current `InheritedBox` style to its default value.
        pub fn reset_inheritedbox_struct(&mut self) {
            self.inheritedbox =
                StyleStructRef::Borrowed(self.reset_style.inheritedbox_arc());
        }
        /// Gets an immutable view of the current `InheritedTable` style.
        pub fn get_inheritedtable(&self) -> &style_structs::InheritedTable {
            &self.inheritedtable
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn mutate_inheritedtable(&mut self) -> &mut style_structs::InheritedTable {
            self.modified_reset = true;
            self.inheritedtable.mutate()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn take_inheritedtable(&mut self) -> UniqueArc<style_structs::InheritedTable> {
            self.modified_reset = true;
            self.inheritedtable.take()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn put_inheritedtable(&mut self, s: UniqueArc<style_structs::InheritedTable>) {
            self.inheritedtable.put(s)
        }

        /// Gets a mutable view of the current `InheritedTable` style,
        /// only if it's been mutated before.
        pub fn get_inheritedtable_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedTable> {
            self.inheritedtable.get_if_mutated()
        }

        /// Reset the current `InheritedTable` style to its default value.
        pub fn reset_inheritedtable_struct(&mut self) {
            self.inheritedtable =
                StyleStructRef::Borrowed(self.reset_style.inheritedtable_arc());
        }
        /// Gets an immutable view of the current `InheritedText` style.
        pub fn get_inheritedtext(&self) -> &style_structs::InheritedText {
            &self.inheritedtext
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn mutate_inheritedtext(&mut self) -> &mut style_structs::InheritedText {
            self.modified_reset = true;
            self.inheritedtext.mutate()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn take_inheritedtext(&mut self) -> UniqueArc<style_structs::InheritedText> {
            self.modified_reset = true;
            self.inheritedtext.take()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn put_inheritedtext(&mut self, s: UniqueArc<style_structs::InheritedText>) {
            self.inheritedtext.put(s)
        }

        /// Gets a mutable view of the current `InheritedText` style,
        /// only if it's been mutated before.
        pub fn get_inheritedtext_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedText> {
            self.inheritedtext.get_if_mutated()
        }

        /// Reset the current `InheritedText` style to its default value.
        pub fn reset_inheritedtext_struct(&mut self) {
            self.inheritedtext =
                StyleStructRef::Borrowed(self.reset_style.inheritedtext_arc());
        }
        /// Gets an immutable view of the current `List` style.
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Gets a mutable view of the current `List` style.
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            self.modified_reset = true;
            self.list.mutate()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn take_list(&mut self) -> UniqueArc<style_structs::List> {
            self.modified_reset = true;
            self.list.take()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn put_list(&mut self, s: UniqueArc<style_structs::List>) {
            self.list.put(s)
        }

        /// Gets a mutable view of the current `List` style,
        /// only if it's been mutated before.
        pub fn get_list_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::List> {
            self.list.get_if_mutated()
        }

        /// Reset the current `List` style to its default value.
        pub fn reset_list_struct(&mut self) {
            self.list =
                StyleStructRef::Borrowed(self.reset_style.list_arc());
        }
        /// Gets an immutable view of the current `Margin` style.
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            self.modified_reset = true;
            self.margin.mutate()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn take_margin(&mut self) -> UniqueArc<style_structs::Margin> {
            self.modified_reset = true;
            self.margin.take()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn put_margin(&mut self, s: UniqueArc<style_structs::Margin>) {
            self.margin.put(s)
        }

        /// Gets a mutable view of the current `Margin` style,
        /// only if it's been mutated before.
        pub fn get_margin_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Margin> {
            self.margin.get_if_mutated()
        }

        /// Reset the current `Margin` style to its default value.
        pub fn reset_margin_struct(&mut self) {
            self.margin =
                StyleStructRef::Borrowed(self.reset_style.margin_arc());
        }
        /// Gets an immutable view of the current `Outline` style.
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            self.modified_reset = true;
            self.outline.mutate()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn take_outline(&mut self) -> UniqueArc<style_structs::Outline> {
            self.modified_reset = true;
            self.outline.take()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn put_outline(&mut self, s: UniqueArc<style_structs::Outline>) {
            self.outline.put(s)
        }

        /// Gets a mutable view of the current `Outline` style,
        /// only if it's been mutated before.
        pub fn get_outline_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Outline> {
            self.outline.get_if_mutated()
        }

        /// Reset the current `Outline` style to its default value.
        pub fn reset_outline_struct(&mut self) {
            self.outline =
                StyleStructRef::Borrowed(self.reset_style.outline_arc());
        }
        /// Gets an immutable view of the current `Padding` style.
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            self.modified_reset = true;
            self.padding.mutate()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn take_padding(&mut self) -> UniqueArc<style_structs::Padding> {
            self.modified_reset = true;
            self.padding.take()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn put_padding(&mut self, s: UniqueArc<style_structs::Padding>) {
            self.padding.put(s)
        }

        /// Gets a mutable view of the current `Padding` style,
        /// only if it's been mutated before.
        pub fn get_padding_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Padding> {
            self.padding.get_if_mutated()
        }

        /// Reset the current `Padding` style to its default value.
        pub fn reset_padding_struct(&mut self) {
            self.padding =
                StyleStructRef::Borrowed(self.reset_style.padding_arc());
        }
        /// Gets an immutable view of the current `Pointing` style.
        pub fn get_pointing(&self) -> &style_structs::Pointing {
            &self.pointing
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn mutate_pointing(&mut self) -> &mut style_structs::Pointing {
            self.modified_reset = true;
            self.pointing.mutate()
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn take_pointing(&mut self) -> UniqueArc<style_structs::Pointing> {
            self.modified_reset = true;
            self.pointing.take()
        }

        /// Gets a mutable view of the current `Pointing` style.
        pub fn put_pointing(&mut self, s: UniqueArc<style_structs::Pointing>) {
            self.pointing.put(s)
        }

        /// Gets a mutable view of the current `Pointing` style,
        /// only if it's been mutated before.
        pub fn get_pointing_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Pointing> {
            self.pointing.get_if_mutated()
        }

        /// Reset the current `Pointing` style to its default value.
        pub fn reset_pointing_struct(&mut self) {
            self.pointing =
                StyleStructRef::Borrowed(self.reset_style.pointing_arc());
        }
        /// Gets an immutable view of the current `Position` style.
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            self.modified_reset = true;
            self.position.mutate()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn take_position(&mut self) -> UniqueArc<style_structs::Position> {
            self.modified_reset = true;
            self.position.take()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn put_position(&mut self, s: UniqueArc<style_structs::Position>) {
            self.position.put(s)
        }

        /// Gets a mutable view of the current `Position` style,
        /// only if it's been mutated before.
        pub fn get_position_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Position> {
            self.position.get_if_mutated()
        }

        /// Reset the current `Position` style to its default value.
        pub fn reset_position_struct(&mut self) {
            self.position =
                StyleStructRef::Borrowed(self.reset_style.position_arc());
        }
        /// Gets an immutable view of the current `Table` style.
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            self.modified_reset = true;
            self.table.mutate()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn take_table(&mut self) -> UniqueArc<style_structs::Table> {
            self.modified_reset = true;
            self.table.take()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn put_table(&mut self, s: UniqueArc<style_structs::Table>) {
            self.table.put(s)
        }

        /// Gets a mutable view of the current `Table` style,
        /// only if it's been mutated before.
        pub fn get_table_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Table> {
            self.table.get_if_mutated()
        }

        /// Reset the current `Table` style to its default value.
        pub fn reset_table_struct(&mut self) {
            self.table =
                StyleStructRef::Borrowed(self.reset_style.table_arc());
        }
        /// Gets an immutable view of the current `Text` style.
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            self.modified_reset = true;
            self.text.mutate()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn take_text(&mut self) -> UniqueArc<style_structs::Text> {
            self.modified_reset = true;
            self.text.take()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn put_text(&mut self, s: UniqueArc<style_structs::Text>) {
            self.text.put(s)
        }

        /// Gets a mutable view of the current `Text` style,
        /// only if it's been mutated before.
        pub fn get_text_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Text> {
            self.text.get_if_mutated()
        }

        /// Reset the current `Text` style to its default value.
        pub fn reset_text_struct(&mut self) {
            self.text =
                StyleStructRef::Borrowed(self.reset_style.text_arc());
        }
        /// Gets an immutable view of the current `UI` style.
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            self.modified_reset = true;
            self.ui.mutate()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn take_ui(&mut self) -> UniqueArc<style_structs::UI> {
            self.modified_reset = true;
            self.ui.take()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn put_ui(&mut self, s: UniqueArc<style_structs::UI>) {
            self.ui.put(s)
        }

        /// Gets a mutable view of the current `UI` style,
        /// only if it's been mutated before.
        pub fn get_ui_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::UI> {
            self.ui.get_if_mutated()
        }

        /// Reset the current `UI` style to its default value.
        pub fn reset_ui_struct(&mut self) {
            self.ui =
                StyleStructRef::Borrowed(self.reset_style.ui_arc());
        }
        /// Gets an immutable view of the current `InheritedSVG` style.
        pub fn get_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            &self.inheritedsvg
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn mutate_inheritedsvg(&mut self) -> &mut style_structs::InheritedSVG {
            self.modified_reset = true;
            self.inheritedsvg.mutate()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn take_inheritedsvg(&mut self) -> UniqueArc<style_structs::InheritedSVG> {
            self.modified_reset = true;
            self.inheritedsvg.take()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn put_inheritedsvg(&mut self, s: UniqueArc<style_structs::InheritedSVG>) {
            self.inheritedsvg.put(s)
        }

        /// Gets a mutable view of the current `InheritedSVG` style,
        /// only if it's been mutated before.
        pub fn get_inheritedsvg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedSVG> {
            self.inheritedsvg.get_if_mutated()
        }

        /// Reset the current `InheritedSVG` style to its default value.
        pub fn reset_inheritedsvg_struct(&mut self) {
            self.inheritedsvg =
                StyleStructRef::Borrowed(self.reset_style.inheritedsvg_arc());
        }
        /// Gets an immutable view of the current `SVG` style.
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            self.modified_reset = true;
            self.svg.mutate()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn take_svg(&mut self) -> UniqueArc<style_structs::SVG> {
            self.modified_reset = true;
            self.svg.take()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn put_svg(&mut self, s: UniqueArc<style_structs::SVG>) {
            self.svg.put(s)
        }

        /// Gets a mutable view of the current `SVG` style,
        /// only if it's been mutated before.
        pub fn get_svg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::SVG> {
            self.svg.get_if_mutated()
        }

        /// Reset the current `SVG` style to its default value.
        pub fn reset_svg_struct(&mut self) {
            self.svg =
                StyleStructRef::Borrowed(self.reset_style.svg_arc());
        }
        /// Gets an immutable view of the current `XUL` style.
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            self.modified_reset = true;
            self.xul.mutate()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn take_xul(&mut self) -> UniqueArc<style_structs::XUL> {
            self.modified_reset = true;
            self.xul.take()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn put_xul(&mut self, s: UniqueArc<style_structs::XUL>) {
            self.xul.put(s)
        }

        /// Gets a mutable view of the current `XUL` style,
        /// only if it's been mutated before.
        pub fn get_xul_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::XUL> {
            self.xul.get_if_mutated()
        }

        /// Reset the current `XUL` style to its default value.
        pub fn reset_xul_struct(&mut self) {
            self.xul =
                StyleStructRef::Borrowed(self.reset_style.xul_arc());
        }

    /// Returns whether this computed style represents a floated object.
    pub fn floated(&self) -> bool {
        self.get_box().clone_float() != longhands::float::computed_value::T::None
    }

    /// Returns whether this computed style represents an out of flow-positioned
    /// object.
    pub fn out_of_flow_positioned(&self) -> bool {
        use properties::longhands::position::computed_value::T as Position;
        matches!(self.get_box().clone_position(),
                 Position::Absolute | Position::Fixed)
    }

    /// Whether this style has a top-layer style. That's implemented in Gecko
    /// via the -moz-top-layer property, but servo doesn't have any concept of a
    /// top layer (yet, it's needed for fullscreen).
    #[cfg(feature = "servo")]
    pub fn in_top_layer(&self) -> bool { false }

    /// Whether this style has a top-layer style.
    #[cfg(feature = "gecko")]
    pub fn in_top_layer(&self) -> bool {
        matches!(self.get_box().clone__moz_top_layer(),
                 longhands::_moz_top_layer::computed_value::T::Top)
    }

    /// Clears the "have any reset structs been modified" flag.
    fn clear_modified_reset(&mut self) {
        self.modified_reset = false;
    }

    /// Returns whether we have mutated any reset structs since the the last
    /// time `clear_modified_reset` was called.
    fn modified_reset(&self) -> bool {
        self.modified_reset
    }

    /// Turns this `StyleBuilder` into a proper `ComputedValues` instance.
    pub fn build(self) -> Arc<ComputedValues> {
        ComputedValues::new(
            self.device,
            self.parent_style,
            self.pseudo,
            self.custom_properties,
            self.writing_mode,
            self.flags,
            self.rules,
            self.visited_style,
            self.background.build(),
            self.border.build(),
            self.box_.build(),
            self.color.build(),
            self.column.build(),
            self.counters.build(),
            self.effects.build(),
            self.font.build(),
            self.inheritedbox.build(),
            self.inheritedtable.build(),
            self.inheritedtext.build(),
            self.list.build(),
            self.margin.build(),
            self.outline.build(),
            self.padding.build(),
            self.pointing.build(),
            self.position.build(),
            self.table.build(),
            self.text.build(),
            self.ui.build(),
            self.inheritedsvg.build(),
            self.svg.build(),
            self.xul.build(),
        )
    }

    /// Get the custom properties map if necessary.
    ///
    /// Cloning the Arc here is fine because it only happens in the case where
    /// we have custom properties, and those are both rare and expensive.
    fn custom_properties(&self) -> Option<&Arc<::custom_properties::CustomPropertiesMap>> {
        self.custom_properties.as_ref()
    }

    /// Access to various information about our inherited styles.  We don't
    /// expose an inherited ComputedValues directly, because in the
    /// ::first-line case some of the inherited information needs to come from
    /// one ComputedValues instance and some from a different one.

    /// Inherited writing-mode.
    pub fn inherited_writing_mode(&self) -> &WritingMode {
        &self.inherited_style.writing_mode
    }

    /// Inherited style flags.
    pub fn inherited_flags(&self) -> &ComputedValueFlags {
        &self.inherited_style.flags
    }

    /// And access to inherited style structs.
        /// Gets our inherited `Background`.  We don't name these
        /// accessors `inherited_background` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_background`
        /// instead.
        pub fn get_parent_background(&self) -> &style_structs::Background {
            self.inherited_style_ignoring_first_line.get_background()
        }
        /// Gets our inherited `Border`.  We don't name these
        /// accessors `inherited_border` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_border`
        /// instead.
        pub fn get_parent_border(&self) -> &style_structs::Border {
            self.inherited_style_ignoring_first_line.get_border()
        }
        /// Gets our inherited `Box`.  We don't name these
        /// accessors `inherited_box` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_box`
        /// instead.
        pub fn get_parent_box(&self) -> &style_structs::Box {
            self.inherited_style_ignoring_first_line.get_box()
        }
        /// Gets our inherited `Color`.  We don't name these
        /// accessors `inherited_color` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_color`
        /// instead.
        pub fn get_parent_color(&self) -> &style_structs::Color {
            self.inherited_style.get_color()
        }
        /// Gets our inherited `Column`.  We don't name these
        /// accessors `inherited_column` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_column`
        /// instead.
        pub fn get_parent_column(&self) -> &style_structs::Column {
            self.inherited_style_ignoring_first_line.get_column()
        }
        /// Gets our inherited `Counters`.  We don't name these
        /// accessors `inherited_counters` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_counters`
        /// instead.
        pub fn get_parent_counters(&self) -> &style_structs::Counters {
            self.inherited_style_ignoring_first_line.get_counters()
        }
        /// Gets our inherited `Effects`.  We don't name these
        /// accessors `inherited_effects` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_effects`
        /// instead.
        pub fn get_parent_effects(&self) -> &style_structs::Effects {
            self.inherited_style_ignoring_first_line.get_effects()
        }
        /// Gets our inherited `Font`.  We don't name these
        /// accessors `inherited_font` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_font`
        /// instead.
        pub fn get_parent_font(&self) -> &style_structs::Font {
            self.inherited_style.get_font()
        }
        /// Gets our inherited `InheritedBox`.  We don't name these
        /// accessors `inherited_inheritedbox` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedbox`
        /// instead.
        pub fn get_parent_inheritedbox(&self) -> &style_structs::InheritedBox {
            self.inherited_style.get_inheritedbox()
        }
        /// Gets our inherited `InheritedTable`.  We don't name these
        /// accessors `inherited_inheritedtable` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedtable`
        /// instead.
        pub fn get_parent_inheritedtable(&self) -> &style_structs::InheritedTable {
            self.inherited_style.get_inheritedtable()
        }
        /// Gets our inherited `InheritedText`.  We don't name these
        /// accessors `inherited_inheritedtext` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedtext`
        /// instead.
        pub fn get_parent_inheritedtext(&self) -> &style_structs::InheritedText {
            self.inherited_style.get_inheritedtext()
        }
        /// Gets our inherited `List`.  We don't name these
        /// accessors `inherited_list` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_list`
        /// instead.
        pub fn get_parent_list(&self) -> &style_structs::List {
            self.inherited_style.get_list()
        }
        /// Gets our inherited `Margin`.  We don't name these
        /// accessors `inherited_margin` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_margin`
        /// instead.
        pub fn get_parent_margin(&self) -> &style_structs::Margin {
            self.inherited_style_ignoring_first_line.get_margin()
        }
        /// Gets our inherited `Outline`.  We don't name these
        /// accessors `inherited_outline` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_outline`
        /// instead.
        pub fn get_parent_outline(&self) -> &style_structs::Outline {
            self.inherited_style_ignoring_first_line.get_outline()
        }
        /// Gets our inherited `Padding`.  We don't name these
        /// accessors `inherited_padding` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_padding`
        /// instead.
        pub fn get_parent_padding(&self) -> &style_structs::Padding {
            self.inherited_style_ignoring_first_line.get_padding()
        }
        /// Gets our inherited `Pointing`.  We don't name these
        /// accessors `inherited_pointing` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_pointing`
        /// instead.
        pub fn get_parent_pointing(&self) -> &style_structs::Pointing {
            self.inherited_style.get_pointing()
        }
        /// Gets our inherited `Position`.  We don't name these
        /// accessors `inherited_position` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_position`
        /// instead.
        pub fn get_parent_position(&self) -> &style_structs::Position {
            self.inherited_style_ignoring_first_line.get_position()
        }
        /// Gets our inherited `Table`.  We don't name these
        /// accessors `inherited_table` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_table`
        /// instead.
        pub fn get_parent_table(&self) -> &style_structs::Table {
            self.inherited_style_ignoring_first_line.get_table()
        }
        /// Gets our inherited `Text`.  We don't name these
        /// accessors `inherited_text` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_text`
        /// instead.
        pub fn get_parent_text(&self) -> &style_structs::Text {
            self.inherited_style_ignoring_first_line.get_text()
        }
        /// Gets our inherited `UI`.  We don't name these
        /// accessors `inherited_ui` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_ui`
        /// instead.
        pub fn get_parent_ui(&self) -> &style_structs::UI {
            self.inherited_style_ignoring_first_line.get_ui()
        }
        /// Gets our inherited `InheritedSVG`.  We don't name these
        /// accessors `inherited_inheritedsvg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inheritedsvg`
        /// instead.
        pub fn get_parent_inheritedsvg(&self) -> &style_structs::InheritedSVG {
            self.inherited_style.get_inheritedsvg()
        }
        /// Gets our inherited `SVG`.  We don't name these
        /// accessors `inherited_svg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_svg`
        /// instead.
        pub fn get_parent_svg(&self) -> &style_structs::SVG {
            self.inherited_style_ignoring_first_line.get_svg()
        }
        /// Gets our inherited `XUL`.  We don't name these
        /// accessors `inherited_xul` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_xul`
        /// instead.
        pub fn get_parent_xul(&self) -> &style_structs::XUL {
            self.inherited_style_ignoring_first_line.get_xul()
        }
}

#[cfg(feature = "servo")]
pub use self::lazy_static_module::INITIAL_SERVO_VALUES;

// Use a module to work around #[cfg] on lazy_static! not being applied to every generated item.
#[cfg(feature = "servo")]
#[allow(missing_docs)]
mod lazy_static_module {
    use logical_geometry::WritingMode;
    use servo_arc::Arc;
    use super::{ComputedValues, ComputedValuesInner, longhands, style_structs};
    use super::computed_value_flags::ComputedValueFlags;

    /// The initial values for all style structs as defined by the specification.
    lazy_static! {
        pub static ref INITIAL_SERVO_VALUES: ComputedValues = ComputedValues {
            inner: ComputedValuesInner {
                    background: Arc::new(style_structs::Background {
                            background_color: longhands::background_color::get_initial_value(),
                            background_image: longhands::background_image::get_initial_value(),
                            background_position_x: longhands::background_position_x::get_initial_value(),
                            background_position_y: longhands::background_position_y::get_initial_value(),
                            background_repeat: longhands::background_repeat::get_initial_value(),
                            background_attachment: longhands::background_attachment::get_initial_value(),
                            background_clip: longhands::background_clip::get_initial_value(),
                            background_origin: longhands::background_origin::get_initial_value(),
                            background_size: longhands::background_size::get_initial_value(),
                            background_blend_mode: longhands::background_blend_mode::get_initial_value(),
                    }),
                    border: Arc::new(style_structs::Border {
                            border_top_color: longhands::border_top_color::get_initial_value(),
                            border_top_style: longhands::border_top_style::get_initial_value(),
                            border_top_width: longhands::border_top_width::get_initial_value(),
                            border_left_color: longhands::border_left_color::get_initial_value(),
                            border_left_style: longhands::border_left_style::get_initial_value(),
                            border_left_width: longhands::border_left_width::get_initial_value(),
                            border_bottom_color: longhands::border_bottom_color::get_initial_value(),
                            border_bottom_style: longhands::border_bottom_style::get_initial_value(),
                            border_bottom_width: longhands::border_bottom_width::get_initial_value(),
                            border_right_color: longhands::border_right_color::get_initial_value(),
                            border_right_style: longhands::border_right_style::get_initial_value(),
                            border_right_width: longhands::border_right_width::get_initial_value(),
                            border_block_start_color: longhands::border_block_start_color::get_initial_value(),
                            border_block_start_style: longhands::border_block_start_style::get_initial_value(),
                            border_block_start_width: longhands::border_block_start_width::get_initial_value(),
                            border_block_end_color: longhands::border_block_end_color::get_initial_value(),
                            border_block_end_style: longhands::border_block_end_style::get_initial_value(),
                            border_block_end_width: longhands::border_block_end_width::get_initial_value(),
                            border_inline_start_color: longhands::border_inline_start_color::get_initial_value(),
                            border_inline_start_style: longhands::border_inline_start_style::get_initial_value(),
                            border_inline_start_width: longhands::border_inline_start_width::get_initial_value(),
                            border_inline_end_color: longhands::border_inline_end_color::get_initial_value(),
                            border_inline_end_style: longhands::border_inline_end_style::get_initial_value(),
                            border_inline_end_width: longhands::border_inline_end_width::get_initial_value(),
                            border_top_left_radius: longhands::border_top_left_radius::get_initial_value(),
                            border_top_right_radius: longhands::border_top_right_radius::get_initial_value(),
                            border_bottom_right_radius: longhands::border_bottom_right_radius::get_initial_value(),
                            border_bottom_left_radius: longhands::border_bottom_left_radius::get_initial_value(),
                            _moz_border_top_colors: longhands::_moz_border_top_colors::get_initial_value(),
                            _moz_border_left_colors: longhands::_moz_border_left_colors::get_initial_value(),
                            _moz_border_bottom_colors: longhands::_moz_border_bottom_colors::get_initial_value(),
                            _moz_border_right_colors: longhands::_moz_border_right_colors::get_initial_value(),
                            box_decoration_break: longhands::box_decoration_break::get_initial_value(),
                            _moz_float_edge: longhands::_moz_float_edge::get_initial_value(),
                            border_image_source: longhands::border_image_source::get_initial_value(),
                            border_image_outset: longhands::border_image_outset::get_initial_value(),
                            border_image_repeat: longhands::border_image_repeat::get_initial_value(),
                            border_image_width: longhands::border_image_width::get_initial_value(),
                            border_image_slice: longhands::border_image_slice::get_initial_value(),
                    }),
                    box_: Arc::new(style_structs::Box {
                            display: longhands::display::get_initial_value(),
                            _moz_top_layer: longhands::_moz_top_layer::get_initial_value(),
                            position: longhands::position::get_initial_value(),
                            float: longhands::float::get_initial_value(),
                            clear: longhands::clear::get_initial_value(),
                            vertical_align: longhands::vertical_align::get_initial_value(),
                            overflow_clip_box_inline: longhands::overflow_clip_box_inline::get_initial_value(),
                            overflow_clip_box_block: longhands::overflow_clip_box_block::get_initial_value(),
                            overflow_x: longhands::overflow_x::get_initial_value(),
                            overflow_y: longhands::overflow_y::get_initial_value(),
                            transition_duration: longhands::transition_duration::get_initial_value(),
                            transition_timing_function: longhands::transition_timing_function::get_initial_value(),
                            transition_property: longhands::transition_property::get_initial_value(),
                            transition_delay: longhands::transition_delay::get_initial_value(),
                            animation_name: longhands::animation_name::get_initial_value(),
                            animation_duration: longhands::animation_duration::get_initial_value(),
                            animation_timing_function: longhands::animation_timing_function::get_initial_value(),
                            animation_iteration_count: longhands::animation_iteration_count::get_initial_value(),
                            animation_direction: longhands::animation_direction::get_initial_value(),
                            animation_play_state: longhands::animation_play_state::get_initial_value(),
                            animation_fill_mode: longhands::animation_fill_mode::get_initial_value(),
                            animation_delay: longhands::animation_delay::get_initial_value(),
                            scroll_snap_points_x: longhands::scroll_snap_points_x::get_initial_value(),
                            scroll_snap_points_y: longhands::scroll_snap_points_y::get_initial_value(),
                            scroll_snap_destination: longhands::scroll_snap_destination::get_initial_value(),
                            scroll_snap_coordinate: longhands::scroll_snap_coordinate::get_initial_value(),
                            transform: longhands::transform::get_initial_value(),
                            scroll_behavior: longhands::scroll_behavior::get_initial_value(),
                            scroll_snap_type_x: longhands::scroll_snap_type_x::get_initial_value(),
                            scroll_snap_type_y: longhands::scroll_snap_type_y::get_initial_value(),
                            overscroll_behavior_x: longhands::overscroll_behavior_x::get_initial_value(),
                            overscroll_behavior_y: longhands::overscroll_behavior_y::get_initial_value(),
                            isolation: longhands::isolation::get_initial_value(),
                            page_break_after: longhands::page_break_after::get_initial_value(),
                            page_break_before: longhands::page_break_before::get_initial_value(),
                            page_break_inside: longhands::page_break_inside::get_initial_value(),
                            resize: longhands::resize::get_initial_value(),
                            perspective: longhands::perspective::get_initial_value(),
                            perspective_origin: longhands::perspective_origin::get_initial_value(),
                            backface_visibility: longhands::backface_visibility::get_initial_value(),
                            transform_box: longhands::transform_box::get_initial_value(),
                            transform_style: longhands::transform_style::get_initial_value(),
                            transform_origin: longhands::transform_origin::get_initial_value(),
                            contain: longhands::contain::get_initial_value(),
                            _moz_appearance: longhands::_moz_appearance::get_initial_value(),
                            _moz_binding: longhands::_moz_binding::get_initial_value(),
                            _moz_orient: longhands::_moz_orient::get_initial_value(),
                            will_change: longhands::will_change::get_initial_value(),
                            shape_image_threshold: longhands::shape_image_threshold::get_initial_value(),
                            shape_outside: longhands::shape_outside::get_initial_value(),
                            touch_action: longhands::touch_action::get_initial_value(),
                            original_display: longhands::display::get_initial_value(),
                    }),
                    color: Arc::new(style_structs::Color {
                            color: longhands::color::get_initial_value(),
                    }),
                    column: Arc::new(style_structs::Column {
                            column_width: longhands::column_width::get_initial_value(),
                            column_count: longhands::column_count::get_initial_value(),
                            column_gap: longhands::column_gap::get_initial_value(),
                            column_fill: longhands::column_fill::get_initial_value(),
                            column_rule_width: longhands::column_rule_width::get_initial_value(),
                            column_rule_color: longhands::column_rule_color::get_initial_value(),
                            column_span: longhands::column_span::get_initial_value(),
                            column_rule_style: longhands::column_rule_style::get_initial_value(),
                    }),
                    counters: Arc::new(style_structs::Counters {
                            content: longhands::content::get_initial_value(),
                            counter_increment: longhands::counter_increment::get_initial_value(),
                            counter_reset: longhands::counter_reset::get_initial_value(),
                    }),
                    effects: Arc::new(style_structs::Effects {
                            opacity: longhands::opacity::get_initial_value(),
                            box_shadow: longhands::box_shadow::get_initial_value(),
                            clip: longhands::clip::get_initial_value(),
                            filter: longhands::filter::get_initial_value(),
                            mix_blend_mode: longhands::mix_blend_mode::get_initial_value(),
                    }),
                    font: Arc::new(style_structs::Font {
                            font_family: longhands::font_family::get_initial_value(),
                            font_style: longhands::font_style::get_initial_value(),
                            font_variant_caps: longhands::font_variant_caps::get_initial_value(),
                            font_weight: longhands::font_weight::get_initial_value(),
                            font_size: longhands::font_size::get_initial_value(),
                            font_size_adjust: longhands::font_size_adjust::get_initial_value(),
                            font_synthesis: longhands::font_synthesis::get_initial_value(),
                            font_stretch: longhands::font_stretch::get_initial_value(),
                            font_kerning: longhands::font_kerning::get_initial_value(),
                            font_variant_alternates: longhands::font_variant_alternates::get_initial_value(),
                            font_variant_east_asian: longhands::font_variant_east_asian::get_initial_value(),
                            font_variant_ligatures: longhands::font_variant_ligatures::get_initial_value(),
                            font_variant_numeric: longhands::font_variant_numeric::get_initial_value(),
                            font_variant_position: longhands::font_variant_position::get_initial_value(),
                            font_feature_settings: longhands::font_feature_settings::get_initial_value(),
                            font_variation_settings: longhands::font_variation_settings::get_initial_value(),
                            font_language_override: longhands::font_language_override::get_initial_value(),
                            _x_lang: longhands::_x_lang::get_initial_value(),
                            _moz_script_size_multiplier: longhands::_moz_script_size_multiplier::get_initial_value(),
                            _moz_script_level: longhands::_moz_script_level::get_initial_value(),
                            _moz_math_display: longhands::_moz_math_display::get_initial_value(),
                            _moz_math_variant: longhands::_moz_math_variant::get_initial_value(),
                            _moz_script_min_size: longhands::_moz_script_min_size::get_initial_value(),
                            _x_text_zoom: longhands::_x_text_zoom::get_initial_value(),
                            _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::get_initial_value(),
                            _moz_font_smoothing_background_color: longhands::_moz_font_smoothing_background_color::get_initial_value(),
                            _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::get_initial_value(),
                            hash: 0,
                    }),
                    inheritedbox: Arc::new(style_structs::InheritedBox {
                            visibility: longhands::visibility::get_initial_value(),
                            writing_mode: longhands::writing_mode::get_initial_value(),
                            direction: longhands::direction::get_initial_value(),
                            text_orientation: longhands::text_orientation::get_initial_value(),
                            color_adjust: longhands::color_adjust::get_initial_value(),
                            image_rendering: longhands::image_rendering::get_initial_value(),
                            image_orientation: longhands::image_orientation::get_initial_value(),
                    }),
                    inheritedtable: Arc::new(style_structs::InheritedTable {
                            border_collapse: longhands::border_collapse::get_initial_value(),
                            empty_cells: longhands::empty_cells::get_initial_value(),
                            caption_side: longhands::caption_side::get_initial_value(),
                            border_spacing: longhands::border_spacing::get_initial_value(),
                    }),
                    inheritedtext: Arc::new(style_structs::InheritedText {
                            line_height: longhands::line_height::get_initial_value(),
                            text_transform: longhands::text_transform::get_initial_value(),
                            hyphens: longhands::hyphens::get_initial_value(),
                            _moz_text_size_adjust: longhands::_moz_text_size_adjust::get_initial_value(),
                            text_indent: longhands::text_indent::get_initial_value(),
                            overflow_wrap: longhands::overflow_wrap::get_initial_value(),
                            word_break: longhands::word_break::get_initial_value(),
                            text_justify: longhands::text_justify::get_initial_value(),
                            text_align_last: longhands::text_align_last::get_initial_value(),
                            text_align: longhands::text_align::get_initial_value(),
                            letter_spacing: longhands::letter_spacing::get_initial_value(),
                            word_spacing: longhands::word_spacing::get_initial_value(),
                            white_space: longhands::white_space::get_initial_value(),
                            text_shadow: longhands::text_shadow::get_initial_value(),
                            text_emphasis_style: longhands::text_emphasis_style::get_initial_value(),
                            text_emphasis_position: longhands::text_emphasis_position::get_initial_value(),
                            text_emphasis_color: longhands::text_emphasis_color::get_initial_value(),
                            _moz_tab_size: longhands::_moz_tab_size::get_initial_value(),
                            _webkit_text_fill_color: longhands::_webkit_text_fill_color::get_initial_value(),
                            _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::get_initial_value(),
                            _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::get_initial_value(),
                            ruby_align: longhands::ruby_align::get_initial_value(),
                            ruby_position: longhands::ruby_position::get_initial_value(),
                            text_combine_upright: longhands::text_combine_upright::get_initial_value(),
                            text_rendering: longhands::text_rendering::get_initial_value(),
                            _moz_control_character_visibility: longhands::_moz_control_character_visibility::get_initial_value(),
                            text_decorations_in_effect: ::values::computed::text::TextDecorationsInEffect::default(),
                    }),
                    list: Arc::new(style_structs::List {
                            list_style_position: longhands::list_style_position::get_initial_value(),
                            list_style_type: longhands::list_style_type::get_initial_value(),
                            list_style_image: longhands::list_style_image::get_initial_value(),
                            quotes: longhands::quotes::get_initial_value(),
                            _moz_image_region: longhands::_moz_image_region::get_initial_value(),
                    }),
                    margin: Arc::new(style_structs::Margin {
                            margin_top: longhands::margin_top::get_initial_value(),
                            margin_left: longhands::margin_left::get_initial_value(),
                            margin_bottom: longhands::margin_bottom::get_initial_value(),
                            margin_right: longhands::margin_right::get_initial_value(),
                            margin_block_start: longhands::margin_block_start::get_initial_value(),
                            margin_block_end: longhands::margin_block_end::get_initial_value(),
                            margin_inline_start: longhands::margin_inline_start::get_initial_value(),
                            margin_inline_end: longhands::margin_inline_end::get_initial_value(),
                    }),
                    outline: Arc::new(style_structs::Outline {
                            outline_color: longhands::outline_color::get_initial_value(),
                            outline_style: longhands::outline_style::get_initial_value(),
                            outline_width: longhands::outline_width::get_initial_value(),
                            _moz_outline_radius_topleft: longhands::_moz_outline_radius_topleft::get_initial_value(),
                            _moz_outline_radius_topright: longhands::_moz_outline_radius_topright::get_initial_value(),
                            _moz_outline_radius_bottomright: longhands::_moz_outline_radius_bottomright::get_initial_value(),
                            _moz_outline_radius_bottomleft: longhands::_moz_outline_radius_bottomleft::get_initial_value(),
                            outline_offset: longhands::outline_offset::get_initial_value(),
                    }),
                    padding: Arc::new(style_structs::Padding {
                            padding_top: longhands::padding_top::get_initial_value(),
                            padding_left: longhands::padding_left::get_initial_value(),
                            padding_bottom: longhands::padding_bottom::get_initial_value(),
                            padding_right: longhands::padding_right::get_initial_value(),
                            padding_block_start: longhands::padding_block_start::get_initial_value(),
                            padding_block_end: longhands::padding_block_end::get_initial_value(),
                            padding_inline_start: longhands::padding_inline_start::get_initial_value(),
                            padding_inline_end: longhands::padding_inline_end::get_initial_value(),
                    }),
                    pointing: Arc::new(style_structs::Pointing {
                            cursor: longhands::cursor::get_initial_value(),
                            pointer_events: longhands::pointer_events::get_initial_value(),
                            _moz_user_input: longhands::_moz_user_input::get_initial_value(),
                            _moz_user_modify: longhands::_moz_user_modify::get_initial_value(),
                            _moz_user_focus: longhands::_moz_user_focus::get_initial_value(),
                            caret_color: longhands::caret_color::get_initial_value(),
                    }),
                    position: Arc::new(style_structs::Position {
                            top: longhands::top::get_initial_value(),
                            left: longhands::left::get_initial_value(),
                            bottom: longhands::bottom::get_initial_value(),
                            right: longhands::right::get_initial_value(),
                            offset_block_start: longhands::offset_block_start::get_initial_value(),
                            offset_block_end: longhands::offset_block_end::get_initial_value(),
                            offset_inline_start: longhands::offset_inline_start::get_initial_value(),
                            offset_inline_end: longhands::offset_inline_end::get_initial_value(),
                            z_index: longhands::z_index::get_initial_value(),
                            flex_direction: longhands::flex_direction::get_initial_value(),
                            flex_wrap: longhands::flex_wrap::get_initial_value(),
                            justify_content: longhands::justify_content::get_initial_value(),
                            align_content: longhands::align_content::get_initial_value(),
                            align_items: longhands::align_items::get_initial_value(),
                            justify_items: longhands::justify_items::get_initial_value(),
                            flex_grow: longhands::flex_grow::get_initial_value(),
                            flex_shrink: longhands::flex_shrink::get_initial_value(),
                            align_self: longhands::align_self::get_initial_value(),
                            justify_self: longhands::justify_self::get_initial_value(),
                            order: longhands::order::get_initial_value(),
                            flex_basis: longhands::flex_basis::get_initial_value(),
                            width: longhands::width::get_initial_value(),
                            min_width: longhands::min_width::get_initial_value(),
                            max_width: longhands::max_width::get_initial_value(),
                            height: longhands::height::get_initial_value(),
                            min_height: longhands::min_height::get_initial_value(),
                            max_height: longhands::max_height::get_initial_value(),
                            block_size: longhands::block_size::get_initial_value(),
                            min_block_size: longhands::min_block_size::get_initial_value(),
                            max_block_size: longhands::max_block_size::get_initial_value(),
                            inline_size: longhands::inline_size::get_initial_value(),
                            min_inline_size: longhands::min_inline_size::get_initial_value(),
                            max_inline_size: longhands::max_inline_size::get_initial_value(),
                            box_sizing: longhands::box_sizing::get_initial_value(),
                            object_fit: longhands::object_fit::get_initial_value(),
                            object_position: longhands::object_position::get_initial_value(),
                            grid_row_gap: longhands::grid_row_gap::get_initial_value(),
                            grid_row_start: longhands::grid_row_start::get_initial_value(),
                            grid_row_end: longhands::grid_row_end::get_initial_value(),
                            grid_auto_rows: longhands::grid_auto_rows::get_initial_value(),
                            grid_template_rows: longhands::grid_template_rows::get_initial_value(),
                            grid_column_gap: longhands::grid_column_gap::get_initial_value(),
                            grid_column_start: longhands::grid_column_start::get_initial_value(),
                            grid_column_end: longhands::grid_column_end::get_initial_value(),
                            grid_auto_columns: longhands::grid_auto_columns::get_initial_value(),
                            grid_template_columns: longhands::grid_template_columns::get_initial_value(),
                            grid_auto_flow: longhands::grid_auto_flow::get_initial_value(),
                            grid_template_areas: longhands::grid_template_areas::get_initial_value(),
                    }),
                    table: Arc::new(style_structs::Table {
                            table_layout: longhands::table_layout::get_initial_value(),
                            _x_span: longhands::_x_span::get_initial_value(),
                    }),
                    text: Arc::new(style_structs::Text {
                            text_overflow: longhands::text_overflow::get_initial_value(),
                            unicode_bidi: longhands::unicode_bidi::get_initial_value(),
                            text_decoration_line: longhands::text_decoration_line::get_initial_value(),
                            text_decoration_style: longhands::text_decoration_style::get_initial_value(),
                            text_decoration_color: longhands::text_decoration_color::get_initial_value(),
                            initial_letter: longhands::initial_letter::get_initial_value(),
                    }),
                    ui: Arc::new(style_structs::UI {
                            ime_mode: longhands::ime_mode::get_initial_value(),
                            _moz_user_select: longhands::_moz_user_select::get_initial_value(),
                            _moz_window_dragging: longhands::_moz_window_dragging::get_initial_value(),
                            _moz_window_shadow: longhands::_moz_window_shadow::get_initial_value(),
                            _moz_window_opacity: longhands::_moz_window_opacity::get_initial_value(),
                            _moz_window_transform: longhands::_moz_window_transform::get_initial_value(),
                            _moz_window_transform_origin: longhands::_moz_window_transform_origin::get_initial_value(),
                            _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::get_initial_value(),
                    }),
                    inheritedsvg: Arc::new(style_structs::InheritedSVG {
                            text_anchor: longhands::text_anchor::get_initial_value(),
                            color_interpolation: longhands::color_interpolation::get_initial_value(),
                            color_interpolation_filters: longhands::color_interpolation_filters::get_initial_value(),
                            fill: longhands::fill::get_initial_value(),
                            fill_opacity: longhands::fill_opacity::get_initial_value(),
                            fill_rule: longhands::fill_rule::get_initial_value(),
                            shape_rendering: longhands::shape_rendering::get_initial_value(),
                            stroke: longhands::stroke::get_initial_value(),
                            stroke_width: longhands::stroke_width::get_initial_value(),
                            stroke_linecap: longhands::stroke_linecap::get_initial_value(),
                            stroke_linejoin: longhands::stroke_linejoin::get_initial_value(),
                            stroke_miterlimit: longhands::stroke_miterlimit::get_initial_value(),
                            stroke_opacity: longhands::stroke_opacity::get_initial_value(),
                            stroke_dasharray: longhands::stroke_dasharray::get_initial_value(),
                            stroke_dashoffset: longhands::stroke_dashoffset::get_initial_value(),
                            clip_rule: longhands::clip_rule::get_initial_value(),
                            marker_start: longhands::marker_start::get_initial_value(),
                            marker_mid: longhands::marker_mid::get_initial_value(),
                            marker_end: longhands::marker_end::get_initial_value(),
                            paint_order: longhands::paint_order::get_initial_value(),
                            _moz_context_properties: longhands::_moz_context_properties::get_initial_value(),
                    }),
                    svg: Arc::new(style_structs::SVG {
                            dominant_baseline: longhands::dominant_baseline::get_initial_value(),
                            vector_effect: longhands::vector_effect::get_initial_value(),
                            stop_color: longhands::stop_color::get_initial_value(),
                            stop_opacity: longhands::stop_opacity::get_initial_value(),
                            flood_color: longhands::flood_color::get_initial_value(),
                            flood_opacity: longhands::flood_opacity::get_initial_value(),
                            lighting_color: longhands::lighting_color::get_initial_value(),
                            mask_type: longhands::mask_type::get_initial_value(),
                            clip_path: longhands::clip_path::get_initial_value(),
                            mask_mode: longhands::mask_mode::get_initial_value(),
                            mask_repeat: longhands::mask_repeat::get_initial_value(),
                            mask_position_x: longhands::mask_position_x::get_initial_value(),
                            mask_position_y: longhands::mask_position_y::get_initial_value(),
                            mask_clip: longhands::mask_clip::get_initial_value(),
                            mask_origin: longhands::mask_origin::get_initial_value(),
                            mask_size: longhands::mask_size::get_initial_value(),
                            mask_composite: longhands::mask_composite::get_initial_value(),
                            mask_image: longhands::mask_image::get_initial_value(),
                    }),
                    xul: Arc::new(style_structs::XUL {
                            _moz_box_align: longhands::_moz_box_align::get_initial_value(),
                            _moz_box_direction: longhands::_moz_box_direction::get_initial_value(),
                            _moz_box_flex: longhands::_moz_box_flex::get_initial_value(),
                            _moz_box_orient: longhands::_moz_box_orient::get_initial_value(),
                            _moz_box_pack: longhands::_moz_box_pack::get_initial_value(),
                            _moz_stack_sizing: longhands::_moz_stack_sizing::get_initial_value(),
                            _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::get_initial_value(),
                    }),
                custom_properties: None,
                writing_mode: WritingMode::empty(),
                rules: None,
                visited_style: None,
                flags: ComputedValueFlags::empty(),
            }
        };
    }
}

/// A per-longhand function that performs the CSS cascade for that longhand.
pub type CascadePropertyFn =
    extern "Rust" fn(
        declaration: &PropertyDeclaration,
        context: &mut computed::Context,
    );

/// A per-longhand array of functions to perform the CSS cascade on each of
/// them, effectively doing virtual dispatch.
static CASCADE_PROPERTY: [CascadePropertyFn; 326] = [
        longhands::background_color::cascade_property,
        longhands::background_image::cascade_property,
        longhands::background_position_x::cascade_property,
        longhands::background_position_y::cascade_property,
        longhands::background_repeat::cascade_property,
        longhands::background_attachment::cascade_property,
        longhands::background_clip::cascade_property,
        longhands::background_origin::cascade_property,
        longhands::background_size::cascade_property,
        longhands::background_blend_mode::cascade_property,
        longhands::border_top_color::cascade_property,
        longhands::border_top_style::cascade_property,
        longhands::border_top_width::cascade_property,
        longhands::border_left_color::cascade_property,
        longhands::border_left_style::cascade_property,
        longhands::border_left_width::cascade_property,
        longhands::border_bottom_color::cascade_property,
        longhands::border_bottom_style::cascade_property,
        longhands::border_bottom_width::cascade_property,
        longhands::border_right_color::cascade_property,
        longhands::border_right_style::cascade_property,
        longhands::border_right_width::cascade_property,
        longhands::border_block_start_color::cascade_property,
        longhands::border_block_start_style::cascade_property,
        longhands::border_block_start_width::cascade_property,
        longhands::border_block_end_color::cascade_property,
        longhands::border_block_end_style::cascade_property,
        longhands::border_block_end_width::cascade_property,
        longhands::border_inline_start_color::cascade_property,
        longhands::border_inline_start_style::cascade_property,
        longhands::border_inline_start_width::cascade_property,
        longhands::border_inline_end_color::cascade_property,
        longhands::border_inline_end_style::cascade_property,
        longhands::border_inline_end_width::cascade_property,
        longhands::border_top_left_radius::cascade_property,
        longhands::border_top_right_radius::cascade_property,
        longhands::border_bottom_right_radius::cascade_property,
        longhands::border_bottom_left_radius::cascade_property,
        longhands::_moz_border_top_colors::cascade_property,
        longhands::_moz_border_left_colors::cascade_property,
        longhands::_moz_border_bottom_colors::cascade_property,
        longhands::_moz_border_right_colors::cascade_property,
        longhands::box_decoration_break::cascade_property,
        longhands::_moz_float_edge::cascade_property,
        longhands::border_image_source::cascade_property,
        longhands::border_image_outset::cascade_property,
        longhands::border_image_repeat::cascade_property,
        longhands::border_image_width::cascade_property,
        longhands::border_image_slice::cascade_property,
        longhands::display::cascade_property,
        longhands::_moz_top_layer::cascade_property,
        longhands::position::cascade_property,
        longhands::float::cascade_property,
        longhands::clear::cascade_property,
        longhands::vertical_align::cascade_property,
        longhands::overflow_clip_box_inline::cascade_property,
        longhands::overflow_clip_box_block::cascade_property,
        longhands::overflow_x::cascade_property,
        longhands::overflow_y::cascade_property,
        longhands::transition_duration::cascade_property,
        longhands::transition_timing_function::cascade_property,
        longhands::transition_property::cascade_property,
        longhands::transition_delay::cascade_property,
        longhands::animation_name::cascade_property,
        longhands::animation_duration::cascade_property,
        longhands::animation_timing_function::cascade_property,
        longhands::animation_iteration_count::cascade_property,
        longhands::animation_direction::cascade_property,
        longhands::animation_play_state::cascade_property,
        longhands::animation_fill_mode::cascade_property,
        longhands::animation_delay::cascade_property,
        longhands::scroll_snap_points_x::cascade_property,
        longhands::scroll_snap_points_y::cascade_property,
        longhands::scroll_snap_destination::cascade_property,
        longhands::scroll_snap_coordinate::cascade_property,
        longhands::transform::cascade_property,
        longhands::scroll_behavior::cascade_property,
        longhands::scroll_snap_type_x::cascade_property,
        longhands::scroll_snap_type_y::cascade_property,
        longhands::overscroll_behavior_x::cascade_property,
        longhands::overscroll_behavior_y::cascade_property,
        longhands::isolation::cascade_property,
        longhands::page_break_after::cascade_property,
        longhands::page_break_before::cascade_property,
        longhands::page_break_inside::cascade_property,
        longhands::resize::cascade_property,
        longhands::perspective::cascade_property,
        longhands::perspective_origin::cascade_property,
        longhands::backface_visibility::cascade_property,
        longhands::transform_box::cascade_property,
        longhands::transform_style::cascade_property,
        longhands::transform_origin::cascade_property,
        longhands::contain::cascade_property,
        longhands::_moz_appearance::cascade_property,
        longhands::_moz_binding::cascade_property,
        longhands::_moz_orient::cascade_property,
        longhands::will_change::cascade_property,
        longhands::shape_image_threshold::cascade_property,
        longhands::shape_outside::cascade_property,
        longhands::touch_action::cascade_property,
        longhands::color::cascade_property,
        longhands::column_width::cascade_property,
        longhands::column_count::cascade_property,
        longhands::column_gap::cascade_property,
        longhands::column_fill::cascade_property,
        longhands::column_rule_width::cascade_property,
        longhands::column_rule_color::cascade_property,
        longhands::column_span::cascade_property,
        longhands::column_rule_style::cascade_property,
        longhands::content::cascade_property,
        longhands::counter_increment::cascade_property,
        longhands::counter_reset::cascade_property,
        longhands::opacity::cascade_property,
        longhands::box_shadow::cascade_property,
        longhands::clip::cascade_property,
        longhands::filter::cascade_property,
        longhands::mix_blend_mode::cascade_property,
        longhands::font_family::cascade_property,
        longhands::font_style::cascade_property,
        longhands::font_variant_caps::cascade_property,
        longhands::font_weight::cascade_property,
        longhands::font_size::cascade_property,
        longhands::font_size_adjust::cascade_property,
        longhands::font_synthesis::cascade_property,
        longhands::font_stretch::cascade_property,
        longhands::font_kerning::cascade_property,
        longhands::font_variant_alternates::cascade_property,
        longhands::font_variant_east_asian::cascade_property,
        longhands::font_variant_ligatures::cascade_property,
        longhands::font_variant_numeric::cascade_property,
        longhands::font_variant_position::cascade_property,
        longhands::font_feature_settings::cascade_property,
        longhands::font_variation_settings::cascade_property,
        longhands::font_language_override::cascade_property,
        longhands::_x_lang::cascade_property,
        longhands::_moz_script_size_multiplier::cascade_property,
        longhands::_moz_script_level::cascade_property,
        longhands::_moz_math_display::cascade_property,
        longhands::_moz_math_variant::cascade_property,
        longhands::_moz_script_min_size::cascade_property,
        longhands::_x_text_zoom::cascade_property,
        longhands::_moz_osx_font_smoothing::cascade_property,
        longhands::_moz_font_smoothing_background_color::cascade_property,
        longhands::_moz_min_font_size_ratio::cascade_property,
        longhands::visibility::cascade_property,
        longhands::writing_mode::cascade_property,
        longhands::direction::cascade_property,
        longhands::text_orientation::cascade_property,
        longhands::color_adjust::cascade_property,
        longhands::image_rendering::cascade_property,
        longhands::image_orientation::cascade_property,
        longhands::border_collapse::cascade_property,
        longhands::empty_cells::cascade_property,
        longhands::caption_side::cascade_property,
        longhands::border_spacing::cascade_property,
        longhands::line_height::cascade_property,
        longhands::text_transform::cascade_property,
        longhands::hyphens::cascade_property,
        longhands::_moz_text_size_adjust::cascade_property,
        longhands::text_indent::cascade_property,
        longhands::overflow_wrap::cascade_property,
        longhands::word_break::cascade_property,
        longhands::text_justify::cascade_property,
        longhands::text_align_last::cascade_property,
        longhands::text_align::cascade_property,
        longhands::letter_spacing::cascade_property,
        longhands::word_spacing::cascade_property,
        longhands::white_space::cascade_property,
        longhands::text_shadow::cascade_property,
        longhands::text_emphasis_style::cascade_property,
        longhands::text_emphasis_position::cascade_property,
        longhands::text_emphasis_color::cascade_property,
        longhands::_moz_tab_size::cascade_property,
        longhands::_webkit_text_fill_color::cascade_property,
        longhands::_webkit_text_stroke_color::cascade_property,
        longhands::_webkit_text_stroke_width::cascade_property,
        longhands::ruby_align::cascade_property,
        longhands::ruby_position::cascade_property,
        longhands::text_combine_upright::cascade_property,
        longhands::text_rendering::cascade_property,
        longhands::_moz_control_character_visibility::cascade_property,
        longhands::list_style_position::cascade_property,
        longhands::list_style_type::cascade_property,
        longhands::list_style_image::cascade_property,
        longhands::quotes::cascade_property,
        longhands::_moz_image_region::cascade_property,
        longhands::margin_top::cascade_property,
        longhands::margin_left::cascade_property,
        longhands::margin_bottom::cascade_property,
        longhands::margin_right::cascade_property,
        longhands::margin_block_start::cascade_property,
        longhands::margin_block_end::cascade_property,
        longhands::margin_inline_start::cascade_property,
        longhands::margin_inline_end::cascade_property,
        longhands::outline_color::cascade_property,
        longhands::outline_style::cascade_property,
        longhands::outline_width::cascade_property,
        longhands::_moz_outline_radius_topleft::cascade_property,
        longhands::_moz_outline_radius_topright::cascade_property,
        longhands::_moz_outline_radius_bottomright::cascade_property,
        longhands::_moz_outline_radius_bottomleft::cascade_property,
        longhands::outline_offset::cascade_property,
        longhands::padding_top::cascade_property,
        longhands::padding_left::cascade_property,
        longhands::padding_bottom::cascade_property,
        longhands::padding_right::cascade_property,
        longhands::padding_block_start::cascade_property,
        longhands::padding_block_end::cascade_property,
        longhands::padding_inline_start::cascade_property,
        longhands::padding_inline_end::cascade_property,
        longhands::cursor::cascade_property,
        longhands::pointer_events::cascade_property,
        longhands::_moz_user_input::cascade_property,
        longhands::_moz_user_modify::cascade_property,
        longhands::_moz_user_focus::cascade_property,
        longhands::caret_color::cascade_property,
        longhands::top::cascade_property,
        longhands::left::cascade_property,
        longhands::bottom::cascade_property,
        longhands::right::cascade_property,
        longhands::offset_block_start::cascade_property,
        longhands::offset_block_end::cascade_property,
        longhands::offset_inline_start::cascade_property,
        longhands::offset_inline_end::cascade_property,
        longhands::z_index::cascade_property,
        longhands::flex_direction::cascade_property,
        longhands::flex_wrap::cascade_property,
        longhands::justify_content::cascade_property,
        longhands::align_content::cascade_property,
        longhands::align_items::cascade_property,
        longhands::justify_items::cascade_property,
        longhands::flex_grow::cascade_property,
        longhands::flex_shrink::cascade_property,
        longhands::align_self::cascade_property,
        longhands::justify_self::cascade_property,
        longhands::order::cascade_property,
        longhands::flex_basis::cascade_property,
        longhands::width::cascade_property,
        longhands::min_width::cascade_property,
        longhands::max_width::cascade_property,
        longhands::height::cascade_property,
        longhands::min_height::cascade_property,
        longhands::max_height::cascade_property,
        longhands::block_size::cascade_property,
        longhands::min_block_size::cascade_property,
        longhands::max_block_size::cascade_property,
        longhands::inline_size::cascade_property,
        longhands::min_inline_size::cascade_property,
        longhands::max_inline_size::cascade_property,
        longhands::box_sizing::cascade_property,
        longhands::object_fit::cascade_property,
        longhands::object_position::cascade_property,
        longhands::grid_row_gap::cascade_property,
        longhands::grid_row_start::cascade_property,
        longhands::grid_row_end::cascade_property,
        longhands::grid_auto_rows::cascade_property,
        longhands::grid_template_rows::cascade_property,
        longhands::grid_column_gap::cascade_property,
        longhands::grid_column_start::cascade_property,
        longhands::grid_column_end::cascade_property,
        longhands::grid_auto_columns::cascade_property,
        longhands::grid_template_columns::cascade_property,
        longhands::grid_auto_flow::cascade_property,
        longhands::grid_template_areas::cascade_property,
        longhands::table_layout::cascade_property,
        longhands::_x_span::cascade_property,
        longhands::text_overflow::cascade_property,
        longhands::unicode_bidi::cascade_property,
        longhands::text_decoration_line::cascade_property,
        longhands::text_decoration_style::cascade_property,
        longhands::text_decoration_color::cascade_property,
        longhands::initial_letter::cascade_property,
        longhands::ime_mode::cascade_property,
        longhands::_moz_user_select::cascade_property,
        longhands::_moz_window_dragging::cascade_property,
        longhands::_moz_window_shadow::cascade_property,
        longhands::_moz_window_opacity::cascade_property,
        longhands::_moz_window_transform::cascade_property,
        longhands::_moz_window_transform_origin::cascade_property,
        longhands::_moz_force_broken_image_icon::cascade_property,
        longhands::text_anchor::cascade_property,
        longhands::color_interpolation::cascade_property,
        longhands::color_interpolation_filters::cascade_property,
        longhands::fill::cascade_property,
        longhands::fill_opacity::cascade_property,
        longhands::fill_rule::cascade_property,
        longhands::shape_rendering::cascade_property,
        longhands::stroke::cascade_property,
        longhands::stroke_width::cascade_property,
        longhands::stroke_linecap::cascade_property,
        longhands::stroke_linejoin::cascade_property,
        longhands::stroke_miterlimit::cascade_property,
        longhands::stroke_opacity::cascade_property,
        longhands::stroke_dasharray::cascade_property,
        longhands::stroke_dashoffset::cascade_property,
        longhands::clip_rule::cascade_property,
        longhands::marker_start::cascade_property,
        longhands::marker_mid::cascade_property,
        longhands::marker_end::cascade_property,
        longhands::paint_order::cascade_property,
        longhands::_moz_context_properties::cascade_property,
        longhands::dominant_baseline::cascade_property,
        longhands::vector_effect::cascade_property,
        longhands::stop_color::cascade_property,
        longhands::stop_opacity::cascade_property,
        longhands::flood_color::cascade_property,
        longhands::flood_opacity::cascade_property,
        longhands::lighting_color::cascade_property,
        longhands::mask_type::cascade_property,
        longhands::clip_path::cascade_property,
        longhands::mask_mode::cascade_property,
        longhands::mask_repeat::cascade_property,
        longhands::mask_position_x::cascade_property,
        longhands::mask_position_y::cascade_property,
        longhands::mask_clip::cascade_property,
        longhands::mask_origin::cascade_property,
        longhands::mask_size::cascade_property,
        longhands::mask_composite::cascade_property,
        longhands::mask_image::cascade_property,
        longhands::_moz_box_align::cascade_property,
        longhands::_moz_box_direction::cascade_property,
        longhands::_moz_box_flex::cascade_property,
        longhands::_moz_box_orient::cascade_property,
        longhands::_moz_box_pack::cascade_property,
        longhands::_moz_stack_sizing::cascade_property,
        longhands::_moz_box_ordinal_group::cascade_property,
];

bitflags! {
    /// A set of flags to tweak the behavior of the `cascade` function.
    pub struct CascadeFlags: u8 {
        /// Whether to inherit all styles from the parent. If this flag is not
        /// present, non-inherited styles are reset to their initial values.
        const INHERIT_ALL = 1;

        /// Whether to skip any display style fixup for root element, flex/grid
        /// item, and ruby descendants.
        const SKIP_ROOT_AND_ITEM_BASED_DISPLAY_FIXUP = 1 << 1;

        /// Whether to only cascade properties that are visited dependent.
        const VISITED_DEPENDENT_ONLY = 1 << 2;

        /// Whether the given element we're styling is the document element,
        /// that is, matches :root.
        ///
        /// Not set for native anonymous content since some NAC form their own
        /// root, but share the device.
        ///
        /// This affects some style adjustments, like blockification, and means
        /// that it may affect global state, like the Device's root font-size.
        const IS_ROOT_ELEMENT = 1 << 3;

        /// Whether we're computing the style of a link, either visited or
        /// unvisited.
        const IS_LINK = 1 << 4;

        /// Whether we're computing the style of a link element that happens to
        /// be visited.
        const IS_VISITED_LINK = 1 << 5;
    }
}

/// Performs the CSS cascade, computing new styles for an element from its parent style.
///
/// The arguments are:
///
///   * `device`: Used to get the initial viewport and other external state.
///
///   * `rule_node`: The rule node in the tree that represent the CSS rules that
///   matched.
///
///   * `parent_style`: The parent style, if applicable; if `None`, this is the root node.
///
/// Returns the computed values.
///   * `flags`: Various flags.
///
pub fn cascade(
    device: &Device,
    pseudo: Option<&PseudoElement>,
    rule_node: &StrongRuleNode,
    guards: &StylesheetGuards,
    parent_style: Option<&ComputedValues>,
    parent_style_ignoring_first_line: Option<&ComputedValues>,
    layout_parent_style: Option<&ComputedValues>,
    visited_style: Option<Arc<ComputedValues>>,
    font_metrics_provider: &FontMetricsProvider,
    flags: CascadeFlags,
    quirks_mode: QuirksMode,
    rule_cache: Option<&RuleCache>,
    rule_cache_conditions: &mut RuleCacheConditions,
) -> Arc<ComputedValues> {
    debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
    let empty = SmallBitVec::new();

    let property_restriction = pseudo.and_then(|p| p.property_restriction());

    let iter_declarations = || {
        rule_node.self_and_ancestors().flat_map(|node| {
            let cascade_level = node.cascade_level();
            let source = node.style_source();

            let declarations = if source.is_some() {
                source.read(cascade_level.guard(guards)).declaration_importance_iter()
            } else {
                // The root node has no style source.
                DeclarationImportanceIterator::new(&[], &empty)
            };
            let node_importance = node.importance();

            declarations
                // Yield declarations later in source order (with more precedence) first.
                .rev()
                .filter_map(move |(declaration, declaration_importance)| {
                    if let Some(property_restriction) = property_restriction {
                        // declaration.id() is either a longhand or a custom
                        // property.  Custom properties are always allowed, but
                        // longhands are only allowed if they have our
                        // property_restriction flag set.
                        if let PropertyDeclarationId::Longhand(id) = declaration.id() {
                            if !id.flags().contains(property_restriction) {
                                return None
                            }
                        }
                    }

                    if declaration_importance == node_importance {
                        Some((declaration, cascade_level))
                    } else {
                        None
                    }
                })
        })
    };

    apply_declarations(
        device,
        pseudo,
        rule_node,
        guards,
        iter_declarations,
        parent_style,
        parent_style_ignoring_first_line,
        layout_parent_style,
        visited_style,
        font_metrics_provider,
        flags,
        quirks_mode,
        rule_cache,
        rule_cache_conditions,
    )
}

/// NOTE: This function expects the declaration with more priority to appear
/// first.
pub fn apply_declarations<'a, F, I>(
    device: &Device,
    pseudo: Option<&PseudoElement>,
    rules: &StrongRuleNode,
    guards: &StylesheetGuards,
    iter_declarations: F,
    parent_style: Option<&ComputedValues>,
    parent_style_ignoring_first_line: Option<&ComputedValues>,
    layout_parent_style: Option<&ComputedValues>,
    visited_style: Option<Arc<ComputedValues>>,
    font_metrics_provider: &FontMetricsProvider,
    flags: CascadeFlags,
    quirks_mode: QuirksMode,
    rule_cache: Option<&RuleCache>,
    rule_cache_conditions: &mut RuleCacheConditions,
) -> Arc<ComputedValues>
where
    F: Fn() -> I,
    I: Iterator<Item = (&'a PropertyDeclaration, CascadeLevel)>,
{
    debug_assert!(layout_parent_style.is_none() || parent_style.is_some());
    debug_assert_eq!(parent_style.is_some(), parent_style_ignoring_first_line.is_some());
    #[cfg(feature = "gecko")]
    debug_assert!(parent_style.is_none() ||
                  ::std::ptr::eq(parent_style.unwrap(),
                                 parent_style_ignoring_first_line.unwrap()) ||
                  parent_style.unwrap().pseudo() == Some(PseudoElement::FirstLine));
    let (inherited_style, layout_parent_style) = match parent_style {
        Some(parent_style) => {
            (parent_style,
             layout_parent_style.unwrap_or(parent_style))
        },
        None => {
            (device.default_computed_values(),
             device.default_computed_values())
        }
    };

    let custom_properties = {
        let mut builder =
            CustomPropertiesBuilder::new(inherited_style.custom_properties());

        for (declaration, _cascade_level) in iter_declarations() {
            if let PropertyDeclaration::Custom(ref name, ref value) = *declaration {
                builder.cascade(name, value.borrow());
            }
        }

        builder.build()
    };

    let mut context = computed::Context {
        is_root_element: flags.contains(CascadeFlags::IS_ROOT_ELEMENT),
        // We'd really like to own the rules here to avoid refcount traffic, but
        // animation's usage of `apply_declarations` make this tricky. See bug
        // 1375525.
        builder: StyleBuilder::new(
            device,
            parent_style,
            parent_style_ignoring_first_line,
            pseudo,
            flags,
            Some(rules.clone()),
            custom_properties,
            WritingMode::empty(),
            ComputedValueFlags::empty(),
            visited_style,
        ),
        cached_system_font: None,
        in_media_query: false,
        for_smil_animation: false,
        for_non_inherited_property: None,
        font_metrics_provider,
        quirks_mode,
        rule_cache_conditions: RefCell::new(rule_cache_conditions),
    };

    let ignore_colors = !device.use_document_colors();

    // Set computed values, overwriting earlier declarations for the same
    // property.
    let mut seen = LonghandIdSet::new();

    // Declaration blocks are stored in increasing precedence order, we want
    // them in decreasing order here.
    //
    // We could (and used to) use a pattern match here, but that bloats this
    // function to over 100K of compiled code!
    //
    // To improve i-cache behavior, we outline the individual functions and use
    // virtual dispatch instead.
    let mut apply_reset = true;
            // Pull these out so that we can compute them in a specific order
            // without introducing more iterations.
            let mut font_size = None;
            let mut font_family = None;
        for (declaration, cascade_level) in iter_declarations() {
            let declaration_id = declaration.id();
            let longhand_id = match declaration_id {
                PropertyDeclarationId::Longhand(id) => id,
                PropertyDeclarationId::Custom(..) => continue,
            };

            // Only a few properties are allowed to depend on the visited state
            // of links.  When cascading visited styles, we can save time by
            // only processing these properties.
            if flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) &&
               !longhand_id.is_visited_dependent() {
                continue
            }

            if !apply_reset && !longhand_id.inherited() {
                continue;
            }

            if
                    !
                longhand_id.is_early_property()
            {
                continue
            }

            
            let physical_longhand_id = longhand_id ;
            if seen.contains(physical_longhand_id) {
                continue
            }

            let mut declaration = match *declaration {
                PropertyDeclaration::WithVariables(id, ref unparsed) => {
                    if !id.inherited() {
                        context.rule_cache_conditions.borrow_mut()
                            .set_uncacheable();
                    }
                    Cow::Owned(unparsed.substitute_variables(
                        id,
                        context.builder.custom_properties.as_ref(),
                        context.quirks_mode
                    ))
                }
                ref d => Cow::Borrowed(d)
            };

            // When document colors are disabled, skip properties that are
            // marked as ignored in that mode, unless they come from a UA or
            // user style sheet.
            if ignore_colors &&
               longhand_id.is_ignored_when_document_colors_disabled(
                   cascade_level,
                   context.builder.pseudo
                )
            {
                let non_transparent_background = match *declaration {
                    PropertyDeclaration::BackgroundColor(ref color) => {
                        // Treat background-color a bit differently.  If the specified
                        // color is anything other than a fully transparent color, convert
                        // it into the Device's default background color.
                        color.is_non_transparent()
                    }
                    _ => continue
                };

                // FIXME: moving this out of `match` is a work around for
                // borrows being lexical.
                if non_transparent_background {
                    let color = device.default_background_color();
                    declaration =
                        Cow::Owned(PropertyDeclaration::BackgroundColor(color.into()));
                }
            }

            seen.insert(physical_longhand_id);

                if LonghandId::FontSize == longhand_id {
                    font_size = Some(declaration.clone());
                    continue;
                }
                if LonghandId::FontFamily == longhand_id {
                    font_family = Some(declaration.clone());
                    continue;
                }

            let discriminant = longhand_id as usize;
            (CASCADE_PROPERTY[discriminant])(&*declaration, &mut context);
        }
            let writing_mode =
                WritingMode::new(context.builder.get_inheritedbox());
            context.builder.writing_mode = writing_mode;

            let mut _skip_font_family = false;


                // <svg:text> is not affected by text zoom, and it uses a preshint to
                // disable it. We fix up the struct when this happens by unzooming
                // its contained font values, which will have been zoomed in the parent
                if seen.contains(LonghandId::XTextZoom) {
                    let zoom = context.builder.get_font().gecko().mAllowZoom;
                    let parent_zoom = context.style().get_parent_font().gecko().mAllowZoom;
                    if  zoom != parent_zoom {
                        debug_assert!(!zoom,
                                      "We only ever disable text zoom (in svg:text), never enable it");
                        // can't borrow both device and font, use the take/put machinery
                        let mut font = context.builder.take_font();
                        font.unzoom_fonts(context.device());
                        context.builder.put_font(font);
                    }
                }

                // Whenever a single generic value is specified, gecko will do a bunch of
                // recalculation walking up the rule tree, including handling the font-size stuff.
                // It basically repopulates the font struct with the default font for a given
                // generic and language. We handle the font-size stuff separately, so this boils
                // down to just copying over the font-family lists (no other aspect of the default
                // font can be configured).

                if seen.contains(LonghandId::XLang) || font_family.is_some() {
                    // if just the language changed, the inherited generic is all we need
                    let mut generic = inherited_style.get_font().gecko().mGenericID;
                    if let Some(ref declaration) = font_family {
                        if let PropertyDeclaration::FontFamily(ref fam) = **declaration {
                            if let Some(id) = fam.single_generic() {
                                generic = id;
                                // In case of a specified font family with a single generic, we will
                                // end up setting font family below, but its value would get
                                // overwritten later in the pipeline when cascading.
                                //
                                // We instead skip cascading font-family in that case.
                                //
                                // In case of the language changing, we wish for a specified font-
                                // family to override this, so we do not skip cascading then.
                                _skip_font_family = true;
                            }
                        }
                    }

                    let pres_context = context.builder.device.pres_context();
                    let gecko_font = context.builder.mutate_font().gecko_mut();
                    gecko_font.mGenericID = generic;
                    unsafe {
                        bindings::Gecko_nsStyleFont_PrefillDefaultForGeneric(
                            gecko_font,
                            pres_context,
                            generic,
                        );
                    }
                }

            // It is important that font_size is computed before
            // the late properties (for em units), but after font-family
            // (for the base-font-size dependence for default and keyword font-sizes)
            // Additionally, when we support system fonts they will have to be
            // computed early, and *before* font_family, so I'm including
            // font_family here preemptively instead of keeping it within
            // the early properties.
            //
            // To avoid an extra iteration, we just pull out the property
            // during the early iteration and cascade them in order
            // after it.
            if !_skip_font_family {
                if let Some(ref declaration) = font_family {

                    let discriminant = LonghandId::FontFamily as usize;
                    (CASCADE_PROPERTY[discriminant])(declaration, &mut context);
                        let device = context.builder.device;
                        if let PropertyDeclaration::FontFamily(ref val) = **declaration {
                            if val.get_system().is_some() {
                                let default = context.cached_system_font
                                                     .as_ref().unwrap().default_font_type;
                                context.builder.mutate_font().fixup_system(default);
                            } else {
                                context.builder.mutate_font().fixup_none_generic(device);
                            }
                        }
                }
            }

            if let Some(ref declaration) = font_size {
                let discriminant = LonghandId::FontSize as usize;
                (CASCADE_PROPERTY[discriminant])(declaration, &mut context);
            // Font size must be explicitly inherited to handle lang changes and
            // scriptlevel changes.
            } else if seen.contains(LonghandId::XLang) ||
                      seen.contains(LonghandId::MozScriptLevel) ||
                      seen.contains(LonghandId::MozMinFontSizeRatio) ||
                      font_family.is_some() {
                let discriminant = LonghandId::FontSize as usize;
                let size = PropertyDeclaration::CSSWideKeyword(
                    LonghandId::FontSize, CSSWideKeyword::Inherit);

                (CASCADE_PROPERTY[discriminant])(&size, &mut context);
            }

            if let Some(style) = rule_cache.and_then(|c| c.find(guards, &context.builder)) {
                context.builder.copy_reset_from(style);
                apply_reset = false;
            }
        for (declaration, cascade_level) in iter_declarations() {
            let declaration_id = declaration.id();
            let longhand_id = match declaration_id {
                PropertyDeclarationId::Longhand(id) => id,
                PropertyDeclarationId::Custom(..) => continue,
            };

            // Only a few properties are allowed to depend on the visited state
            // of links.  When cascading visited styles, we can save time by
            // only processing these properties.
            if flags.contains(CascadeFlags::VISITED_DEPENDENT_ONLY) &&
               !longhand_id.is_visited_dependent() {
                continue
            }

            if !apply_reset && !longhand_id.inherited() {
                continue;
            }

            if
                longhand_id.is_early_property()
            {
                continue
            }

            
            let physical_longhand_id = longhand_id .to_physical(writing_mode);
            if seen.contains(physical_longhand_id) {
                continue
            }

            let mut declaration = match *declaration {
                PropertyDeclaration::WithVariables(id, ref unparsed) => {
                    if !id.inherited() {
                        context.rule_cache_conditions.borrow_mut()
                            .set_uncacheable();
                    }
                    Cow::Owned(unparsed.substitute_variables(
                        id,
                        context.builder.custom_properties.as_ref(),
                        context.quirks_mode
                    ))
                }
                ref d => Cow::Borrowed(d)
            };

            // When document colors are disabled, skip properties that are
            // marked as ignored in that mode, unless they come from a UA or
            // user style sheet.
            if ignore_colors &&
               longhand_id.is_ignored_when_document_colors_disabled(
                   cascade_level,
                   context.builder.pseudo
                )
            {
                let non_transparent_background = match *declaration {
                    PropertyDeclaration::BackgroundColor(ref color) => {
                        // Treat background-color a bit differently.  If the specified
                        // color is anything other than a fully transparent color, convert
                        // it into the Device's default background color.
                        color.is_non_transparent()
                    }
                    _ => continue
                };

                // FIXME: moving this out of `match` is a work around for
                // borrows being lexical.
                if non_transparent_background {
                    let color = device.default_background_color();
                    declaration =
                        Cow::Owned(PropertyDeclaration::BackgroundColor(color.into()));
                }
            }

            seen.insert(physical_longhand_id);


            let discriminant = longhand_id as usize;
            (CASCADE_PROPERTY[discriminant])(&*declaration, &mut context);
        }

    let mut builder = context.builder;

        if let Some(ref mut bg) = builder.get_background_if_mutated() {
            bg.fill_arrays();
        }

        if let Some(ref mut svg) = builder.get_svg_if_mutated() {
            svg.fill_arrays();
        }


    builder.clear_modified_reset();

    StyleAdjuster::new(&mut builder)
        .adjust(layout_parent_style, flags);

    if builder.modified_reset() || !apply_reset {
        // If we adjusted any reset structs, we can't cache this ComputedValues.
        //
        // Also, if we re-used existing reset structs, don't bother caching it
        // back again. (Aside from being wasted effort, it will be wrong, since
        // context.rule_cache_conditions won't be set appropriately if we
        // didn't compute those reset properties.)
        context.rule_cache_conditions.borrow_mut()
            .set_uncacheable();
    }

    builder.build()
}

/// See StyleAdjuster::adjust_for_border_width.
pub fn adjust_border_width(style: &mut StyleBuilder) {
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_top_style().none_or_hidden() &&
           style.get_border().border_top_has_nonzero_width() {
            style.set_border_top_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_right_style().none_or_hidden() &&
           style.get_border().border_right_has_nonzero_width() {
            style.set_border_right_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_bottom_style().none_or_hidden() &&
           style.get_border().border_bottom_has_nonzero_width() {
            style.set_border_bottom_width(NonNegativeLength::zero());
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_left_style().none_or_hidden() &&
           style.get_border().border_left_has_nonzero_width() {
            style.set_border_left_width(NonNegativeLength::zero());
        }
}

/// An identifier for a given alias property.
#[derive(Clone, Copy, Eq, PartialEq)]
#[cfg_attr(feature = "servo", derive(MallocSizeOf))]
pub enum AliasId {
        /// -webkit-background-clip
        WebkitBackgroundClip = 0,
        /// -webkit-background-origin
        WebkitBackgroundOrigin = 1,
        /// -webkit-background-size
        WebkitBackgroundSize = 2,
        /// -moz-border-start-color
        MozBorderStartColor = 3,
        /// -moz-border-start-style
        MozBorderStartStyle = 4,
        /// -moz-border-start-width
        MozBorderStartWidth = 5,
        /// -moz-border-end-color
        MozBorderEndColor = 6,
        /// -moz-border-end-style
        MozBorderEndStyle = 7,
        /// -moz-border-end-width
        MozBorderEndWidth = 8,
        /// -webkit-border-top-left-radius
        WebkitBorderTopLeftRadius = 9,
        /// -webkit-border-top-right-radius
        WebkitBorderTopRightRadius = 10,
        /// -webkit-border-bottom-right-radius
        WebkitBorderBottomRightRadius = 11,
        /// -webkit-border-bottom-left-radius
        WebkitBorderBottomLeftRadius = 12,
        /// -moz-transition-duration
        MozTransitionDuration = 13,
        /// -webkit-transition-duration
        WebkitTransitionDuration = 14,
        /// -moz-transition-timing-function
        MozTransitionTimingFunction = 15,
        /// -webkit-transition-timing-function
        WebkitTransitionTimingFunction = 16,
        /// -moz-transition-property
        MozTransitionProperty = 17,
        /// -webkit-transition-property
        WebkitTransitionProperty = 18,
        /// -moz-transition-delay
        MozTransitionDelay = 19,
        /// -webkit-transition-delay
        WebkitTransitionDelay = 20,
        /// -moz-animation-name
        MozAnimationName = 21,
        /// -webkit-animation-name
        WebkitAnimationName = 22,
        /// -moz-animation-duration
        MozAnimationDuration = 23,
        /// -webkit-animation-duration
        WebkitAnimationDuration = 24,
        /// -moz-animation-timing-function
        MozAnimationTimingFunction = 25,
        /// -webkit-animation-timing-function
        WebkitAnimationTimingFunction = 26,
        /// -moz-animation-iteration-count
        MozAnimationIterationCount = 27,
        /// -webkit-animation-iteration-count
        WebkitAnimationIterationCount = 28,
        /// -moz-animation-direction
        MozAnimationDirection = 29,
        /// -webkit-animation-direction
        WebkitAnimationDirection = 30,
        /// -moz-animation-play-state
        MozAnimationPlayState = 31,
        /// -webkit-animation-play-state
        WebkitAnimationPlayState = 32,
        /// -moz-animation-fill-mode
        MozAnimationFillMode = 33,
        /// -webkit-animation-fill-mode
        WebkitAnimationFillMode = 34,
        /// -moz-animation-delay
        MozAnimationDelay = 35,
        /// -webkit-animation-delay
        WebkitAnimationDelay = 36,
        /// -webkit-transform
        WebkitTransform = 37,
        /// -moz-perspective
        MozPerspective = 38,
        /// -webkit-perspective
        WebkitPerspective = 39,
        /// -moz-perspective-origin
        MozPerspectiveOrigin = 40,
        /// -webkit-perspective-origin
        WebkitPerspectiveOrigin = 41,
        /// -moz-backface-visibility
        MozBackfaceVisibility = 42,
        /// -webkit-backface-visibility
        WebkitBackfaceVisibility = 43,
        /// -moz-transform-style
        MozTransformStyle = 44,
        /// -webkit-transform-style
        WebkitTransformStyle = 45,
        /// -moz-transform-origin
        MozTransformOrigin = 46,
        /// -webkit-transform-origin
        WebkitTransformOrigin = 47,
        /// -moz-column-width
        MozColumnWidth = 48,
        /// -moz-column-count
        MozColumnCount = 49,
        /// -moz-column-gap
        MozColumnGap = 50,
        /// -moz-column-fill
        MozColumnFill = 51,
        /// -moz-column-rule-width
        MozColumnRuleWidth = 52,
        /// -moz-column-rule-color
        MozColumnRuleColor = 53,
        /// -moz-column-span
        MozColumnSpan = 54,
        /// -moz-column-rule-style
        MozColumnRuleStyle = 55,
        /// -webkit-box-shadow
        WebkitBoxShadow = 56,
        /// -webkit-filter
        WebkitFilter = 57,
        /// -moz-font-feature-settings
        MozFontFeatureSettings = 58,
        /// -moz-font-language-override
        MozFontLanguageOverride = 59,
        /// -moz-hyphens
        MozHyphens = 60,
        /// -webkit-text-size-adjust
        WebkitTextSizeAdjust = 61,
        /// word-wrap
        WordWrap = 62,
        /// -moz-margin-start
        MozMarginStart = 63,
        /// -moz-margin-end
        MozMarginEnd = 64,
        /// -moz-padding-start
        MozPaddingStart = 65,
        /// -moz-padding-end
        MozPaddingEnd = 66,
        /// -webkit-flex-direction
        WebkitFlexDirection = 67,
        /// -webkit-flex-wrap
        WebkitFlexWrap = 68,
        /// -webkit-justify-content
        WebkitJustifyContent = 69,
        /// -webkit-align-content
        WebkitAlignContent = 70,
        /// -webkit-align-items
        WebkitAlignItems = 71,
        /// -webkit-flex-grow
        WebkitFlexGrow = 72,
        /// -webkit-flex-shrink
        WebkitFlexShrink = 73,
        /// -webkit-align-self
        WebkitAlignSelf = 74,
        /// -webkit-order
        WebkitOrder = 75,
        /// -webkit-flex-basis
        WebkitFlexBasis = 76,
        /// -moz-box-sizing
        MozBoxSizing = 77,
        /// -webkit-box-sizing
        WebkitBoxSizing = 78,
        /// -webkit-user-select
        WebkitUserSelect = 79,
        /// -webkit-mask-repeat
        WebkitMaskRepeat = 80,
        /// -webkit-mask-position-x
        WebkitMaskPositionX = 81,
        /// -webkit-mask-position-y
        WebkitMaskPositionY = 82,
        /// -webkit-mask-clip
        WebkitMaskClip = 83,
        /// -webkit-mask-origin
        WebkitMaskOrigin = 84,
        /// -webkit-mask-size
        WebkitMaskSize = 85,
        /// -webkit-mask-composite
        WebkitMaskComposite = 86,
        /// -webkit-mask-image
        WebkitMaskImage = 87,
        /// -webkit-box-align
        WebkitBoxAlign = 88,
        /// -webkit-box-direction
        WebkitBoxDirection = 89,
        /// -webkit-box-flex
        WebkitBoxFlex = 90,
        /// -webkit-box-orient
        WebkitBoxOrient = 91,
        /// -webkit-box-pack
        WebkitBoxPack = 92,
        /// -webkit-box-ordinal-group
        WebkitBoxOrdinalGroup = 93,
        /// -moz-border-start
        MozBorderStart = 94,
        /// -moz-border-end
        MozBorderEnd = 95,
        /// -webkit-border-radius
        WebkitBorderRadius = 96,
        /// -moz-border-image
        MozBorderImage = 97,
        /// -webkit-border-image
        WebkitBorderImage = 98,
        /// -moz-transition
        MozTransition = 99,
        /// -webkit-transition
        WebkitTransition = 100,
        /// -moz-animation
        MozAnimation = 101,
        /// -webkit-animation
        WebkitAnimation = 102,
        /// -moz-columns
        MozColumns = 103,
        /// -moz-column-rule
        MozColumnRule = 104,
        /// -webkit-mask
        WebkitMask = 105,
        /// -webkit-mask-position
        WebkitMaskPosition = 106,
        /// -webkit-flex-flow
        WebkitFlexFlow = 107,
        /// -webkit-flex
        WebkitFlex = 108,
}

impl fmt::Debug for AliasId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        let name = match *self {
                AliasId::WebkitBackgroundClip => "WebkitBackgroundClip",
                AliasId::WebkitBackgroundOrigin => "WebkitBackgroundOrigin",
                AliasId::WebkitBackgroundSize => "WebkitBackgroundSize",
                AliasId::MozBorderStartColor => "MozBorderStartColor",
                AliasId::MozBorderStartStyle => "MozBorderStartStyle",
                AliasId::MozBorderStartWidth => "MozBorderStartWidth",
                AliasId::MozBorderEndColor => "MozBorderEndColor",
                AliasId::MozBorderEndStyle => "MozBorderEndStyle",
                AliasId::MozBorderEndWidth => "MozBorderEndWidth",
                AliasId::WebkitBorderTopLeftRadius => "WebkitBorderTopLeftRadius",
                AliasId::WebkitBorderTopRightRadius => "WebkitBorderTopRightRadius",
                AliasId::WebkitBorderBottomRightRadius => "WebkitBorderBottomRightRadius",
                AliasId::WebkitBorderBottomLeftRadius => "WebkitBorderBottomLeftRadius",
                AliasId::MozTransitionDuration => "MozTransitionDuration",
                AliasId::WebkitTransitionDuration => "WebkitTransitionDuration",
                AliasId::MozTransitionTimingFunction => "MozTransitionTimingFunction",
                AliasId::WebkitTransitionTimingFunction => "WebkitTransitionTimingFunction",
                AliasId::MozTransitionProperty => "MozTransitionProperty",
                AliasId::WebkitTransitionProperty => "WebkitTransitionProperty",
                AliasId::MozTransitionDelay => "MozTransitionDelay",
                AliasId::WebkitTransitionDelay => "WebkitTransitionDelay",
                AliasId::MozAnimationName => "MozAnimationName",
                AliasId::WebkitAnimationName => "WebkitAnimationName",
                AliasId::MozAnimationDuration => "MozAnimationDuration",
                AliasId::WebkitAnimationDuration => "WebkitAnimationDuration",
                AliasId::MozAnimationTimingFunction => "MozAnimationTimingFunction",
                AliasId::WebkitAnimationTimingFunction => "WebkitAnimationTimingFunction",
                AliasId::MozAnimationIterationCount => "MozAnimationIterationCount",
                AliasId::WebkitAnimationIterationCount => "WebkitAnimationIterationCount",
                AliasId::MozAnimationDirection => "MozAnimationDirection",
                AliasId::WebkitAnimationDirection => "WebkitAnimationDirection",
                AliasId::MozAnimationPlayState => "MozAnimationPlayState",
                AliasId::WebkitAnimationPlayState => "WebkitAnimationPlayState",
                AliasId::MozAnimationFillMode => "MozAnimationFillMode",
                AliasId::WebkitAnimationFillMode => "WebkitAnimationFillMode",
                AliasId::MozAnimationDelay => "MozAnimationDelay",
                AliasId::WebkitAnimationDelay => "WebkitAnimationDelay",
                AliasId::WebkitTransform => "WebkitTransform",
                AliasId::MozPerspective => "MozPerspective",
                AliasId::WebkitPerspective => "WebkitPerspective",
                AliasId::MozPerspectiveOrigin => "MozPerspectiveOrigin",
                AliasId::WebkitPerspectiveOrigin => "WebkitPerspectiveOrigin",
                AliasId::MozBackfaceVisibility => "MozBackfaceVisibility",
                AliasId::WebkitBackfaceVisibility => "WebkitBackfaceVisibility",
                AliasId::MozTransformStyle => "MozTransformStyle",
                AliasId::WebkitTransformStyle => "WebkitTransformStyle",
                AliasId::MozTransformOrigin => "MozTransformOrigin",
                AliasId::WebkitTransformOrigin => "WebkitTransformOrigin",
                AliasId::MozColumnWidth => "MozColumnWidth",
                AliasId::MozColumnCount => "MozColumnCount",
                AliasId::MozColumnGap => "MozColumnGap",
                AliasId::MozColumnFill => "MozColumnFill",
                AliasId::MozColumnRuleWidth => "MozColumnRuleWidth",
                AliasId::MozColumnRuleColor => "MozColumnRuleColor",
                AliasId::MozColumnSpan => "MozColumnSpan",
                AliasId::MozColumnRuleStyle => "MozColumnRuleStyle",
                AliasId::WebkitBoxShadow => "WebkitBoxShadow",
                AliasId::WebkitFilter => "WebkitFilter",
                AliasId::MozFontFeatureSettings => "MozFontFeatureSettings",
                AliasId::MozFontLanguageOverride => "MozFontLanguageOverride",
                AliasId::MozHyphens => "MozHyphens",
                AliasId::WebkitTextSizeAdjust => "WebkitTextSizeAdjust",
                AliasId::WordWrap => "WordWrap",
                AliasId::MozMarginStart => "MozMarginStart",
                AliasId::MozMarginEnd => "MozMarginEnd",
                AliasId::MozPaddingStart => "MozPaddingStart",
                AliasId::MozPaddingEnd => "MozPaddingEnd",
                AliasId::WebkitFlexDirection => "WebkitFlexDirection",
                AliasId::WebkitFlexWrap => "WebkitFlexWrap",
                AliasId::WebkitJustifyContent => "WebkitJustifyContent",
                AliasId::WebkitAlignContent => "WebkitAlignContent",
                AliasId::WebkitAlignItems => "WebkitAlignItems",
                AliasId::WebkitFlexGrow => "WebkitFlexGrow",
                AliasId::WebkitFlexShrink => "WebkitFlexShrink",
                AliasId::WebkitAlignSelf => "WebkitAlignSelf",
                AliasId::WebkitOrder => "WebkitOrder",
                AliasId::WebkitFlexBasis => "WebkitFlexBasis",
                AliasId::MozBoxSizing => "MozBoxSizing",
                AliasId::WebkitBoxSizing => "WebkitBoxSizing",
                AliasId::WebkitUserSelect => "WebkitUserSelect",
                AliasId::WebkitMaskRepeat => "WebkitMaskRepeat",
                AliasId::WebkitMaskPositionX => "WebkitMaskPositionX",
                AliasId::WebkitMaskPositionY => "WebkitMaskPositionY",
                AliasId::WebkitMaskClip => "WebkitMaskClip",
                AliasId::WebkitMaskOrigin => "WebkitMaskOrigin",
                AliasId::WebkitMaskSize => "WebkitMaskSize",
                AliasId::WebkitMaskComposite => "WebkitMaskComposite",
                AliasId::WebkitMaskImage => "WebkitMaskImage",
                AliasId::WebkitBoxAlign => "WebkitBoxAlign",
                AliasId::WebkitBoxDirection => "WebkitBoxDirection",
                AliasId::WebkitBoxFlex => "WebkitBoxFlex",
                AliasId::WebkitBoxOrient => "WebkitBoxOrient",
                AliasId::WebkitBoxPack => "WebkitBoxPack",
                AliasId::WebkitBoxOrdinalGroup => "WebkitBoxOrdinalGroup",
                AliasId::MozBorderStart => "MozBorderStart",
                AliasId::MozBorderEnd => "MozBorderEnd",
                AliasId::WebkitBorderRadius => "WebkitBorderRadius",
                AliasId::MozBorderImage => "MozBorderImage",
                AliasId::WebkitBorderImage => "WebkitBorderImage",
                AliasId::MozTransition => "MozTransition",
                AliasId::WebkitTransition => "WebkitTransition",
                AliasId::MozAnimation => "MozAnimation",
                AliasId::WebkitAnimation => "WebkitAnimation",
                AliasId::MozColumns => "MozColumns",
                AliasId::MozColumnRule => "MozColumnRule",
                AliasId::WebkitMask => "WebkitMask",
                AliasId::WebkitMaskPosition => "WebkitMaskPosition",
                AliasId::WebkitFlexFlow => "WebkitFlexFlow",
                AliasId::WebkitFlex => "WebkitFlex",
        };
        formatter.write_str(name)
    }
}

impl AliasId {
    /// Returns an nsCSSPropertyID.
    #[cfg(feature = "gecko")]
    #[allow(non_upper_case_globals)]
    pub fn to_nscsspropertyid(&self) -> nsCSSPropertyID {
        use gecko_bindings::structs::*;

        match *self {
                AliasId::WebkitBackgroundClip => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundClip
                },
                AliasId::WebkitBackgroundOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundOrigin
                },
                AliasId::WebkitBackgroundSize => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackgroundSize
                },
                AliasId::MozBorderStartColor => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartColor
                },
                AliasId::MozBorderStartStyle => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartStyle
                },
                AliasId::MozBorderStartWidth => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStartWidth
                },
                AliasId::MozBorderEndColor => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndColor
                },
                AliasId::MozBorderEndStyle => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndStyle
                },
                AliasId::MozBorderEndWidth => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEndWidth
                },
                AliasId::WebkitBorderTopLeftRadius => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopLeftRadius
                },
                AliasId::WebkitBorderTopRightRadius => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderTopRightRadius
                },
                AliasId::WebkitBorderBottomRightRadius => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomRightRadius
                },
                AliasId::WebkitBorderBottomLeftRadius => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderBottomLeftRadius
                },
                AliasId::MozTransitionDuration => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDuration
                },
                AliasId::WebkitTransitionDuration => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDuration
                },
                AliasId::MozTransitionTimingFunction => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionTimingFunction
                },
                AliasId::WebkitTransitionTimingFunction => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionTimingFunction
                },
                AliasId::MozTransitionProperty => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionProperty
                },
                AliasId::WebkitTransitionProperty => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionProperty
                },
                AliasId::MozTransitionDelay => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransitionDelay
                },
                AliasId::WebkitTransitionDelay => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransitionDelay
                },
                AliasId::MozAnimationName => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationName
                },
                AliasId::WebkitAnimationName => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationName
                },
                AliasId::MozAnimationDuration => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDuration
                },
                AliasId::WebkitAnimationDuration => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDuration
                },
                AliasId::MozAnimationTimingFunction => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationTimingFunction
                },
                AliasId::WebkitAnimationTimingFunction => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationTimingFunction
                },
                AliasId::MozAnimationIterationCount => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationIterationCount
                },
                AliasId::WebkitAnimationIterationCount => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationIterationCount
                },
                AliasId::MozAnimationDirection => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDirection
                },
                AliasId::WebkitAnimationDirection => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDirection
                },
                AliasId::MozAnimationPlayState => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationPlayState
                },
                AliasId::WebkitAnimationPlayState => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationPlayState
                },
                AliasId::MozAnimationFillMode => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationFillMode
                },
                AliasId::WebkitAnimationFillMode => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationFillMode
                },
                AliasId::MozAnimationDelay => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimationDelay
                },
                AliasId::WebkitAnimationDelay => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimationDelay
                },
                AliasId::WebkitTransform => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransform
                },
                AliasId::MozPerspective => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspective
                },
                AliasId::WebkitPerspective => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspective
                },
                AliasId::MozPerspectiveOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPerspectiveOrigin
                },
                AliasId::WebkitPerspectiveOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitPerspectiveOrigin
                },
                AliasId::MozBackfaceVisibility => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBackfaceVisibility
                },
                AliasId::WebkitBackfaceVisibility => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBackfaceVisibility
                },
                AliasId::MozTransformStyle => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformStyle
                },
                AliasId::WebkitTransformStyle => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformStyle
                },
                AliasId::MozTransformOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransformOrigin
                },
                AliasId::WebkitTransformOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransformOrigin
                },
                AliasId::MozColumnWidth => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnWidth
                },
                AliasId::MozColumnCount => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnCount
                },
                AliasId::MozColumnGap => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnGap
                },
                AliasId::MozColumnFill => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnFill
                },
                AliasId::MozColumnRuleWidth => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleWidth
                },
                AliasId::MozColumnRuleColor => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleColor
                },
                AliasId::MozColumnSpan => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnSpan
                },
                AliasId::MozColumnRuleStyle => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRuleStyle
                },
                AliasId::WebkitBoxShadow => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxShadow
                },
                AliasId::WebkitFilter => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFilter
                },
                AliasId::MozFontFeatureSettings => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontFeatureSettings
                },
                AliasId::MozFontLanguageOverride => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozFontLanguageOverride
                },
                AliasId::MozHyphens => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozHyphens
                },
                AliasId::WebkitTextSizeAdjust => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTextSizeAdjust
                },
                AliasId::WordWrap => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WordWrap
                },
                AliasId::MozMarginStart => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginStart
                },
                AliasId::MozMarginEnd => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozMarginEnd
                },
                AliasId::MozPaddingStart => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingStart
                },
                AliasId::MozPaddingEnd => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozPaddingEnd
                },
                AliasId::WebkitFlexDirection => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexDirection
                },
                AliasId::WebkitFlexWrap => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexWrap
                },
                AliasId::WebkitJustifyContent => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitJustifyContent
                },
                AliasId::WebkitAlignContent => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignContent
                },
                AliasId::WebkitAlignItems => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignItems
                },
                AliasId::WebkitFlexGrow => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexGrow
                },
                AliasId::WebkitFlexShrink => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexShrink
                },
                AliasId::WebkitAlignSelf => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAlignSelf
                },
                AliasId::WebkitOrder => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitOrder
                },
                AliasId::WebkitFlexBasis => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexBasis
                },
                AliasId::MozBoxSizing => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBoxSizing
                },
                AliasId::WebkitBoxSizing => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxSizing
                },
                AliasId::WebkitUserSelect => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitUserSelect
                },
                AliasId::WebkitMaskRepeat => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskRepeat
                },
                AliasId::WebkitMaskPositionX => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionX
                },
                AliasId::WebkitMaskPositionY => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPositionY
                },
                AliasId::WebkitMaskClip => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskClip
                },
                AliasId::WebkitMaskOrigin => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskOrigin
                },
                AliasId::WebkitMaskSize => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskSize
                },
                AliasId::WebkitMaskComposite => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskComposite
                },
                AliasId::WebkitMaskImage => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskImage
                },
                AliasId::WebkitBoxAlign => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxAlign
                },
                AliasId::WebkitBoxDirection => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxDirection
                },
                AliasId::WebkitBoxFlex => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxFlex
                },
                AliasId::WebkitBoxOrient => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrient
                },
                AliasId::WebkitBoxPack => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxPack
                },
                AliasId::WebkitBoxOrdinalGroup => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBoxOrdinalGroup
                },
                AliasId::MozBorderStart => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderStart
                },
                AliasId::MozBorderEnd => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderEnd
                },
                AliasId::WebkitBorderRadius => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderRadius
                },
                AliasId::MozBorderImage => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozBorderImage
                },
                AliasId::WebkitBorderImage => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitBorderImage
                },
                AliasId::MozTransition => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozTransition
                },
                AliasId::WebkitTransition => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitTransition
                },
                AliasId::MozAnimation => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozAnimation
                },
                AliasId::WebkitAnimation => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitAnimation
                },
                AliasId::MozColumns => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumns
                },
                AliasId::MozColumnRule => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_MozColumnRule
                },
                AliasId::WebkitMask => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMask
                },
                AliasId::WebkitMaskPosition => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitMaskPosition
                },
                AliasId::WebkitFlexFlow => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlexFlow
                },
                AliasId::WebkitFlex => {
                    
    nsCSSPropertyID::eCSSPropertyAlias_WebkitFlex
                },
        }
    }
}

// FIXME(emilio): This macro doesn't account for experimental properties, so
// even with the pref disabled you can set them from CSSOM in Servo.
#[macro_export]
macro_rules! css_properties_accessors {
    ($macro_name: ident) => {
        $macro_name! {
                                [Background_color, SetBackground_color,
                                 PropertyId::Longhand(LonghandId::BackgroundColor)],
                            [BackgroundColor, SetBackgroundColor,
                             PropertyId::Longhand(LonghandId::BackgroundColor)],
                                [Background_image, SetBackground_image,
                                 PropertyId::Longhand(LonghandId::BackgroundImage)],
                            [BackgroundImage, SetBackgroundImage,
                             PropertyId::Longhand(LonghandId::BackgroundImage)],
                                [Background_position_x, SetBackground_position_x,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                            [BackgroundPositionX, SetBackgroundPositionX,
                             PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                                [Background_position_y, SetBackground_position_y,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                            [BackgroundPositionY, SetBackgroundPositionY,
                             PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                                [Background_repeat, SetBackground_repeat,
                                 PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                            [BackgroundRepeat, SetBackgroundRepeat,
                             PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                                [Background_attachment, SetBackground_attachment,
                                 PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                            [BackgroundAttachment, SetBackgroundAttachment,
                             PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                                [Background_clip, SetBackground_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [BackgroundClip, SetBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [_webkit_background_clip, Set_webkit_background_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [WebkitBackgroundClip, SetWebkitBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [Background_origin, SetBackground_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [BackgroundOrigin, SetBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [_webkit_background_origin, Set_webkit_background_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [WebkitBackgroundOrigin, SetWebkitBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [Background_size, SetBackground_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [BackgroundSize, SetBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [_webkit_background_size, Set_webkit_background_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [WebkitBackgroundSize, SetWebkitBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [Background_blend_mode, SetBackground_blend_mode,
                                 PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                            [BackgroundBlendMode, SetBackgroundBlendMode,
                             PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                                [Border_top_color, SetBorder_top_color,
                                 PropertyId::Longhand(LonghandId::BorderTopColor)],
                            [BorderTopColor, SetBorderTopColor,
                             PropertyId::Longhand(LonghandId::BorderTopColor)],
                                [Border_top_style, SetBorder_top_style,
                                 PropertyId::Longhand(LonghandId::BorderTopStyle)],
                            [BorderTopStyle, SetBorderTopStyle,
                             PropertyId::Longhand(LonghandId::BorderTopStyle)],
                                [Border_top_width, SetBorder_top_width,
                                 PropertyId::Longhand(LonghandId::BorderTopWidth)],
                            [BorderTopWidth, SetBorderTopWidth,
                             PropertyId::Longhand(LonghandId::BorderTopWidth)],
                                [Border_left_color, SetBorder_left_color,
                                 PropertyId::Longhand(LonghandId::BorderLeftColor)],
                            [BorderLeftColor, SetBorderLeftColor,
                             PropertyId::Longhand(LonghandId::BorderLeftColor)],
                                [Border_left_style, SetBorder_left_style,
                                 PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                            [BorderLeftStyle, SetBorderLeftStyle,
                             PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                                [Border_left_width, SetBorder_left_width,
                                 PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                            [BorderLeftWidth, SetBorderLeftWidth,
                             PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                                [Border_bottom_color, SetBorder_bottom_color,
                                 PropertyId::Longhand(LonghandId::BorderBottomColor)],
                            [BorderBottomColor, SetBorderBottomColor,
                             PropertyId::Longhand(LonghandId::BorderBottomColor)],
                                [Border_bottom_style, SetBorder_bottom_style,
                                 PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                            [BorderBottomStyle, SetBorderBottomStyle,
                             PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                                [Border_bottom_width, SetBorder_bottom_width,
                                 PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                            [BorderBottomWidth, SetBorderBottomWidth,
                             PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                                [Border_right_color, SetBorder_right_color,
                                 PropertyId::Longhand(LonghandId::BorderRightColor)],
                            [BorderRightColor, SetBorderRightColor,
                             PropertyId::Longhand(LonghandId::BorderRightColor)],
                                [Border_right_style, SetBorder_right_style,
                                 PropertyId::Longhand(LonghandId::BorderRightStyle)],
                            [BorderRightStyle, SetBorderRightStyle,
                             PropertyId::Longhand(LonghandId::BorderRightStyle)],
                                [Border_right_width, SetBorder_right_width,
                                 PropertyId::Longhand(LonghandId::BorderRightWidth)],
                            [BorderRightWidth, SetBorderRightWidth,
                             PropertyId::Longhand(LonghandId::BorderRightWidth)],
                                [Border_block_start_color, SetBorder_block_start_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                            [BorderBlockStartColor, SetBorderBlockStartColor,
                             PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                                [Border_block_start_style, SetBorder_block_start_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                            [BorderBlockStartStyle, SetBorderBlockStartStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                                [Border_block_start_width, SetBorder_block_start_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                            [BorderBlockStartWidth, SetBorderBlockStartWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                                [Border_block_end_color, SetBorder_block_end_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                            [BorderBlockEndColor, SetBorderBlockEndColor,
                             PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                                [Border_block_end_style, SetBorder_block_end_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                            [BorderBlockEndStyle, SetBorderBlockEndStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                                [Border_block_end_width, SetBorder_block_end_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                            [BorderBlockEndWidth, SetBorderBlockEndWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                                [Border_inline_start_color, SetBorder_inline_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [BorderInlineStartColor, SetBorderInlineStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [_moz_border_start_color, Set_moz_border_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [MozBorderStartColor, SetMozBorderStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [Border_inline_start_style, SetBorder_inline_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [BorderInlineStartStyle, SetBorderInlineStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [_moz_border_start_style, Set_moz_border_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [MozBorderStartStyle, SetMozBorderStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [Border_inline_start_width, SetBorder_inline_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [BorderInlineStartWidth, SetBorderInlineStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [_moz_border_start_width, Set_moz_border_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [MozBorderStartWidth, SetMozBorderStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [Border_inline_end_color, SetBorder_inline_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [BorderInlineEndColor, SetBorderInlineEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [_moz_border_end_color, Set_moz_border_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [MozBorderEndColor, SetMozBorderEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [Border_inline_end_style, SetBorder_inline_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [BorderInlineEndStyle, SetBorderInlineEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [_moz_border_end_style, Set_moz_border_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [MozBorderEndStyle, SetMozBorderEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [Border_inline_end_width, SetBorder_inline_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [BorderInlineEndWidth, SetBorderInlineEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [_moz_border_end_width, Set_moz_border_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [MozBorderEndWidth, SetMozBorderEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [Border_top_left_radius, SetBorder_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [BorderTopLeftRadius, SetBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [_webkit_border_top_left_radius, Set_webkit_border_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [WebkitBorderTopLeftRadius, SetWebkitBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [Border_top_right_radius, SetBorder_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [BorderTopRightRadius, SetBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [_webkit_border_top_right_radius, Set_webkit_border_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [WebkitBorderTopRightRadius, SetWebkitBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [Border_bottom_right_radius, SetBorder_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [BorderBottomRightRadius, SetBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [_webkit_border_bottom_right_radius, Set_webkit_border_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [WebkitBorderBottomRightRadius, SetWebkitBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [Border_bottom_left_radius, SetBorder_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [BorderBottomLeftRadius, SetBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [_webkit_border_bottom_left_radius, Set_webkit_border_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [WebkitBorderBottomLeftRadius, SetWebkitBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [Box_decoration_break, SetBox_decoration_break,
                                 PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                            [BoxDecorationBreak, SetBoxDecorationBreak,
                             PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                                [_moz_float_edge, Set_moz_float_edge,
                                 PropertyId::Longhand(LonghandId::MozFloatEdge)],
                            [MozFloatEdge, SetMozFloatEdge,
                             PropertyId::Longhand(LonghandId::MozFloatEdge)],
                                [Border_image_source, SetBorder_image_source,
                                 PropertyId::Longhand(LonghandId::BorderImageSource)],
                            [BorderImageSource, SetBorderImageSource,
                             PropertyId::Longhand(LonghandId::BorderImageSource)],
                                [Border_image_outset, SetBorder_image_outset,
                                 PropertyId::Longhand(LonghandId::BorderImageOutset)],
                            [BorderImageOutset, SetBorderImageOutset,
                             PropertyId::Longhand(LonghandId::BorderImageOutset)],
                                [Border_image_repeat, SetBorder_image_repeat,
                                 PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                            [BorderImageRepeat, SetBorderImageRepeat,
                             PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                                [Border_image_width, SetBorder_image_width,
                                 PropertyId::Longhand(LonghandId::BorderImageWidth)],
                            [BorderImageWidth, SetBorderImageWidth,
                             PropertyId::Longhand(LonghandId::BorderImageWidth)],
                                [Border_image_slice, SetBorder_image_slice,
                                 PropertyId::Longhand(LonghandId::BorderImageSlice)],
                            [BorderImageSlice, SetBorderImageSlice,
                             PropertyId::Longhand(LonghandId::BorderImageSlice)],
                            [Display, SetDisplay,
                             PropertyId::Longhand(LonghandId::Display)],
                            [Position, SetPosition,
                             PropertyId::Longhand(LonghandId::Position)],
                            [Float, SetFloat,
                             PropertyId::Longhand(LonghandId::Float)],
                            [Clear, SetClear,
                             PropertyId::Longhand(LonghandId::Clear)],
                                [Vertical_align, SetVertical_align,
                                 PropertyId::Longhand(LonghandId::VerticalAlign)],
                            [VerticalAlign, SetVerticalAlign,
                             PropertyId::Longhand(LonghandId::VerticalAlign)],
                                [Overflow_x, SetOverflow_x,
                                 PropertyId::Longhand(LonghandId::OverflowX)],
                            [OverflowX, SetOverflowX,
                             PropertyId::Longhand(LonghandId::OverflowX)],
                                [Overflow_y, SetOverflow_y,
                                 PropertyId::Longhand(LonghandId::OverflowY)],
                            [OverflowY, SetOverflowY,
                             PropertyId::Longhand(LonghandId::OverflowY)],
                                [Transition_duration, SetTransition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [TransitionDuration, SetTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_moz_transition_duration, Set_moz_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [MozTransitionDuration, SetMozTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_webkit_transition_duration, Set_webkit_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [WebkitTransitionDuration, SetWebkitTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [Transition_timing_function, SetTransition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [TransitionTimingFunction, SetTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_moz_transition_timing_function, Set_moz_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [MozTransitionTimingFunction, SetMozTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_webkit_transition_timing_function, Set_webkit_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [WebkitTransitionTimingFunction, SetWebkitTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [Transition_property, SetTransition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [TransitionProperty, SetTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_moz_transition_property, Set_moz_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [MozTransitionProperty, SetMozTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_webkit_transition_property, Set_webkit_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [WebkitTransitionProperty, SetWebkitTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [Transition_delay, SetTransition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [TransitionDelay, SetTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_moz_transition_delay, Set_moz_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [MozTransitionDelay, SetMozTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_webkit_transition_delay, Set_webkit_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [WebkitTransitionDelay, SetWebkitTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [Animation_name, SetAnimation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [AnimationName, SetAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_moz_animation_name, Set_moz_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [MozAnimationName, SetMozAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_webkit_animation_name, Set_webkit_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [WebkitAnimationName, SetWebkitAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [Animation_duration, SetAnimation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [AnimationDuration, SetAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_moz_animation_duration, Set_moz_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [MozAnimationDuration, SetMozAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_webkit_animation_duration, Set_webkit_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [WebkitAnimationDuration, SetWebkitAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [Animation_timing_function, SetAnimation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [AnimationTimingFunction, SetAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_moz_animation_timing_function, Set_moz_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [MozAnimationTimingFunction, SetMozAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_webkit_animation_timing_function, Set_webkit_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [WebkitAnimationTimingFunction, SetWebkitAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [Animation_iteration_count, SetAnimation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [AnimationIterationCount, SetAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_moz_animation_iteration_count, Set_moz_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [MozAnimationIterationCount, SetMozAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_webkit_animation_iteration_count, Set_webkit_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [WebkitAnimationIterationCount, SetWebkitAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [Animation_direction, SetAnimation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [AnimationDirection, SetAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_moz_animation_direction, Set_moz_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [MozAnimationDirection, SetMozAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_webkit_animation_direction, Set_webkit_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [WebkitAnimationDirection, SetWebkitAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [Animation_play_state, SetAnimation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [AnimationPlayState, SetAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_moz_animation_play_state, Set_moz_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [MozAnimationPlayState, SetMozAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_webkit_animation_play_state, Set_webkit_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [WebkitAnimationPlayState, SetWebkitAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [Animation_fill_mode, SetAnimation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [AnimationFillMode, SetAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_moz_animation_fill_mode, Set_moz_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [MozAnimationFillMode, SetMozAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_webkit_animation_fill_mode, Set_webkit_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [WebkitAnimationFillMode, SetWebkitAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [Animation_delay, SetAnimation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [AnimationDelay, SetAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_moz_animation_delay, Set_moz_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [MozAnimationDelay, SetMozAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_webkit_animation_delay, Set_webkit_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [WebkitAnimationDelay, SetWebkitAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [Scroll_snap_points_x, SetScroll_snap_points_x,
                                 PropertyId::Longhand(LonghandId::ScrollSnapPointsX)],
                            [ScrollSnapPointsX, SetScrollSnapPointsX,
                             PropertyId::Longhand(LonghandId::ScrollSnapPointsX)],
                                [Scroll_snap_points_y, SetScroll_snap_points_y,
                                 PropertyId::Longhand(LonghandId::ScrollSnapPointsY)],
                            [ScrollSnapPointsY, SetScrollSnapPointsY,
                             PropertyId::Longhand(LonghandId::ScrollSnapPointsY)],
                                [Scroll_snap_destination, SetScroll_snap_destination,
                                 PropertyId::Longhand(LonghandId::ScrollSnapDestination)],
                            [ScrollSnapDestination, SetScrollSnapDestination,
                             PropertyId::Longhand(LonghandId::ScrollSnapDestination)],
                                [Scroll_snap_coordinate, SetScroll_snap_coordinate,
                                 PropertyId::Longhand(LonghandId::ScrollSnapCoordinate)],
                            [ScrollSnapCoordinate, SetScrollSnapCoordinate,
                             PropertyId::Longhand(LonghandId::ScrollSnapCoordinate)],
                            [Transform, SetTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [_webkit_transform, Set_webkit_transform,
                                 PropertyId::Longhand(LonghandId::Transform)],
                            [WebkitTransform, SetWebkitTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [Scroll_behavior, SetScroll_behavior,
                                 PropertyId::Longhand(LonghandId::ScrollBehavior)],
                            [ScrollBehavior, SetScrollBehavior,
                             PropertyId::Longhand(LonghandId::ScrollBehavior)],
                                [Scroll_snap_type_x, SetScroll_snap_type_x,
                                 PropertyId::Longhand(LonghandId::ScrollSnapTypeX)],
                            [ScrollSnapTypeX, SetScrollSnapTypeX,
                             PropertyId::Longhand(LonghandId::ScrollSnapTypeX)],
                                [Scroll_snap_type_y, SetScroll_snap_type_y,
                                 PropertyId::Longhand(LonghandId::ScrollSnapTypeY)],
                            [ScrollSnapTypeY, SetScrollSnapTypeY,
                             PropertyId::Longhand(LonghandId::ScrollSnapTypeY)],
                                [Overscroll_behavior_x, SetOverscroll_behavior_x,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                            [OverscrollBehaviorX, SetOverscrollBehaviorX,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                                [Overscroll_behavior_y, SetOverscroll_behavior_y,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                            [OverscrollBehaviorY, SetOverscrollBehaviorY,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                            [Isolation, SetIsolation,
                             PropertyId::Longhand(LonghandId::Isolation)],
                                [Page_break_after, SetPage_break_after,
                                 PropertyId::Longhand(LonghandId::PageBreakAfter)],
                            [PageBreakAfter, SetPageBreakAfter,
                             PropertyId::Longhand(LonghandId::PageBreakAfter)],
                                [Page_break_before, SetPage_break_before,
                                 PropertyId::Longhand(LonghandId::PageBreakBefore)],
                            [PageBreakBefore, SetPageBreakBefore,
                             PropertyId::Longhand(LonghandId::PageBreakBefore)],
                                [Page_break_inside, SetPage_break_inside,
                                 PropertyId::Longhand(LonghandId::PageBreakInside)],
                            [PageBreakInside, SetPageBreakInside,
                             PropertyId::Longhand(LonghandId::PageBreakInside)],
                            [Resize, SetResize,
                             PropertyId::Longhand(LonghandId::Resize)],
                            [Perspective, SetPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_moz_perspective, Set_moz_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [MozPerspective, SetMozPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_webkit_perspective, Set_webkit_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [WebkitPerspective, SetWebkitPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [Perspective_origin, SetPerspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [PerspectiveOrigin, SetPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_moz_perspective_origin, Set_moz_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [MozPerspectiveOrigin, SetMozPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_webkit_perspective_origin, Set_webkit_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [WebkitPerspectiveOrigin, SetWebkitPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [Backface_visibility, SetBackface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [BackfaceVisibility, SetBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_moz_backface_visibility, Set_moz_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [MozBackfaceVisibility, SetMozBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_webkit_backface_visibility, Set_webkit_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [WebkitBackfaceVisibility, SetWebkitBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [Transform_box, SetTransform_box,
                                 PropertyId::Longhand(LonghandId::TransformBox)],
                            [TransformBox, SetTransformBox,
                             PropertyId::Longhand(LonghandId::TransformBox)],
                                [Transform_style, SetTransform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [TransformStyle, SetTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_moz_transform_style, Set_moz_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [MozTransformStyle, SetMozTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_webkit_transform_style, Set_webkit_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [WebkitTransformStyle, SetWebkitTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [Transform_origin, SetTransform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [TransformOrigin, SetTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_moz_transform_origin, Set_moz_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [MozTransformOrigin, SetMozTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_webkit_transform_origin, Set_webkit_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [WebkitTransformOrigin, SetWebkitTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [Contain, SetContain,
                             PropertyId::Longhand(LonghandId::Contain)],
                                [_moz_appearance, Set_moz_appearance,
                                 PropertyId::Longhand(LonghandId::MozAppearance)],
                            [MozAppearance, SetMozAppearance,
                             PropertyId::Longhand(LonghandId::MozAppearance)],
                                [_moz_binding, Set_moz_binding,
                                 PropertyId::Longhand(LonghandId::MozBinding)],
                            [MozBinding, SetMozBinding,
                             PropertyId::Longhand(LonghandId::MozBinding)],
                                [_moz_orient, Set_moz_orient,
                                 PropertyId::Longhand(LonghandId::MozOrient)],
                            [MozOrient, SetMozOrient,
                             PropertyId::Longhand(LonghandId::MozOrient)],
                                [Will_change, SetWill_change,
                                 PropertyId::Longhand(LonghandId::WillChange)],
                            [WillChange, SetWillChange,
                             PropertyId::Longhand(LonghandId::WillChange)],
                                [Shape_image_threshold, SetShape_image_threshold,
                                 PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                            [ShapeImageThreshold, SetShapeImageThreshold,
                             PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                                [Shape_outside, SetShape_outside,
                                 PropertyId::Longhand(LonghandId::ShapeOutside)],
                            [ShapeOutside, SetShapeOutside,
                             PropertyId::Longhand(LonghandId::ShapeOutside)],
                                [Touch_action, SetTouch_action,
                                 PropertyId::Longhand(LonghandId::TouchAction)],
                            [TouchAction, SetTouchAction,
                             PropertyId::Longhand(LonghandId::TouchAction)],
                            [Color, SetColor,
                             PropertyId::Longhand(LonghandId::Color)],
                                [Column_width, SetColumn_width,
                                 PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [ColumnWidth, SetColumnWidth,
                             PropertyId::Longhand(LonghandId::ColumnWidth)],
                                [_moz_column_width, Set_moz_column_width,
                                 PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [MozColumnWidth, SetMozColumnWidth,
                             PropertyId::Longhand(LonghandId::ColumnWidth)],
                                [Column_count, SetColumn_count,
                                 PropertyId::Longhand(LonghandId::ColumnCount)],
                            [ColumnCount, SetColumnCount,
                             PropertyId::Longhand(LonghandId::ColumnCount)],
                                [_moz_column_count, Set_moz_column_count,
                                 PropertyId::Longhand(LonghandId::ColumnCount)],
                            [MozColumnCount, SetMozColumnCount,
                             PropertyId::Longhand(LonghandId::ColumnCount)],
                                [Column_gap, SetColumn_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [ColumnGap, SetColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [_moz_column_gap, Set_moz_column_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [MozColumnGap, SetMozColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [Column_fill, SetColumn_fill,
                                 PropertyId::Longhand(LonghandId::ColumnFill)],
                            [ColumnFill, SetColumnFill,
                             PropertyId::Longhand(LonghandId::ColumnFill)],
                                [_moz_column_fill, Set_moz_column_fill,
                                 PropertyId::Longhand(LonghandId::ColumnFill)],
                            [MozColumnFill, SetMozColumnFill,
                             PropertyId::Longhand(LonghandId::ColumnFill)],
                                [Column_rule_width, SetColumn_rule_width,
                                 PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                            [ColumnRuleWidth, SetColumnRuleWidth,
                             PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                                [_moz_column_rule_width, Set_moz_column_rule_width,
                                 PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                            [MozColumnRuleWidth, SetMozColumnRuleWidth,
                             PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                                [Column_rule_color, SetColumn_rule_color,
                                 PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                            [ColumnRuleColor, SetColumnRuleColor,
                             PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                                [_moz_column_rule_color, Set_moz_column_rule_color,
                                 PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                            [MozColumnRuleColor, SetMozColumnRuleColor,
                             PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                                [Column_span, SetColumn_span,
                                 PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [ColumnSpan, SetColumnSpan,
                             PropertyId::Longhand(LonghandId::ColumnSpan)],
                                [_moz_column_span, Set_moz_column_span,
                                 PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [MozColumnSpan, SetMozColumnSpan,
                             PropertyId::Longhand(LonghandId::ColumnSpan)],
                                [Column_rule_style, SetColumn_rule_style,
                                 PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [ColumnRuleStyle, SetColumnRuleStyle,
                             PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                                [_moz_column_rule_style, Set_moz_column_rule_style,
                                 PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [MozColumnRuleStyle, SetMozColumnRuleStyle,
                             PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [Content, SetContent,
                             PropertyId::Longhand(LonghandId::Content)],
                                [Counter_increment, SetCounter_increment,
                                 PropertyId::Longhand(LonghandId::CounterIncrement)],
                            [CounterIncrement, SetCounterIncrement,
                             PropertyId::Longhand(LonghandId::CounterIncrement)],
                                [Counter_reset, SetCounter_reset,
                                 PropertyId::Longhand(LonghandId::CounterReset)],
                            [CounterReset, SetCounterReset,
                             PropertyId::Longhand(LonghandId::CounterReset)],
                            [Opacity, SetOpacity,
                             PropertyId::Longhand(LonghandId::Opacity)],
                                [Box_shadow, SetBox_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [BoxShadow, SetBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                                [_webkit_box_shadow, Set_webkit_box_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [WebkitBoxShadow, SetWebkitBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                            [Clip, SetClip,
                             PropertyId::Longhand(LonghandId::Clip)],
                            [Filter, SetFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [_webkit_filter, Set_webkit_filter,
                                 PropertyId::Longhand(LonghandId::Filter)],
                            [WebkitFilter, SetWebkitFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [Mix_blend_mode, SetMix_blend_mode,
                                 PropertyId::Longhand(LonghandId::MixBlendMode)],
                            [MixBlendMode, SetMixBlendMode,
                             PropertyId::Longhand(LonghandId::MixBlendMode)],
                                [Font_family, SetFont_family,
                                 PropertyId::Longhand(LonghandId::FontFamily)],
                            [FontFamily, SetFontFamily,
                             PropertyId::Longhand(LonghandId::FontFamily)],
                                [Font_style, SetFont_style,
                                 PropertyId::Longhand(LonghandId::FontStyle)],
                            [FontStyle, SetFontStyle,
                             PropertyId::Longhand(LonghandId::FontStyle)],
                                [Font_variant_caps, SetFont_variant_caps,
                                 PropertyId::Longhand(LonghandId::FontVariantCaps)],
                            [FontVariantCaps, SetFontVariantCaps,
                             PropertyId::Longhand(LonghandId::FontVariantCaps)],
                                [Font_weight, SetFont_weight,
                                 PropertyId::Longhand(LonghandId::FontWeight)],
                            [FontWeight, SetFontWeight,
                             PropertyId::Longhand(LonghandId::FontWeight)],
                                [Font_size, SetFont_size,
                                 PropertyId::Longhand(LonghandId::FontSize)],
                            [FontSize, SetFontSize,
                             PropertyId::Longhand(LonghandId::FontSize)],
                                [Font_size_adjust, SetFont_size_adjust,
                                 PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                            [FontSizeAdjust, SetFontSizeAdjust,
                             PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                                [Font_synthesis, SetFont_synthesis,
                                 PropertyId::Longhand(LonghandId::FontSynthesis)],
                            [FontSynthesis, SetFontSynthesis,
                             PropertyId::Longhand(LonghandId::FontSynthesis)],
                                [Font_stretch, SetFont_stretch,
                                 PropertyId::Longhand(LonghandId::FontStretch)],
                            [FontStretch, SetFontStretch,
                             PropertyId::Longhand(LonghandId::FontStretch)],
                                [Font_kerning, SetFont_kerning,
                                 PropertyId::Longhand(LonghandId::FontKerning)],
                            [FontKerning, SetFontKerning,
                             PropertyId::Longhand(LonghandId::FontKerning)],
                                [Font_variant_alternates, SetFont_variant_alternates,
                                 PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                            [FontVariantAlternates, SetFontVariantAlternates,
                             PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                                [Font_variant_east_asian, SetFont_variant_east_asian,
                                 PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                            [FontVariantEastAsian, SetFontVariantEastAsian,
                             PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                                [Font_variant_ligatures, SetFont_variant_ligatures,
                                 PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                            [FontVariantLigatures, SetFontVariantLigatures,
                             PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                                [Font_variant_numeric, SetFont_variant_numeric,
                                 PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                            [FontVariantNumeric, SetFontVariantNumeric,
                             PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                                [Font_variant_position, SetFont_variant_position,
                                 PropertyId::Longhand(LonghandId::FontVariantPosition)],
                            [FontVariantPosition, SetFontVariantPosition,
                             PropertyId::Longhand(LonghandId::FontVariantPosition)],
                                [Font_feature_settings, SetFont_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [FontFeatureSettings, SetFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [_moz_font_feature_settings, Set_moz_font_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [MozFontFeatureSettings, SetMozFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [Font_variation_settings, SetFont_variation_settings,
                                 PropertyId::Longhand(LonghandId::FontVariationSettings)],
                            [FontVariationSettings, SetFontVariationSettings,
                             PropertyId::Longhand(LonghandId::FontVariationSettings)],
                                [Font_language_override, SetFont_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [FontLanguageOverride, SetFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [_moz_font_language_override, Set_moz_font_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [MozFontLanguageOverride, SetMozFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [_moz_osx_font_smoothing, Set_moz_osx_font_smoothing,
                                 PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                            [MozOsxFontSmoothing, SetMozOsxFontSmoothing,
                             PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                            [Visibility, SetVisibility,
                             PropertyId::Longhand(LonghandId::Visibility)],
                                [Writing_mode, SetWriting_mode,
                                 PropertyId::Longhand(LonghandId::WritingMode)],
                            [WritingMode, SetWritingMode,
                             PropertyId::Longhand(LonghandId::WritingMode)],
                            [Direction, SetDirection,
                             PropertyId::Longhand(LonghandId::Direction)],
                                [Text_orientation, SetText_orientation,
                                 PropertyId::Longhand(LonghandId::TextOrientation)],
                            [TextOrientation, SetTextOrientation,
                             PropertyId::Longhand(LonghandId::TextOrientation)],
                                [Color_adjust, SetColor_adjust,
                                 PropertyId::Longhand(LonghandId::ColorAdjust)],
                            [ColorAdjust, SetColorAdjust,
                             PropertyId::Longhand(LonghandId::ColorAdjust)],
                                [Image_rendering, SetImage_rendering,
                                 PropertyId::Longhand(LonghandId::ImageRendering)],
                            [ImageRendering, SetImageRendering,
                             PropertyId::Longhand(LonghandId::ImageRendering)],
                                [Image_orientation, SetImage_orientation,
                                 PropertyId::Longhand(LonghandId::ImageOrientation)],
                            [ImageOrientation, SetImageOrientation,
                             PropertyId::Longhand(LonghandId::ImageOrientation)],
                                [Border_collapse, SetBorder_collapse,
                                 PropertyId::Longhand(LonghandId::BorderCollapse)],
                            [BorderCollapse, SetBorderCollapse,
                             PropertyId::Longhand(LonghandId::BorderCollapse)],
                                [Empty_cells, SetEmpty_cells,
                                 PropertyId::Longhand(LonghandId::EmptyCells)],
                            [EmptyCells, SetEmptyCells,
                             PropertyId::Longhand(LonghandId::EmptyCells)],
                                [Caption_side, SetCaption_side,
                                 PropertyId::Longhand(LonghandId::CaptionSide)],
                            [CaptionSide, SetCaptionSide,
                             PropertyId::Longhand(LonghandId::CaptionSide)],
                                [Border_spacing, SetBorder_spacing,
                                 PropertyId::Longhand(LonghandId::BorderSpacing)],
                            [BorderSpacing, SetBorderSpacing,
                             PropertyId::Longhand(LonghandId::BorderSpacing)],
                                [Line_height, SetLine_height,
                                 PropertyId::Longhand(LonghandId::LineHeight)],
                            [LineHeight, SetLineHeight,
                             PropertyId::Longhand(LonghandId::LineHeight)],
                                [Text_transform, SetText_transform,
                                 PropertyId::Longhand(LonghandId::TextTransform)],
                            [TextTransform, SetTextTransform,
                             PropertyId::Longhand(LonghandId::TextTransform)],
                            [Hyphens, SetHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [_moz_hyphens, Set_moz_hyphens,
                                 PropertyId::Longhand(LonghandId::Hyphens)],
                            [MozHyphens, SetMozHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [_moz_text_size_adjust, Set_moz_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [MozTextSizeAdjust, SetMozTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [_webkit_text_size_adjust, Set_webkit_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [WebkitTextSizeAdjust, SetWebkitTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [Text_indent, SetText_indent,
                                 PropertyId::Longhand(LonghandId::TextIndent)],
                            [TextIndent, SetTextIndent,
                             PropertyId::Longhand(LonghandId::TextIndent)],
                                [Overflow_wrap, SetOverflow_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [OverflowWrap, SetOverflowWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Word_wrap, SetWord_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [WordWrap, SetWordWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Word_break, SetWord_break,
                                 PropertyId::Longhand(LonghandId::WordBreak)],
                            [WordBreak, SetWordBreak,
                             PropertyId::Longhand(LonghandId::WordBreak)],
                                [Text_justify, SetText_justify,
                                 PropertyId::Longhand(LonghandId::TextJustify)],
                            [TextJustify, SetTextJustify,
                             PropertyId::Longhand(LonghandId::TextJustify)],
                                [Text_align_last, SetText_align_last,
                                 PropertyId::Longhand(LonghandId::TextAlignLast)],
                            [TextAlignLast, SetTextAlignLast,
                             PropertyId::Longhand(LonghandId::TextAlignLast)],
                                [Text_align, SetText_align,
                                 PropertyId::Longhand(LonghandId::TextAlign)],
                            [TextAlign, SetTextAlign,
                             PropertyId::Longhand(LonghandId::TextAlign)],
                                [Letter_spacing, SetLetter_spacing,
                                 PropertyId::Longhand(LonghandId::LetterSpacing)],
                            [LetterSpacing, SetLetterSpacing,
                             PropertyId::Longhand(LonghandId::LetterSpacing)],
                                [Word_spacing, SetWord_spacing,
                                 PropertyId::Longhand(LonghandId::WordSpacing)],
                            [WordSpacing, SetWordSpacing,
                             PropertyId::Longhand(LonghandId::WordSpacing)],
                                [White_space, SetWhite_space,
                                 PropertyId::Longhand(LonghandId::WhiteSpace)],
                            [WhiteSpace, SetWhiteSpace,
                             PropertyId::Longhand(LonghandId::WhiteSpace)],
                                [Text_shadow, SetText_shadow,
                                 PropertyId::Longhand(LonghandId::TextShadow)],
                            [TextShadow, SetTextShadow,
                             PropertyId::Longhand(LonghandId::TextShadow)],
                                [Text_emphasis_style, SetText_emphasis_style,
                                 PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                            [TextEmphasisStyle, SetTextEmphasisStyle,
                             PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                                [Text_emphasis_position, SetText_emphasis_position,
                                 PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                            [TextEmphasisPosition, SetTextEmphasisPosition,
                             PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                                [Text_emphasis_color, SetText_emphasis_color,
                                 PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                            [TextEmphasisColor, SetTextEmphasisColor,
                             PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                                [_moz_tab_size, Set_moz_tab_size,
                                 PropertyId::Longhand(LonghandId::MozTabSize)],
                            [MozTabSize, SetMozTabSize,
                             PropertyId::Longhand(LonghandId::MozTabSize)],
                                [_webkit_text_fill_color, Set_webkit_text_fill_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                            [WebkitTextFillColor, SetWebkitTextFillColor,
                             PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                                [_webkit_text_stroke_color, Set_webkit_text_stroke_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                            [WebkitTextStrokeColor, SetWebkitTextStrokeColor,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                                [_webkit_text_stroke_width, Set_webkit_text_stroke_width,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                            [WebkitTextStrokeWidth, SetWebkitTextStrokeWidth,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                                [Ruby_align, SetRuby_align,
                                 PropertyId::Longhand(LonghandId::RubyAlign)],
                            [RubyAlign, SetRubyAlign,
                             PropertyId::Longhand(LonghandId::RubyAlign)],
                                [Ruby_position, SetRuby_position,
                                 PropertyId::Longhand(LonghandId::RubyPosition)],
                            [RubyPosition, SetRubyPosition,
                             PropertyId::Longhand(LonghandId::RubyPosition)],
                                [Text_combine_upright, SetText_combine_upright,
                                 PropertyId::Longhand(LonghandId::TextCombineUpright)],
                            [TextCombineUpright, SetTextCombineUpright,
                             PropertyId::Longhand(LonghandId::TextCombineUpright)],
                                [Text_rendering, SetText_rendering,
                                 PropertyId::Longhand(LonghandId::TextRendering)],
                            [TextRendering, SetTextRendering,
                             PropertyId::Longhand(LonghandId::TextRendering)],
                                [_moz_control_character_visibility, Set_moz_control_character_visibility,
                                 PropertyId::Longhand(LonghandId::MozControlCharacterVisibility)],
                            [MozControlCharacterVisibility, SetMozControlCharacterVisibility,
                             PropertyId::Longhand(LonghandId::MozControlCharacterVisibility)],
                                [List_style_position, SetList_style_position,
                                 PropertyId::Longhand(LonghandId::ListStylePosition)],
                            [ListStylePosition, SetListStylePosition,
                             PropertyId::Longhand(LonghandId::ListStylePosition)],
                                [List_style_type, SetList_style_type,
                                 PropertyId::Longhand(LonghandId::ListStyleType)],
                            [ListStyleType, SetListStyleType,
                             PropertyId::Longhand(LonghandId::ListStyleType)],
                                [List_style_image, SetList_style_image,
                                 PropertyId::Longhand(LonghandId::ListStyleImage)],
                            [ListStyleImage, SetListStyleImage,
                             PropertyId::Longhand(LonghandId::ListStyleImage)],
                            [Quotes, SetQuotes,
                             PropertyId::Longhand(LonghandId::Quotes)],
                                [_moz_image_region, Set_moz_image_region,
                                 PropertyId::Longhand(LonghandId::MozImageRegion)],
                            [MozImageRegion, SetMozImageRegion,
                             PropertyId::Longhand(LonghandId::MozImageRegion)],
                                [Margin_top, SetMargin_top,
                                 PropertyId::Longhand(LonghandId::MarginTop)],
                            [MarginTop, SetMarginTop,
                             PropertyId::Longhand(LonghandId::MarginTop)],
                                [Margin_left, SetMargin_left,
                                 PropertyId::Longhand(LonghandId::MarginLeft)],
                            [MarginLeft, SetMarginLeft,
                             PropertyId::Longhand(LonghandId::MarginLeft)],
                                [Margin_bottom, SetMargin_bottom,
                                 PropertyId::Longhand(LonghandId::MarginBottom)],
                            [MarginBottom, SetMarginBottom,
                             PropertyId::Longhand(LonghandId::MarginBottom)],
                                [Margin_right, SetMargin_right,
                                 PropertyId::Longhand(LonghandId::MarginRight)],
                            [MarginRight, SetMarginRight,
                             PropertyId::Longhand(LonghandId::MarginRight)],
                                [Margin_block_start, SetMargin_block_start,
                                 PropertyId::Longhand(LonghandId::MarginBlockStart)],
                            [MarginBlockStart, SetMarginBlockStart,
                             PropertyId::Longhand(LonghandId::MarginBlockStart)],
                                [Margin_block_end, SetMargin_block_end,
                                 PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                            [MarginBlockEnd, SetMarginBlockEnd,
                             PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                                [Margin_inline_start, SetMargin_inline_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MarginInlineStart, SetMarginInlineStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [_moz_margin_start, Set_moz_margin_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MozMarginStart, SetMozMarginStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [Margin_inline_end, SetMargin_inline_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MarginInlineEnd, SetMarginInlineEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [_moz_margin_end, Set_moz_margin_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MozMarginEnd, SetMozMarginEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [Outline_color, SetOutline_color,
                                 PropertyId::Longhand(LonghandId::OutlineColor)],
                            [OutlineColor, SetOutlineColor,
                             PropertyId::Longhand(LonghandId::OutlineColor)],
                                [Outline_style, SetOutline_style,
                                 PropertyId::Longhand(LonghandId::OutlineStyle)],
                            [OutlineStyle, SetOutlineStyle,
                             PropertyId::Longhand(LonghandId::OutlineStyle)],
                                [Outline_width, SetOutline_width,
                                 PropertyId::Longhand(LonghandId::OutlineWidth)],
                            [OutlineWidth, SetOutlineWidth,
                             PropertyId::Longhand(LonghandId::OutlineWidth)],
                                [_moz_outline_radius_topleft, Set_moz_outline_radius_topleft,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft)],
                            [MozOutlineRadiusTopleft, SetMozOutlineRadiusTopleft,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusTopleft)],
                                [_moz_outline_radius_topright, Set_moz_outline_radius_topright,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright)],
                            [MozOutlineRadiusTopright, SetMozOutlineRadiusTopright,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusTopright)],
                                [_moz_outline_radius_bottomright, Set_moz_outline_radius_bottomright,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright)],
                            [MozOutlineRadiusBottomright, SetMozOutlineRadiusBottomright,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomright)],
                                [_moz_outline_radius_bottomleft, Set_moz_outline_radius_bottomleft,
                                 PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft)],
                            [MozOutlineRadiusBottomleft, SetMozOutlineRadiusBottomleft,
                             PropertyId::Longhand(LonghandId::MozOutlineRadiusBottomleft)],
                                [Outline_offset, SetOutline_offset,
                                 PropertyId::Longhand(LonghandId::OutlineOffset)],
                            [OutlineOffset, SetOutlineOffset,
                             PropertyId::Longhand(LonghandId::OutlineOffset)],
                                [Padding_top, SetPadding_top,
                                 PropertyId::Longhand(LonghandId::PaddingTop)],
                            [PaddingTop, SetPaddingTop,
                             PropertyId::Longhand(LonghandId::PaddingTop)],
                                [Padding_left, SetPadding_left,
                                 PropertyId::Longhand(LonghandId::PaddingLeft)],
                            [PaddingLeft, SetPaddingLeft,
                             PropertyId::Longhand(LonghandId::PaddingLeft)],
                                [Padding_bottom, SetPadding_bottom,
                                 PropertyId::Longhand(LonghandId::PaddingBottom)],
                            [PaddingBottom, SetPaddingBottom,
                             PropertyId::Longhand(LonghandId::PaddingBottom)],
                                [Padding_right, SetPadding_right,
                                 PropertyId::Longhand(LonghandId::PaddingRight)],
                            [PaddingRight, SetPaddingRight,
                             PropertyId::Longhand(LonghandId::PaddingRight)],
                                [Padding_block_start, SetPadding_block_start,
                                 PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                            [PaddingBlockStart, SetPaddingBlockStart,
                             PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                                [Padding_block_end, SetPadding_block_end,
                                 PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                            [PaddingBlockEnd, SetPaddingBlockEnd,
                             PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                                [Padding_inline_start, SetPadding_inline_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [PaddingInlineStart, SetPaddingInlineStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [_moz_padding_start, Set_moz_padding_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [MozPaddingStart, SetMozPaddingStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [Padding_inline_end, SetPadding_inline_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [PaddingInlineEnd, SetPaddingInlineEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                                [_moz_padding_end, Set_moz_padding_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [MozPaddingEnd, SetMozPaddingEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [Cursor, SetCursor,
                             PropertyId::Longhand(LonghandId::Cursor)],
                                [Pointer_events, SetPointer_events,
                                 PropertyId::Longhand(LonghandId::PointerEvents)],
                            [PointerEvents, SetPointerEvents,
                             PropertyId::Longhand(LonghandId::PointerEvents)],
                                [_moz_user_input, Set_moz_user_input,
                                 PropertyId::Longhand(LonghandId::MozUserInput)],
                            [MozUserInput, SetMozUserInput,
                             PropertyId::Longhand(LonghandId::MozUserInput)],
                                [_moz_user_modify, Set_moz_user_modify,
                                 PropertyId::Longhand(LonghandId::MozUserModify)],
                            [MozUserModify, SetMozUserModify,
                             PropertyId::Longhand(LonghandId::MozUserModify)],
                                [_moz_user_focus, Set_moz_user_focus,
                                 PropertyId::Longhand(LonghandId::MozUserFocus)],
                            [MozUserFocus, SetMozUserFocus,
                             PropertyId::Longhand(LonghandId::MozUserFocus)],
                                [Caret_color, SetCaret_color,
                                 PropertyId::Longhand(LonghandId::CaretColor)],
                            [CaretColor, SetCaretColor,
                             PropertyId::Longhand(LonghandId::CaretColor)],
                            [Top, SetTop,
                             PropertyId::Longhand(LonghandId::Top)],
                            [Left, SetLeft,
                             PropertyId::Longhand(LonghandId::Left)],
                            [Bottom, SetBottom,
                             PropertyId::Longhand(LonghandId::Bottom)],
                            [Right, SetRight,
                             PropertyId::Longhand(LonghandId::Right)],
                                [Offset_block_start, SetOffset_block_start,
                                 PropertyId::Longhand(LonghandId::OffsetBlockStart)],
                            [OffsetBlockStart, SetOffsetBlockStart,
                             PropertyId::Longhand(LonghandId::OffsetBlockStart)],
                                [Offset_block_end, SetOffset_block_end,
                                 PropertyId::Longhand(LonghandId::OffsetBlockEnd)],
                            [OffsetBlockEnd, SetOffsetBlockEnd,
                             PropertyId::Longhand(LonghandId::OffsetBlockEnd)],
                                [Offset_inline_start, SetOffset_inline_start,
                                 PropertyId::Longhand(LonghandId::OffsetInlineStart)],
                            [OffsetInlineStart, SetOffsetInlineStart,
                             PropertyId::Longhand(LonghandId::OffsetInlineStart)],
                                [Offset_inline_end, SetOffset_inline_end,
                                 PropertyId::Longhand(LonghandId::OffsetInlineEnd)],
                            [OffsetInlineEnd, SetOffsetInlineEnd,
                             PropertyId::Longhand(LonghandId::OffsetInlineEnd)],
                                [Z_index, SetZ_index,
                                 PropertyId::Longhand(LonghandId::ZIndex)],
                            [ZIndex, SetZIndex,
                             PropertyId::Longhand(LonghandId::ZIndex)],
                                [Flex_direction, SetFlex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [FlexDirection, SetFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [_webkit_flex_direction, Set_webkit_flex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [WebkitFlexDirection, SetWebkitFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [Flex_wrap, SetFlex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [FlexWrap, SetFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                                [_webkit_flex_wrap, Set_webkit_flex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [WebkitFlexWrap, SetWebkitFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                                [Justify_content, SetJustify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [JustifyContent, SetJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [_webkit_justify_content, Set_webkit_justify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [WebkitJustifyContent, SetWebkitJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [Align_content, SetAlign_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [AlignContent, SetAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [_webkit_align_content, Set_webkit_align_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [WebkitAlignContent, SetWebkitAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [Align_items, SetAlign_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [AlignItems, SetAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [_webkit_align_items, Set_webkit_align_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [WebkitAlignItems, SetWebkitAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [Justify_items, SetJustify_items,
                                 PropertyId::Longhand(LonghandId::JustifyItems)],
                            [JustifyItems, SetJustifyItems,
                             PropertyId::Longhand(LonghandId::JustifyItems)],
                                [Flex_grow, SetFlex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [FlexGrow, SetFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [_webkit_flex_grow, Set_webkit_flex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [WebkitFlexGrow, SetWebkitFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [Flex_shrink, SetFlex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [FlexShrink, SetFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [_webkit_flex_shrink, Set_webkit_flex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [WebkitFlexShrink, SetWebkitFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [Align_self, SetAlign_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [AlignSelf, SetAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [_webkit_align_self, Set_webkit_align_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [WebkitAlignSelf, SetWebkitAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [Justify_self, SetJustify_self,
                                 PropertyId::Longhand(LonghandId::JustifySelf)],
                            [JustifySelf, SetJustifySelf,
                             PropertyId::Longhand(LonghandId::JustifySelf)],
                            [Order, SetOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [_webkit_order, Set_webkit_order,
                                 PropertyId::Longhand(LonghandId::Order)],
                            [WebkitOrder, SetWebkitOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [Flex_basis, SetFlex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [FlexBasis, SetFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                                [_webkit_flex_basis, Set_webkit_flex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [WebkitFlexBasis, SetWebkitFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                            [Width, SetWidth,
                             PropertyId::Longhand(LonghandId::Width)],
                                [Min_width, SetMin_width,
                                 PropertyId::Longhand(LonghandId::MinWidth)],
                            [MinWidth, SetMinWidth,
                             PropertyId::Longhand(LonghandId::MinWidth)],
                                [Max_width, SetMax_width,
                                 PropertyId::Longhand(LonghandId::MaxWidth)],
                            [MaxWidth, SetMaxWidth,
                             PropertyId::Longhand(LonghandId::MaxWidth)],
                            [Height, SetHeight,
                             PropertyId::Longhand(LonghandId::Height)],
                                [Min_height, SetMin_height,
                                 PropertyId::Longhand(LonghandId::MinHeight)],
                            [MinHeight, SetMinHeight,
                             PropertyId::Longhand(LonghandId::MinHeight)],
                                [Max_height, SetMax_height,
                                 PropertyId::Longhand(LonghandId::MaxHeight)],
                            [MaxHeight, SetMaxHeight,
                             PropertyId::Longhand(LonghandId::MaxHeight)],
                                [Block_size, SetBlock_size,
                                 PropertyId::Longhand(LonghandId::BlockSize)],
                            [BlockSize, SetBlockSize,
                             PropertyId::Longhand(LonghandId::BlockSize)],
                                [Min_block_size, SetMin_block_size,
                                 PropertyId::Longhand(LonghandId::MinBlockSize)],
                            [MinBlockSize, SetMinBlockSize,
                             PropertyId::Longhand(LonghandId::MinBlockSize)],
                                [Max_block_size, SetMax_block_size,
                                 PropertyId::Longhand(LonghandId::MaxBlockSize)],
                            [MaxBlockSize, SetMaxBlockSize,
                             PropertyId::Longhand(LonghandId::MaxBlockSize)],
                                [Inline_size, SetInline_size,
                                 PropertyId::Longhand(LonghandId::InlineSize)],
                            [InlineSize, SetInlineSize,
                             PropertyId::Longhand(LonghandId::InlineSize)],
                                [Min_inline_size, SetMin_inline_size,
                                 PropertyId::Longhand(LonghandId::MinInlineSize)],
                            [MinInlineSize, SetMinInlineSize,
                             PropertyId::Longhand(LonghandId::MinInlineSize)],
                                [Max_inline_size, SetMax_inline_size,
                                 PropertyId::Longhand(LonghandId::MaxInlineSize)],
                            [MaxInlineSize, SetMaxInlineSize,
                             PropertyId::Longhand(LonghandId::MaxInlineSize)],
                                [Box_sizing, SetBox_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [BoxSizing, SetBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_moz_box_sizing, Set_moz_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [MozBoxSizing, SetMozBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_webkit_box_sizing, Set_webkit_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [WebkitBoxSizing, SetWebkitBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [Object_fit, SetObject_fit,
                                 PropertyId::Longhand(LonghandId::ObjectFit)],
                            [ObjectFit, SetObjectFit,
                             PropertyId::Longhand(LonghandId::ObjectFit)],
                                [Object_position, SetObject_position,
                                 PropertyId::Longhand(LonghandId::ObjectPosition)],
                            [ObjectPosition, SetObjectPosition,
                             PropertyId::Longhand(LonghandId::ObjectPosition)],
                                [Grid_row_gap, SetGrid_row_gap,
                                 PropertyId::Longhand(LonghandId::GridRowGap)],
                            [GridRowGap, SetGridRowGap,
                             PropertyId::Longhand(LonghandId::GridRowGap)],
                                [Grid_row_start, SetGrid_row_start,
                                 PropertyId::Longhand(LonghandId::GridRowStart)],
                            [GridRowStart, SetGridRowStart,
                             PropertyId::Longhand(LonghandId::GridRowStart)],
                                [Grid_row_end, SetGrid_row_end,
                                 PropertyId::Longhand(LonghandId::GridRowEnd)],
                            [GridRowEnd, SetGridRowEnd,
                             PropertyId::Longhand(LonghandId::GridRowEnd)],
                                [Grid_auto_rows, SetGrid_auto_rows,
                                 PropertyId::Longhand(LonghandId::GridAutoRows)],
                            [GridAutoRows, SetGridAutoRows,
                             PropertyId::Longhand(LonghandId::GridAutoRows)],
                                [Grid_template_rows, SetGrid_template_rows,
                                 PropertyId::Longhand(LonghandId::GridTemplateRows)],
                            [GridTemplateRows, SetGridTemplateRows,
                             PropertyId::Longhand(LonghandId::GridTemplateRows)],
                                [Grid_column_gap, SetGrid_column_gap,
                                 PropertyId::Longhand(LonghandId::GridColumnGap)],
                            [GridColumnGap, SetGridColumnGap,
                             PropertyId::Longhand(LonghandId::GridColumnGap)],
                                [Grid_column_start, SetGrid_column_start,
                                 PropertyId::Longhand(LonghandId::GridColumnStart)],
                            [GridColumnStart, SetGridColumnStart,
                             PropertyId::Longhand(LonghandId::GridColumnStart)],
                                [Grid_column_end, SetGrid_column_end,
                                 PropertyId::Longhand(LonghandId::GridColumnEnd)],
                            [GridColumnEnd, SetGridColumnEnd,
                             PropertyId::Longhand(LonghandId::GridColumnEnd)],
                                [Grid_auto_columns, SetGrid_auto_columns,
                                 PropertyId::Longhand(LonghandId::GridAutoColumns)],
                            [GridAutoColumns, SetGridAutoColumns,
                             PropertyId::Longhand(LonghandId::GridAutoColumns)],
                                [Grid_template_columns, SetGrid_template_columns,
                                 PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                            [GridTemplateColumns, SetGridTemplateColumns,
                             PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                                [Grid_auto_flow, SetGrid_auto_flow,
                                 PropertyId::Longhand(LonghandId::GridAutoFlow)],
                            [GridAutoFlow, SetGridAutoFlow,
                             PropertyId::Longhand(LonghandId::GridAutoFlow)],
                                [Grid_template_areas, SetGrid_template_areas,
                                 PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                            [GridTemplateAreas, SetGridTemplateAreas,
                             PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                                [Table_layout, SetTable_layout,
                                 PropertyId::Longhand(LonghandId::TableLayout)],
                            [TableLayout, SetTableLayout,
                             PropertyId::Longhand(LonghandId::TableLayout)],
                                [Text_overflow, SetText_overflow,
                                 PropertyId::Longhand(LonghandId::TextOverflow)],
                            [TextOverflow, SetTextOverflow,
                             PropertyId::Longhand(LonghandId::TextOverflow)],
                                [Unicode_bidi, SetUnicode_bidi,
                                 PropertyId::Longhand(LonghandId::UnicodeBidi)],
                            [UnicodeBidi, SetUnicodeBidi,
                             PropertyId::Longhand(LonghandId::UnicodeBidi)],
                                [Text_decoration_line, SetText_decoration_line,
                                 PropertyId::Longhand(LonghandId::TextDecorationLine)],
                            [TextDecorationLine, SetTextDecorationLine,
                             PropertyId::Longhand(LonghandId::TextDecorationLine)],
                                [Text_decoration_style, SetText_decoration_style,
                                 PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                            [TextDecorationStyle, SetTextDecorationStyle,
                             PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                                [Text_decoration_color, SetText_decoration_color,
                                 PropertyId::Longhand(LonghandId::TextDecorationColor)],
                            [TextDecorationColor, SetTextDecorationColor,
                             PropertyId::Longhand(LonghandId::TextDecorationColor)],
                                [Initial_letter, SetInitial_letter,
                                 PropertyId::Longhand(LonghandId::InitialLetter)],
                            [InitialLetter, SetInitialLetter,
                             PropertyId::Longhand(LonghandId::InitialLetter)],
                                [Ime_mode, SetIme_mode,
                                 PropertyId::Longhand(LonghandId::ImeMode)],
                            [ImeMode, SetImeMode,
                             PropertyId::Longhand(LonghandId::ImeMode)],
                                [_moz_user_select, Set_moz_user_select,
                                 PropertyId::Longhand(LonghandId::MozUserSelect)],
                            [MozUserSelect, SetMozUserSelect,
                             PropertyId::Longhand(LonghandId::MozUserSelect)],
                                [_webkit_user_select, Set_webkit_user_select,
                                 PropertyId::Longhand(LonghandId::MozUserSelect)],
                            [WebkitUserSelect, SetWebkitUserSelect,
                             PropertyId::Longhand(LonghandId::MozUserSelect)],
                                [_moz_window_dragging, Set_moz_window_dragging,
                                 PropertyId::Longhand(LonghandId::MozWindowDragging)],
                            [MozWindowDragging, SetMozWindowDragging,
                             PropertyId::Longhand(LonghandId::MozWindowDragging)],
                                [_moz_force_broken_image_icon, Set_moz_force_broken_image_icon,
                                 PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                            [MozForceBrokenImageIcon, SetMozForceBrokenImageIcon,
                             PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                                [Text_anchor, SetText_anchor,
                                 PropertyId::Longhand(LonghandId::TextAnchor)],
                            [TextAnchor, SetTextAnchor,
                             PropertyId::Longhand(LonghandId::TextAnchor)],
                                [Color_interpolation, SetColor_interpolation,
                                 PropertyId::Longhand(LonghandId::ColorInterpolation)],
                            [ColorInterpolation, SetColorInterpolation,
                             PropertyId::Longhand(LonghandId::ColorInterpolation)],
                                [Color_interpolation_filters, SetColor_interpolation_filters,
                                 PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                            [ColorInterpolationFilters, SetColorInterpolationFilters,
                             PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                            [Fill, SetFill,
                             PropertyId::Longhand(LonghandId::Fill)],
                                [Fill_opacity, SetFill_opacity,
                                 PropertyId::Longhand(LonghandId::FillOpacity)],
                            [FillOpacity, SetFillOpacity,
                             PropertyId::Longhand(LonghandId::FillOpacity)],
                                [Fill_rule, SetFill_rule,
                                 PropertyId::Longhand(LonghandId::FillRule)],
                            [FillRule, SetFillRule,
                             PropertyId::Longhand(LonghandId::FillRule)],
                                [Shape_rendering, SetShape_rendering,
                                 PropertyId::Longhand(LonghandId::ShapeRendering)],
                            [ShapeRendering, SetShapeRendering,
                             PropertyId::Longhand(LonghandId::ShapeRendering)],
                            [Stroke, SetStroke,
                             PropertyId::Longhand(LonghandId::Stroke)],
                                [Stroke_width, SetStroke_width,
                                 PropertyId::Longhand(LonghandId::StrokeWidth)],
                            [StrokeWidth, SetStrokeWidth,
                             PropertyId::Longhand(LonghandId::StrokeWidth)],
                                [Stroke_linecap, SetStroke_linecap,
                                 PropertyId::Longhand(LonghandId::StrokeLinecap)],
                            [StrokeLinecap, SetStrokeLinecap,
                             PropertyId::Longhand(LonghandId::StrokeLinecap)],
                                [Stroke_linejoin, SetStroke_linejoin,
                                 PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                            [StrokeLinejoin, SetStrokeLinejoin,
                             PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                                [Stroke_miterlimit, SetStroke_miterlimit,
                                 PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                            [StrokeMiterlimit, SetStrokeMiterlimit,
                             PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                                [Stroke_opacity, SetStroke_opacity,
                                 PropertyId::Longhand(LonghandId::StrokeOpacity)],
                            [StrokeOpacity, SetStrokeOpacity,
                             PropertyId::Longhand(LonghandId::StrokeOpacity)],
                                [Stroke_dasharray, SetStroke_dasharray,
                                 PropertyId::Longhand(LonghandId::StrokeDasharray)],
                            [StrokeDasharray, SetStrokeDasharray,
                             PropertyId::Longhand(LonghandId::StrokeDasharray)],
                                [Stroke_dashoffset, SetStroke_dashoffset,
                                 PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                            [StrokeDashoffset, SetStrokeDashoffset,
                             PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                                [Clip_rule, SetClip_rule,
                                 PropertyId::Longhand(LonghandId::ClipRule)],
                            [ClipRule, SetClipRule,
                             PropertyId::Longhand(LonghandId::ClipRule)],
                                [Marker_start, SetMarker_start,
                                 PropertyId::Longhand(LonghandId::MarkerStart)],
                            [MarkerStart, SetMarkerStart,
                             PropertyId::Longhand(LonghandId::MarkerStart)],
                                [Marker_mid, SetMarker_mid,
                                 PropertyId::Longhand(LonghandId::MarkerMid)],
                            [MarkerMid, SetMarkerMid,
                             PropertyId::Longhand(LonghandId::MarkerMid)],
                                [Marker_end, SetMarker_end,
                                 PropertyId::Longhand(LonghandId::MarkerEnd)],
                            [MarkerEnd, SetMarkerEnd,
                             PropertyId::Longhand(LonghandId::MarkerEnd)],
                                [Paint_order, SetPaint_order,
                                 PropertyId::Longhand(LonghandId::PaintOrder)],
                            [PaintOrder, SetPaintOrder,
                             PropertyId::Longhand(LonghandId::PaintOrder)],
                                [_moz_context_properties, Set_moz_context_properties,
                                 PropertyId::Longhand(LonghandId::MozContextProperties)],
                            [MozContextProperties, SetMozContextProperties,
                             PropertyId::Longhand(LonghandId::MozContextProperties)],
                                [Dominant_baseline, SetDominant_baseline,
                                 PropertyId::Longhand(LonghandId::DominantBaseline)],
                            [DominantBaseline, SetDominantBaseline,
                             PropertyId::Longhand(LonghandId::DominantBaseline)],
                                [Vector_effect, SetVector_effect,
                                 PropertyId::Longhand(LonghandId::VectorEffect)],
                            [VectorEffect, SetVectorEffect,
                             PropertyId::Longhand(LonghandId::VectorEffect)],
                                [Stop_color, SetStop_color,
                                 PropertyId::Longhand(LonghandId::StopColor)],
                            [StopColor, SetStopColor,
                             PropertyId::Longhand(LonghandId::StopColor)],
                                [Stop_opacity, SetStop_opacity,
                                 PropertyId::Longhand(LonghandId::StopOpacity)],
                            [StopOpacity, SetStopOpacity,
                             PropertyId::Longhand(LonghandId::StopOpacity)],
                                [Flood_color, SetFlood_color,
                                 PropertyId::Longhand(LonghandId::FloodColor)],
                            [FloodColor, SetFloodColor,
                             PropertyId::Longhand(LonghandId::FloodColor)],
                                [Flood_opacity, SetFlood_opacity,
                                 PropertyId::Longhand(LonghandId::FloodOpacity)],
                            [FloodOpacity, SetFloodOpacity,
                             PropertyId::Longhand(LonghandId::FloodOpacity)],
                                [Lighting_color, SetLighting_color,
                                 PropertyId::Longhand(LonghandId::LightingColor)],
                            [LightingColor, SetLightingColor,
                             PropertyId::Longhand(LonghandId::LightingColor)],
                                [Mask_type, SetMask_type,
                                 PropertyId::Longhand(LonghandId::MaskType)],
                            [MaskType, SetMaskType,
                             PropertyId::Longhand(LonghandId::MaskType)],
                                [Clip_path, SetClip_path,
                                 PropertyId::Longhand(LonghandId::ClipPath)],
                            [ClipPath, SetClipPath,
                             PropertyId::Longhand(LonghandId::ClipPath)],
                                [Mask_mode, SetMask_mode,
                                 PropertyId::Longhand(LonghandId::MaskMode)],
                            [MaskMode, SetMaskMode,
                             PropertyId::Longhand(LonghandId::MaskMode)],
                                [Mask_repeat, SetMask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [MaskRepeat, SetMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [_webkit_mask_repeat, Set_webkit_mask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [WebkitMaskRepeat, SetWebkitMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [Mask_position_x, SetMask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [MaskPositionX, SetMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [_webkit_mask_position_x, Set_webkit_mask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [WebkitMaskPositionX, SetWebkitMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [Mask_position_y, SetMask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [MaskPositionY, SetMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [_webkit_mask_position_y, Set_webkit_mask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [WebkitMaskPositionY, SetWebkitMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [Mask_clip, SetMask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [MaskClip, SetMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [_webkit_mask_clip, Set_webkit_mask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [WebkitMaskClip, SetWebkitMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [Mask_origin, SetMask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [MaskOrigin, SetMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [_webkit_mask_origin, Set_webkit_mask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [WebkitMaskOrigin, SetWebkitMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [Mask_size, SetMask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [MaskSize, SetMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [_webkit_mask_size, Set_webkit_mask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [WebkitMaskSize, SetWebkitMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [Mask_composite, SetMask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [MaskComposite, SetMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [_webkit_mask_composite, Set_webkit_mask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [WebkitMaskComposite, SetWebkitMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [Mask_image, SetMask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [MaskImage, SetMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [_webkit_mask_image, Set_webkit_mask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [WebkitMaskImage, SetWebkitMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [_moz_box_align, Set_moz_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [MozBoxAlign, SetMozBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_webkit_box_align, Set_webkit_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [WebkitBoxAlign, SetWebkitBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_moz_box_direction, Set_moz_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [MozBoxDirection, SetMozBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_webkit_box_direction, Set_webkit_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [WebkitBoxDirection, SetWebkitBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_moz_box_flex, Set_moz_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [MozBoxFlex, SetMozBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [_webkit_box_flex, Set_webkit_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [WebkitBoxFlex, SetWebkitBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [_moz_box_orient, Set_moz_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [MozBoxOrient, SetMozBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_webkit_box_orient, Set_webkit_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [WebkitBoxOrient, SetWebkitBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_moz_box_pack, Set_moz_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [MozBoxPack, SetMozBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_webkit_box_pack, Set_webkit_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [WebkitBoxPack, SetWebkitBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_moz_stack_sizing, Set_moz_stack_sizing,
                                 PropertyId::Longhand(LonghandId::MozStackSizing)],
                            [MozStackSizing, SetMozStackSizing,
                             PropertyId::Longhand(LonghandId::MozStackSizing)],
                                [_moz_box_ordinal_group, Set_moz_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [MozBoxOrdinalGroup, SetMozBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                                [_webkit_box_ordinal_group, Set_webkit_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [WebkitBoxOrdinalGroup, SetWebkitBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [Background, SetBackground,
                             PropertyId::Shorthand(ShorthandId::Background)],
                                [Background_position, SetBackground_position,
                                 PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                            [BackgroundPosition, SetBackgroundPosition,
                             PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                                [Border_color, SetBorder_color,
                                 PropertyId::Shorthand(ShorthandId::BorderColor)],
                            [BorderColor, SetBorderColor,
                             PropertyId::Shorthand(ShorthandId::BorderColor)],
                                [Border_style, SetBorder_style,
                                 PropertyId::Shorthand(ShorthandId::BorderStyle)],
                            [BorderStyle, SetBorderStyle,
                             PropertyId::Shorthand(ShorthandId::BorderStyle)],
                                [Border_width, SetBorder_width,
                                 PropertyId::Shorthand(ShorthandId::BorderWidth)],
                            [BorderWidth, SetBorderWidth,
                             PropertyId::Shorthand(ShorthandId::BorderWidth)],
                                [Border_top, SetBorder_top,
                                 PropertyId::Shorthand(ShorthandId::BorderTop)],
                            [BorderTop, SetBorderTop,
                             PropertyId::Shorthand(ShorthandId::BorderTop)],
                                [Border_left, SetBorder_left,
                                 PropertyId::Shorthand(ShorthandId::BorderLeft)],
                            [BorderLeft, SetBorderLeft,
                             PropertyId::Shorthand(ShorthandId::BorderLeft)],
                                [Border_bottom, SetBorder_bottom,
                                 PropertyId::Shorthand(ShorthandId::BorderBottom)],
                            [BorderBottom, SetBorderBottom,
                             PropertyId::Shorthand(ShorthandId::BorderBottom)],
                                [Border_right, SetBorder_right,
                                 PropertyId::Shorthand(ShorthandId::BorderRight)],
                            [BorderRight, SetBorderRight,
                             PropertyId::Shorthand(ShorthandId::BorderRight)],
                                [Border_block_start, SetBorder_block_start,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                            [BorderBlockStart, SetBorderBlockStart,
                             PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                                [Border_block_end, SetBorder_block_end,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                            [BorderBlockEnd, SetBorderBlockEnd,
                             PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                                [Border_inline_start, SetBorder_inline_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [BorderInlineStart, SetBorderInlineStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [_moz_border_start, Set_moz_border_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [MozBorderStart, SetMozBorderStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [Border_inline_end, SetBorder_inline_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [BorderInlineEnd, SetBorderInlineEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                                [_moz_border_end, Set_moz_border_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [MozBorderEnd, SetMozBorderEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [Border, SetBorder,
                             PropertyId::Shorthand(ShorthandId::Border)],
                                [Border_radius, SetBorder_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [BorderRadius, SetBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [_webkit_border_radius, Set_webkit_border_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [WebkitBorderRadius, SetWebkitBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [Border_image, SetBorder_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [BorderImage, SetBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_moz_border_image, Set_moz_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [MozBorderImage, SetMozBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_webkit_border_image, Set_webkit_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [WebkitBorderImage, SetWebkitBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [Overflow, SetOverflow,
                             PropertyId::Shorthand(ShorthandId::Overflow)],
                            [Transition, SetTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_moz_transition, Set_moz_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [MozTransition, SetMozTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_webkit_transition, Set_webkit_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [WebkitTransition, SetWebkitTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                            [Animation, SetAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_moz_animation, Set_moz_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [MozAnimation, SetMozAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_webkit_animation, Set_webkit_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [WebkitAnimation, SetWebkitAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [Scroll_snap_type, SetScroll_snap_type,
                                 PropertyId::Shorthand(ShorthandId::ScrollSnapType)],
                            [ScrollSnapType, SetScrollSnapType,
                             PropertyId::Shorthand(ShorthandId::ScrollSnapType)],
                                [Overscroll_behavior, SetOverscroll_behavior,
                                 PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                            [OverscrollBehavior, SetOverscrollBehavior,
                             PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                                [_moz_transform, Set_moz_transform,
                                 PropertyId::Shorthand(ShorthandId::MozTransform)],
                            [MozTransform, SetMozTransform,
                             PropertyId::Shorthand(ShorthandId::MozTransform)],
                            [Columns, SetColumns,
                             PropertyId::Shorthand(ShorthandId::Columns)],
                                [_moz_columns, Set_moz_columns,
                                 PropertyId::Shorthand(ShorthandId::Columns)],
                            [MozColumns, SetMozColumns,
                             PropertyId::Shorthand(ShorthandId::Columns)],
                                [Column_rule, SetColumn_rule,
                                 PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [ColumnRule, SetColumnRule,
                             PropertyId::Shorthand(ShorthandId::ColumnRule)],
                                [_moz_column_rule, Set_moz_column_rule,
                                 PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [MozColumnRule, SetMozColumnRule,
                             PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [Font, SetFont,
                             PropertyId::Shorthand(ShorthandId::Font)],
                                [Font_variant, SetFont_variant,
                                 PropertyId::Shorthand(ShorthandId::FontVariant)],
                            [FontVariant, SetFontVariant,
                             PropertyId::Shorthand(ShorthandId::FontVariant)],
                                [Text_emphasis, SetText_emphasis,
                                 PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                            [TextEmphasis, SetTextEmphasis,
                             PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                                [_webkit_text_stroke, Set_webkit_text_stroke,
                                 PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                            [WebkitTextStroke, SetWebkitTextStroke,
                             PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                                [List_style, SetList_style,
                                 PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [ListStyle, SetListStyle,
                             PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [Margin, SetMargin,
                             PropertyId::Shorthand(ShorthandId::Margin)],
                            [Mask, SetMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [_webkit_mask, Set_webkit_mask,
                                 PropertyId::Shorthand(ShorthandId::Mask)],
                            [WebkitMask, SetWebkitMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [Mask_position, SetMask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [MaskPosition, SetMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                                [_webkit_mask_position, Set_webkit_mask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [WebkitMaskPosition, SetWebkitMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [Outline, SetOutline,
                             PropertyId::Shorthand(ShorthandId::Outline)],
                                [_moz_outline_radius, Set_moz_outline_radius,
                                 PropertyId::Shorthand(ShorthandId::MozOutlineRadius)],
                            [MozOutlineRadius, SetMozOutlineRadius,
                             PropertyId::Shorthand(ShorthandId::MozOutlineRadius)],
                            [Padding, SetPadding,
                             PropertyId::Shorthand(ShorthandId::Padding)],
                                [Flex_flow, SetFlex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [FlexFlow, SetFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                                [_webkit_flex_flow, Set_webkit_flex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [WebkitFlexFlow, SetWebkitFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [Flex, SetFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                                [_webkit_flex, Set_webkit_flex,
                                 PropertyId::Shorthand(ShorthandId::Flex)],
                            [WebkitFlex, SetWebkitFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                                [Grid_gap, SetGrid_gap,
                                 PropertyId::Shorthand(ShorthandId::GridGap)],
                            [GridGap, SetGridGap,
                             PropertyId::Shorthand(ShorthandId::GridGap)],
                                [Grid_row, SetGrid_row,
                                 PropertyId::Shorthand(ShorthandId::GridRow)],
                            [GridRow, SetGridRow,
                             PropertyId::Shorthand(ShorthandId::GridRow)],
                                [Grid_column, SetGrid_column,
                                 PropertyId::Shorthand(ShorthandId::GridColumn)],
                            [GridColumn, SetGridColumn,
                             PropertyId::Shorthand(ShorthandId::GridColumn)],
                                [Grid_area, SetGrid_area,
                                 PropertyId::Shorthand(ShorthandId::GridArea)],
                            [GridArea, SetGridArea,
                             PropertyId::Shorthand(ShorthandId::GridArea)],
                                [Grid_template, SetGrid_template,
                                 PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [GridTemplate, SetGridTemplate,
                             PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [Grid, SetGrid,
                             PropertyId::Shorthand(ShorthandId::Grid)],
                                [Place_content, SetPlace_content,
                                 PropertyId::Shorthand(ShorthandId::PlaceContent)],
                            [PlaceContent, SetPlaceContent,
                             PropertyId::Shorthand(ShorthandId::PlaceContent)],
                                [Place_self, SetPlace_self,
                                 PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                            [PlaceSelf, SetPlaceSelf,
                             PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                                [Place_items, SetPlace_items,
                                 PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [PlaceItems, SetPlaceItems,
                             PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [Marker, SetMarker,
                             PropertyId::Shorthand(ShorthandId::Marker)],
                                [Text_decoration, SetText_decoration,
                                 PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [TextDecoration, SetTextDecoration,
                             PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [All, SetAll,
                             PropertyId::Shorthand(ShorthandId::All)],
        }
    }
}

#[macro_export]
macro_rules! longhand_properties_idents {
    ($macro_name: ident) => {
        $macro_name! {
                { background_color, false }
                { background_image, false }
                { background_position_x, false }
                { background_position_y, false }
                { background_repeat, false }
                { background_attachment, false }
                { background_clip, false }
                { background_origin, false }
                { background_size, false }
                { background_blend_mode, false }
                { border_top_color, false }
                { border_top_style, false }
                { border_top_width, false }
                { border_left_color, false }
                { border_left_style, false }
                { border_left_width, false }
                { border_bottom_color, false }
                { border_bottom_style, false }
                { border_bottom_width, false }
                { border_right_color, false }
                { border_right_style, false }
                { border_right_width, false }
                { border_block_start_color, false }
                { border_block_start_style, false }
                { border_block_start_width, false }
                { border_block_end_color, false }
                { border_block_end_style, false }
                { border_block_end_width, false }
                { border_inline_start_color, false }
                { border_inline_start_style, false }
                { border_inline_start_width, false }
                { border_inline_end_color, false }
                { border_inline_end_style, false }
                { border_inline_end_width, false }
                { border_top_left_radius, true }
                { border_top_right_radius, true }
                { border_bottom_right_radius, true }
                { border_bottom_left_radius, true }
                { _moz_border_top_colors, false }
                { _moz_border_left_colors, false }
                { _moz_border_bottom_colors, false }
                { _moz_border_right_colors, false }
                { box_decoration_break, false }
                { _moz_float_edge, false }
                { border_image_source, true }
                { border_image_outset, true }
                { border_image_repeat, false }
                { border_image_width, true }
                { border_image_slice, true }
                { display, false }
                { _moz_top_layer, false }
                { position, false }
                { float, false }
                { clear, false }
                { vertical_align, false }
                { overflow_clip_box_inline, false }
                { overflow_clip_box_block, false }
                { overflow_x, false }
                { overflow_y, false }
                { transition_duration, false }
                { transition_timing_function, false }
                { transition_property, false }
                { transition_delay, false }
                { animation_name, false }
                { animation_duration, false }
                { animation_timing_function, false }
                { animation_iteration_count, false }
                { animation_direction, false }
                { animation_play_state, false }
                { animation_fill_mode, false }
                { animation_delay, false }
                { scroll_snap_points_x, false }
                { scroll_snap_points_y, false }
                { scroll_snap_destination, true }
                { scroll_snap_coordinate, false }
                { transform, false }
                { scroll_behavior, false }
                { scroll_snap_type_x, false }
                { scroll_snap_type_y, false }
                { overscroll_behavior_x, false }
                { overscroll_behavior_y, false }
                { isolation, false }
                { page_break_after, false }
                { page_break_before, false }
                { page_break_inside, false }
                { resize, false }
                { perspective, false }
                { perspective_origin, true }
                { backface_visibility, false }
                { transform_box, false }
                { transform_style, false }
                { transform_origin, true }
                { contain, false }
                { _moz_appearance, false }
                { _moz_binding, true }
                { _moz_orient, false }
                { will_change, false }
                { shape_image_threshold, false }
                { shape_outside, true }
                { touch_action, false }
                { color, false }
                { column_width, false }
                { column_count, false }
                { column_gap, false }
                { column_fill, false }
                { column_rule_width, false }
                { column_rule_color, false }
                { column_span, false }
                { column_rule_style, false }
                { content, true }
                { counter_increment, false }
                { counter_reset, false }
                { opacity, false }
                { box_shadow, false }
                { clip, true }
                { filter, false }
                { mix_blend_mode, false }
                { font_family, false }
                { font_style, false }
                { font_variant_caps, false }
                { font_weight, false }
                { font_size, false }
                { font_size_adjust, false }
                { font_synthesis, false }
                { font_stretch, false }
                { font_kerning, false }
                { font_variant_alternates, false }
                { font_variant_east_asian, false }
                { font_variant_ligatures, false }
                { font_variant_numeric, false }
                { font_variant_position, false }
                { font_feature_settings, true }
                { font_variation_settings, false }
                { font_language_override, false }
                { _x_lang, false }
                { _moz_script_size_multiplier, false }
                { _moz_script_level, false }
                { _moz_math_display, false }
                { _moz_math_variant, false }
                { _moz_script_min_size, false }
                { _x_text_zoom, false }
                { _moz_osx_font_smoothing, false }
                { _moz_font_smoothing_background_color, false }
                { _moz_min_font_size_ratio, false }
                { visibility, false }
                { writing_mode, false }
                { direction, false }
                { text_orientation, false }
                { color_adjust, false }
                { image_rendering, false }
                { image_orientation, false }
                { border_collapse, false }
                { empty_cells, false }
                { caption_side, false }
                { border_spacing, true }
                { line_height, false }
                { text_transform, false }
                { hyphens, false }
                { _moz_text_size_adjust, false }
                { text_indent, false }
                { overflow_wrap, false }
                { word_break, false }
                { text_justify, false }
                { text_align_last, false }
                { text_align, false }
                { letter_spacing, false }
                { word_spacing, false }
                { white_space, false }
                { text_shadow, false }
                { text_emphasis_style, true }
                { text_emphasis_position, false }
                { text_emphasis_color, false }
                { _moz_tab_size, false }
                { _webkit_text_fill_color, false }
                { _webkit_text_stroke_color, false }
                { _webkit_text_stroke_width, false }
                { ruby_align, false }
                { ruby_position, false }
                { text_combine_upright, false }
                { text_rendering, false }
                { _moz_control_character_visibility, false }
                { list_style_position, false }
                { list_style_type, true }
                { list_style_image, true }
                { quotes, false }
                { _moz_image_region, true }
                { margin_top, false }
                { margin_left, false }
                { margin_bottom, false }
                { margin_right, false }
                { margin_block_start, false }
                { margin_block_end, false }
                { margin_inline_start, false }
                { margin_inline_end, false }
                { outline_color, false }
                { outline_style, false }
                { outline_width, false }
                { _moz_outline_radius_topleft, true }
                { _moz_outline_radius_topright, true }
                { _moz_outline_radius_bottomright, true }
                { _moz_outline_radius_bottomleft, true }
                { outline_offset, false }
                { padding_top, false }
                { padding_left, false }
                { padding_bottom, false }
                { padding_right, false }
                { padding_block_start, false }
                { padding_block_end, false }
                { padding_inline_start, false }
                { padding_inline_end, false }
                { cursor, false }
                { pointer_events, false }
                { _moz_user_input, false }
                { _moz_user_modify, false }
                { _moz_user_focus, false }
                { caret_color, false }
                { top, false }
                { left, false }
                { bottom, false }
                { right, false }
                { offset_block_start, false }
                { offset_block_end, false }
                { offset_inline_start, false }
                { offset_inline_end, false }
                { z_index, false }
                { flex_direction, false }
                { flex_wrap, false }
                { justify_content, false }
                { align_content, false }
                { align_items, false }
                { justify_items, false }
                { flex_grow, false }
                { flex_shrink, false }
                { align_self, false }
                { justify_self, false }
                { order, false }
                { flex_basis, false }
                { width, false }
                { min_width, false }
                { max_width, false }
                { height, false }
                { min_height, false }
                { max_height, false }
                { block_size, false }
                { min_block_size, false }
                { max_block_size, false }
                { inline_size, false }
                { min_inline_size, false }
                { max_inline_size, false }
                { box_sizing, false }
                { object_fit, false }
                { object_position, true }
                { grid_row_gap, false }
                { grid_row_start, true }
                { grid_row_end, true }
                { grid_auto_rows, true }
                { grid_template_rows, true }
                { grid_column_gap, false }
                { grid_column_start, true }
                { grid_column_end, true }
                { grid_auto_columns, true }
                { grid_template_columns, true }
                { grid_auto_flow, false }
                { grid_template_areas, true }
                { table_layout, false }
                { _x_span, false }
                { text_overflow, true }
                { unicode_bidi, false }
                { text_decoration_line, false }
                { text_decoration_style, false }
                { text_decoration_color, false }
                { initial_letter, false }
                { ime_mode, false }
                { _moz_user_select, false }
                { _moz_window_dragging, false }
                { _moz_window_shadow, false }
                { _moz_window_opacity, false }
                { _moz_window_transform, false }
                { _moz_window_transform_origin, true }
                { _moz_force_broken_image_icon, false }
                { text_anchor, false }
                { color_interpolation, false }
                { color_interpolation_filters, false }
                { fill, true }
                { fill_opacity, false }
                { fill_rule, false }
                { shape_rendering, false }
                { stroke, true }
                { stroke_width, false }
                { stroke_linecap, false }
                { stroke_linejoin, false }
                { stroke_miterlimit, false }
                { stroke_opacity, false }
                { stroke_dasharray, false }
                { stroke_dashoffset, false }
                { clip_rule, false }
                { marker_start, true }
                { marker_mid, true }
                { marker_end, true }
                { paint_order, false }
                { _moz_context_properties, false }
                { dominant_baseline, false }
                { vector_effect, false }
                { stop_color, false }
                { stop_opacity, false }
                { flood_color, false }
                { flood_opacity, false }
                { lighting_color, false }
                { mask_type, false }
                { clip_path, true }
                { mask_mode, false }
                { mask_repeat, false }
                { mask_position_x, false }
                { mask_position_y, false }
                { mask_clip, false }
                { mask_origin, false }
                { mask_size, false }
                { mask_composite, false }
                { mask_image, false }
                { _moz_box_align, false }
                { _moz_box_direction, false }
                { _moz_box_flex, false }
                { _moz_box_orient, false }
                { _moz_box_pack, false }
                { _moz_stack_sizing, false }
                { _moz_box_ordinal_group, false }
        }
    }
}
